/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=568256;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function SM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=0,U=E(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=E(0),Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=E(0),Va=0;ea=fb-32|0;fb=ea;ha=ea+28|0;x[ha>>2]=48900;x[ha>>2]=48800;e=CB(ea+20|0);f=CB(ea+12|0);ia=b;na=c;oa=x[e>>2];Da=y[e+4|0];pa=x[f>>2];Ea=y[f+4|0];b=0;J=fb-96|0;fb=J;d=a;qa=a+24604|0;a=qa;a:{if(!x[a+16>>2]){break a}c=x[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=J+80|0;rS(a,9133,13070,220,45);b=fb-48|0;fb=b;c=tc(b+24|0,18366);x[31725]=0;f=b+12|0;O(888,f|0,17442);e=x[31725];x[31725]=0;b:{c:{d:{e:{if((e|0)!=1){x[31725]=0;e=b+36|0;S(2,e|0,c|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;S(889,a|0,1,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;tb(e);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0}ra=d+8204|0;sa=d+397452|0;ta=d+397448|0;aa=d+393352|0;I=d+397456|0;X=d+12|0;Fa=d+1074376|0;while(1){f:{g:{b=x[d+480208>>2];if(!(!ia|b&512)){h:{if(x[d+1074380>>2]){break h}a=b|512;i:{if(b&256){break i}k=fb-48|0;fb=k;t=fb-32|0;fb=t;i=d+1074312|0;n=d+1074992|0;m=d+1298264|0;h=d+1074424|0;G=d+484360|0;o=d+1074448|0;q=d+1074376|0;b=x[d+1074392>>2];R=d+480210|0;j:{k:while(1){l:{a=b+1|0;x[d+1074392>>2]=a;if(Pl(q)>>>0>a>>>0){break l}NT(t+30|0,x[d+480180>>2],z[d+480188>>1],q,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{L=x[d+480208>>2];if(L&32){C=x[d+484348>>2];s=x[d+484344>>2];c=z[d+1074446>>1];break p}c=65535;r=Xb(x[d+484360>>2],y[d+484376|0]);l=x[r>>2];u=x[r+4>>2];e=Zc(l,u);b=z[d+1074448>>1];if(e>>>0>b>>>0){c=z[_b(l,b)>>1]}w[d+1074446>>1]=c;q:{r:{a=c&65535;s=x[d+484344>>2];C=x[d+484348>>2];M=ek(s,C);if(a>>>0>=M>>>0){break r}a=Wb(s,a);if(Ib(x[a>>2],x[a+4>>2])){break r}a=0;break q}a=1}while(1){if(!a){c=65534;w[d+1074446>>1]=65534;a=1;continue}j=z[r+28>>1];while(1){g=d;s:{t:{u:{a=c&65535;if(a>>>0>=M>>>0){c=b&65535;if(!((a|0)!=65535&e>>>0>c>>>0)){if(j){b=j;a=Zc(l,u);break t}if(!(b&65535)|c>>>0>e>>>0){break u}while(1){f=c;b=b-1|0;a=b&65535;if(!a){break u}c=c-1|0;if(z[_b(l,a)>>1]!=65535){continue}break}b=f;a=e;break t}b=b+1|0;w[o>>1]=b;c=b&65535;break s}w[d+1074450>>1]=b;break p}b=0;a=e}w[g+1074448>>1]=b;L=L&-524289;x[d+480208>>2]=L;while(1){c=b&65535;if(c>>>0>=a>>>0){break o}if(z[_b(l,c)>>1]==65534){b=b+1|0;w[o>>1]=b;continue}break}if(!bj(r,b&65535)){break o}}if(c>>>0>=e>>>0){c=65535;w[d+1074446>>1]=65535;continue}c=z[_b(l,c)>>1];w[d+1074446>>1]=c;if(c>>>0>=M>>>0){continue}a=Wb(s,c);if(Ib(x[a>>2],x[a+4>>2])){continue}break}a=0;continue}}a=c&65535;if(!He(s,C,a)){break n}b=x[h>>2];if(b>>>0>=A[Wb(s,a)+12>>2]){x[h>>2]=0;b=0}if(L&32?x[d+480272>>2]!=-1:0){break m}if(!Wu(m,z[o>>1],b,Nq(t+20|0,n),y[t+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Ro(m,1);Wu(m,z[o>>1],x[h>>2],Nq(t+20|0,n),y[t+30|0]);break m}if(!(y[R|0]&64)){break o}if(!Vu(m,o,h)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;b=Oj(x[d+484360>>2],x[d+484364>>2])-1|0;a=y[d+484376|0];if((b|0)<=(a|0)){ck(G,0);break o}ck(G,a+1&255);Ro(m,1)}b=0;while(1)if((b|0)==256){iS(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Xb(x[d+484360>>2],y[d+484376|0]);e=x[c>>2];if(Zc(e,x[c+4>>2])>>>0>a>>>0){Sa=d,Ta=z[_b(e,a)>>1],w[Sa+1074446>>1]=Ta}Wu(m,a,b,Nq(t+20|0,n),y[t+30|0]);if(!He(x[d+484344>>2],x[d+484348>>2],z[d+1074446>>1])){break n}break m}else{Vo((D(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}}Ro(m,1)}a=0;break j}MT(d,q,(x[d+480208>>2]&32)>>>5|0);a=Wb(x[d+484344>>2],z[d+1074446>>1]);c=jd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=n+D(z[d+480188>>1],872)|0;b=n;while(1){if((b|0)==(e|0)){v:{w:{a=x[d+484344>>2];b=z[d+1074446>>1];if(xp(a,x[d+484348>>2],b)){a=Wb(a,b);c=x[a+16>>2];b=x[a+20>>2];if(JT(c,b)){break w}}x[d+1074408>>2]=x[d+480216>>2];b=x[d+480220>>2];break v}x[d+1074408>>2]=c}x[d+1074412>>2]=b;if(!y[t+30|0]){break l}b=x[d+1074416>>2];x[d+1074392>>2]=b;continue k}Kb(t+20|0,i,82);x:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])|y[b+805|0]!=1){break x}a=y[c+3|0];if((a|0)!=2&(a|0)!=3){break x}Sa=b,Ta=xh(d,y[b+800|0],w[b+772>>1],x[b+704>>2]),x[Sa+700>>2]=Ta}Kb(t+20|0,i,91);y:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break y}if(Tc(y[c|0])){break y}a=y[b+788|0];if(!Tc(a)|y[b+791|0]!=19){break y}f=y[b+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break y}Sa=b,Ta=xh(d,a,w[b+772>>1],0),x[Sa+700>>2]=Ta}Kb(t+20|0,i,118);z:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break z}if(Tc(y[c|0])|!(y[b+89|0]&2)){break z}a=x[b+708>>2];if(!a){break z}if(!Tc(y[b+788|0])){break z}if(!Ql(y[b+790|0],y[b+791|0])){break z}x[b+700>>2]=a}a=t+20|0;Kb(a,i,92);A:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break A}Kb(t+12|0,i,5);if(Hb(x[x[t+12>>2]>>2],x[t+16>>2])|x[d+1074416>>2]!=1|y[b+791|0]!=17){break A}v[t+20|0]=1;Sa=d,Ta=D(y[ef(a,b+793|0)|0],1e4),x[Sa+1074420>>2]=Ta}a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b+788|0]=a;v[b+789|0]=a>>>8;v[b+790|0]=a>>>16;v[b+791|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[b+792|0]=a;v[b+793|0]=a>>>8;a=x[b+676>>2];x[b+20>>2]=x[b+672>>2];x[b+24>>2]=a;x[b+88>>2]=x[b+88>>2]&-393217;Kb(t+20|0,i,21);if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){v[b+831|0]=0}x[b+860>>2]=0;v[b+805|0]=0;c=c+6|0;b=b+872|0;continue}}break}a=x[d+1074416>>2];if(!a){x[d+1074416>>2]=1;a=1}b=x[d+480208>>2];e=x[d+1074392>>2];B:{C:{if(e){c=b&-4097;x[d+480208>>2]=c;f=x[d+480180>>2];if(f&1048580|!(b&2097152)&(f|0)==1){break B}if(Pl(q)>>>0<=e>>>0){break B}if(!((e>>>0)%(x[d+1074400>>2]+a>>>0)|0)){break C}break B}c=b&-528385}x[d+480208>>2]=c|4096}o=0;h=fb-16|0;fb=h;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;W=d+1075809|0;r=d+1074312|0;H=d+906300|0;M=d+1074376|0;V=d+480209|0;Y=d+480210|0;while(1){if(z[d+480188>>1]<=o>>>0){D:{if(!(y[d+480209|0]&16)){break D}if(!BT(d,M,Xb(x[d+484360>>2],y[d+484376|0]),1)){break D}x[d+480208>>2]=x[d+480208>>2]|524288}fb=h+16|0}else{q=D(o,872)+d|0;g=q+1075785|0;a=y[g|0];i=q+1075784|0;m=y[i|0];T=q+1075781|0;c=y[T|0];b=x[d+1074400>>2];e=x[d+1074392>>2];f=x[d+1074416>>2];P=q+1075782|0;j=y[P|0];l=q+1075783|0;L=y[l|0];n=Ql(j,L);K=q+1075843|0;v[K|0]=x[d+480208>>2]>>>12&1|y[K|0]&254;f=(e>>>0)%(b+f>>>0)|0;R=q+1075780|0;b=y[R|0];E:{F:{G:{if((b|0)==252){s=Kj(j,m);G=Kj(L,a);b=252;e=c-1|0;if((e&255)>>>0>249){break G}if(!x[vd(H,e)>>2]){break G}b=x[vd(H,e)>>2];ib[x[x[b>>2]+44>>2]](b,s,E(E(G>>>0)/E(999)));b=y[R|0]}if((b&255)==251){break F}}if(B[q+1075852>>2]==E(0)|L){break E}}s=x[d+480208>>2]&4096;H:{if(!s){e=y[q+1075862|0];break H}e=y[T|0];v[q+1075862|0]=e}e=e-1|0;if((e&255)>>>0>249){break E}if(!x[vd(H,e)>>2]){break E}I:{if(!s){b=z[q+1075860>>1];break I}b=rB(y[P|0],y[i|0]);w[q+1075860>>1]=b;U=E(E(rB(y[l|0],y[g|0])>>>0)/E(999));B[q+1075856>>2]=U;g=x[vd(H,e)>>2];Sa=q+1075852|0,Ua=E(E(U-E(ib[x[x[g>>2]+48>>2]](g,b)))/E(Pl(M)>>>0)),B[Sa>>2]=Ua}g=x[d+1074392>>2];i=Pl(M);e=x[vd(H,e)>>2];l=b;b=(i|0)==(g+1|0);ib[x[x[e>>2]+(b?44:108)>>2]](e,l,B[(b?q+1075856|0:q+1075852|0)>>2]);b=y[R|0]}g=q+1074992|0;if(rT(b&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=bh(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[g+788|0]=c;v[g+789|0]=c>>>8;v[g+790|0]=c>>>16;v[g+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[g+792|0]=a;v[g+793|0]=a>>>8;fb=b+16|0;L=0;m=0;j=0;c=0;n=0;a=0}J:{if(!(y[V|0]&16)){US(d,g);break J}if(!c){break J}x[q+1075752>>2]=0}K:{L:{if((L|0)==33){Kb(h+8|0,r,30);b=a>>>4|0;cB(d,o&65535,b+(a&15)|0,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));break L}b=0;if((L-19&255)>>>0>1){break L}M:{if(!(!(x[d+480180>>2]&16777250)|a)){a=y[q+1075825|0];break M}v[q+1075825|0]=a}e=a&240;if((e|0)==208){e=a&15;if(!e){e=x[d+480180>>2];if(e&16777248){b=1;break L}if((e|0)!=2){break L}break K}if(e>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Kb(h+8|0,r,14);b=e;if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break L}if(!c){break K}v[q+1075795|0]=c;break K}b=e;break L}if(!(x[d+480208>>2]&4096)|(e|0)!=224){break L}e=x[d+480180>>2];if(x[d+1074396>>2]?e&16777250:0){break L}i=a&15;if(!(e&2?i:1)){break L}x[d+1074396>>2]=i+1}u=a&15;i=x[d+480180>>2]==16&(L|0)==19&(a&240)==208;G=i?0:b;N:{if(!G|y[R|0]!=255|y[P|0]!=2){break N}Kb(h+8|0,r,74);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break N}v[P|0]=0}l=u|144;e=x[d+1074392>>2];Kb(h+8|0,r,72);O:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){s=0;if(G>>>0>=A[d+1074416>>2]){break O}}Kb(h+8|0,r,88);e=(e|0)==(G|0);s=e|(f|0)==(G|0);if(!(!G|!Hb(x[x[h+8>>2]>>2],x[h+12>>2]))){break O}s=e}a=i?l:a;b=h+8|0;Kb(b,r,44);e=y[K|0];Sa=K,Ta=(Hb(x[x[h+8>>2]>>2],x[h+12>>2])?e&252|(f|0)==(G|0):e)&253,v[Sa|0]=Ta;Kb(b,r,66);e=(!G|Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1)&n;P:{Q:{R:{if(!(x[d+1074392>>2]|(!(y[Y|0]&32)|!c))){x[q+1075652>>2]=0;if(s){n=y[R|0];break R}if(!Ti(x[g+8>>2],x[g+12>>2])){break P}v[q+1075795|0]=c;if(z[d+480190>>1]<c>>>0){break P}b=D(c,104)+d|0;x[q+1075680>>2]=z[b+484410>>1];w[q+1075764>>1]=v[b+484417|0];break P}if(!s){break P}n=y[R|0];if(!c){break Q}}v[q+1075795|0]=c}S:{T:{b=n&255;if(!Tc(b)){break T}Kb(h+8|0,r,67);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break T}f=w[q+1075762>>1];U:{if(!c|e){break U}i=wr(d,b,c);if(!i){break U}f=v[ti(d,i)+36|0]}n=(b+f|0)-132>>>0>=4294967176?n:0;break S}if(!(x[d+480180>>2]&25165856)){break S}f=z[d+480192>>1];if(!f){break S}if(b){b=Tc(b)}else{b=1}if(!b){break S}b=c;V:{if(!b){b=y[q+1075796|0];if(!b){break V}}if(x[((b<<2)+d|0)+900380>>2]?b>>>0<=f>>>0:0){break S}n=0}c=0}if(!((L|0)!=25|a)){Kb(h+8|0,r,55);b=Hb(x[x[h+8>>2]>>2],x[h+12>>2]);c=b?0:c;n=b?0:n}b=h+8|0;Kb(b,r,65);l=Hb(x[x[h+8>>2]>>2],x[h+12>>2]);C=1;if(!(x[d+480180>>2]&16777248)){Kb(b,r,107);C=Hb(x[x[h+8>>2]>>2],x[h+12>>2])}f=(c|0)!=0;b=n&255;Z=!b;Kb(h+8|0,r,85);W:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break W}if(Ti(x[g+8>>2],x[g+12>>2])){break W}i=x[q+1075096>>2];if(i){if(je(x[i>>2],x[i+20>>2])){break W}}C=1}i=f&Z;l=f&l;X:{Y:{Z:{_:{$:{aa:{if(!(x[d+480180>>2]&1048580)){break aa}ba:{if((b|0)!=255){break ba}if(!(!((j|0)==1|c)&(L|0)!=13)){Kb(h+8|0,r,55);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ba}}f=x[q+1075648>>2];if(v[f+60|0]&1?f:0){break ba}x[q+1075680>>2]=0;b=q+1075080|0;x[b>>2]=x[b>>2]|2097152;ca:{if(!(x[d+480208>>2]&4096)){break ca}Kb(h+8|0,r,86);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ca}x[b>>2]=x[b>>2]|4096}c=0;n=0;b=0;f=0;i=1;if(l){break Y}break X}Kb(h+8|0,r,59);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|x[d+480208>>2]&4096){break aa}da:{if(!b){n=y[q+1075789|0]-y[q+1075762|0]|0;break da}if(b>>>0>250){C=0;l=1;n=0;break da}ea:{if(c){break ea}Kb(h+8|0,r,98);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ea}c=0;break da}C=1;l=1}f=n;e=0;break $}f=0;if(!i){break _}}Kb(h+8|0,r,65);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Z}n=f;f=1}b=n;i=1;if(l){break Y}break X}n=f;f=1;i=l}fa:{ga:{if(!z[d+480192>>1]){if(z[d+480190>>1]<c>>>0){break fa}b=(D(c,104)+d|0)+484380|0;break ga}b=x[q+1075096>>2];if(!b){break fa}}ha:{if(w[b+34>>1]<0){break ha}if(x[d+480180>>2]==2){if(!je(x[b>>2],x[b+20>>2])){break ha}}x[q+1075680>>2]=z[b+30>>1];l=q+1075080|0;x[l>>2]=x[l>>2]|2097152}if(!i){break fa}Xq(g,z[b+28>>1],d)}b=n}Kb(h+8|0,r,71);if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c)){v[q+1075831|0]=32}ia:{if(!z[d+480192>>1]){break ia}Kb(h+8|0,r,100);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c){break ia}if(Tc(b&255)){break ia}n=x[d+480208>>2];ja:{if(e){if(n&8){break ja}break ia}if(!(n&4)){break ia}}dn(g);x[q+1075688>>2]=65536;n=q+1075080|0;x[n>>2]=x[n>>2]|2097152}if(f){Kb(h+8|0,r,11);ka:{la:{ma:{if(!(Hb(x[x[h+8>>2]>>2],x[h+12>>2])|x[d+480180>>2]==268435456)){n=z[d+480192>>1];break ma}Kb(h+8|0,r,87);f=0;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){f=Ti(x[g+8>>2],x[g+12>>2])^1}n=z[d+480192>>1];na:{if(n){if(c>>>0>n>>>0){break la}if(x[q+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break na}break la}if((f^-1)&x[q+1075096>>2]==((D(c,104)+d|0)+484380|0)){break ka}}b=y[q+1075789|0]}if(!(n&65535)){break ka}}if(!(x[d+480180>>2]&1048588)){break ka}dn(g);v[q+1075810|0]=0;x[q+1075748>>2]=0;x[q+1075688>>2]=65536;f=q+1075080|0;x[f>>2]=x[f>>2]&-2101249|2097152;Kb(h+8|0,r,86);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ka}x[f>>2]=x[f>>2]&-2049}c=C?c:0}n=b&255;oa:{if(n>>>0<251){break oa}Kb(h+8|0,r,50);pa:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c){break pa}f=wr(d,y[q+1075791|0],c);if(!f){break pa}f=D(f,104)+d|0;if(w[f+484414>>1]<0){break pa}x[q+1075680>>2]=z[f+484410>>1]}Kb(h+8|0,r,100);if(Sa=Hb(x[x[h+8>>2]>>2],x[h+12>>2]),Ta=0,Va=x[d+480208>>2]&4,Va?Sa:Ta){break oa}c=0}i=Tc(n);if(i){v[q+1075794|0]=b;v[q+1075791|0]=b;if(!e){VS(d,o&65535,c,n,0)}vV(g)}qa:{ra:{sa:{ta:{ua:{if(c){f=q+1075096|0;l=x[f>>2];Qo(d,g,c,e,1,1);b=x[f>>2];va:{if(!b|!(y[b+35|0]&2)){break va}C=x[d+1298300>>2];if(!Dd(C)){break va}RB(C,o&65535,b+68|0)}wa:{xa:{if(x[d+480180>>2]==1){if(!e){break xa}Kb(h+8|0,r,85);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break xa}break wa}Kb(h+8|0,r,50);if((i|Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1)!=1){break wa}}v[q+1075795|0]=0}Kb(h+8|0,r,42);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!i|(l|0)==x[f>>2]){break ta}break ua}if(x[d+480180>>2]&16777248){b=0;if(i&(l|0)!=x[f>>2]){break sa}}Kb(h+8|0,r,107);ya:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|(!(i^1|e)|(l|0)==x[f>>2])){break ya}b=q+1075068|0;if(A[b>>2]>=A[g+4>>2]){break ya}x[b>>2]=0;break ta}Kb(h+8|0,r,85);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ta}if(!Ti(x[g+8>>2],x[g+12>>2])){break ua}break ta}if(!n){b=e;break qa}f=0;l=q+1075795|0;b=y[l|0];if(!(!b|i^1)){Qo(d,g,b,e,!(x[q+1075096>>2]?1:x[q+1075648>>2]),!(x[d+480180>>2]&1048580));v[l|0]=0;f=1}b=e;break ra}x[g>>2]=0;x[g+4>>2]=0}b=e}f=0;if(!n){break qa}}e=x[q+1075096>>2];za:{if(!e|!(y[e+35|0]&2)){break za}i=x[d+1298300>>2];if(!Dd(i)){break za}if(!f){if(WS(i,o&65535)){break za}}RB(i,o&65535,e+68|0)}e=o&65535;Ru(d,g,n,b,!(x[d+480180>>2]&1048580),0,e);GT(x[d+480180>>2],z[d+480188>>1],M,e);if(!(!(x[d+480180>>2]&1048580)|(!b|!c))){c=q+1075080|0;x[c>>2]=x[c>>2]|2097152;dn(g);v[q+1075810|0]=0;x[q+1075748>>2]=0}if(!(x[q+1075080>>2]&512)){break qa}if(!Dd(x[d+1298300>>2])){break qa}if(n>>>0<=253){if((n|0)!=253){break qa}Kb(h+8|0,r,99);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break qa}}Kb(h+8|0,r,110);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){SB(x[d+1298300>>2],e,0,1,0)}Fk(x[d+1298300>>2],e)}Aa:{Ba:{switch(j-1|0){case 0:m=m>>>0>=64?64:m;x[q+1075680>>2]=m<<2;c=q+1075080|0;x[c>>2]=x[c>>2]|2097152;break Aa;case 1:break Ba;default:break Aa}}en(d,g,m,6)}if(z[d+480192>>1]){TS(d,o&65535)}e=b}c=h+8|0;Kb(c,r,77);if(Sa=Hb(x[x[h+8>>2]>>2],x[h+12>>2]),Ta=0,Va=x[((o<<5)+d|0)+480280>>2]&1024,Va?Sa:Ta){break K}b=x[d+1074392>>2];Kb(c,r,75);f=b>>>0>=G>>>0;Ca:{Da:{Ea:{Fa:{if(!G|!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Fa}c=x[d+1074392>>2];if(!c){break Ea}f=1;if((c|0)!=(G|0)){break Fa}f=!y[T|0]&(j|0)!=11}b=j;if(!f|b>>>0<3){break Ea}if((b|0)==11){b=h+8|0;vB(b,d,y[R+3|0],y[R+4|0],G);b=y[af(b)|0];bB(d,o&65535,z[h+8>>1]);if(b){break Da}j=11;break Ea}Kb(h+8|0,r,62);Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|m)){m=0;j=0;Na:{switch(b-8|0){case 0:break Ma;case 1:break Na;default:break Ea}}if(y[V|0]&16){break Ea}x[q+1075684>>2]=0;break Ea}Kb(h+8|0,r,41);Oa:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Oa}if(m){v[q+1075826|0]=m;break Oa}m=y[q+1075826|0]}Pa:{switch(b-3|0){case 0:case 1:Qa:{Ra:{if(m){break Ra}Kb(h+8|0,r,41);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ra}m=y[q+1075826|0];if(m){break Qa}m=0;break Ea}v[q+1075826|0]=m}Oo(d,g,((b|0)==3?m<<4:m)&255);break Ea;case 2:if((G|0)!=x[d+1074392>>2]){Kb(h+8|0,r,41);j=5;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ea}}Kb(h+8|0,r,41);No(d,g,m,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));j=5;break Ea;case 3:if((G|0)!=x[d+1074392>>2]){Kb(h+8|0,r,41);j=6;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ea}}Kb(h+8|0,r,41);Mo(d,g,m,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));j=6;break Ea;case 11:break Ga;case 12:break Ha;case 10:break Ia;case 9:break Ja;case 7:break Ka;case 6:break La;case 5:break Ma;case 4:break Pa;default:break Ea}}Kb(h+8|0,r,53);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){v[q+1075815|0]=m&15;j=7;break Ea}Ol(g,m<<4);j=7;break Ea}Ol(g,m);j=8;break Ea}Kb(h+8|0,r,62);aB(d,g,m,Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1);j=9;break Ea}Kb(h+8|0,r,62);aB(d,g,m<<4&240,Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1);j=10;break Ea}j=12;Kb(h+8|0,r,12);SS(d,o&65535,m<<2&252,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));break Ea}Kb(h+8|0,r,12);RS(d,o&65535,m<<2&252,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));j=13;break Ea}j=15;if(!s){break Ea}b=x[q+1075096>>2];if(!b|m>>>0>9){break Ea}Sa:{if(!m){c=x[q+1075656>>2];break Sa}c=x[yb(b+68|0,m-1|0)>>2];x[q+1075656>>2]=c}Po(d,g,c);break Ea}j=14;if(m>>>0>1){break Ea}v[K|0]=y[K|0]&247|!m<<3}c=a;Ta:{Ua:{Va:{switch(L-1|0){case 12:if(!(y[d+480209|0]&16)){break Da}b=D(o,872)+d|0;x[b+1075680>>2]=a>>>0>=64?256:a<<2;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 45:if(!(y[d+480209|0]&16)){break Da}b=D(o,872)+d|0;x[b+1075680>>2]=a;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 1:if(!a){c=0;if(v[d+480180|0]&1){break Ca}}SS(d,o&65535,a,0);break Da;case 2:if(!a){c=0;if(v[d+480180|0]&1){break Ca}}RS(d,o&65535,a,0);break Da;case 10:if(!a){c=0;if(x[d+480180>>2]==1){break Ca}}Oo(d,g,a);break Da;case 3:bB(d,o&65535,a);break Da;case 5:if(!(!a&x[d+480180>>2]==1)){Oo(d,g,a)}bB(d,o&65535,0);break Da;case 4:Ol(g,a);break Da;case 6:if(!(!a&x[d+480180>>2]==1)){Oo(d,g,a)}Ol(g,0);break Da;case 15:if(!(y[d+480209|0]&16)){break Da}break Ta;case 16:Kb(h+8|0,r,5);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!(y[d+480209|0]&16)){break Da}if(a){break Ta}break Da}c=Lo(d,z[d+1074446>>1],x[d+1074424>>2],o&65535,0);Wa:{if(!(x[d+480180>>2]&16777250)){break Wa}if(c){v[(D(o,872)+d|0)+1075827|0]=c;break Wa}c=y[(D(o,872)+d|0)+1075827|0]}x[h+8>>2]=D(c,1e4);wc(h+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=x[h+8>>2];x[a+12>>2]=e;b=x[d+8>>2];Xa:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];f=a+4|0;Kb(f,d+1074312|0,92);if((Hb(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break Xa}x[a+4>>2]=D(x[b+24>>2],1e4);Sa=d+1074420|0,Ta=x[Gb(a+12|0,f)>>2],x[Sa>>2]=Ta;break Xa}if(y[d+480209|0]&16){break Xa}f=d+1074420|0;e=(e>>>0)/1e4|0;n=D(e&15,1e4);x[f>>2]=x[f>>2]+((e&240)==16?n:0-n|0);e=x[b+20>>2];b=x[b+24>>2];Kb(a+4|0,d+1074312|0,8);Lp(f,D(e,1e4),Hb(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}fb=a+16|0;break Ca;case 9:if(!s|x[d+480180>>2]==4&e){break Da}FT(d,g,o&65535,x[d+1074424>>2],z[d+1074446>>1]);break Da;case 43:if(!s){break Da}c=nva(x[(D(o,872)+d|0)+1075068>>2],0,a,0);b=hb;j=b>>>8|0;Po(d,g,Bc((b&255)<<24|c>>>8,j));break Da;case 0:if(x[d+1074392>>2]){break Da}b=D(o,872)+d|0;Ya:{if(y[b+1075789|0]?x[b+1075692>>2]:0){break Ya}b=x[b+1075648>>2];if(b){if(Rj(y[b+31|0])){break Ya}}Kb(h+8|0,r,13);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ya}if(x[d+480180>>2]&16777248){break Da}}if(!a){c=0;if(y[d+480180|0]&5){break Ca}v[(D(o,872)+d|0)+1075797|0]=1;break Ca}b=D(o,872)+d|0;v[b+1075798|0]=a;v[b+1075797|0]=1;break Da;case 14:if(x[d+480180>>2]&1048580){a=a&240?a:y[(D(o,872)+d|0)+1075799|0]&240|a;if(!(a&15)){a=y[(D(o,872)+d|0)+1075799|0]&15|a}a=a|256}c=a;Kb(h+8|0,r,23);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){b=d;e=o&65535;if(a){v[(D(o,872)+d|0)+1075799|0]=a}else{a=y[(D(o,872)+d|0)+1075799|0]}$A(b,e,a&255,(j|0)==15?m+1|0:0);break Ca}Za:{if(c){v[(D(o,872)+d|0)+1075799|0]=c;break Za}c=y[(D(o,872)+d|0)+1075799|0]}$A(d,o&65535,c,(j|0)==15?m+1|0:0);break Ca;case 17:if(!(y[d+480209|0]&16)){break Da}Kb(h+8|0,r,22);_a:{$a:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!a){a=0;break $a}if(y[d+480208|0]&4){break $a}a=a&240?a-16|0:a;a=a-((a&15)!=0)|0;v[(D(o,872)+d|0)+1075832|0]=a;break $a}Kb(h+8|0,r,71);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break _a}}b=(D(o,872)+d|0)+1075831|0;v[b|0]=y[b|0]|128}b=D(o,872)+d|0;v[b+1075797|0]=18;if(!a){c=0;break Ca}v[b+1075832|0]=a;break Da;case 22:if(!(y[d+480209|0]&16)){break Da}b=a;a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ca}if(a&16777250){break Ca}x[d+1074456>>2]=256;break Ca;case 23:Kb(h+8|0,r,9);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){QS(d,a,(D(o,872)+d|0)+1075809|0);break Da}QS(d,a,W);break Da;case 8:if(!(y[d+480209|0]&16)){break Da}en(d,g,a,8);break Da;case 28:aB(d,g,a,1);break Da;case 7:xT(g,a);break Da;case 25:yT(d,g,a);break Da;case 18:f=fb-16|0;fb=f;j=d+1074376|0;c=o&65535;n=D(c,872);e=(j+n|0)+616|0;b=a&15;ab:{bb:{switch(a>>>4|0){case 0:c=(a&1)<<14;e=z[d+480188>>1];b=0;while(1){if((b|0)==(e|0)){break ab}n=(D(b,872)+d|0)+1075080|0;x[n>>2]=(c|x[n>>2]&-16385)^16384;b=b+1|0;continue};case 1:if(!b){b=0;if(!(x[d+480180>>2]&1048580)){break ab}}nB(d,e,b);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Fo(d,c,a|240,1);break ab;case 2:if(!b){b=0;if(!(x[d+480180>>2]&1048580)){break ab}}mB(d,e,b);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Fo(d,c,0-(a|240)|0,1);break ab;case 3:c=(d+n|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((b|0)!=0)<<20;break ab;case 4:v[(d+n|0)+1075814|0]=a&7;break ab;case 5:if(!(y[d+480209|0]&16)){break ab}j=x[d+480180>>2];if(j&69206025){c=D(c,872)+d|0;b=b<<28>>24;w[c+1075764>>1]=b;e=c+1075692|0;if(!x[e>>2]){break ab}if(!Tc(y[c+1075780|0])){break ab}Sa=e,Ta=xh(d,y[c+1075789|0],b,x[c+1075696>>2]),x[Sa>>2]=Ta;break ab}e=D(c,872)+d|0;n=Tc(y[e+1075780|0]);if((j|0)==16){if(!n){break ab}c=x[e+1075096>>2];if(!c){break ab}v[c+37|0]=b;w[e+1075764>>1]=b;c=e+1075692|0;if(!x[c>>2]){break ab}Sa=c,Ta=xh(d,y[e+1075789|0],b,x[e+1075696>>2]),x[Sa>>2]=Ta;break ab}if(!n){break ab}b=D(c,872)+d|0;c=(a<<4^-128)<<24>>24;w[b+1075764>>1]=c;e=b+1075692|0;if(!x[e>>2]){break ab}Sa=e,Ta=xh(d,y[b+1075789|0],c,x[b+1075696>>2]),x[Sa>>2]=Ta;break ab;case 6:if(!(y[d+480209|0]&16)){break ab}uB(d,j,c,b);break ab;case 7:v[(d+n|0)+1075817|0]=a&7;break ab;case 8:if(!(y[d+480209|0]&16)){break ab}en(d,e,b,4);break ab;case 9:$A(d,c,b,0);break ab;case 10:if(b){No(d,e,b,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}No(d,e,0,0);break ab;case 11:if(b){Mo(d,e,b,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}Mo(d,e,0,0);break ab;case 12:cB(d,c,b,0);break ab;case 15:break bb;default:break ab}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=b;if(!(y[d+480209|0]&16)){break ab}US(d,e);break ab}v[(D(c,872)+d|0)+1075836|0]=b}fb=f+16|0;break Da;case 19:PS(d,o&65535,a);break Da;case 24:Kb(h+8|0,r,55);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(x[d+1074392>>2]!=(a|0)){break Da}c=D(o,872)+d|0;b=x[c+1075648>>2];if(v[b+60|0]&1?b:0){break Ua}if(!(!(y[T|0]|y[P|0])|a)){b=c+1075080|0;x[b>>2]=x[b>>2]|4096;break Ua}b=D(o,872)+d|0;x[b+1075680>>2]=0;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Ua}if(y[d+480209|0]&16){break Ua}break Da;case 27:b=(a&240)-16>>>4|0;if(b>>>0>9){break Da}if(!(1<<b&880)){if(b){if((b|0)!=1){break Da}lB(d,g,u);Kb(h+8|0,r,117);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}Fo(d,o&65535,-224-u|0,1);break Da}oB(d,g,u);Kb(h+8|0,r,117);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}Fo(d,o&65535,u|224,1);break Da}Kb(h+8|0,r,58);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}PS(d,o&65535,a);break Da;case 34:case 35:f=(L|0)==36;if(!(f|x[d+480208>>2]&4096)){break Da}e=o&65535;c=M+D(e,872)|0;n=c+616|0;b=CT(d,z[d+1074446>>1],x[d+1074424>>2],e);cb:{if(!f){break cb}f=Pl(M)-x[M+16>>2]|0;if((f|0)<2){break cb}j=b;b=w[c+1390>>1];b=ed(((j-b|0)/(f|0)|0)+b|0)}w[c+1390>>1]=b;c=Jq(d,x[c+704>>2],x[n+656>>2]);if(c){ib[x[x[c>>2]+80>>2]](c,(b<<16>>16)+32768>>>2|0,e)}break Da;case 20:if(!(y[d+480209|0]&16)|a>>>0>64){break Da}b=D(o,872)+d|0;x[b+1075740>>2]=a;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 21:n=x[d+480180>>2];f=x[d+480208>>2];b=a;db:{if(a){v[g+816|0]=a;break db}b=y[g+816|0]}c=b&15;e=b&255;eb:{fb:{if(!((c|0)!=15|e>>>0<16)){if(!(f&4096)){break eb}b=e>>>4|0;break fb}f=f&4096;j=e&240;if(!(!c|(j|0)!=240)){if(!f){break eb}b=0-c|0;break fb}if(f){break eb}if(c){b=0-c|0;if(!j|!(n&25690144)){break fb}break eb}if((b&255)>>>0<16){break eb}b=e>>>4|0}Sa=g,Ta=Yb(b+x[g+748>>2]|0,0,64),x[Sa+748>>2]=Ta}break Da;case 26:wT(g,a);break Da;case 29:if(!(y[d+480209|0]&16)){break Da}b=D(o,872)+d|0;x[b+1075716>>2]=a;Kb(h+8|0,r,60);if(Sa=0,Ta=Hb(x[x[h+8>>2]>>2],x[h+12>>2]),Va=y[b+1075722|0]&4,Va?Sa:Ta){break Da}x[b+1075732>>2]=a;x[b+1075724>>2]=a;break Da;case 11:AT(d,M,o&65535);break Da;case 13:b=zT(d,M,o&65535,a);if((b|0)==-1){break Da}x[d+1074436>>2]=b;if(!(y[d+480208|0]&32)){break Da}w[d+1074444>>1]=z[d+1074448>>1];break Da;case 37:case 38:case 39:case 40:oT(d,g,a,(L|0)==38|(L|0)==40,(L&254)==40);break Da;case 41:ET(g,a);break Da;case 42:if(x[d+1074392>>2]|u>>>0>1|a>>>0>47){break Da}b=(a&240)==16;f=b?z[d+480188>>1]-1|0:o;c=b?0:o;b=((u|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Da}n=((e<<5)+d|0)+480280|0;x[n>>2]=b|x[n>>2]&-67108865;e=(D(e,872)+d|0)+1075080|0;x[e>>2]=b|x[e>>2]&-67108865;c=c+1|0;continue};case 44:break Va;default:break Ca}}DT(g,a);break Da}Ko(d,g);break Da}KT(d,M,a)}c=a}Kb(h+8|0,r,78);if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c)){tT(g,c&255)}a=y[T|0];if(!a){break K}v[q+1075796|0]=a}o=o+1|0;continue}break}a=1}fb=t+32|0;K=a&x[d+1074420>>2]!=0;gb:{if(!K){break gb}a=IT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Kd(z[d+480188>>1],1,31);hb:{if(Ed(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}o=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+30560|0]|0;break hb}o=x[d+480228>>2]}w[d+480212>>1]=0;q=d+1074312|0;u=d+480210|0;L=d+480209|0;s=0;while(1){if((s|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break gb}g=fb-16|0;fb=g;x[g+12>>2]=d;e=d+1074478|0;c=e+(a<<1)|0;if((c|0)!=(e|0)){b=e+(b<<1)|0;j=g+12|0;ib:{a=c-e|0;if((a|0)<3){break ib}f=a>>1;a=f-2>>>1|0;while(1){if((a|0)<0){break ib}VR(e,x[j>>2],f,e+(a<<1)|0);a=a-1|0;continue}}f=c-e>>1;a=c;while(1){if((a|0)!=(b|0)){if(Ml(x[j>>2],z[a>>1],z[e>>1])){UR(a,e);VR(e,x[j>>2],f,e)}a=a+2|0;continue}break}a=c-e>>1;while(1){if((a|0)>1){m=z[e>>1];b=e;o=x[j>>2];f=0;n=a;l=a-2>>>1|0;while(1){a=f<<1;f=a|1;i=a+2|0;a=i+b|0;if((i|0)<(n|0)){s=i;i=Ml(o,z[a>>1],z[a+2>>1]);f=i?s:f;a=i?a+2|0:a}w[b>>1]=z[a>>1];b=a;if((f|0)<=(l|0)){continue}break}a=c-2|0;jb:{if((b|0)==(a|0)){w[b>>1]=m;break jb}w[b>>1]=z[a>>1];w[a>>1]=m;m=x[j>>2];b=b+2|0;a=b-e>>1;kb:{if((a|0)<2){break kb}f=a-2|0;a=e+(f&-2)|0;b=b-2|0;if(!Ml(m,z[a>>1],z[b>>1])){break kb}f=f>>>1|0;i=z[b>>1];while(1){lb:{o=b;b=a;w[o>>1]=z[a>>1];if(!f){break lb}a=f-1|0;f=a>>>1|0;a=e+(a&-2)|0;if(Ml(m,z[a>>1],i)){continue}}break}w[b>>1]=i}}a=n-1|0;c=c-2|0;continue}break}}fb=g+16|0}else{l=D(s,872)+d|0;h=l+1075080|0;mb:{if(!(x[h>>2]&4096)|(x[l+1075016>>2]|(x[l+1075012>>2]|x[l+1075688>>2]))){break mb}Kb(k+16|0,q,64);if(Hb(x[x[k+16>>2]>>2],x[k+20>>2])){break mb}x[l+1075068>>2]=0;a=l+1075084|0;x[a>>2]=0;x[a+4>>2]=0}c=z[d+480188>>1];b=x[h>>2];nb:{if(x[l+1075068>>2]|c>>>0>s>>>0?b&1024:1){if(c>>>0>s>>>0){_R(d,s&65535)}w[l+1075834>>1]=0;break nb}a=0;H=l+1075712|0;x[H>>2]=0;G=l+1075672|0;x[G>>2]=0;r=l+1075e3|0;e=r;x[e>>2]=0;x[e+4>>2]=0;x[l+1075092>>2]=0;x[k+44>>2]=1065353216;w[k+42>>1]=0;R=l+1075648|0;M=x[R>>2];x[k+36>>2]=0;j=0;t=l+1075692|0;j=x[t>>2]?x[l+1075068>>2]!=0:j;f=l+1074992|0;ob:{pb:{qb:{if(c>>>0<=s>>>0){break qb}if(y[((s<<5)+d|0)+480288|0]){break pb}if(!M){break qb}a=y[M+34|0]!=0}if((a|j)!=1){break ob}}x[k+8>>2]=x[l+1075680>>2];x[k+32>>2]=x[l+1075744>>2];C=k+16|0;Kb(C,q,28);b=k+8|0;a=Hb(x[x[k+16>>2]>>2],x[k+20>>2])?k+32|0:b;c=d+1074312|0;rb:{if(Ob(c,28)){x[a>>2]=x[a>>2]+w[f+776>>1];Fe(a,0,64);break rb}e=Ob(c,1);c=w[f+776>>1];if(e){x[a>>2]=c+x[a>>2];Fe(a,0,256);break rb}x[f+688>>2]=c+x[f+688>>2];Fe(f+688|0,0,256);x[a>>2]=x[f+688>>2];w[f+776>>1]=0}sb:{tb:{a=d+1074312|0;if(!Ob(a,28)){if(!Ob(a,1)){break tb}}x[f+684>>2]=x[f+692>>2]+w[f+778>>1];Fe(f+684|0,0,256);break sb}x[f+692>>2]=x[f+692>>2]+w[f+778>>1];Fe(f+692|0,0,256);w[f+778>>1]=0;x[f+684>>2]=x[f+692>>2]}ub:{if(!(y[f+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break ub}vb:{if(x[b>>2]<=0){if(!Ob(d+1074312|0,21)){break vb}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}a=JA(d,y[f+825|0],y[f+820|0]);wb:{if((y[f+825|0]&3)!=1){break wb}if(!Ob(d+1074312|0,89)){break wb}a=y[f+819|0];n=y[f+820|0];e=n<<2&124;a=(!(y[f+90|0]&2)|y[d+480209|0]&16?a:y[f+823|0]+a|0)&32?e^127:e;a=n&32?0-a|0:a}if(x[d+480180>>2]!=131072){a=x[b>>2]+((D(y[f+827|0],a)|0)/(1<<c)|0)|0}else{c=64-a|0;a=x[b>>2];a=((D(y[f+827|0],D(c,a))|0)/-8192|0)+a|0}x[b>>2]=a}a=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|a&4?a&4096:0){break ub}a=Ob(d+1074312|0,21);c=y[f+826|0];e=y[f+820|0];v[f+820|0]=(a?c<<2:e)+(a?e:c)}e=s&65535;n=fb-16|0;fb=n;a=d+1074312|0;Kb(n+8|0,a,71);xb:{if(Hb(x[x[n+8>>2]>>2],x[n+12>>2])){g=D(e,872)+d|0;a=g+1075831|0;c=v[a|0];if((c|0)>=0){break xb}if(!(y[d+480209|0]&16|y[g+1075797|0]!=18)){yb:{zb:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break zb}c=y[g+1075832|0]>>>4|-64;break yb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break yb}c=c-1|0}v[a|0]=c;a=(D(e,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}if((c&224)!=128){break xb}x[b>>2]=0;break xb}g=D(e,872)+d|0;if(y[g+1075797|0]!=18){break xb}Kb(n+8|0,a,22);Ab:{if(Hb(x[x[n+8>>2]>>2],x[n+12>>2])){a=g+1075831|0;m=y[a|0];c=m<<24>>24;if(!(!x[g+1075068>>2]|(c|0)>=0)){Bb:{Cb:{if((m|0)!=192){if((m|0)!=128){break Cb}c=y[g+1075832|0]>>>4|-64;break Bb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break Bb}c=c-1|0}v[a|0]=c}if((c&192)!=128){break Ab}x[b>>2]=0;break Ab}a=y[(D(e,872)+d|0)+1075832|0];c=a>>>4|0;m=c+(a&15)|0;g=x[d+480180>>2];if(!(y[d+480208|0]&4?0:g&16777248)){m=m+2|0;c=c+1|0}a=(D(e,872)+d|0)+1075831|0;i=y[a|0];if(!(g&4)){g=c;c=(i&255)>>>0<m>>>0?i:0;if(g>>>0<=(c&255)>>>0){x[b>>2]=0}v[a|0]=c+1;break Ab}Db:{if(y[d+480209|0]&16){a=i&255;g=a-1|0;i=a>>>0>=g>>>0?g:0;break Db}v[a|0]=i+1}if(((i&255)>>>0)%(m>>>0)>>>0<c>>>0){break Ab}x[b>>2]=0}a=(D(e,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}a=D(e,872)+d|0;Eb:{if(y[a+1075797|0]!=18){break Eb}c=x[a+1075648>>2];if(!c){break Eb}m=y[c+34|0];if(x[a+1075080>>2]&134218752|(!m|y[c+15|0]&2)){break Eb}g=a+1075791|0;i=y[g|0];if(!Tc(i)){break Eb}a=x[vd(d+906300|0,m-1|0)>>2];if(!a){break Eb}m=ib[x[x[a>>2]+104>>2]](a,i,e)|0;i=x[b>>2];if(!(!m|i)){ib[x[x[a>>2]+96>>2]](a,c,y[g|0]|256,0,e);break Eb}if(m|!i){break Eb}ib[x[x[a>>2]+96>>2]](a,c,y[g|0],z[(D(e,872)+d|0)+1075680>>1],e)}fb=n+16|0;Fe(b,0,256);x[k+8>>2]=x[k+8>>2]<<6;Fb:{if(M){Kb(C,q,31);if(Hb(x[x[k+16>>2]>>2],x[k+20>>2])){Mu(d,f)}a=k+8|0;Gb:{if(!HA(d,f,0)){break Gb}c=x[f+656>>2];n=d+1074312|0;g=Ob(n,31);b=x[f+724>>2];if(b?0:g){break Gb}m=b-Ob(n,31)|0;b=Wq(c+48|0,m,256,64);i=y[c+65|0];Hb:{if((i|0)==255){break Hb}g=w[f+728>>1];if((g|0)==-1){break Hb}i=yb(x[c+48>>2],i);C=y[i+2|0];c=C<<2;b=(m|0)==z[i>>1]?c:b;if(Ob(n,94)){b=g+(b-c<<1)|0;break Hb}if(!C){b=0;break Hb}b=(D(b,g)|0)/(c|0)|0}Sa=a,Ta=(D(Yb(b,0,512),x[a>>2])|0)/256|0,x[Sa>>2]=Ta}mT(f,a);Ib:{if(!HA(d,f,1)){break Ib}a=x[f+656>>2];b=d+1074312|0;g=Ob(b,31);c=x[f+732>>2];if(c?0:g){break Ib}b=Wq(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[f+684>>2];Sa=f,Ta=Yb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Sa+684>>2]=Ta}Kb(k+16|0,q,115);if(Hb(x[x[k+16>>2]>>2],x[k+20>>2])){break Fb}b=y[l+1075789|0];if(!b){break Fb}a=x[R>>2];if(!a|!y[a+26|0]){break Fb}pT(l+1075676|0,b,y[a+26|0],y[a+27|0]);break Fb}if(!(y[h+1|0]&16)){break Fb}x[l+1075688>>2]=0;x[k+8>>2]=0}Jb:{if(y[l+1075843|0]&8){c=0;x[k+8>>2]=0;break Jb}c=x[k+8>>2];if(!c){c=0;break Jb}if(y[h+3|0]&8){x[G>>2]=0;break Jb}if(Ed(y[d+1074365|0])){a=D(x[k+32>>2],x[l+1075740>>2]);b=a;g=a>>31;a=c<<8;Sa=G,Ta=Gc(ova(nva(b,g,a,a>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;break Jb}a=D(x[k+32>>2],x[l+1075740>>2]);b=a;g=a>>31;a=D(x[d+1074456>>2],c);Sa=G,Ta=Gc(ova(nva(b,g,a,a>>31),hb,1048576,0),hb),x[Sa>>2]=Ta}x[H>>2]=c;Kb:{Lb:{c=x[t>>2];if(!(x[d+480180>>2]==2|(c|0)>=x[d+480260>>2])){if(!Hj(d)){break Lb}c=x[t>>2]}if((c|0)<x[d+480264>>2]){break Kb}Kb(k+16|0,q,113);if(!Hb(x[x[k+16>>2]>>2],x[k+20>>2])){break Kb}if(Hj(d)){break Kb}x[t>>2]=x[d+480264>>2];break Kb}x[t>>2]=x[d+480260>>2]}Kb(k+16|0,q,73);a=x[t>>2];x[k+36>>2]=a;Mb:{if((x[h>>2]&1572864)!=1572864){break Mb}b=x[d+480208>>2];if(b&2097152){if(!Ql(y[l+1075782|0],y[l+1075783|0])|b&4096){break Mb}}b=l+1075704|0;Nb:{if((a|0)==x[b>>2]){c=x[l+1075708>>2];break Nb}x[b>>2]=a;c=a;a=l+1075764|0;b=l+1075696|0;c=xh(d,Ju(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[l+1075708>>2]=c}x[k+36>>2]=c}n=fb-16|0;fb=n;b=D(e,872)+d|0;i=b;C=b+1075648|0;a=x[C>>2];Ob:{if(!a){break Ob}c=y[a+34|0];if(x[b+1075080>>2]&134218752|(!c|y[a+15|0]&2)){break Ob}if(!x[vd(d+906300|0,c-1|0)>>2]){break Ob}g=b+1075780|0;a=y[b+1075793|0];T=b+1075783|0;m=y[T|0];Pb:{Qb:{if((m|0)==1){b=a;Rb:{Sb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(y[(D(e,872)+d|0)+1075798|0]>>>4|0)|0;break Rb;case 1:break Sb;default:break Rb}}b=a+(y[(D(e,872)+d|0)+1075798|0]&15)|0}c=D(e,872)+d|0;if(y[c+1075792|0]==(b&255)){break Pb}if(!(v[c+1075843|0]&1)){break Qb}if(!Tc(y[g|0])){break Qb}if(Ql(y[g+2|0],1)){break Qb}break Pb}if(y[g|0]){b=a;if(!Ql(y[g+2|0],m)){break Pb}}b=a;if(!y[(D(e,872)+d|0)+1075792|0]){break Pb}}cn(d,e,b&255|512,z[(D(e,872)+d|0)+1075680>>1])}P=(D(e,872)+d|0)+1075792|0;c=y[P|0];Tb:{Ub:{if(c){if((m|0)!=1|(b&255)!=(c|0)){break Ub}break Tb}if(!(v[(D(e,872)+d|0)+1075843|0]&1)|(m|0)!=1){break Tb}if(Tc(y[g|0])){break Tb}c=a;if(!Tc(a)){break Tb}}cn(d,e,c&255|256,0)}v[P|0]=y[T|0]==1?b:0}Vb:{if(y[i+1075797|0]!=1){break Vb}if(Sj(x[C>>2])){b=0;Wb:{Xb:{Yb:{switch(A[d+1074392>>2]%3|0){case 1:b=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break Xb;case 0:break Xb;case 2:break Yb;default:break Wb}}b=y[(D(e,872)+d|0)+1075798|0]&15}w[k+42>>1]=b}a=(D(e,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break Vb}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(e,872)+d|0;b=xh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[k+36>>2]=b;x[a+1075692>>2]=b}c=d+1074312|0;Kb(n+8|0,c,13);if(Hb(x[x[n+8>>2]>>2],x[n+12>>2])){b=y[(D(e,872)+d|0)+1075798|0];if(!b){break Vb}a=65536;Zb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=x[((b&240)<<2)+35568>>2];break;default:break Zb}}e=Hj(d);b=x[k+36>>2];c=b>>31;if(e){a=nva(b,c,a,a>>31);e=hb;a=a+32768|0;e=a>>>0<32768?e+1|0:e;a=ova(a,e,65536,0);b=hb}else{e=(a|0)/2|0;m=e>>31;g=c<<16|b>>>16;c=b<<16;b=c+e|0;g=g+m|0;a=ova(b,b>>>0<c>>>0?g+1|0:g,a,a>>31);b=hb}Sa=k,Ta=Gc(a,b),x[Sa+36>>2]=Ta;break Vb}Kb(n+8|0,c,51);if(Hb(x[x[n+8>>2]>>2],x[n+12>>2])){if(y[d+480209|0]&16){break Vb}_b:{$b:{a=x[d+1074416>>2];b=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break $b}if((b|0)==16){break Vb}a=0;ac:{switch((b|0)%3|0){case 0:break Vb;case 2:break $b;case 1:break ac;default:break _b}}a=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break _b}a=y[(D(e,872)+d|0)+1075798|0]&15}c=a;a=D(e,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+Ju(d,x[k+36>>2],w[b>>1],x[a>>2])|0;b=xh(d,c,w[b>>1],x[a>>2]);x[k+36>>2]=b;if(c>>>0<109){break Vb}x[n+8>>2]=b;Sa=n,Ta=xh(d,109,0,x[a>>2]),x[Sa+4>>2]=Ta;Sa=k,Ta=x[ad(n+8|0,n+4|0)>>2],x[Sa+36>>2]=Ta;break Vb}g=x[d+1074392>>2];b=x[d+480180>>2];bc:{if((b|0)!=1){a=y[(D(e,872)+d|0)+1075789|0];break bc}a=D(e,872)+d|0;a=Ju(d,x[k+36>>2],w[a+1075764>>1],x[a+1075696>>2]);b=x[d+480180>>2]}cc:{dc:{switch((((b&67633152?g+2|0:g)>>>0)%3|0)-1|0){case 0:a=(y[(D(e,872)+d|0)+1075798|0]>>>4|0)+a|0;break cc;case 1:break dc;default:break cc}}a=(y[(D(e,872)+d|0)+1075798|0]&15)+a|0}if(!(b&67633408|y[(D(e,872)+d|0)+1075789|0]!=(a&255))){Kb(n+8|0,c,82);if(!Hb(x[x[n+8>>2]>>2],x[n+12>>2])){break Vb}}if(y[d+480210|0]&32){b=a&255;if((b|0)==85){x[k+36>>2]=2147483647;break Vb}a=b>>>0>85?a-37|0:a}b=D(e,872)+d|0;g=xh(d,a&255,w[b+1075764>>1],x[b+1075696>>2]);x[k+36>>2]=g;if(x[d+480180>>2]&71860480){x[b+1075692>>2]=g;break Vb}Kb(n+8|0,c,82);if(!Hb(x[x[n+8>>2]>>2],x[n+12>>2])){break Vb}v[(D(e,872)+d|0)+1075792|0]=a}fb=n+16|0;if(!(!(y[u|0]&33)|x[k+36>>2]==2147483647)){ec:{if(x[d+480180>>2]==2){c=452;a=3424;break ec}a=D(z[l+1075764>>1]>>>4&15,24);b=z[a+31302>>1]>>>1|0;c=b>>>0<=452?452:b;a=z[a+31280>>1]<<1}Fe(k+36|0,c,a);Fe(t,c,a)}uT(d,f);b=x[h>>2]}fc:{if(!(b&256)|y[L|0]&64){break fc}Kb(k+16|0,q,37);if(!Hb(x[x[k+16>>2]>>2],x[k+20>>2])){break fc}x[l+1075676>>2]=128}a=HT(d,f);gc:{if((a|0)<0|!(y[h+1|0]&2)){break gc}b=x[d+1298300>>2];if(!Dd(b)){break gc}Uq(b,s&65535,a&255,1)}n=s&65535;_R(d,n);hc:{if(!j){break hc}a=nT(d,f,k+36|0);if((a|0)<0|!(y[h+1|0]&2)){break hc}b=x[d+1298300>>2];if(!Dd(b)){break hc}Uq(b,n,a>>>2&255,1)}ic:{if(y[l+1075782|0]!=8){break ic}jc:{kc:{a=y[l+1075783|0];switch(a-5|0){case 1:break ic;case 0:case 2:break jc;default:break kc}}if((a|0)!=26){break ic}}a=x[d+480180>>2];if((a|0)==4){if(y[L|0]&16){break ic}a=l+1075811|0;v[a|0]=y[a|0]+y[l+1075815|0];break ic}if(!(a&16777248)){break ic}Ol(f,y[l+1075784|0]);ZR(d,n,k+36|0,k+44|0)}g=k+36|0;ZR(d,n,g,k+44|0);lc:{if(!j){break lc}x[k+32>>2]=0;m=fb-16|0;fb=m;a=x[f+104>>2];mc:{if(!a|!y[a+40|0]){break mc}e=Sj(x[f+656>>2]);i=Hj(d);b=i?36592:35568;j=i?35568:36592;if(!(e|!Ob(d+1074312|0,21)|x[d+480180>>2]==1048576)){t=y[a+41|0];if(!t){break mc}c=y[f+818|0];x[m+12>>2]=x[f+756>>2]+y[a+39|0];Ai(m+12|0,y[a+40|0]<<8);e=x[m+12>>2];v[f+818|0]=c+t;x[f+756>>2]=e;e=(e|0)/256|0;nc:{oc:{switch(y[a+38|0]-1|0){case 3:c=XR(Jo(d))+-64|0;break nc;case 2:c=64-(c+1>>>1|0)|0;break nc;case 1:c=(c+1>>>1|0)+-64|0;break nc;case 0:c=(c^-1)>>>1&64;break nc;default:break oc}}c=v[c+31872|0]}Ai(g,8388607);a=x[g>>2]<<8;x[g>>2]=a;e=D(c,e);c=(e|0)/64|0;pc:{qc:{if((e|0)<=-64){e=a>>31;c=0-c|0;b=x[(c&-4)+b>>2];b=Gc(ova(nva(a,e,b,b>>31),hb,65536,0),hb)-a|0;c=c&3;if(!c){break pc}c=(c<<2)+(i?35504:35440)|0;break qc}e=a>>31;b=x[j+(c&-4)>>2];b=Gc(ova(nva(a,e,b,b>>31),hb,65536,0),hb)-a|0;c=c&3;if(!c){break pc}c=(c<<2)+(i?35440:35504)|0}c=x[c>>2];b=(Gc(ova(nva(c,c>>31,a,e),hb,65536,0),hb)+b|0)-a|0}x[g>>2]=(a+b|0)/256;x[k+32>>2]=b&255;break mc}i=x[d+480180>>2]&16777248;c=y[a+39|0];rc:{if(!(i|c)){x[f+756>>2]=y[a+40|0]<<8;break rc}sc:{if(i){x[f+756>>2]=x[f+756>>2]+(c<<1);i=y[a+40|0];break sc}i=y[a+40|0];if(y[f+89|0]&8){break sc}x[f+756>>2]=x[f+756>>2]+(((i<<8&65280)>>>0)/(c>>>0)|0)}Ai(f+756|0,i<<8)}c=y[f+818|0]+y[a+41|0]|0;v[f+818|0]=c;c=c<<24>>24;tc:{uc:{switch(y[a+38|0]-1|0){case 3:v[f+818|0]=c+1;i=v[(c&63)+31808|0];break tc;case 2:i=(64-(c>>>1|0)&127)+-64|0;break tc;case 1:i=((c>>>1|0)- -64&127)+-64|0;break tc;case 0:i=(c|0)>=0?-64:64;break tc;default:break uc}}i=0-v[(c&255)+31872|0]|0;if(x[d+480180>>2]!=1048576){break tc}i=(64-v[(c+-64&255)+31872|0]|0)/2<<16>>16}c=i;t=D(c,x[f+756>>2]);i=(t|0)/256|0;if(e){B[k+44>>2]=B[k+44>>2]+E(E(E(E(y[a+40|0])*E(.05000000074505806))*E(c|0))*E(.000244140625));v[f+851|0]=y[f+851|0]|64;break mc}if(x[d+480180>>2]!=4){vc:{if((t|0)<=-256){i=0-i|0;c=i>>>8|0;a=(c<<2)+b|0;break vc}b=j;c=i>>>8|0;a=b+(c<<2)|0}e=x[g>>2];a=x[a>>2];a=((D(x[((c<<2)+b|0)+4>>2]-a|0,i>>>2&63)|0)/64|0)+a|0;a=Gc(ova(nva(e,e>>31,a,a>>31),hb,256,0),hb);x[g>>2]=a;x[k+32>>2]=a&255;x[g>>2]=x[g>>2]/256;break mc}x[g>>2]=x[g>>2]+((t|0)/16384|0)}fb=m+16|0;j=x[k+36>>2];if((j|0)<=x[d+480260>>2]){Kb(k+16|0,q,81);if(Hb(x[x[k+16>>2]>>2],x[k+20>>2])){x[l+1075068>>2]=0}j=x[d+480260>>2];x[k+36>>2]=j}wc:{if(!Sj(x[f+656>>2])){break wc}a=l+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break wc}uV(f,B[k+44>>2],w[k+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=k+16|0;wB(a,d,f,j,x[k+32>>2]);c=zb(a);a=nva(x[k+16>>2],x[k+20>>2],x[d+480240>>2],0);j=hb;b=ova(a,j,65536,0);e=hb;g=b;a=a+65535|0;b=!(a>>>0<65535?j+1|0:j)&a>>>0<131071;a=b?1:g;x[k+16>>2]=a;b=b?0:e;x[k+20>>2]=b;x[r>>2]=a;x[r+4>>2]=b;if((x[h>>2]&134219264)!=512){break lc}if(!Dd(x[d+1298300>>2])){break lc}Kb(k+8|0,q,99);e=x[h>>2];b=e&4096;xc:{yc:{if(Sa=Hb(x[x[k+8>>2]>>2],x[k+12>>2]),Ta=1,Va=b,Va?Sa:Ta){a=x[d+480180>>2];break yc}a=x[d+480180>>2];if((a|0)!=2){break xc}}m=e&2048;zc:{if(m?(a|0)==2:0){break zc}a=x[d+480240>>2];c=nva(x[c>>2],0,261625,0);e=hb;c=c+66904|0;e=c>>>0<66904?e+1|0:e;a=nva(a,0,Bc(pva(c,e,133808,0),hb),0);j=hb;a=a+32768|0;j=a>>>0<32768?j+1|0:j;c=Bc((j&65535)<<16|a>>>16,j>>>16|0);a=1;Ac:{if(m){break Ac}a=0;if(!b){break Ac}a=!x[l+1075688>>2]}b=k+8|0;Kb(b,q,110);if(Sa=Hb(x[x[k+8>>2]>>2],x[k+12>>2]),Ta=0,Va=a,Va?Sa:Ta){break zc}e=x[d+1298300>>2];Kb(b,q,95);SB(e,n,c,a,Hb(x[x[k+8>>2]>>2],x[k+12>>2]))}a=x[d+1298300>>2];b=nva(D(x[l+1075744>>2],D(x[l+1075740>>2],x[H>>2])),0,63,0);g=hb;b=b+33554432|0;g=b>>>0<33554432?g+1|0:g;Uq(a,n,Bc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);a=l+1075676|0;j=a;b=x[a>>2];c=0;a=x[d+1298300>>2];e=Xl(a,n);Bc:{if((e|0)==255){break Bc}g=x[a>>2];if(Nj(g)){break Bc}c=xb(Hd(a+318|0,e),10);i=x[a+4>>2];e=bv(e)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;zh(g,i,n,e,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[j>>2]=(c<<7)+128}Cc:{a=x[R>>2];if(!a|(y[a+60|0]&7)!=1){break Cc}b=x[a+48>>2];a=x[a+52>>2];if(lc(b,a)){break Cc}b=x[YR(f,0)>>2];a=xf(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Cc}Mj(x[d+1298300>>2],n,1);Kb(k+8|0,q,109);a=x[h>>2];Sa=h,Ta=(Hb(x[x[k+8>>2]>>2],x[k+12>>2])?a:a&-4609)|4096,x[Sa>>2]=Ta;x[l+1075688>>2]=0;break lc}Kb(k+8|0,q,99);if(!Hb(x[x[k+8>>2]>>2],x[k+12>>2])|!(y[h+1|0]&16)|x[l+1075688>>2]){break lc}Mj(x[d+1298300>>2],n,1);x[h>>2]=x[h>>2]&-513}Dc:{if(!M){break Dc}Kb(k+16|0,q,31);if(Hb(x[x[k+16>>2]>>2],x[k+20>>2])){break Dc}Mu(d,f)}b=x[h>>2];a=b&-65537;g=x[G>>2];i=l+1075016|0;t=l+1075012|0;c=g|(x[i>>2]|x[t>>2])?(a|b<<7&65536)^65536:a;x[h>>2]=c;G=l+1075664|0;a=G;x[a>>2]=0;x[a+4>>2]=0;n=l+1075834|0;a=y[n|0];b=a-4|0;b=a>>>0>=b>>>0?b:0;v[n|0]=b;m=l+1075835|0;a=y[m|0];e=a-4|0;a=a>>>0>=e>>>0?e:0;v[m|0]=a;Ec:{Fc:{Gc:{Hc:{Ic:{Jc:{Kc:{Lc:{Mc:{e=x[l+1075096>>2];Nc:{if(!e){break Nc}j=x[e+20>>2];if(!je(x[e>>2],j)|!x[l+1075068>>2]){break Nc}if(Ti(x[f+8>>2],x[f+12>>2])){break Mc}}x[l+1075008>>2]=0;break Lc}x[l+1075008>>2]=j;if(j){break Kc}}if(!Jj(x[f+656>>2])){break Jc}j=0;if(c&6144){break Jc}}M=x[l+1075676>>2];e=(D(g,256-M|0)|0)/16384|0;e=e>>>0>=127?127:e;if(b<<24>>24<0){v[n|0]=e;_=e}else{_=b}b=e>>>1|0;if((_&255)>>>0<b>>>0){v[n|0]=b}b=(D(g,M)|0)/16384|0;b=b>>>0>=127?127:b;if(a<<24>>24<0){v[m|0]=b;a=b}b=b>>>1|0;if(b>>>0>(a&255)>>>0){break Ic}break Hc}if((b&255)>>>0>=129){v[n|0]=0}j=0;b=0;if((a&255)>>>0<129){break Gc}}v[m|0]=b}if(!j){break Gc}j=128;n=x[d+24624>>2];if(n>>>0>=2){j=Yb(x[l+1075676>>2],0,256)}x[k+16>>2]=j;b=D(g,o)>>>(Ed(y[d+1074366|0])?7:8)|0;Oc:{Pc:{Qc:{switch(y[d+1074364|0]){case 0:if(!(y[d+24616|0]&16)){break Pc}case 1:if((j|0)<=127){a=b>>>1|0;e=(D(b,j)|0)/256|0;break Oc}a=(D(b,256-j|0)|0)/256|0;e=b>>>1|0;break Oc;case 3:break Qc;default:break Pc}}Ai(k+16|0,255);e=x[k+16>>2];if((e|0)<=0){a=65536}else{a=z[(0-e<<1)+38128>>1]}a=D(a,b)>>>16|0;e=D(b,z[(e<<1)+37616>>1])>>>16|0;break Oc}a=(D(b,256-j|0)|0)/256|0;e=(D(b,j)|0)/256|0}b=x[R>>2];Rc:{if(b){j=y[b+14|0];if(Ap(j)){break Rc}}j=y[d+480268|0];if(Ap(j)){break Rc}b=y[d+24648|0];j=y[u|0]&128?x[d+24668>>2]?-1:b:b}g=l+1075668|0;m=l+1075786|0;v[m|0]=j;b=x[r>>2];i=x[r+4>>2];if(!(c&131072|((b|0)!=0|(i|0)!=1)|(x[l+1075748>>2]|(j&255)==255))){v[m|0]=0}j=a;a=1<<x[d+1074360>>2];x[G>>2]=(j|0)/(a|0);a=(e|0)/(a|0)|0;x[g>>2]=(c&256)>>>8|0?(n|0)==2?0-a|0:a:a;if(c&128){x[r>>2]=0-b;x[r+4>>2]=0-(((b|0)!=0)+i|0)}i=0;n=fb-16|0;fb=n;x[f+28>>2]=0;x[f+32>>2]=0;Ai(f+672|0,524287);Ai(f+676|0,524287);a=x[f+676>>2];b=x[f+672>>2];Sc:{Tc:{c=x[f+88>>2];if(!(c&65536)){break Tc}e=x[f+20>>2];j=x[f+24>>2];if((e|0)==(b|0)&(j|0)==(a|0)){break Tc}c=x[d+24620>>2];j=(b|0)<=(e|0)&(a|0)<=(j|0);Uc:{if(!j){a=dv(c,x[d+24636>>2]);break Uc}a=dv(c,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=nva(a,a>>31,5,0);e=hb;a=a+500|0;e=a>>>0<500?e+1|0:e;a=Gc(ova(a,e,1e3,0),hb)}b=a;c=x[f+656>>2];Vc:{if(j|!c){break Vc}c=z[c+12>>1];if(!c){break Vc}i=1;b=(D(c,x[d+24620>>2])>>>0)/1e5|0}j=b>>>0<=1?1:b;e=x[f+672>>2];m=x[f+20>>2];r=e-m<<12;G=f;c=x[f+676>>2];b=x[f+24>>2];g=c-b<<12;if(!(y[f+90|0]&32|(!(c|e)|(!(b|m)|i)))){x[n+12>>2]=x[d+1074380>>2];Fe(n+12|0,a,2048);j=x[n+12>>2]}g=(g|0)/(j|0)|0;x[G+32>>2]=g;m=(r|0)/(j|0)|0;x[f+28>>2]=m;a=c+((D(g,j)|0)/-4096|0)|0;x[f+24>>2]=a;b=e+((D(j,m)|0)/-4096|0)|0;x[f+20>>2]=b;if(g|m){x[f+100>>2]=j;c=x[f+88>>2];break Sc}x[f+24>>2]=c;x[f+20>>2]=e;a=c;b=e;c=x[f+88>>2]&-65537;break Sc}x[f+24>>2]=a;x[f+20>>2]=b;c=c&-65537}x[f+88>>2]=c&-2097153;x[f+40>>2]=a<<12;x[f+36>>2]=b<<12;fb=n+16|0;c=x[h>>2];if(!(c&512)){break Fc}break Ec}x[t>>2]=0;x[i>>2]=0;x[l+1075068>>2]=0;if(x[l+1075088>>2]){break Fc}if(!x[l+1075084>>2]){break Ec}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=s}x[l+1075660>>2]=c;a=l+1075843|0;v[a|0]=y[a|0]&253}s=s+1|0;continue}break}}fb=k+48|0;if(K){b=x[d+480208>>2];break h}if(Ed(y[d+1298424|0])){a=x[d+480208>>2]|512;break i}o=0;Wc:{a=x[d+24620>>2]/10|0;b=Gc(a,a>>31);if(!b){break Wc}c=b>>>0>=1048576?1048576:b;x[d+1074380>>2]=c;f=z[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(o|0)){break Wc}a=e+D(z[(e+(o<<1)|0)+102>>1],872)|0;n=a+1288|0;x[n>>2]=0;x[n+4>>2]=0;x[a+716>>2]=c;n=x[a+640>>2]<<12;x[a+656>>2]=n;j=x[a+636>>2]<<12;x[a+652>>2]=j;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-j|0)/(c|0);x[a+648>>2]=(0-n|0)/(c|0);o=o+1|0;continue}}c=x[d+480208>>2];a=c|256;if(b){break i}a=c|512}b=a;x[d+480208>>2]=b}if(!(b&512)){break g}Sa=d+1074392|0,Ta=Pl(Fa),x[Sa>>2]=Ta}fb=J+96|0;break f}x[J+80>>2]=512;a=x[d+1074380>>2];x[J+88>>2]=ia;x[J+84>>2]=a;n=sE(J+80|0);if(x[d+24632>>2]){b=0;a=fb-48|0;fb=a;c=n<<2;while(1){if((b|0)==4){Xc:{b=0;while(1){if((b|0)==4){break Xc}x[(a+32|0)+(b<<2)>>2]=((b<<11)+d|0)+16396;b=b+1|0;continue}}}else{x[a+32>>2]=0;e=((b<<11)+d|0)+16396|0;Yz(e,c+e|0,a+32|0);b=b+1|0;continue}break}b=x[d+24632>>2];x[a+28>>2]=n;x[a+24>>2]=b;x[a+20>>2]=a+32;b=x[x[ha>>2]+8>>2];x[a+16>>2]=n;c=x[a+24>>2];x[a+8>>2]=x[a+20>>2];x[a+12>>2]=c;ib[b|0](ha,a+8|0);fb=a+48|0}if(Ed(Ea)){b=0;while(1){if((b|0)==4){a=x[d+24632>>2];x[J+76>>2]=n;x[J+72>>2]=a;x[J+68>>2]=J+80;a=x[x[pa>>2]+8>>2];x[J+40>>2]=n;b=x[J+72>>2];x[J+32>>2]=x[J+68>>2];x[J+36>>2]=b;ib[a|0](pa,J+32|0)}else{x[(J+80|0)+(b<<2)>>2]=((b<<11)+d|0)+16396;b=b+1|0;continue}break}}ba=0;L=0;k=fb-48|0;fb=k;if(n){G=d+12|0;M=d+24592|0;R=d+24588|0;Qn(G,n,M,R);if(A[d+24624>>2]>=3){Qn(d+8204|0,n,d+24600|0,d+24596|0)}w[k+42>>1]=0;ua=d+1074312|0;Ga=d+24648|0;ca=d+906300|0;_=d+24596|0;Ha=d+24600|0;Ia=d+8204|0;q=d+397452|0;r=d+397448|0;t=d+393352|0;va=d+397456|0;ma=d+1074376|0;while(1){if(z[d+480212>>1]<=ba>>>0){Sa=d,Ta=z[qe(d+480214|0,k+42|0)>>1],w[Sa+480214>>1]=Ta}else{m=ma+(ba<<1)|0;u=z[m+102>>1];a=D(u,872);P=a+ma|0;Yc:{Zc:{if(x[P+632>>2]){break Zc}b=a+d|0;if(x[b+1075088>>2]){break Zc}if(!x[b+1075084>>2]){break Yc}}g=a+d|0;a=y[g+1075786|0]+1&255;if(a>>>0<=5){j=x[(a<<2)+26144>>2]}else{j=0}H=g+1075080|0;f=x[H>>2];_c:{if(!(!(f&16777216)&y[d+24612|0]>>>5)){b=M;e=G;c=f;i=R;if(!(c&8388608)){break _c}}if(!y[va+12|0]){Qn(t,n,r,q)}v[va+12|0]=1;u=z[m+102>>1];c=x[H>>2];b=r;e=t;i=q}a=c>>>8&A[d+24624>>2]>2;V=a?_:i;C=a?Ha:b;c=a?Ia:e;fa=vm(d,ma,u&65535,2,1)-1|0;wa=(fa&255)>>>0>249;$c:{if(wa){break $c}if(!x[vd(ca,fa)>>2]){break $c}b=x[vd(ca,fa)>>2];a=x[b+24>>2];if(!a){break $c}V=b+36|0;C=b+40|0;if(!(v[b+28|0]&1)){Qn(a,n,C,V);x[b+28>>2]=x[b+28>>2]|1}c=a}m=P+616|0;if(y[g+1075843|0]&8){ZF(m,c,n);a=g+1075084|0;x[C>>2]=x[C>>2]+x[a>>2];x[V>>2]=x[V>>2]+x[g+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break Yc}ja=0;a=k+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=d+1074312|0;Sa=a,Ta=Ob(b,33),v[Sa+16|0]=Ta;Sa=a,Ta=Ob(b,116)^1,v[Sa+17|0]=Ta;if(x[m+16>>2]){YF(a,m);b=x[m+12>>2];e=b>>31;o=e^x[m+8>>2];b=(b^e)-((e>>>0>o>>>0)+e|0)|0;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Ja=f>>>12&8|(f>>>5&2|(j|f&1));Ka=L&65535;La=g+1075795|0;Ma=g+1075778|0;Na=g+1075688|0;Oa=g+1075024|0;Pa=g+1075020|0;Qa=g+1075668|0;Ra=g+1075664|0;W=g+1075088|0;Y=g+1075084|0;xa=g+1075016|0;ya=g+1075012|0;ka=g+1075096|0;Z=g+1075076|0;T=g+1075068|0;K=g+1075e3|0;la=g+1075072|0;$=g+1075092|0;h=a;b=n;while(1){ad:{a=x[$>>2];ga=a?a>>>0<b>>>0?a:b:b;x[k+12>>2]=ga;bd:{cd:{if(!ga){break cd}a=x[K+4>>2];i=a;f=x[K>>2];if(!(a|f)){break cd}j=x[T>>2];if(!j){break cd}a=x[h>>2];if(!a){break cd}u=x[H>>2];l=u&2;g=x[la>>2];x[P+632>>2]=a;a=x[m>>2];dd:{ed:{o=g&u<<30>>31;e=x[m+4>>2];if((o|0)>(e|0)){if((i|0)<0){a=ih(0,o<<1,a,e);x[m>>2]=a;e=hb;x[m+4>>2]=e;if(!(e>>>0<j+o>>>1>>>0&(e|0)>=(o|0))){a=0;x[m>>2]=a;e=o;x[m+4>>2]=e}fd:{if(u&4){u=u&-129;x[H>>2]=u;i=0-(((f|0)!=0)+i|0)|0;f=0-f|0;x[K>>2]=f;x[K+4>>2]=i;break fd}x[m>>2]=a;e=j-1|0;x[m+4>>2]=e}if(!l){break cd}if(e>>>0<j>>>0){break dd}break cd}if((e|0)>0|(e|0)>=0){break dd}e=0;break ed}if(e>>>0<j>>>0){break dd}if(!l){break cd}if(u&4){if(!!f&(i|0)>=0|(i|0)>0){i=0-(((f|0)!=0)+i|0)|0;f=0-f|0;x[K>>2]=f;x[K+4>>2]=i}u=u|128;x[H>>2]=u;if(y[k+37|0]){l=y[k+36|0];s=x[Z>>2]-(l+g|0)|0;a=ih(a,e,0,j);e=hb;if(e>>>0<s>>>0){a=ih(0,j-l|0,a,e);e=hb;break ed}e=g;a=0;break ed}l=0-a|0;s=(j<<1)-((1-((a|0)!=0)|0)+e|0)|0;e=s;a=l;x[m>>2]=a;da=0;e=da|e;x[m+4>>2]=e;if(g>>>0<s>>>0&j>>>0>s>>>0){break dd}x[k+44>>2]=y[k+36|0]+1;e=da|j-x[Gb(T,k+44|0)>>2];break ed}if((i|0)<0){e=0-(((f|0)!=0)+i|0)|0;i=e;f=0-f|0;x[K>>2]=f;x[K+4>>2]=e}Pb(m,0,g-j|0);u=x[H>>2]|8192;x[H>>2]=u;a=x[m>>2];e=x[m+4>>2];break dd}x[m>>2]=a;x[m+4>>2]=e}gd:{if((e|0)<(o|0)){if((e|i)<0){break cd}x[k+44>>2]=ga;g=f;j=i;break gd}j=x[T>>2];if(j>>>0<e>>>0|(!!f&(i|0)>=0|(i|0)>0)&(e|0)==(j|0)){break cd}x[k+44>>2]=ga;j=i>>31;s=j^f;g=s-j|0;j=(j^i)-((j>>>0>s>>>0)+j|0)|0}l=g;s=j;wc(k+12|0,x[k+32>>2]);za=x[k+12>>2];hg(a,e,vf(f,i,za-1|0),hb);g=hb;j=x[la>>2];Aa=j>>>0>e>>>0|j+16>>>0<=e>>>0;if(Aa){u=u&-8193;x[H>>2]=u}hd:{id:{da=x[k+24>>2];jd:{if(da){j=x[k+28>>2];if(j>>>0<=e>>>0){kd:{if((i|0)<0){f=0;i=j;break kd}f=a;i=e;a=0;e=x[Z>>2]}Sa=k,Ta=Mp(ih(ih(a,e,f,i),hb,1,0),hb,l,s)+1|0,x[Sa+44>>2]=Ta;x[P+632>>2]=da;break hd}if(!(Aa|!(u&8192))){Sa=k,Ta=Mp(ih(ih(0,o+16|0,a,e),hb,1,0),hb,l,s)+1|0,x[Sa+44>>2]=Ta;Sa=P,Ta=da+D(x[Z>>2]-o|0,dl(z[x[ka>>2]+34>>1]))|0,x[Sa+632>>2]=Ta;break hd}if(!f&(i|0)<=0|(i|0)<0){break jd}if(ga>>>0<2|g>>>0<j>>>0){break id}Sa=k,Ta=Mp(ih(ih(0,j,a,e),hb,1,0),hb,l,s)+1|0,x[Sa+44>>2]=Ta;break hd}if((i|0)>0|(i|0)>=0){break id}}if((g|0)>=(o|0)){break hd}Sa=k,Ta=Mp(ih(ih(a,e,0,o),hb,1,0),hb,l,s)+1|0,x[Sa+44>>2]=Ta;break hd}f=g;g=x[T>>2];if((f|0)<(g|0)){break hd}Sa=k,Ta=Mp(ih(ih(0,g,a,e),hb,1,0),hb,l,s)+1|0,x[Sa+44>>2]=Ta}Lp(k+44|0,1,za);f=x[k+44>>2];if((f|0)>0){break bd}}x[P+632>>2]=0;x[T>>2]=0;x[m>>2]=0;x[m+4>>2]=0;x[$>>2]=0;ZF(m,c,b);x[C>>2]=x[C>>2]+x[Y>>2];x[V>>2]=x[V>>2]+x[W>>2];x[W>>2]=0;x[Y>>2]=0;x[H>>2]=x[H>>2]&-129;break ad}ld:{md:{if(Ka>>>0<A[d+24608>>2]){a=4;if(x[$>>2]){break md}a=0;if(x[xa>>2]|x[ya>>2]){break md}}Pb(m,vf(x[K>>2],x[K+4>>2],f),hb);ja=0;x[W>>2]=0;x[Y>>2]=0;c=(f<<3)+c|0;break ld}e=(f<<3)+c|0;j=e-8|0;x[Y>>2]=0-x[j>>2];g=e-4|0;x[W>>2]=0-x[g>>2];ib[x[((a|Ja)<<2)+25760>>2]](m,Ga,c,f);x[Y>>2]=x[Y>>2]+x[j>>2];x[W>>2]=x[W>>2]+x[g>>2];ja=1;c=e}a=x[$>>2];nd:{if(!a){break nd}if(a>>>0<=f>>>0){x[$>>2]=0;x[ya>>2]=x[Ra>>2];x[xa>>2]=x[Qa>>2];x[Pa>>2]=0;x[Oa>>2]=0;if(x[Na>>2]|!(y[H+1|0]&16)){break nd}x[T>>2]=0;x[P+632>>2]=0;break nd}x[$>>2]=a-f}l=0;u=0;a=x[m+4>>2];u=a>>>0>=A[Z>>2]?(y[H|0]&2)>>>1|0:u;e=a;a=x[T>>2];l=x[H>>2]&2|(e>>>0<a>>>0|!a)?l:!z[Ma>>1];b=b-f|0;Kb(k+12|0,ua,85);od:{pd:{qd:{if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])){break qd}a=y[La|0];if(!a){break qd}if(a>>>0<=z[d+480190>>1]){break pd}}i=0;break od}f=x[ka>>2];a=D(a,104)+d|0;e=a+484380|0;i=(f|0)!=(e|0);if((e|0)==(f|0)|(l|u)!=1){break od}x[ka>>2]=e;e=x[a+484400>>2];x[P+632>>2]=e;f=z[a+484414>>1];x[H>>2]=f|x[H>>2]&-768;g=f<<30>>31;f=x[a+484388>>2];x[T>>2]=g&f;a=x[a+484384>>2];x[la>>2]=a;x[Z>>2]=f;x[m+4>>2]=a;YF(h,m);if(!e){break ad}if((b|0)>0){continue}break ad}rd:{if(!u|i){break rd}Kb(k+12|0,ua,83);if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])|x[la>>2]){break rd}x[m>>2]=x[m>>2];x[m+4>>2]=0;a=x[x[ka>>2]+8>>2];x[T>>2]=a;x[Z>>2]=a}if((b|0)>0){continue}}break}x[P+632>>2]=x[h>>2];L=L+ja|0;w[k+42>>1]=L;if(wa|!ja){break Yc}if(!x[vd(ca,fa)>>2]){break Yc}a=x[vd(ca,fa)>>2];ib[x[x[a>>2]+152>>2]](a)}ba=ba+1|0;continue}break}}fb=k+48|0;h=x[d+1298300>>2];if(Dd(h)){b=X;c=n;a=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=fb-16|0;fb=k;sd:{if(!y[h+534|0]){break sd}e=nva(a,0,6169,0);a=hb;g=a>>>16|0;q=Bc((a&65535)<<16|e>>>16,g);while(1){if(!c){break sd}g=x[h>>2];j=x[g>>2];a=x[g+4>>2];while(1){if((a|0)>=(j|0)){x[g+8>>2]=x[g+12>>2];j=0;i=0;o=0;a=fb-16|0;fb=a;while(1){if((o|0)==18){e=(j|0)>=32767?32767:j;w[g+12>>1]=(e|0)<=-32768?-32768:e;e=(i|0)>=32767?32767:i;w[g+14>>1]=(e|0)<=-32768?-32768:e;w[g+3832>>1]=z[g+3832>>1]+1;e=(z[g+3834>>1]+1>>>0)%13440|0;w[g+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[g+3836>>1]=e>>>8;if(!y[g+3843|0]){w[g+3836>>1]=e>>>10}e=z[g+3838>>1]+1|0;w[g+3838>>1]=e;if((e&65535)>>>0>=1024){w[g+3838>>1]=0;w[g+3840>>1]=z[g+3840>>1]+1&7}fb=a+16|0}else{f=g+D(o,44)|0;td:{if(!y[f+56|0]){w[a+12>>1]=0;w[a+14>>1]=0;break td}m=x[f+32>>2];e=z[m+3840>>1];if(e&3){m=(z[f+36>>1]>>>7&7)>>>!y[m+3844|0]>>>(e&1)<<z[f+38>>1];e=e&4?0-m|0:m}else{e=0}m=x[f+52>>2];ud:{if(m){t=z[m+32>>1];r=z[f+48>>1];e=e<<16>>16;m=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);l=x[f+40>>2];s=x[f+20>>2];if(!t){if(!r){m=Dg(s,l,e,m,0);m=Dg(x[f+24>>2],x[f+40>>2],e,m,0);e=Dg(x[f+28>>2],x[f+40>>2],e,m,0);break ud}l=Dg(s,l,e,0,0);l=Dg(x[f+24>>2],x[f+40>>2],e,l,0);e=Dg(x[f+28>>2],x[f+40>>2],e,l,0)+m|0;break ud}if(!r){m=Dg(s,l,e,m,0);l=Dg(x[f+24>>2],x[f+40>>2],e,0,0);e=Dg(x[f+28>>2],x[f+40>>2],e,l,0)+m|0;break ud}l=Dg(s,l,e,0,0);e=(Dg(x[f+24>>2],x[f+40>>2],e,l,0)+m|0)+Dg(x[f+28>>2],x[f+40>>2],e,0,0)|0;break ud}r=z[f+48>>1];e=e<<16>>16;m=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);l=x[f+40>>2];s=x[f+20>>2];if(!r){e=Dg(s,l,e,m,0);break ud}e=Dg(s,l,e,0,0)+m|0}w[a+14>>1]=y[f+57|0]?e:0;w[a+12>>1]=y[f+58|0]?e:0}o=o+1|0;i=w[a+12>>1]+i|0;j=w[a+14>>1]+j|0;continue}break}j=x[g>>2];a=x[g+4>>2]-j|0;x[g+4>>2]=a;continue}break}e=j-a|0;w[k+14>>1]=(D(w[g+12>>1],a)+D(e,w[g+8>>1])|0)/(j|0);w[k+12>>1]=(D(w[g+14>>1],a)+D(e,w[g+10>>1])|0)/(j|0);x[g+4>>2]=a+49716;x[b>>2]=x[b>>2]+D(q,w[k+14>>1]);x[b+4>>2]=x[b+4>>2]+D(q,w[k+12>>1]);b=b+8|0;c=c-1|0;continue}}fb=k+16|0}a=y[I+12|0];if(a|x[I+16>>2]){if(!a){Qn(aa,n,ta,sa)}a=x[I>>2];b=x[I+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[I+98>>1]=c;w[I+96>>1]=c;c=x[I+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[I+49946>>1]=f;e=e+255>>>4|0;w[I+49944>>1]=e;w[I+49942>>1]=e;w[I+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;j=0;while(1){if((j|0)!=(n|0)){b=j<<3;c=b+X|0;x[c>>2]=x[c>>2]+D(a,x[b+aa>>2]>>4);b=b|4;c=b+X|0;x[c>>2]=x[c>>2]+D(a,x[b+aa>>2]>>4);j=j+1|0;continue}break}k=I+68|0;o=0;c=w[I+84>>1];a=x[I+40>>2];f=x[I+36>>2];while(1){if((n|0)==(o|0)){x[I+40>>2]=a;x[I+36>>2]=f}else{b=(o<<3)+aa|0;e=x[b>>2]>>12;f=(D(c,e-f|0)>>15)+e|0;x[b>>2]=f;e=b;b=x[b+4>>2]>>12;a=(D(c,b-a|0)>>15)+b|0;x[e+4>>2]=a;o=o+1|0;continue}break}g=n;if(g){c=aa;b=g;o=x[k>>2]-1|0;e=z[k+22>>1];m=z[k+20>>1];a=w[k+26>>1];f=w[k+24>>1];s=w[k+18>>1];h=w[k+16>>1];u=x[k+4>>2];j=k+32928|0;while(1){if(b){i=nd(x[c>>2]);l=nd(x[c+4>>2]);m=nd((m<<16>>16)-i|0);e=nd((e<<16>>16)-l|0);m=ed(nd((D(h,m)|0)/65536<<1)+i|0);e=ed(nd((D(e,s)|0)/65536<<1)+l|0);l=j+(u<<2)|0;q=w[l>>1];i=ed(((D(q,f)|0)/-65536|0)+m|0);u=u+1&127;r=j+(u<<2)|0;l=w[l+2>>1];t=ed(((D(l,a)|0)/-65536|0)+e|0);w[r+2>>1]=t;w[r>>1]=i;o=o+1&8191;r=k+(o<<2)|0;Sa=r,Ta=ed(q+((D(f,i)|0)/65536|0)|0),w[Sa+160>>1]=Ta;Sa=r,Ta=ed(l+((D(a,t)|0)/65536|0)|0),w[Sa+162>>1]=Ta;c=c+8|0;b=b-1|0;continue}break}w[k+22>>1]=e;w[k+20>>1]=m;x[k+4>>2]=u}j=I+49892|0;t=I+33508|0;c=g;b=aa;while(1){if(c){f=x[I+76>>2];m=f&4095;e=t+(m<<2)|0;a=b;m=4096-m|0;r=f-x[I+49892>>2]&4095;f=4096-r|0;f=f>>>0>m>>>0?m:f;f=c>>>0<f>>>0?c:f;f=f>>>0>=64?64:f;u=f;l=0;m=fb-32|0;fb=m;i=x[k>>2];while(1){if((l|0)==7){vd:{h=w[k+28>>1]/8<<16>>16;wd:while(1){if(!u){break vd}u=u-1|0;l=0;i=0;s=0;while(1)if((l|0)==4){l=4;o=0;G=ed((s|0)/32768|0);M=ed((i|0)/32768|0);i=0;while(1)if((l|0)==7){i=ed(G+((i|0)/32768|0)|0);w[e>>1]=i;x[a>>2]=D(h,i);i=ed(M+((o|0)/32768|0)|0);w[e+2>>1]=i;x[a+4>>2]=D(h,i);a=a+8|0;e=e+4|0;continue wd}else{s=m+(l<<2)|0;q=x[s>>2]+1&8191;x[s>>2]=q;_=o;o=k+(q<<2)|0;q=w[o+160>>1];s=k+(l<<4)|0;R=w[o+162>>1];o=(_+D(q,w[s+44>>1])|0)+D(R,w[s+46>>1])|0;i=(D(q,w[s+40>>1])+i|0)+D(R,w[s+42>>1])|0;l=l+1|0;continue}}else{o=m+(l<<2)|0;q=x[o>>2]+1&8191;x[o>>2]=q;_=i;i=k+(q<<2)|0;q=w[i+160>>1];o=k+(l<<4)|0;G=w[i+162>>1];i=(_+D(q,w[o+44>>1])|0)+D(G,w[o+46>>1])|0;s=(D(q,w[o+40>>1])+s|0)+D(G,w[o+42>>1])|0;l=l+1|0;continue}}}}else{x[m+(l<<2)>>2]=i+(x[(k+(l<<4)|0)+32>>2]^-1);l=l+1|0;continue}break}fb=m+32|0;L=t+(r<<2)|0;e=b;a=f;G=j+2|0;i=x[j+4>>2];m=j+24640|0;o=j+16448|0;while(1){l=i&2047;if(a){T=j+8256|0;M=w[T+((i+1206&2047)<<2)>>1];h=j- -64|0;r=w[h+((i+1750&2047)<<2)>>1];R=w[(G+((i+754&2047)<<2)|0)+8256>>1];u=w[(G+((i+1602&2047)<<2)|0)- -64>>1];s=w[L>>1];q=w[L+2>>1];H=m+((i+502&2047)<<2)|0;K=w[H>>1];C=nd(w[j+32>>1]-K|0);H=w[H+2>>1];P=nd(w[j+34>>1]-H|0);V=w[j+26>>1];W=m+((i+22&2047)<<2)|0;Y=w[W>>1];Z=nd(w[j+36>>1]-Y|0);$=w[j+28>>1];W=w[W+2>>1];ba=nd(w[j+38>>1]-W|0);ca=w[j+30>>1];K=ed(nd((D(C,w[j+24>>1])|0)/65536<<1)+K|0);w[j+32>>1]=K;Sa=j,Ta=ed(nd((D(P,V)|0)/65536<<1)+H|0),w[Sa+34>>1]=Ta;Sa=j,Ta=ed(nd((D(Z,$)|0)/65536<<1)+Y|0),w[Sa+36>>1]=Ta;H=ed(nd((D(ba,ca)|0)/65536<<1)+W|0);w[j+38>>1]=H;K=nd((D(K,w[j+16>>1])|0)/32768|0);C=nd((D(H,w[j+22>>1])|0)/32768|0);H=nd(((s|0)/4<<16>>16)+K|0);K=nd(C+((q|0)/4<<16>>16)|0);s=w[j+8>>1];C=nd(H+((D(s,r)|0)/-65536|0)|0);_=h;h=l<<2;P=_+h|0;q=w[j+10>>1];V=nd(K+((D(q,u)|0)/-65536|0)|0);w[P+2>>1]=V;w[P>>1]=C;r=nd(r+((D(s,C)|0)/65536|0)|0);C=h+o|0;P=nd(u+((D(q,V)|0)/65536|0)|0);w[C+2>>1]=P;w[C>>1]=r;u=nd(r+H|0);H=nd(K+P|0);r=o+((i+682&2047)<<2)|0;K=w[r+2>>1];C=w[r>>1];r=nd((D(K,w[j+42>>1])+D(C,w[j+40>>1])|0)/32768|0);i=o+((i+426&2047)<<2)|0;P=w[i+2>>1];V=w[i>>1];i=nd((D(P,w[j+46>>1])+D(V,w[j+44>>1])|0)/32768|0);C=nd(nd(u+C|0)-r|0);K=nd(nd(H+K|0)-i|0);u=nd(nd(u+V|0)-r|0);H=nd(nd(H+P|0)-i|0);r=nd(r+((D(s,M)|0)/-65536|0)|0);T=h+T|0;P=nd(i+((D(q,R)|0)/-65536|0)|0);w[T+2>>1]=P;w[T>>1]=r;s=(D(r,s)|0)/65536|0;i=nd(s+M|0);h=h+m|0;q=(D(q,P)|0)/65536|0;r=nd(q+R|0);w[h+2>>1]=r;w[h>>1]=i;Sa=e,Ta=(x[e>>2]+D(nd(i+C|0),w[j+48>>1])|0)+D(nd(r+K|0),w[j+50>>1])|0,x[Sa>>2]=Ta;Sa=e,Ta=(x[e+4>>2]+D(nd(nd(s)+u|0),w[j+52>>1])|0)+D(nd(nd(q)+H|0),w[j+54>>1])|0,x[Sa+4>>2]=Ta;e=e+8|0;i=l+1|0;L=L+4|0;a=a-1|0;continue}break}x[j+4>>2]=l;x[I+76>>2]=f+x[I+76>>2]&4095;x[I+68>>2]=f+x[I+68>>2]&8191;c=c-f|0;b=(f<<3)+b|0;continue}break}x[I+68>>2]=x[I+68>>2]&8191;o=aa;e=X;a=g;f=0;k=0;i=x[I+56>>2];c=x[I- -64>>2];j=x[I+52>>2];b=x[I+60>>2];while(1){if(a){f=x[o>>2];k=x[o+4>>2];c=c-k|0;c=(((c|0)/1024|0)-c|0)+i|0;x[e+4>>2]=c+x[e+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;x[e>>2]=b+x[e>>2];i=c+((c|0)/-512|0)|0;j=b+((b|0)/-512|0)|0;e=e+8|0;o=o+8|0;a=a-1|0;b=f;c=k;continue}break}x[I+64>>2]=k;x[I+60>>2]=f;x[I+56>>2]=i;x[I+52>>2]=j;a=x[I+20>>2];xd:{if(y[I+12|0]){break xd}a=x[I+16>>2];if(a>>>0>g>>>0){a=a-g|0;break xd}WP(I,ta,sa);a=0}v[I+12|0]=0;x[I+16>>2]=a}if(x[d+946300>>2]){yd:{l=0;e=0;f=n<<2;h=d+906300|0;u=z[d+480214>>1]!=0;Ba=B[d+1074336>>2];U=B[d+1074332>>2];while(1)if((l|0)==250){m=d+12|0;k=d+12300|0;o=d+14348|0;Vw(m,k,o,n,U);a=d+1074476|0;G=y[a|0];v[a|0]=0;b=o;a=k;while(1){zd:{Ad:{Bd:{if((e|0)!=250){s=vd(h,e);g=x[s>>2];if(!g|!x[g+24>>2]){break zd}if(!zi(g+44|0)){break zd}i=g;Cd:{if(Kp(y[s+24|0])){break Cd}c=ib[x[x[g>>2]+148>>2]](g)|0;i=x[s>>2];if(c){break Cd}l=0;if(y[i+28|0]&2){break Cd}while(1){if((e|0)==(l|0)){break zd}c=vd(h,l);l=l+1|0;if((um(x[c+28>>2])|0)!=(e|0)){continue}break}}c=x[g+44>>2];q=Hc(c,0);r=Hc(c,1);t=(a|0)==(q|0);a=t?k:a;j=a;b=t?o:b;f=x[s+28>>2];c=b;Dd:{if(!f){break Dd}f=um(f);c=b;if(f>>>0<=e>>>0){break Dd}c=b;if(f>>>0>249){break Dd}c=b;if(!x[vd(h,f)>>2]){break Dd}f=x[vd(h,f)>>2];if(!(y[i+28|0]&4)){ib[x[x[f>>2]+152>>2]](f)}c=b;if(!zi(f+44|0)){break Dd}c=x[f+44>>2];j=Hc(c,0);c=Hc(c,1)}if(!Kp(y[s+24|0])){break Ad}l=0;Ed:{if(t){break Ed}while(1){if((l|0)==(n|0)){break Ed}f=l<<2;t=f+q|0;M=a+f|0;B[t>>2]=B[M>>2]+B[t>>2];t=f+r|0;f=b+f|0;B[t>>2]=B[f>>2]+B[t>>2];x[M>>2]=0;x[f>>2]=0;l=l+1|0;continue}}b=c;a=j;if(!(u&1)){break Ad}a=x[s>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}f=um(x[s+28>>2]);b=e;while(1){a=f;f=a&255;if(f>>>0>249|f>>>0<=(b&255)>>>0){break Bd}l=vd(h,f);f=um(x[l+28>>2]);b=a;a=x[l>>2];if(!a){continue}ib[x[x[a>>2]+152>>2]](a);continue}}c=0;while(1){if((c|0)!=(n|0)){U=E(B[a>>2]*Ba);Fd:{if(E(F(U))<E(2147483648)){e=~~U;break Fd}e=-2147483648}x[m>>2]=e;U=E(B[b>>2]*Ba);Gd:{if(E(F(U))<E(2147483648)){e=~~U;break Gd}e=-2147483648}x[m+4>>2]=e;c=c+1|0;m=m+8|0;b=b+4|0;a=a+4|0;continue}break}break yd}b=c;a=j}Hd:{Id:{f=y[s+24|0];if(!VF(f)){if(!UF(f)|!(y[i+28|0]&4)){break Id}}l=0;while(1){if((l|0)==(n|0)){break Hd}f=l<<2;g=f+j|0;B[g>>2]=B[f+q>>2]+B[g>>2];g=c+f|0;B[g>>2]=B[f+r>>2]+B[g>>2];l=l+1|0;continue}}if(G){ib[x[x[g>>2]+132>>2]](g)}ib[x[x[g>>2]+60>>2]](g,j,c,n);x[i+32>>2]=n+x[i+32>>2];if(!UF(y[s+24|0])){break Hd}if((ib[x[x[g>>2]+160>>2]](g)|0)<=0){break Hd}l=0;if(A[i+32>>2]<x[d+24620>>2]<<2>>>0){break Hd}Jd:{while(1){if((l|0)==(n|0)){break Jd}f=l<<2;U=B[f+j>>2];Kd:{if(U>=E(1.1920928955078125e-7)|U<=E(-1.1920928955078125e-7)){break Kd}U=B[c+f>>2];if(U>=E(1.1920928955078125e-7)){break Kd}l=l+1|0;if(!(U<=E(-1.1920928955078125e-7))){continue}}break}x[i+32>>2]=0;break Hd}x[i+28>>2]=x[i+28>>2]|4}x[i+28>>2]=x[i+28>>2]&-3}e=e+1|0;continue}}else{j=vd(h,l);a=x[j>>2];Ld:{if(!a|!x[a+24>>2]){break Ld}if(!zi(a+44|0)){break Ld}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Hc(c,0);c=Hc(c,1);Md:{if(v[a+28|0]&1){Vw(x[a+24>>2],b,c,n,U);break Md}g=a+40|0;if(x[g>>2]|x[a+36>>2]){Qn(x[a+24>>2],n,g,a+36|0);Vw(x[a+24>>2],b,c,n,U);break Md}Sb(b,0,f);Sb(c,0,f)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(Kp(y[j+24|0])){break Ld}u=!(a&4)|u}l=l+1|0;continue}}}if(x[d+24624>>2]==1){c=0;while(1){if((c|0)!=(n|0)){a=(c<<3)+X|0;x[(c<<2)+X>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(Ed(y[d+1074365|0])){a=0;j=fb-16|0;fb=j;Nd:{if(!x[d+1074376>>2]){o=d+1074460|0;b=o;x[b>>2]=0;x[b+4>>2]=0;b=x[d+1074456>>2];x[d+1074468>>2]=b;break Nd}b=x[d+1074456>>2];c=x[d+1074468>>2];Od:{if((b|0)==(c|0)){e=x[d+1074460>>2];break Od}x[d+1074468>>2]=b;e=x[d+24620>>2];f=d+1074460|0;Pd:{if((b|0)>(c|0)){e=dv(e,x[d+24636>>2]);break Pd}e=dv(e,x[d+24640>>2])}x[f>>2]=e;x[d+1074464>>2]=e;c=b}o=d+1074460|0;if((e|0)<=0){break Nd}c=(c<<12)-x[d+1074472>>2]|0;a=(c|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Nd}x[j+12>>2]=50;f=x[d+1074464>>2];x[j+8>>2]=1e4/(f+1|0);g=x[Ze(j+12|0,j+8|0)>>2];while(1){k=a>>31;if((g|0)>=((k^a)-k|0)){break Nd}e=e+f|0;x[o>>2]=e;a=(c|0)/(e|0)|0;continue}}Qd:{Rd:{switch(x[d+24624>>2]-1|0){case 0:g=b<<12;e=d+12|0;k=b>>31;c=0;while(1){if((c|0)==(n|0)){break Qd}Sd:{if(x[o>>2]>0){f=x[d+1074472>>2]+a|0;x[d+1074472>>2]=f;m=x[e>>2];Sa=e,Ta=Gc(ova(nva(m,m>>31,f,f>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Sd}f=x[e>>2];Sa=e,Ta=Gc(ova(nva(f,f>>31,b,k),hb,256,0),hb),x[Sa>>2]=Ta;x[d+1074472>>2]=g}c=c+1|0;e=e+4|0;continue};case 1:k=b<<12;e=d+12|0;f=b>>31;c=0;while(1){if((c|0)==(n|0)){break Qd}Td:{if(x[o>>2]>0){g=x[d+1074472>>2]+a|0;x[d+1074472>>2]=g;m=x[e>>2];Sa=e,Ta=Gc(ova(nva(m,m>>31,g,g>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;g=x[d+1074472>>2];i=g;l=g>>31;g=x[e+4>>2];Sa=e,Ta=Gc(ova(nva(i,l,g,g>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Td}g=x[e>>2];Sa=e,Ta=Gc(ova(nva(g,g>>31,b,f),hb,256,0),hb),x[Sa>>2]=Ta;g=x[e+4>>2];Sa=e,Ta=Gc(ova(nva(g,g>>31,b,f),hb,256,0),hb),x[Sa+4>>2]=Ta;x[d+1074472>>2]=k}c=c+1|0;e=e+8|0;continue};case 3:break Rd;default:break Qd}}m=b<<12;e=d+8204|0;c=d+12|0;f=b;g=b>>31;b=0;while(1){if((b|0)==(n|0)){break Qd}Ud:{if(x[o>>2]>0){k=x[d+1074472>>2]+a|0;x[d+1074472>>2]=k;i=x[c>>2];Sa=c,Ta=Gc(ova(nva(i,i>>31,k,k>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;k=x[d+1074472>>2];i=k;l=k>>31;k=x[c+4>>2];Sa=c,Ta=Gc(ova(nva(i,l,k,k>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;k=x[d+1074472>>2];i=k;l=k>>31;k=x[e>>2];Sa=e,Ta=Gc(ova(nva(i,l,k,k>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;k=x[d+1074472>>2];i=k;l=k>>31;k=x[e+4>>2];Sa=e,Ta=Gc(ova(nva(i,l,k,k>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Ud}k=x[c>>2];Sa=c,Ta=Gc(ova(nva(k,k>>31,f,g),hb,256,0),hb),x[Sa>>2]=Ta;k=x[c+4>>2];Sa=c,Ta=Gc(ova(nva(k,k>>31,f,g),hb,256,0),hb),x[Sa+4>>2]=Ta;k=x[e>>2];Sa=e,Ta=Gc(ova(nva(k,k>>31,f,g),hb,256,0),hb),x[Sa>>2]=Ta;k=x[e+4>>2];Sa=e,Ta=Gc(ova(nva(k,k>>31,f,g),hb,256,0),hb),x[Sa+4>>2]=Ta;x[d+1074472>>2]=m}b=b+1|0;e=e+8|0;c=c+8|0;continue}}fb=j+16|0}if(x[qa>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];Vd:{if((a|0)==128|e>>>0<2){break Vd}TR(b,n,a);if(e>>>0<4){break Vd}TR(c,n,a)}}b=x[d+24624>>2];if((b|0)==4){b=n;while(1){b=b-1|0;if((b|0)>=0){a=(b<<4)+X|0;c=b<<3;e=c|4;x[a+12>>2]=x[e+ra>>2];x[a+8>>2]=x[c+ra>>2];x[a+4>>2]=x[e+X>>2];x[a>>2]=x[c+X>>2];continue}break}b=x[d+24624>>2]}if(Ed(Da)){x[J- -64>>2]=n;x[J+60>>2]=b;x[J+56>>2]=X;a=x[x[oa>>2]+8>>2];x[J+24>>2]=n;b=x[J+60>>2];x[J+16>>2]=x[J+56>>2];x[J+20>>2]=b;ib[a|0](oa,J+16|0);b=x[d+24624>>2]}x[J+52>>2]=n;x[J+48>>2]=b;x[J+44>>2]=X;a=x[x[na>>2]+8>>2];x[J+8>>2]=n;b=x[J+48>>2];x[J>>2]=x[J+44>>2];x[J+4>>2]=b;ib[a|0](na,J);x[d+1074380>>2]=x[d+1074380>>2]-n;x[d+1074376>>2]=n+x[d+1074376>>2];ia=ia-n|0;Ca=n+Ca|0;continue}break}fb=ea+32|0;return Ca}function fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=E(0),q=E(0),s=0,t=0,u=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,O=0,V=0;k=fb-2240|0;fb=k;a:{b:{c:{d:{e:{f:{if(Yw(x[c>>2])){wc(b,268435456);L=x[c+8>>2];H=k+2220|0;x[H>>2]=0;x[H+4>>2]=0;Nb(H+8|0);x[k+2216>>2]=0;g:{h:{i:{j:{k:{l:{m:{f=y[a+3|0];n:{o:{if((f-4&255)>>>0<=4){x[31725]=0;g=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[k+2216>>2]=g;break o}if(f>>>0>17){break n}p:{d=1<<f;if(!(d&63503)){if(!(d&198144)){break n}break p}if(y[a|0]){break p}break o}f=0;d=wD(a,x[b>>2]);x[31725]=0;e=k+48|0;S(188,e|0,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break l}d=x[e+4>>2];x[H>>2]=x[e>>2];x[H+4>>2]=d;En(H+8|0,e+8|0);Kc(e);e=$e(H);g=x[H>>2];x[k+2216>>2]=g;if(!e){break g}}f=y[a+3|0]}q:{r:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:i=!y[a|0];case 9:case 10:case 16:case 17:d=x[b>>2];if(!(d>>>0<262145|i)){f=f&255;x[k+48>>2]=((f|0)==10)<<4;g=g-x[Gb(k+48|0,k+2216|0)>>2]|0;if(f>>>0>15){break k}s:{if(!(1<<f&63503)){if((f|0)==10){break s}break k}if(!(y[a|0]&7)){break k}}d=(g|0)<0?-1:g<<1;break j}f=f&255;if(f>>>0>8){break h}if(1<<f&432){break q}if((f|0)!=6){break h}break;case 4:case 5:case 7:case 8:break q;case 6:break r;default:break i}}f=0;if(g>>>0<10){break g}x[31725]=0;P(185,c|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[31725]=0;d=R(153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){x[k+48>>2]=d;x[k+28>>2]=x[k+2216>>2];d=x[Gb(k+48|0,k+28|0)>>2];Gh(c,8);d=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}d=8/(pr(y[a+1|0])>>>0)|0;f=D(d,g);nva(d,0,g,0);d=hb?-1:f;break j}a=N()|0;break a}a=N()|0;break a}d=0;h=pr(y[a+1|0]);t:{u:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:d=y[a|0];break t;case 9:d=16;break t;case 10:d=4;break t;case 16:case 17:break u;default:break t}}d=8}d=D(h,d&255)>>>3|0;f=(d+g|0)-1|0;d=((f>>>0<g>>>0?-1:f)>>>0)/(d>>>0)|0}wc(b,d)}d=x[b>>2]}if(!d){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Fh(b)){f=0;x[b>>2]=0;break g}v:{d=k+48|0;if(ne(a,Xc(d,8,1,0,10))){x[31725]=0;a=P(205,c|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){f=0;if(!a){break v}a=x[b>>2];g=0;x[31725]=0;x[k+28>>2]=a+1>>>1;a=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}wc(k+28|0,a);a=e+16|0;b=x[b+20>>2];e=x[k+28>>2];f=e;while(1)if(f){d=k+48|0;g=y[d|y[a|0]&15]+g|0;v[b|0]=g;g=y[d|y[a|0]>>>4]+(g&255)|0;v[b+1|0]=g;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=e+16|0;break v}}a=N()|0;break a}w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{d=y[a+3|0];switch(d-4|0){case 3:break C;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break E}}x[31725]=0;a=ba(206,k+1128|0,c|0,b|0,(d|0)==5|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}ub(a);f=x[c+8>>2]-L|0;break v}if(y[a+1|0]!=1){break D}x[31725]=0;P(185,c|0,4)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;a=R(153,c|0)|0;e=x[31725];x[31725]=0;J:{K:{L:{if((e|0)!=1){x[31725]=0;x[k+28>>2]=a;d=R(199,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break L}x[31725]=0;e=k+48|0;S(207,e|0,c|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break K}wc(k+28|0,x[k+48>>2]);a=x[k+28>>2];Sn(k+1120|0,e);bc(k+1112|0,x[b+20>>2],Wk(x[b>>2],z[b+34>>1]));x[31725]=0;aa(208,x[k+1120>>2],x[k+1124>>2],x[k+1112>>2],x[k+1116>>2],d<<24>>24);b=x[31725];x[31725]=0;if((b|0)==1){break J}f=a+9|0;Kc(e);break v}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Kc(k+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break D}d=x[k+2216>>2];a=bl(k+1110|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){h=y[e|0]+g|0;g=h+y[e+1|0]|0;w[b>>1]=g<<8|h&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}if(y[a+1|0]!=1|y[a|0]>16){break D}e=x[c+8>>2];d=x[c>>2];f=0;x[31725]=0;e=U(152,d|0,e|0,8)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}if(!e){break v}x[31725]=0;e=R(153,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[k+2216>>2]=e;if(e>>>0<4){break v}x[31725]=0;d=k+28|0;S(187,d|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}e=ps(k+48|0,d);ub(d);d=x[e>>2];x[31725]=0;d=R(209,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}f=d+4|0;h=y[a|0];j=(h|0)!=16;g=0;i=0;while(1){if(A[b>>2]<=i>>>0){break x}M:{if(j){break M}x[31725]=0;m=P(160,e|0,8)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break M}a=T(28848)|0;break y}x[31725]=0;t=P(160,e|0,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break z}x[31725]=0;a=P(160,e|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}N:{O:{P:{if(!a){d=8;while(1){x[31725]=0;a=P(160,e|0,1)|0;G=x[31725];x[31725]=0;if((G|0)==1){break N}if(a){break P}d=d+16|0;continue}}x[31725]=0;a=P(160,e|0,3)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break O}break z}x[31725]=0;a=P(160,e|0,4)|0;G=x[31725];x[31725]=0;if((G|0)==1){break z}a=a+d|0}g=(g&255)+(((t?-1:0)^a)&255)|0;Q:{if((h|0)!=16){v[x[b+20>>2]+i|0]=g;break Q}w[x[b+20>>2]+(i<<1)>>1]=m&255|g<<8}i=i+1|0;continue}break}a=T(28848)|0;break y}R:{if((d|0)==16){f=y[a|0];break R}f=y[a|0];if((d|0)!=17){break A}}if((f&255)!=16){break A}g=y[a+1|0];if((g-1&255)>>>0>1){break A}M=k,O=D(x[b>>2],pr(g)),x[M+48>>2]=O;wc(k+48|0,x[k+2216>>2]);a=x[b+20>>2];f=x[k+48>>2];if((d|0)==16){b=f;while(1){if(!b){break v}M=a,O=z[_b(28880,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break v}M=a,O=z[_b(29392,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}if((d|0)!=7){break B}}if(y[a+1|0]!=1|y[a|0]>16){break B}f=0;if(A[k+2216>>2]<5){break v}a=x[b+20>>2];e=z[b+34>>1];b=x[b>>2];x[31725]=0;f=U(210,c|0,a|0,Wk(b,e)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break v}break f}f=y[a|0]}g=(f&255)!=8;if(!(g|y[a+1|0]!=1)){S:{switch(d|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break S}}a=x[k+2216>>2];d=qv(k+27|0);f=x[b>>2];b=x[b+20>>2];g=y[d|0];d=fb-16|0;fb=d;x[d+12>>2]=a;x[d+8>>2]=f;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}fb=d+16|0;f=a;break v}if(!(y[a+1|0]!=3|g)){T:{switch(d|0){case 0:g=fb-16|0;fb=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Gb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Gb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};fb=g+16|0;f=d+f|0;break v;case 1:g=fb-16|0;fb=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Gb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Gb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};fb=g+16|0;f=d+f|0;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break T}}d=x[k+2216>>2];f=y[qv(k+26|0)|0];t=fb-16|0;fb=t;x[t+12>>2]=d;g=x[b>>2];x[t+8>>2]=g;h=t+8|0;i=x[Gb(h,t+12|0)>>2];x[t+8>>2]=g;x[t+4>>2]=d-i;j=x[Gb(h,t+4|0)>>2];g=b;m=x[b+20>>2];h=f;b=i;d=e;while(1){if(b){h=y[d|0]+h|0;v[m|0]=h;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}m=x[g+20>>2]+1|0;d=x[g>>2]+e|0;b=j;while(1){if(b){f=y[d|0]+f|0;v[m|0]=f;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}fb=t+16|0;f=i+j|0;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break v}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}g=f&255;if(!((g|0)!=8|y[a+1|0]!=2)){f=0;U:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 2:break U;default:break v}}d=x[k+2216>>2];a=qv(k+25|0);h=x[b>>2];g=x[b+20>>2];a=y[a|0];f=fb-16|0;fb=f;x[f+12>>2]=d>>>1;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=1))){V:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break V}}d=x[k+2216>>2];a=bl(k+22|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){f=0;W:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 2:break W;default:break v}}d=x[k+2216>>2];a=bl(k+20|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=3))){X:{switch(d|0){case 0:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 1:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break X}}d=x[k+2216>>2];f=z[bl(k+18|0)>>1];i=fb-16|0;fb=i;x[i+12>>2]=d;j=x[b>>2]<<1;x[i+8>>2]=j;g=i+8|0;m=x[Gb(g,i+12|0)>>2];x[i+8>>2]=j;x[i+4>>2]=d-m;t=x[Gb(g,i+4|0)>>2];g=b;h=x[b+20>>2];b=f;G=m>>>1|0;m=G;d=e;while(1){if(m){b=(y[d|0]+b|0)+(y[d+1|0]<<8)|0;w[h>>1]=b;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}d=e+j|0;h=x[g+20>>2]+2|0;b=t>>>1|0;m=b;while(1){if(m){f=(y[d|0]+f|0)+(y[d+1|0]<<8)|0;w[h>>1]=f;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}fb=i+16|0;f=b+G<<1;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break v}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}g=f&255;if(!((g|0)!=16|y[a+1|0]!=3|y[a+2|0]!=1)){f=0;Y:{switch(d|0){case 0:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=m<<8|m>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=e<<8|e>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 1:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=(m<<8|m>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=(e<<8|e>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 2:break Y;default:break v}}d=x[k+2216>>2];a=z[bl(k+16|0)>>1];f=fb-16|0;fb=f;x[f+12>>2]=d;j=x[b>>2]<<1;x[f+8>>2]=j;h=f+8|0;g=x[Gb(h,f+12|0)>>2];x[f+8>>2]=j;x[f+4>>2]=d-g;m=x[Gb(h,f+4|0)>>2];d=b;i=x[d+20>>2];b=a;t=g>>>1|0;h=t;g=e;while(1){if(h){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[i>>1]=b;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}g=e+j|0;i=x[d+20>>2]+2|0;b=m>>>1|0;h=b;while(1){if(h){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[i>>1]=a;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}fb=f+16|0;f=b+t<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=2))){f=0;Z:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 2:break Z;default:break v}}d=x[k+2216>>2];a=bl(k+14|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=fb-16|0;fb=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<2;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=2|y[a+2|0]!=1)){f=0;_:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=g<<8|g>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(g<<8|g>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 2:break _;default:break v}}d=x[k+2216>>2];a=bl(k+12|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=fb-16|0;fb=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<2;break v}if(!(d|y[a+1|0]!=1|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,3);break v}a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,3);break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;M=f,O=qd(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=O;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,6);break v}a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;M=f,O=qd(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=O;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,6);break v}if(!(d|y[a+1|0]!=1|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<2;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<2;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;M=f,O=qd(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<3;break v}if(!(d|y[a+1|0]!=1|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;h=x[Gb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=h<<3;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;M=f,O=Rc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<4;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;h=x[Gb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=O;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+16|0;f=h<<4;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));$:{if(E(F(o))<E(2147483648)){g=~~o;break $}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<2;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));aa:{if(E(F(o))<E(2147483648)){d=~~o;break aa}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<2;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ba:{if(E(F(o))<E(2147483648)){g=~~o;break ba}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;o=cg((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ca:{if(E(F(o))<E(2147483648)){g=~~o;break ca}g=-2147483648}M=f,O=ed(g),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));da:{if(E(F(o))<E(2147483648)){d=~~o;break da}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=ri(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ea:{if(E(F(o))<E(2147483648)){d=~~o;break ea}d=-2147483648}M=f,O=ed(d),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<3;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-32|0;fb=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;d=x[Gb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);fa:{if(F(s)<2147483648){g=~~s;break fa}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+32|0;f=d<<3;break v}a=fb-32|0;fb=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;h=x[Gb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ga:{if(F(s)<2147483648){d=~~s;break ga}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+32|0;f=h<<3;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-32|0;fb=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;d=x[Gb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ha:{if(F(s)<2147483648){g=~~s;break ha}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ia:{if(F(s)<2147483648){g=~~s;break ia}g=-2147483648}M=f,O=ed(g),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+32|0;f=d<<4;break v}a=fb-32|0;fb=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;h=x[Gb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ja:{if(F(s)<2147483648){d=~~s;break ja}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ka:{if(F(s)<2147483648){d=~~s;break ka}d=-2147483648}M=f,O=ed(d),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+32|0;f=h<<4;break v}la:{if((g|0)==24){if((d|0)!=15|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=-2147483648;d=x[k+2216>>2];ma:{if(!y[a+2|0]){m=k+48|0;f=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;na:{oa:{pa:{if((j|0)>=0){d=j;break pa}d=-2147483648;if((j|0)==-2147483648){break oa}d=0-j|0}if(d>>>0<=f>>>0){break na}}f=d}i=i-1|0;a=a+3|0;continue}else{qa:{if(!f){break qa}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break qa}j=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;ra:{if((d|0)>0|(d|0)>=0){d=pva(j,d,f,0);j=hb;break ra}j=pva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}fb=h+16|0;f=D(g,3);break ma}m=k+48|0;f=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;sa:{ta:{ua:{if((j|0)>=0){d=j;break ua}d=-2147483648;if((j|0)==-2147483648){break ta}d=0-j|0}if(d>>>0<=f>>>0){break sa}}f=d}i=i-1|0;a=a+3|0;continue}else{va:{if(!f){break va}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break va}j=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;wa:{if((d|0)>0|(d|0)>=0){d=pva(j,d,f,0);j=hb;break wa}j=pva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}fb=h+16|0;f=D(g,3)}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=nva(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,O=Kd(Bc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}g=f&255;if((g|0)==32){if(!((d|0)!=15|(y[a+1|0]-1&255)>>>0>1)){x[k+48>>2]=-2147483648;d=x[k+2216>>2];xa:{if(!y[a+2|0]){m=k+48|0;a=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){j=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);ya:{za:{Aa:{if((j|0)>=0){d=j;break Aa}d=-2147483648;if((j|0)==-2147483648){break za}d=0-j|0}if(d>>>0<=a>>>0){break ya}}a=d}e=e-1|0;i=i+4|0;continue}else{Ba:{if(!a){break Ba}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ba}j=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=j&-2147483648|j>>>1;j=G|j<<31;Ca:{if((d|0)>0|(d|0)>=0){d=pva(j,d,a,0);j=hb;break Ca}j=pva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}fb=h+16|0;f=g<<2;break xa}m=k+48|0;a=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){d=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Da:{Ea:{Fa:{if((j|0)>=0){d=j;break Fa}d=-2147483648;if((j|0)==-2147483648){break Ea}d=0-j|0}if(a>>>0>=d>>>0){break Da}}a=d}e=e-1|0;i=i+4|0;continue}else{Ga:{if(!a){break Ga}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ga}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);d=j&-2147483648|j>>>1;j=G|j<<31;Ha:{if((d|0)>0|(d|0)>=0){d=pva(j,d,a,0);j=hb;break Ha}j=pva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}fb=h+16|0;f=g<<2}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=nva(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,O=Kd(Bc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=1065353216;d=x[k+2216>>2];Ia:{if(!y[a+2|0]){h=k+48|0;f=fb-16|0;fb=f;M=f,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){q=cg((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));q=E(F(Jg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{Ja:{a=o==E(0);if(a){break Ja}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break Ja}q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=ri(E(Pd(E(I*(Jg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ka:{if(E(F(q))<E(2147483648)){j=~~q;break Ka}j=-2147483648}M=g,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(h){B[h>>2]=o}fb=f+16|0;f=d<<2}break}break Ia}i=k+48|0;f=fb-16|0;fb=f;M=f,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);q=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=E(F(Jg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{La:{a=o==E(0);if(a){break La}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break La}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=ri(E(Pd(E(I*(Jg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ma:{if(E(F(q))<E(2147483648)){j=~~q;break Ma}j=-2147483648}M=g,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(i){B[i>>2]=o}fb=f+16|0;f=d<<2}break}}if(!f){break v}o=B[k+48>>2];if(o==E(1)){break v}o=ri(BB(E(o*E(z[b+32>>1])),E(1),E(64)));a=65535;Na:{if(o>=E(65535)){break Na}a=0;if(o<=E(0)){break Na}a=~~o>>>0;if(o<E(4294967296)&o>=E(0)){break Na}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1|(g|0)!=64){break la}x[k+48>>2]=0;x[k+52>>2]=1072693248;d=x[k+2216>>2];Oa:{if(!y[a+2|0]){h=k+48|0;g=fb-32|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,i|0);u=Ig(+n());u=F(zf(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Pa:{a=s==0;if(a){break Pa}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Pa}i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,i|0);u=Ig(+n());M=g,V=J*(zf(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);Qa:{if(F(u)<2147483648){j=~~u;break Qa}j=-2147483648}M=d,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=s}fb=g+32|0;f=f<<3}break}break Oa}j=k+48|0;g=fb-32|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){h=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=Ig(+n());u=F(zf(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Ra:{a=s==0;if(a){break Ra}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Ra}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=Ig(+n());M=g,V=J*(zf(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);Sa:{if(F(u)<2147483648){h=~~u;break Sa}h=-2147483648}M=d,O=ed(h),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(j){C[j>>3]=s}fb=g+32|0;f=f<<3}break}}if(!f){break v}s=C[k+48>>3];if(s==1){break v}M=b,O=HD(Tv(s*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}Ta:{Ua:{Va:{Wa:{g=(f&255)!=32;Xa:{if(!(g|(y[a+1|0]!=1|(d|0)!=12))){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Xa}break Ta}if(!(y[a+1|0]!=2|(d|0)!=12|g)){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Va}break Ua}g=(f&255)!=32;if(g|(y[a+1|0]!=1|(d|0)!=13)){break Wa}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Ta}}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));Ya:{if(E(F(q))<E(2147483648)){g=~~q;break Ya}g=-2147483648}M=b,O=ed(g),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<2;break v}f=0;if(y[a+1|0]!=2|(d|0)!=13|g){break v}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Ua}}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));Za:{if(E(F(q))<E(2147483648)){g=~~q;break Za}g=-2147483648}M=b,O=ed(g),w[M>>1]=O;q=cg((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));_a:{if(E(F(q))<E(2147483648)){g=~~q;break _a}g=-2147483648}M=b,O=ed(g),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<3;break v}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;g=x[Gb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));$a:{if(E(F(q))<E(2147483648)){d=~~q;break $a}d=-2147483648}M=b,O=ed(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));ab:{if(E(F(q))<E(2147483648)){d=~~q;break ab}d=-2147483648}M=b,O=ed(d),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=a+16|0;f=g<<3;break v}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;g=x[Gb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=ri(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));bb:{if(E(F(q))<E(2147483648)){d=~~q;break bb}d=-2147483648}M=b,O=ed(d),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=a+16|0;f=g<<2;break v}a=T(28848)|0}if((gb|0)!=($(28848)|0)){break d}Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break w}}ub(e);break v}a=N()|0;break d}x[31725]=0;P(151,c|0,f+L|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}}Kc(H)}fb=k+2240|0;return f|0}a=N()|0;break a}a=N()|0}ub(e);break a}a=N()|0;break a}a=N()|0}Kc(H);Q(a|0);p()}function Nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;e=fb-608|0;fb=e;xc(b);d=fb-16|0;fb=d;g=e+416|0;mw(d+8|0,g);j=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(j|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(j|0);if(!d){VZ(g)}a:{b:{c:{if(!d){break c}if(!XZ(g)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(WZ(g),hb))){break c}if(!c){f=1;break c}Bd(a,32);v[e+415|0]=0;j=Fb(e+400|0);d:{e:{f:{g:{h:{i:{if((y[e+416|0]|y[e+417|0]<<8|(y[e+418|0]<<16|y[e+419|0]<<24))==778924148){x[31725]=0;O(419,a|0,16777216);d=x[31725];x[31725]=0;if((d|0)==1){break b}d=x[b>>2];x[31725]=0;d=R(156,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}x[31725]=0;P(151,b|0,d-4|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}x[31725]=0;u=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[e+456|0]|y[e+457|0]<<8)-2185&65535)>>>0>1910){break o}d=x[b>>2];x[31725]=0;d=R(156,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}x[31725]=0;P(151,b|0,d-4|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}x[31725]=0;u=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}if(u>>>0<256){break o}d=x[b>>2];x[31725]=0;d=R(156,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(d>>>0<=u>>>0){break o}x[31725]=0;d=P(151,b|0,u|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(!d){break o}x[31725]=0;d=R(420,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(!d){break o}x[31725]=0;O(419,a|0,16777216);d=x[31725];x[31725]=0;if((d|0)==1){break b}d=y[e+456|0]|y[e+457|0]<<8;if(d>>>0>=4096){x[31725]=0;c=P(1,e+160|0,16528)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c);break d}b=N()|0;tb(c);break a}if(d>>>0<2194){break o}x[31725]=0;d=P(1,e+388|0,16057)|0;f=x[31725];x[31725]=0;if((f|0)==1){break n}f=x[a+1298472>>2];x[31725]=0;S(387,f|0,4,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break m}tb(d)}if(x[a+480180>>2]!=32){break i}d=y[e+456|0]|y[e+457|0]<<8;if((d&61440)!=20480){break j}d=d&4095;f=d<<16;if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))!=1414548815){break l}v[e+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(d);break a}if(d>>>0<297){break k}f=y[e+476|0]|y[e+477|0]<<8|f}x[a+1074308>>2]=f;break i}f=y[e+458|0]|y[e+459|0]<<8;if(!((f|0)!=2184&(d|0)!=2184)){v[e+415|0]=1;x[a+1074308>>2]=18284544;break i}if((d|0)!=768){if((d|0)!=532|(f|0)!=514|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31725]=0;d=P(1,e+376|0,14700)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(j,d);tb(d);v[e+415|0]=1;break i}b=N()|0;break a}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|(f|0)!=768|((y[e+448|0]|y[e+449|0]<<8)!=256|y[e+468|0]!=128)){break i}if(y[e+469|0]){break i}x[a+1074308>>2]=18285088;v[e+415|0]=1}d=y[e+460|0]|y[e+461|0]<<8;f=d>>>2|0;x[a+480208>>2]=d<<3&32768|(f&8|(f&4|(x[a+480208>>2]&-32797|d<<1&16)));f=e+280|0;$r(f,e+420|0);x[31725]=0;d=e+160|0;O(220,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break g}Ab(a+1298308|0,d);tb(d);if(!(!(y[e+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[e+446|0];x[a+480220>>2]=y[e+447|0]}d=y[e+464|0];x[a+480200>>2]=d>>>0>128?256:d<<1;d=y[e+466|0];if(d){x[a+480196>>2]=d}v[e+160|0]=31;v[e+280|0]=y[e+467|0];d=e+160|0;f=e+280|0;M=a,T=D(y[ef(d,f)|0],1e4),x[M+480204>>2]=T;v[e+160|0]=y[e+465|0];v[e+280|0]=128;M=a,T=y[Rb(d,f)|0],x[M+480228>>2]=T;f=0;while(1){if((f|0)==64){p:{x[31725]=0;P(151,b|0,192)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}if(x[a+480180>>2]==16777216&((y[e+456|0]|y[e+457|0]<<8)-2187&65535)>>>0<=2){break p}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;aa(350,Xb(f,d)|0,b|0,y[e+448|0]|y[e+449|0]<<8,255,254);d=x[31725];x[31725]=0;if((d|0)==1){break b}break e}}else{h=(e+416|0)+f|0;i=h- -64|0;q:{if(y[i|0]==255){break q}g=(f<<5)+a|0;d=g+480280|0;Xe(d);M=g+480286|0,T=Kd(y[h+128|0],0,64),w[M>>1]=T;h=v[i|0];if((h|0)<0){x[d>>2]=x[d>>2]|1024}h=h&127;if(h>>>0<=64){w[g+480284>>1]=h<<2;break q}if((h|0)!=100){break q}x[d>>2]=x[d>>2]|256}f=f+1|0;continue}break}f=0;x[31725]=0;d=R(191,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}if(d){break d}x[31725]=0;d=R(153,b|0)|0;g=x[31725];x[31725]=0;r:{if((g|0)==1){break r}if(d>>>0>4e3){break d}g=y[a+484376|0];h=x[a+484360>>2];x[31725]=0;d=U(421,Xb(h,g)|0,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break r}if(!d){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}r=Nb(e+364|0);q=Nb(e+352|0);f=0;o=Nb(e+340|0);x[31725]=0;d=U(422,b|0,r|0,y[e+450|0]|y[e+451|0]<<8)|0;g=x[31725];x[31725]=0;s:{t:{u:{if((g|0)==1){break u}if(!d){break s}x[31725]=0;d=U(422,b|0,q|0,y[e+452|0]|y[e+453|0]<<8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}if(!d){break s}x[31725]=0;d=U(422,b|0,o|0,y[e+454|0]|y[e+455|0]<<8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}if(!d){break s}x[e+336>>2]=-1;M=e,T=wb(x[r>>2]),x[M+160>>2]=T;g=wb(x[r+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{M=e,T=wb(x[q>>2]),x[M+160>>2]=T;g=wb(x[q+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{M=e,T=wb(x[o>>2]),x[M+160>>2]=T;g=wb(x[o+4>>2]);d=x[e+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{if(v[e+462|0]&1){x[e+160>>2]=y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24);d=x[Gb(e+336|0,e+160|0)>>2];x[e+336>>2]=d}f=0;if((y[e+458|0]|y[e+459|0]<<8)!=532){break D}g=y[e+456|0]|y[e+457|0]<<8;if(y[e+447|0]|(g?(g|0)!=532:0)|(y[e+446|0]|y[e+469|0])){break D}if(y[e+460|0]&192|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break D}if(y[e+450|0]|y[e+451|0]<<8){break E}g=y[e+452|0]|y[e+453|0]<<8;if(!g){break E}if((x[b+8>>2]+(oc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>d>>>0){break E}}break}while(1){d=f&65535;if(d>>>0<(g&65535)>>>0){x[31725]=0;g=R(153,b|0)|0;h=x[31725];x[31725]=0;F:{if((h|0)!=1){if(!g){break F}Gh(b,(d<<2)+4|0);break E}b=N()|0;break t}f=f+1|0;g=y[e+452|0]|y[e+453|0]<<8;continue}break}x[31725]=0;d=P(1,e+324|0,14979)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}Ab(j,d);tb(d)}f=1;if(y[e+456|0]|y[e+457|0]<<8){break D}x[31725]=0;d=P(1,e+312|0,15486)|0;g=x[31725];x[31725]=0;if((g|0)==1){break B}Ab(j,d);tb(d)}d=y[e+462|0]|y[e+463|0]<<8;G:{if(d&2){x[31725]=0;g=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break w}d=x[b+8>>2];h=x[b>>2];x[31725]=0;i=d;d=g<<3;h=U(152,h|0,i|0,d|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break w}if(!(!h|A[e+336>>2]<d+x[b+8>>2]>>>0)){x[31725]=0;O(423,a+1298412|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break w}M=e,T=wb(x[a+1298412>>2]),x[M+280>>2]=T;h=wb(x[a+1298416>>2]);H:{I:{while(1){d=x[e+280>>2];if(!Ib(d,h)){if(!(!g&f)){break G}if(!(y[e+462|0]&4)){break H}x[31725]=0;d=P(1,e+300|0,15519)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}Ab(j,d);tb(d);break G}x[31725]=0;O(424,b|0,e+160|0);i=x[31725];x[31725]=0;if((i|0)!=1){x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;i=y[e+160|0]|y[e+161|0]<<8;if(i|(y[e+162|0]|y[e+163|0]<<8)){x[d>>2]=((i&65024)>>>9|0)+1980;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)>>>5&15,1,12),x[M+4>>2]=T;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)&31,1,31),x[M+8>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>11|0,0,23),x[M+12>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>5&63,0,59),x[M+16>>2]=T;i=Yb((y[e+162|0]|y[e+163|0]<<8)<<1&62,0,59);x[d+24>>2]=i;x[d+28>>2]=i>>31}x[d+32>>2]=y[e+164|0]|y[e+165|0]<<8|(y[e+166|0]<<16|y[e+167|0]<<24);x[e+280>>2]=x[e+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31725]=0;d=P(1,e+300|0,15001)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(j,d);tb(d);break G}b=N()|0;break t}Gh(b,2);break G}if(f^1|d>>>0>1){break G}x[31725]=0;d=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}if(!d){x[31725]=0;d=P(1,e+300|0,14979)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(j,d);tb(d);break G}b=N()|0;break t}Gh(b,2)}J:{if(!(y[e+460|0]&128|y[e+462|0]&8)){break J}x[31725]=0;d=a+901404|0;f=P(425,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break A}if(!f){break J}zD(d)}if((y[e+456|0]|y[e+457|0]<<8)>>>0<=531){rr(a+901404|0)}x[31725]=0;B=R(170,e+280|0)|0;d=x[31725];x[31725]=0;K:{L:{M:{if((d|0)!=1){x[31725]=0;f=P(414,b|0,13890)|0;d=x[31725];x[31725]=0;if((d|0)==1){break M}if(f){x[31725]=0;g=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break L}x[31725]=0;d=e+260|0;S(187,d|0,b|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break L}g=ic(e+160|0,d);hd(B,g);ub(g);ub(d)}w[a+480188>>1]=1;x[31725]=0;d=P(414,b|0,13895)|0;g=x[31725];x[31725]=0;if((g|0)==1){break M}if(!d){break y}x[31725]=0;d=R(153,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;S(187,e+260|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}f=e+260|0;d=ic(e+160|0,f);ub(f);g=x[d>>2];x[31725]=0;g=R(156,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break z}w[e+260>>1]=(g>>>0)/20;g=z[Nc(25012,f)>>1];w[a+480188>>1]=g;f=0;while(1){if((f|0)==(g|0)){ub(d);f=1;break y}x[31725]=0;S(426,d|0,((f<<5)+a|0)+480289|0,20);h=x[31725];x[31725]=0;if((h|0)!=1){f=f+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(d);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{d=x[e+336>>2];g=x[b+8>>2];W:{if(d>>>0>=g>>>0){d=d-g|0;break W}x[31725]=0;d=R(204,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break V}}x[31725]=0;g=e+160|0;S(187,g|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break V}C=ic(e+260|0,g);ub(g);x[31725]=0;d=e+258|0;S(427,d|0,a|0,C|0);g=x[31725];x[31725]=0;if((g|0)==1){break U}E=Jc(d);F=y[e+258|0]!=0|f;if((y[e+456|0]|y[e+457|0]<<8)!=535|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[E|0]|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break Q}X:{if(F){break X}f=Xb(x[a+484360>>2],y[a+484376|0]);d=x[f+4>>2];if(!lc(x[f>>2],d)){if(z[Nn(d)>>1]==65535){break X}}if(!fu(e+480|0,255,64)){break S}}x[a+1074308>>2]=18219008;x[31725]=0;d=P(1,e+244|0,14836)|0;f=x[31725];x[31725]=0;if((f|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31725]=0;d=P(1,e+244|0,16879)|0;f=x[31725];x[31725]=0;if((f|0)==1){break P}}Ab(j,d);tb(d);v[e+415|0]=1}Y:{if(!(v[e+462|0]&1)|!(y[e+470|0]|y[e+471|0]<<8)){break Y}x[31725]=0;d=P(151,b|0,y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24))|0;f=x[31725];x[31725]=0;if((f|0)==1){break O}if(!d){break Y}x[31725]=0;V(338,a+1298332|0,b|0,y[e+470|0]|y[e+471|0]<<8,4);d=x[31725];x[31725]=0;if((d|0)==1){break O}}w[a+480192>>1]=0;d=0;if(y[e+460|0]&4){w[e+160>>1]=y[e+450|0]|y[e+451|0]<<8;w[e+100>>1]=255;d=z[Nc(e+160|0,e+100|0)>>1];w[a+480192>>1]=d}f=0;Z:{while(1){if((d&65535)>>>0<=f>>>0){x[e+240>>2]=0;f=y[e+452|0]|y[e+453|0]<<8;if(f){d=yb(x[q>>2],f-1|0);x[e+240>>2]=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+80}w[e+160>>1]=f;w[e+100>>1]=3999;d=z[Nc(e+160|0,e+100|0)>>1];w[a+480190>>1]=d;m=c&2;s=e+180|0;f=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((d&65535)>>>0>f>>>0){d=yb(x[q>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(!d){break $}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;ha:{ia:{ja:{ka:{la:{if((g|0)==1){break la}if(!d){break $}x[31725]=0;d=e+160|0;g=P(428,b|0,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break la}if(!g){break $}x[31725]=0;g=f+1|0;h=D(g,104)+a|0;i=h+484380|0;k=P(429,d|0,i|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ka}n=e+148|0;$r(n,s);x[31725]=0;d=e+100|0;O(220,d|0,n|0);n=x[31725];x[31725]=0;if((n|0)==1){break ja}zc(((g<<5)+a|0)+946304|0,d);tb(d);x[31725]=0;k=P(151,b|0,k|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break ka}if(!k){break $}h=z[h+484414>>1];if(!(h&512)){break ia}x[31725]=0;d=P(430,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ga}if(!d){break ha}x[e+16>>2]=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);d=y[e+104|0]|y[e+105|0]<<8|(y[e+106|0]<<16|y[e+107|0]<<24);x[e+8>>2]=y[e+100|0]|y[e+101|0]<<8|(y[e+102|0]<<16|y[e+103|0]<<24);x[e+12>>2]=d;Zk(i,1,e+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(h&16384)){n=y[e+456|0]|y[e+457|0]<<8;t=e+100|0;h=y[e+178|0];k=h&2;d=y[e+206|0];g=Xc(t,k?16:8,1,0,(d^-1)&1);if(!(!(h&4)|n>>>0<532)){Cp(g,3)}ma:{na:{if(h&8){h=d&4?5:4;break na}if(!k){h=10;if((d|0)==255){break na}}if(d&2){v[g+2|0]=1}if(d&4){yg(g,2)}if(!(d&8)){break ma}h=9;if(!k){break ma}}yg(g,h)}if(m){d=0;x[31725]=0;U(217,t|0,i|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break ca}break _}d=1;g=y[e+103|0];if(g>>>0>17){break ba}h=1<<g;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[e+100|0]){break da}break ca}x[31725]=0;O(431,b|0,e+88|0);d=x[31725];x[31725]=0;if((d|0)==1){break ea}h=x[e+88>>2];if(!(!m|!h)){d=Fb(e+100|0);x[31725]=0;S(272,b|0,d|0,h|0);h=x[31725];x[31725]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31725]=0;h=e+136|0;O(385,h|0,16450);i=x[31725];x[31725]=0;if((i|0)==1){break ua}x[e+76>>2]=g;x[31725]=0;g=e+124|0;S(260,g|0,0,d|0);i=x[31725];x[31725]=0;if((i|0)==1){break ta}x[31725]=0;i=e+148|0;V(432,i|0,h|0,e+76|0,g|0);k=x[31725];x[31725]=0;if((k|0)==1){break sa}k=x[a+1298472>>2];x[31725]=0;S(387,k|0,2,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break ra}tb(i);tb(g);Eb(h);tb(d);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(e+148|0)}tb(e+124|0)}Eb(e+136|0)}tb(d);break N}x[31725]=0;P(185,b|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ea}}d=0;break aa}w[e+160>>1]=1;w[e+100>>1]=d;M=a,T=z[qe(e+160|0,e+100|0)>>1],w[M+480190>>1]=T;if(!((y[e+456|0]|y[e+457|0]<<8)==516&l)|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+462|0]|y[e+463|0]<<8|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break fa}if(((y[e+460|0]|y[e+461|0]<<8)&65527)!=21|y[e+464|0]!=128|(y[e+465|0]!=48|y[e+468|0]!=128)){break fa}if(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8)){break fa}d=e+544|0;g=e+480|0;f=1;while(1)if((d|0)==(g|0)){g=e+608|0;while(1)if((d|0)==(g|0)){d=20;while(1){if((d|0)==26){va:{if(!(f&1)){break fa}x[31725]=0;d=P(1,e+148|0,9879)|0;f=x[31725];x[31725]=0;if((f|0)==1){break va}Ab(j,d);tb(d);break fa}}else{f=!y[(e+d|0)+420|0]&f;d=d+1|0;continue}break}b=N()|0;break N}else{f=y[d|0]==64&f;d=d+1|0;continue}}else{f=(y[g|0]&127)==32&f;g=g+1|0;continue}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;f=oc(x[o>>2],x[o+4>>2]);w[e+160>>1]=f;d=e+160|0;s=z[Nc(d,x[a+8>>2]+10|0)>>1];w[e+122>>1]=s;wa:{xa:{ya:{za:{if((f|0)!=(s|0)){x[31725]=0;f=e+100|0;W(433,f|0);g=x[31725];x[31725]=0;if((g|0)==1){break wa}g=x[o+4>>2];h=x[o>>2];x[31725]=0;M=e,T=oc(h,g),x[M+136>>2]=T;V(434,d|0,f|0,e+136|0,e+122|0);g=x[31725];x[31725]=0;if((g|0)==1){break ya}g=x[a+1298472>>2];x[31725]=0;S(387,g|0,2,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break za}tb(d);Eb(f)}if(!(c&1)){w[e+122>>1]=0;s=0}h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(s|0)){c=x[e+240>>2];if(!c){break Oa}x[31725]=0;P(151,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Qa}if(!t){break Oa}while(1){Sa:{c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Sa}if(!c){break Oa}x[31725]=0;c=P(414,b|0,13869)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Sa}Ta:{if(!c){x[31725]=0;c=P(414,b|0,13874)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Sa}if(!c){break Ta}}x[31725]=0;c=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Pa}Gh(b,8);if(c&-2139062144){break Ta}if(c&1616928864){break Oa}}x[31725]=0;c=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Sa}x[31725]=0;P(185,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}b=N()|0;break N}Ua:{c=yb(x[o>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);Va:{if(!c){break Va}x[31725]=0;c=P(151,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Na}if(!c){break Va}x[31725]=0;d=R(191,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Aa}x[31725]=0;m=R(191,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ba}if((m-1025&65535)>>>0<64512){break Va}x[31725]=0;c=P(185,b|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ba}if(!c){break Va}x[31725]=0;c=e+100|0;S(187,c|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ca}d=ic(e+160|0,c);ub(c);c=z[a+480188>>1];l=0;x[31725]=0;g=P(435,e+136|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ea}Wa:{while(1){if(l>>>0>=m>>>0){break Wa}c=x[d>>2];x[31725]=0;c=U(152,c|0,x[e+168>>2],1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ua}if(!c){break Wa}x[31725]=0;c=R(199,d|0)|0;f=x[31725];x[31725]=0;Xa:{if((f|0)!=1){c=c<<24>>24;if(c){break Xa}l=l+1|0;continue}break Ra}Ya:{f=c&127;k=f?f+65535|0:0;i=k&65535;if(Sc(x[g>>2],x[e+140>>2])>>>0>i>>>0){break Ya}x[31725]=0;v[e+100|0]=0;S(436,g|0,i+1|0,e+100|0);f=x[31725];x[31725]=0;if((f|0)!=1){break Ya}break Ra}Za:{if((c|0)<0){x[31725]=0;c=R(199,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Za}M=xb(x[g>>2],i),T=c,v[M|0]=T}f=xb(x[g>>2],i);c=y[f|0];if(!(!(c&15)|i>>>0<z[a+480188>>1])){w[a+480188>>1]=k+1;c=y[f|0]}if(c&1){x[31725]=0;P(185,d|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}f=xb(x[g>>2],i)}if(y[f|0]&2){x[31725]=0;P(185,d|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}f=xb(x[g>>2],i)}if(y[f|0]&4){x[31725]=0;P(185,d|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}f=xb(x[g>>2],i)}if(!(y[f|0]&8)){continue}x[31725]=0;P(185,d|0,2)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}break Ra}x[e+100>>2]=x[b+8>>2];M=e,T=x[ad(e+240|0,e+100|0)>>2],x[M+240>>2]=T;dc(g);ub(d)}h=h+1|0;continue}}break}b=N()|0;dc(g);break Da}b=N()|0;break N}b=N()|0;break N}x[31725]=0;t=P(437,a|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=t|y[e+415|0];v[e+415|0]=c;if(!(y[E|0]|!(c&255))){Pv(a+1074312|0);v[a+1074368|0]=0}x[31725]=0;H=ba(438,a|0,b|0,0,e+415|0)|0;c=x[31725];x[31725]=0;_a:{if((c|0)==1){break _a}x[31725]=0;n=a+484344|0;O(225,n|0,s|0);c=x[31725];x[31725]=0;if((c|0)==1){break _a}L=a+480183|0;h=0;while(1){$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{if((h|0)!=(s|0)){c=yb(x[o>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(c){x[31725]=0;c=P(151,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break nb}if(c){break mb}}x[31725]=0;c=U(198,n|0,h&65535,64)|0;d=x[31725];x[31725]=0;if((d|0)==1){break nb}if(c){break ob}w[e+64>>1]=h;x[31725]=0;c=e+100|0;W(439,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break sb}x[31725]=0;d=e+160|0;S(440,d|0,c|0,e- -64|0);f=x[31725];x[31725]=0;if((f|0)==1){break rb}f=x[a+1298472>>2];x[31725]=0;S(387,f|0,2,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break qb}tb(d);Eb(c)}if(!x[a+1074308>>2]){f=y[e+456|0]|y[e+457|0]<<8;if((f|0)!=2184){break kb}x[a+1074308>>2]=18284544}if(!Ad(x[j+4>>2],y[j+11|0])){break lb}x[31725]=0;c=P(1,e+100|0,18237)|0;d=x[31725];x[31725]=0;if((d|0)==1){break bb}f=x[a+1074308>>2];x[31725]=0;d=e+76|0;O(136,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break db}x[31725]=0;f=e+160|0;S(2,f|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break eb}g=Ab(j,f);tb(f);tb(d);tb(c);f=x[a+1074308>>2];if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1414548815){break jb}if((f|0)!=18284544){break ib}f=18284544;if(!(t|(F|H))){break hb}break gb}b=N()|0;break N}b=N()|0;break pb}b=N()|0;tb(e+160|0)}Eb(e+100|0);break N}c=x[n>>2];x[31725]=0;O(441,Wb(c,h)|0,B|0);c=x[31725];x[31725]=0;if((c|0)!=1){break $a}}b=N()|0;break N}x[31725]=0;d=R(191,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fa}x[31725]=0;I=R(191,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ga}x[31725]=0;c=P(185,b|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ga}if(!c){break $a}x[31725]=0;c=U(198,n|0,h&65535,I|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ga}if(!c){break $a}x[31725]=0;c=e+100|0;S(187,c|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ha}m=ic(e+160|0,c);ub(c);d=x[n>>2];x[31725]=0;O(441,Wb(d,h)|0,B|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ja}d=z[a+480188>>1];x[31725]=0;k=P(435,e+124|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Ka}d=z[a+480188>>1];w[e+104>>1]=0;x[31725]=0;x[e+100>>2]=0;l=U(442,e+88|0,d|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ma}M=e,T=wb(x[Wb(x[n>>2],h)>>2]),x[M+76>>2]=T;G=0;while(1){tb:{ub:{vb:{wb:{if(G>>>0>=I>>>0){break wb}c=x[m>>2];x[31725]=0;c=U(152,c|0,x[e+168>>2],1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ab}if(!c){break wb}x[31725]=0;c=R(199,m|0)|0;d=x[31725];x[31725]=0;xb:{if((d|0)!=1){c=c<<24>>24;if(c){break xb}J_(e+76|0,z[a+480188>>1]);G=G+1|0;continue}break ab}yb:{d=c&127;i=d?d-1&65535:0;if(Sc(x[k>>2],x[e+128>>2])>>>0>i>>>0){break yb}x[31725]=0;v[e+100|0]=0;d=i+1|0;f=e+100|0;S(436,k|0,d|0,f|0);g=x[31725];x[31725]=0;if((g|0)==1){break ab}w[e+104>>1]=0;x[31725]=0;x[e+100>>2]=0;S(443,l|0,d|0,f|0);d=x[31725];x[31725]=0;if((d|0)!=1){break yb}break ab}if((c|0)<0){x[31725]=0;c=R(199,m|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ab}M=xb(x[k>>2],i),T=c,v[M|0]=T}w[e+104>>1]=0;x[e+100>>2]=0;d=e+100|0;if(i>>>0<z[a+480188>>1]){d=Wc(x[e+76>>2],i)}g=xb(x[k>>2],i);f=y[g|0];if(f&16){M=d,T=y[Wc(x[l>>2],i)|0],v[M|0]=T;f=y[g|0]}if(f&32){M=d,T=y[Wc(x[l>>2],i)+1|0],v[M+1|0]=T;f=y[g|0]}if(f&64){c=Wc(x[l>>2],i);v[d+2|0]=y[c+2|0];v[d+4|0]=y[c+4|0];f=y[g|0]}if(f<<24>>24<0){c=Wc(x[l>>2],i);v[d+3|0]=y[c+3|0];v[d+5|0]=y[c+5|0];f=y[g|0]}if(f&1){x[31725]=0;c=R(199,m|0)|0;f=x[31725];x[31725]=0;zb:{Ab:{if((f|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[L|0]&1)){break Ab}f=c;break zb}break ab}f=253;if((c-121&255)>>>0<132){break zb}f=(c&255)!=253?c:0}v[d|0]=f;M=Wc(x[l>>2],i),T=f,v[M|0]=T;g=xb(x[k>>2],i)}if(y[g|0]&2){x[31725]=0;c=R(199,m|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ab}v[d+1|0]=c;M=Wc(x[l>>2],i),T=c,v[M+1|0]=T;g=xb(x[k>>2],i)}if(!(y[g|0]&4)){break tb}x[31725]=0;g=R(199,m|0)|0;c=x[31725];x[31725]=0;Bb:{Cb:{if((c|0)!=1){if(g>>>0>64){break Cb}v[d+4|0]=g;f=1;break Bb}break ab}if(g<<24>>24<=-64){f=2;v[d+2|0]=2;g=g^-128;v[d+4|0]=g;break ub}if(g>>>0<=74){f=5;v[d+2|0]=5;g=g-65|0;v[d+4|0]=g;break ub}if(g>>>0<=84){f=6;v[d+2|0]=6;g=g-75|0;v[d+4|0]=g;break ub}if(g>>>0<=94){f=3;v[d+2|0]=3;g=g-85|0;v[d+4|0]=g;break ub}if(g>>>0<=104){f=4;v[d+2|0]=4;g=g-95|0;v[d+4|0]=g;break ub}if(g>>>0<=114){f=13;v[d+2|0]=13;g=g-105|0;v[d+4|0]=g;break ub}if(g>>>0<=124){f=12;v[d+2|0]=12;g=g-115|0;v[d+4|0]=g;break ub}c=g+63|0;if((c&255)>>>0<=9){v[d+4|0]=c;f=11;v[d+2|0]=11;g=c;break ub}c=g+53|0;J=c&255;if(J>>>0<=9){v[d+4|0]=c;f=8;v[d+2|0]=8;if(!J){g=0;break ub}if(x[a+1074308>>2]-1>>>0>18285139){break vb}f=7;v[d+2|0]=7;break vb}g=g+33|0;if((g&255)>>>0>=10){g=y[d+4|0];f=y[d+2|0];break ub}v[d+4|0]=g;f=15}v[d+2|0]=f;break ub}Rk(l);dc(k);ub(m);break $a}g=c}c=Wc(x[l>>2],i);v[c+4|0]=g;v[c+2|0]=f;g=xb(x[k>>2],i)}if(!(y[g|0]&8)){continue}x[31725]=0;c=e+52|0;O(200,c|0,m|0);f=x[31725];x[31725]=0;if((f|0)!=1){xD(d,y[e+52|0],y[Jc(c)|0],1);c=Wc(x[l>>2],i);v[c+3|0]=y[d+3|0];v[c+5|0]=y[d+5|0];continue}break}break ab}f=y[e+456|0]|y[e+457|0]<<8}Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{c=f&65535;switch(c>>>12|0){case 13:break Ib;case 7:break Jb;case 6:break Kb;case 4:break Lb;case 1:break Nb;case 0:break Ob;default:break fb}}if(y[E|0]){x[31725]=0;c=P(1,e+160|0,8340)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break fb}b=N()|0;break N}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{c=f&65535;if((c|0)!=532){break Xb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Wb}if(y[e+462|0]|y[e+463|0]<<8|(y[e+460|0]|y[e+461|0]<<8)!=9|(y[e+447|0]|y[e+446|0])){break Xb}if(y[e+450|0]|y[e+451|0]<<8|((y[e+454|0]|y[e+455|0]<<8)+1|0)!=(y[e+448|0]|y[e+449|0]<<8)|(y[e+464|0]!=128|y[e+465|0]!=100)){break Xb}if(y[e+466|0]!=1|y[e+468|0]!=128|(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8))){break Xb}if(y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24)|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break Xb}x[31725]=0;c=P(1,e+160|0,9860)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break fb}b=N()|0;break N}Yb:{if((c|0)!=514|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+447|0]|y[e+446|0])){break Yb}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Yb}c=x[o>>2];if(lc(c,x[o+4>>2])){break Ub}d=x[q>>2];if(lc(d,x[q+4>>2])){break Ub}c=yb(c,0);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(!g){break Ub}c=yb(d,0);if(g>>>0>=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0){break Ub}x[a+1074308>>2]=16777376;x[31725]=0;c=P(1,e+160|0,13471)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);v[e+415|0]=1;break fb}b=N()|0;break N}if((f&65535)!=532){break Vb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Wb}f=532;if(y[e+447|0]|y[e+446|0]){break Eb}d=512;if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Db}Zb:{if(y[e+462|0]&6){_b:{d=x[r>>2];if(oc(d,x[r+4>>2])>>>0<2){break _b}c=yb(d,1);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=yb(d,0);if((f-(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))|0)!=557){break _b}x[a+1074308>>2]=16777394;x[31725]=0;c=P(1,e+160|0,15205)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777393;x[31725]=0;c=P(1,e+160|0,13361)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777381;x[31725]=0;c=P(1,e+160|0,14917)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Hb}}Ab(j,c);tb(c);v[e+415|0]=1;break fb}f=532;if((d|0)!=532){break Tb}if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1229080643){x[31725]=0;c=P(1,e+160|0,8378)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);d=38;break Mb}b=N()|0;break N}if(y[e+469|0]|(y[e+462|0]|y[e+463|0]<<8)>>>0>1|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|((y[e+460|0]|y[e+461|0]<<8)&4294)!=4)){break Ub}if(!z[a+480190>>1]){break Ub}x[31725]=0;f=P(36,e+100|0,13604)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Rb}c=fb-32|0;fb=c;d=fb-16|0;fb=d;Ow(d+8|0,a+484527|0);AZ(c+24|0,x[d+8>>2],x[d+12>>2]);fb=d+16|0;ee(c+16|0,f);d=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=d;d=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;tb(f);if(d){break Sb}f=y[e+456|0]|y[e+457|0]<<8}if(f&65535){break Ub}if(Ad(x[j+4>>2],y[j+11|0])){break Pb}}d=y[e+458|0]|y[e+459|0]<<8}if((d&65535)>>>0>767){break fb}break Db}x[31725]=0;c=P(1,e+160|0,8404)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Qb}Ab(j,c);tb(c);break fb}b=N()|0;break N}b=N()|0;break N}x[31725]=0;c=P(1,e+160|0,9750)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break fb}b=N()|0;break N}f=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);x[31725]=0;d=e+160|0;S(444,d|0,c|0,y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24));g=x[31725];x[31725]=0;$b:{ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{if((g|0)!=1){Ab(j,d);tb(d);c=(c|0)==8191?f:c-4176|0;if((c|0)>1915){break hc}d=x[a+480208>>2];if(!(d&16)){break gc}x[31725]=0;P(269,a+1074312|0,7)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break fc}break Fb}b=N()|0;break N}if(c>>>0>4200){break dc}d=x[a+480208>>2]}if(!(d&16)){x[31725]=0;P(269,a+1074312|0,7)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Fb}}if((c|0)>2385){break ec}}x[31725]=0;P(269,a+1074312|0,38)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}}x[31725]=0;c=P(269,a+1074312|0,102)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Fb}x[31725]=0;P(269,c|0,48)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}break cc}if(c>>>0>4383){break bc}}x[31725]=0;c=U(268,a+1074312|0,116,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Fb}x[31725]=0;P(269,c|0,115)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}break ac}if(c>>>0>4563){break $b}}x[31725]=0;c=P(269,a+1074312|0,43)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Fb}x[31725]=0;c=P(269,c|0,42)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Fb}x[31725]=0;P(269,c|0,87)|0;c=x[31725];x[31725]=0;d=120;if((c|0)==1){break Fb}break Mb}d=120;if(c>>>0>4876){break fb}}x[31725]=0;P(269,a+1074312|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}break fb}x[31725]=0;c=e+100|0;W(445,c|0);d=x[31725];x[31725]=0;ic:{jc:{kc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+64>>2]=d>>>8&15;x[31725]=0;x[e+52>>2]=d&255;d=e+76|0;O(446,d|0,e+52|0);f=x[31725];x[31725]=0;if((f|0)==1){break kc}x[31725]=0;f=e+160|0;V(432,f|0,c|0,e- -64|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break jc}Ab(j,f);tb(f);tb(d);Eb(c);break fb}b=N()|0;break N}b=N()|0;break ic}b=N()|0;tb(e+76|0)}Eb(e+100|0);break N}x[31725]=0;c=P(1,e+160|0,8340)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break fb}b=N()|0;break N}if(!((c|0)!=32767|(y[e+458|0]|y[e+459|0]<<8)!=533)){x[31725]=0;c=P(1,e+160|0,5042)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break fb}b=N()|0;break N}x[31725]=0;c=e+100|0;O(133,c|0,4150);d=x[31725];x[31725]=0;lc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+76>>2]=d>>>8&15;x[e+64>>2]=d>>>4&15;x[31725]=0;x[e+52>>2]=d&15;d=e+160|0;aa(134,d|0,c|0,e+76|0,e- -64|0,e+52|0);f=x[31725];x[31725]=0;if((f|0)==1){break lc}Ab(j,d);tb(d);Eb(c);break fb}b=N()|0;break N}b=N()|0;Eb(e+100|0);break N}x[31725]=0;c=P(1,e+160|0,6123)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Gb}Ab(j,c);tb(c);break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}d=512}if(!Ad(x[j+4>>2],y[j+11|0])){break fb}mc:{nc:{oc:{pc:{qc:{if((d&65535)>>>0>=533){x[31725]=0;c=P(1,e+76|0,14949)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Ab(j,c);tb(c);break qc}b=N()|0;break N}if((f&65535)>>>0>=533){x[31725]=0;c=e+76|0;O(447,c|0,4015);d=x[31725];x[31725]=0;rc:{if((d|0)!=1){x[31725]=0;x[e+64>>2]=(y[e+456|0]|y[e+457|0]<<8)-532;d=e+160|0;S(448,d|0,c|0,e- -64|0);f=x[31725];x[31725]=0;if((f|0)==1){break rc}Ab(j,d);tb(d);Eb(c);break qc}b=N()|0;break N}b=N()|0;Eb(e+76|0);break N}x[31725]=0;c=e+76|0;O(270,c|0,4314);d=x[31725];x[31725]=0;if((d|0)==1){break pc}d=y[e+456|0]|y[e+457|0]<<8;x[e+52>>2]=d>>>8&15;x[31725]=0;x[e+40>>2]=d&255;d=e- -64|0;O(446,d|0,e+40|0);f=x[31725];x[31725]=0;if((f|0)==1){break oc}x[31725]=0;f=e+160|0;V(432,f|0,c|0,e+52|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break nc}Ab(j,f);tb(f);tb(d);Eb(c)}if(!lc(x[a+1298412>>2],x[a+1298416>>2])){break fb}c=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);if(!c){break fb}c=GF(y[e+456|0]|y[e+457|0]<<8,c);d=qp(e+160|0);x[d+32>>2]=c;x[31725]=0;O(449,a+1298412|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break mc}b=N()|0;tb(e- -64|0)}Eb(e+76|0);break N}if(!(t|((f|0)!=18284544|H|F))){break hb}break gb}if(((y[e+456|0]|y[e+457|0]<<8)&61440)!=20480){break gb}}x[31725]=0;c=P(1,e+160|0,16891)|0;d=x[31725];x[31725]=0;sc:{if((d|0)!=1){x[31725]=0;P(76,g|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break sc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!YG(f)){break fb}x[31725]=0;c=P(1,e+160|0,17127)|0;d=x[31725];x[31725]=0;tc:{if((d|0)!=1){x[31725]=0;P(76,g|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break tc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(K&1){x[31725]=0;c=P(1,e- -64|0,17141)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Cc}x[31725]=0;P(76,j|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Bc}tb(c)}f=x[a+480180>>2];if(!((f|0)!=16777216|(y[e+456|0]|y[e+457|0]<<8)>>>0<2186)){x[31725]=0;c=P(151,b|0,u|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break _a}if(c){x[31725]=0;S(450,a|0,b|0,y[e+456|0]|y[e+457|0]<<8);b=x[31725];x[31725]=0;if((b|0)==1){break _a}}f=x[a+480180>>2]}if((f|0)!=16777216){break Ac}x[31725]=0;P(1,e+52|0,13852)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break zc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31725]=0;b=e+40|0;O(270,b|0,4314);c=x[31725];x[31725]=0;if((c|0)==1){break yc}c=y[e+458|0]|y[e+459|0]<<8;x[e+36>>2]=c>>>8;x[31725]=0;x[e+20>>2]=c&255;c=e+24|0;O(446,c|0,e+20|0);d=x[31725];x[31725]=0;if((d|0)==1){break xc}x[31725]=0;V(432,e+52|0,b|0,e+36|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break wc}}b=e+52|0;Ab(a+1298344|0,b);tb(b);if((f|0)!=16777216){tb(e+24|0);Eb(e+40|0)}b=x[a+480180>>2];x[31725]=0;b=P(1,e+52|0,((b|0)==16777216?10124:6127)|0)|0;c=x[31725];x[31725]=0;f=1;if((c|0)==1){break uc}Ab(a+1298356|0,b);tb(b);Ab(a+1298368|0,j);M=a+1298404|0,T=x[Fc(e+36|0,x[a+1074308>>2]?22:4)>>2],x[M>>2]=T;x[a+1298408>>2]=0;ub(C);ub(B);break s}b=N()|0;break N}b=N()|0;break vc}b=N()|0;tb(e+24|0)}Eb(e+40|0);break N}b=N()|0;break N}b=N()|0;tb(e+76|0);break cb}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Rk(l);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}dc(k);break Ia}b=N()|0;break Ia}b=N()|0}ub(m);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(d);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(e+160|0);break xa}b=N()|0}Eb(e+100|0);break N}b=N()|0;break N}b=N()|0;break N}d=0;g=wD(e+100|0,x[i>>2]);x[31725]=0;P(185,b|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break _}}g=y[e+103|0];if(!x[i>>2]|(g|0)!=1){break ba}l=1;break aa}K=(g|0)==10|K}x[e+100>>2]=x[b+8>>2];M=e,T=x[ad(e+240|0,e+100|0)>>2],x[M+240>>2]=T;t=(d|0)!=0}f=f+1|0;d=z[a+480190>>1];continue}break}b=N()|0;break N}Dc:{d=yb(x[r>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Ec:{if(!d){break Ec}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Dc}if(!d){break Ec}d=x[b+8>>2];g=x[b>>2];x[31725]=0;d=U(152,g|0,d|0,554)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Dc}if(!d){break Ec}x[31725]=0;d=U(253,a|0,f+1&65535,0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Z}if(!d){break Ec}x[31725]=0;V(451,a|0,b|0,d|0,y[e+458|0]|y[e+459|0]<<8);g=x[31725];x[31725]=0;if((g|0)==1){break Z}v[d+33|0]=y[e+469|0]}f=f+1|0;d=z[a+480192>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(C)}ub(B);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}uc(o);uc(q);uc(r);break a}uc(o);uc(q);uc(r)}tb(j)}fb=e+608|0;return f|0}b=N()|0}tb(j);Q(b|0);p()}function ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;d=fb-1712|0;fb=d;xc(b);h=d+1704|0;a:{if(!Bi(b,h)){break a}if(!IY(h)){break a}if(!c){i=1;break a}m=y[d+1707|0];v[d+1703|0]=m;x[d+1696>>2]=-1;x[d+1692>>2]=1048576;if(m>>>0>=5){h=Pg(b);x[d+1696>>2]=h;if(!Mb(x[b>>2],x[b+8>>2],h)){break a}x[d+288>>2]=134217727;M=d,T=x[Gb(d+288|0,d+1696|0)>>2]<<5,x[M+1692>>2]=T}C=Nb(d+1680|0);x[d+288>>2]=y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24);h=x[Gb(d+1692|0,d+288|0)>>2];x[31725]=0;O(554,C|0,h|0);h=x[31725];x[31725]=0;b:{c:{d:{e:{f:{if((h|0)!=1){x[31725]=0;h=U(555,b|0,C|0,y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24))|0;f=x[31725];x[31725]=0;g:{if((f|0)==1){break g}if(!h){break b}if(m>>>0>=5){x[31725]=0;P(151,b|0,x[d+1696>>2]+12|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break g}}x[31725]=0;O(248,a|0,0);h=x[31725];x[31725]=0;if((h|0)==1){break g}gg(a);oe(d+1648|0,x[C>>2],x[C+4>>2]);h=Nd(d+1640|0);x[31725]=0;f=x[h+4>>2];x[d+88>>2]=x[h>>2];x[d+92>>2]=f;n=jg(556,d+1660|0,x[d+1648>>2],x[d+1652>>2],d+88|0);h=x[31725];x[31725]=0;h:{i:{j:{if((h|0)!=1){x[31725]=0;S(360,n|0,a+1298308|0,-1);h=x[31725];x[31725]=0;if((h|0)==1){break j}x[31725]=0;S(360,n|0,a+1298332|0,-1);h=x[31725];x[31725]=0;if((h|0)==1){break j}x[31725]=0;h=P(557,n|0,d+1218|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}if(!h){break c}h=v[d+1218|0];if((h|0)<=0|(y[d+1227|0]|y[d+1228|0]<<8)>>>0>255|(y[d+1229|0]|y[d+1230|0]<<8)>>>0>3999){break c}w[a+480188>>1]=h&255;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[d+1221|0]|y[d+1222|0]<<8);w[a+480192>>1]=y[d+1227|0]|y[d+1228|0]<<8;w[a+480190>>1]=y[d+1229|0]|y[d+1230|0]<<8;h=y[d+1231|0];x[a+480196>>2]=h?h:6;h=y[d+1232|0];x[a+480204>>2]=D(h?h:125,1e4);f=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);h=32;k:{if(f&256){break k}h=2;if(f&2){break k}h=1;if(f&128){break k}h=f&8?16:4}x[31725]=0;O(419,a|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}e=x[a+480208>>2];f=e|16777216;x[a+480208>>2]=f;h=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);if(h&1){f=e|16777232;x[a+480208>>2]=f}k=x[a+480180>>2];i=(k|0)==32;e=i&!(h&1024);j=(k|0)==2;g=j&h>>>4;s=h&2097152;j=j&h>>>2;i=i&!(h&2048);if(e|(s|j|(i|g))){f=g?f|65536:f;f=j?f|2:f;f=i?f|4:f;x[a+480208>>2]=s>>>6|(e?f|8:f)}if(h&524288){x[31725]=0;U(268,a+1074312|0,5,1)|0;h=x[31725];x[31725]=0;if((h|0)==1){break f}k=x[a+480180>>2]}if((k|0)==2){break i}if((k|0)!=32){break h}v[d+288|0]=y[d+1237|0];v[d+220|0]=128;M=a,T=y[Rb(d+288|0,d+220|0)|0]<<1,x[M+480200>>2]=T;break h}e=N()|0;break d}e=N()|0;break e}v[d+288|0]=y[d+1237|0];v[d+220|0]=64;M=a,T=y[Rb(d+288|0,d+220|0)|0]<<2,x[M+480200>>2]=T}E=a+480188|0;h=v[d+1239|0];l:{if((h|0)<0){h=h+52|0;break l}G=wt(+(h|0)*3.1/20);m:{if(G<4294967296&G>=0){h=~~G>>>0;break m}h=0}h=h+51|0}x[a+480228>>2]=h;w[d+288>>1]=64;e=z[Nc(E,d+288|0)>>1];f=0;g=(k|0)!=32;j=(k|0)==4;i=0;while(1)if((e|0)==(i|0)){i=0;j=0;while(1){if((f|0)!=16){j=y[(d+f|0)+1368|0]!=0|j;f=f+1|0;continue}break}while(1){if((i|0)!=128){j=y[((i<<1)+d|0)+1385|0]!=0|j;i=i+1|0;continue}break}n:{if(!(j&1)){break n}h=a+901692|0;i=0;while(1){if((i|0)==16){h=a+902204|0;i=0;while(1){if((i|0)!=128){f=(d+1218|0)+(i<<1)|0;o:{if(y[f+167|0]){x[31725]=0;e=d+220|0;W(558,e|0);g=x[31725];x[31725]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=y[f+167|0];x[31725]=0;x[d+244>>2]=g-1;g=d+1164|0;O(559,g|0,d+244|0);j=x[31725];x[31725]=0;if((j|0)==1){break t}f=y[f+166|0];x[31725]=0;v[d+192|0]=f;f=d+1144|0;O(560,f|0,d+192|0);j=x[31725];x[31725]=0;if((j|0)==1){break s}x[31725]=0;j=d+288|0;V(561,j|0,e|0,g|0,f|0);k=x[31725];x[31725]=0;if((k|0)==1){break r}ee(d+1192|0,j);sf(Oe(h,i),x[d+1192>>2],x[d+1196>>2]);tb(j);tb(f);tb(g);Eb(e);break o}e=N()|0;break e}e=N()|0;break p}e=N()|0;break q}e=N()|0;tb(d+1144|0)}tb(d+1164|0)}Eb(d+220|0);break e}f=qc(d+1184|0,22267);sf(Oe(h,i),x[f>>2],x[d+1188>>2])}i=i+1|0;continue}break}k=x[a+480180>>2];break n}e=(d+i|0)+1368|0;u:{if(y[e|0]){x[31725]=0;f=d+220|0;W(562,f|0);g=x[31725];x[31725]=0;v:{w:{x:{if((g|0)!=1){e=y[e|0];x[31725]=0;x[d+1144>>2]=e-1;e=d+1164|0;O(559,e|0,d+1144|0);g=x[31725];x[31725]=0;if((g|0)==1){break x}x[31725]=0;g=d+288|0;S(292,g|0,f|0,e|0);j=x[31725];x[31725]=0;if((j|0)==1){break w}ee(d+1208|0,g);sf(Oe(h,i),x[d+1208>>2],x[d+1212>>2]);tb(g);tb(e);Eb(f);break u}e=N()|0;break e}e=N()|0;break v}e=N()|0;tb(d+1164|0)}Eb(d+220|0);break e}f=qc(d+1200|0,22267);sf(Oe(h,i),x[f>>2],x[d+1204>>2])}i=i+1|0;continue}}h=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;e=Xb(f,h);h=k&5;aa(350,e|0,n|0,y[d+1219|0]|y[d+1220|0]<<8,(h?65535:255)|0,(h?65535:254)|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;h=d+288|0;S(187,h|0,n|0,D(y[d+1218|0],y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31725];x[31725]=0;if((f|0)!=1){H=ic(d+1164|0,h);ub(h);x[31725]=0;S(187,h|0,n|0,(y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31725];x[31725]=0;y:{if((f|0)!=1){I=ic(d+1144|0,h);ub(h);x[31725]=0;s=P(216,d+1132|0,y[d+1225|0]|y[d+1226|0]<<8)|0;h=x[31725];x[31725]=0;z:{if((h|0)!=1){M=d,T=wb(x[s>>2]),x[M+244>>2]=T;f=wb(x[s+4>>2]);A:{B:{C:{while(1){e=x[d+244>>2];if(!Ib(e,f)){h=x[a+480180>>2];t=c&1;if(!t){break B}x[31725]=0;O(225,a+484344|0,y[d+1223|0]|y[d+1224|0]<<8);f=x[31725];x[31725]=0;if((f|0)!=1){break B}e=N()|0;break A}x[31725]=0;g=R(153,n|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;h=d+220|0;S(187,h|0,n|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break C}g=e;e=ic(d+288|0,h);hd(g,e);ub(e);ub(h);Sf(d+244|0);continue}break}e=N()|0;break A}e=N()|0;break A}r=(h|0)==16?14:(h|0)==32?1:13;J=a+484344|0;k=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1223|0]|y[d+1224|0]<<8)>>>0<=q>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[31725]=0;h=R(191,I|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break H}x[d+220>>2]=h;if(!t){break D}x[31725]=0;f=U(198,J|0,q&65535,h|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break H}h=0;if(!f){break D}while(1){e=h&65535;if(e>>>0>=y[d+1218|0]){break D}x[31725]=0;f=R(191,H|0)|0;g=x[31725];x[31725]=0;J:{if((g|0)!=1){g=x[s>>2];if(Uf(g,x[s+4>>2])>>>0<=f>>>0){break J}l=dh(g,f);xc(l);f=0;g=Wb(x[J>>2],q);i=jd(x[g>>2],x[x[g+48>>2]+12>>2],0,e);K:while(1){if(A[d+220>>2]<=f>>>0){break J}x[31725]=0;e=R(199,l|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){if(!e){break J}u=e>>>4|0;B=e&15;j=0;g=bh(d+288|0);while(1){L:{M:{N:{if(B>>>0>(j&255)>>>0){x[31725]=0;e=d+244|0;O(200,e|0,l|0);o=x[31725];x[31725]=0;if((o|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{e=y[xb(e,0)|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(e-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}e=y[xb(d+244|0,1)|0];fa:{if(e>>>0<=119){e=e+r|0;break fa}ga:{switch(e-254|0){case 1:e=255;break fa;case 0:e=254;break fa;default:break ga}}e=253}v[g|0]=e;k=KD(e)&k;break L}M=d,T=y[xb(d+244|0,1)|0]+1|0,v[M+289|0]=T;break L}ha:{if(y[d+290|0]){break ha}e=x[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break ha}e=y[xb(d+244|0,1)|0];if(e&15){break ha}v[d+290|0]=11;v[d+292|0]=e>>>4;break L}o=y[xb(d+244|0,1)|0];e=0;while(1){if((e|0)==10){break ha}if((o|0)==y[e+42208|0]){v[d+292|0]=e;v[d+290|0]=11;break L}else{e=e+1|0;continue}}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=4;break L}e=xb(d+244|0,1);ia:{if(y[d+290|0]){break ia}o=y[e|0];if(x[a+480180>>2]!=32|o>>>0>9){break ia}v[d+292|0]=o;v[d+290|0]=8;break L}v[d+293|0]=y[e|0];v[d+291|0]=5;break L}ja:{if(y[d+290|0]){break ja}ka:{e=x[a+480180>>2];if((e|0)!=4){if((e|0)!=32){break ja}e=xb(d+244|0,1);o=y[e|0];if((o|0)!=255){break ka}v[d+292|0]=64;v[d+290|0]=2;break L}e=xb(d+244|0,1);if(y[e|0]&15){break ja}break M}if(!(o&3)){break M}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=9;break L}o=y[d+290|0];e=xb(d+244|0,1);la:{if(o|x[a+480180>>2]==1){break la}o=y[e|0];if(o>>>0>64){break la}v[d+292|0]=o;v[d+290|0]=1;break L}v[d+293|0]=y[e|0];v[d+291|0]=13;break L}e=y[xb(d+244|0,1)|0];v[d+293|0]=e;v[d+291|0]=14;if(x[a+480180>>2]==32){break L}v[d+293|0]=D((e&240)>>>4|0,10)+(e&15);break L}e=y[xb(d+244|0,1)|0];v[d+293|0]=e;v[d+291|0]=e>>>0<32?16:17;break L}o=y[xb(d+244|0,1)|0];if(o>>>0>=16){v[d+292|0]=o>>>4;v[d+290|0]=(e|0)==20?3:5;break L}v[d+292|0]=o&15;v[d+290|0]=(e|0)==20?4:6;break L}e=y[xb(d+244|0,1)|0];if(e>>>0>=16){v[d+290|0]=10;v[d+292|0]=e>>>4;break L}v[d+290|0]=9;v[d+292|0]=e&15;break L}e=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=e|16;break L}e=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=e|32;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(e|0)==31?7:8;break L}e=y[d+291|0];v[d+291|0]=(e|0)==4?6:(e|0)==5?7:11;M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;break L}e=xb(d+244|0,1);v[d+292|0]=y[e|0]%10;e=y[e|0];if(e>>>0<=9){v[d+290|0]=5;break L}if(e>>>0<=19){v[d+290|0]=6;break L}if(e>>>0<=29){v[d+290|0]=3;break L}if(e>>>0>39){break L}v[d+290|0]=4;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(e|0)==49?13:12;break L}e=y[xb(d+244|0,1)|0]+33|0;if((e&255)>>>0>9){break L}v[d+290|0]=15;v[d+292|0]=e;break L}if(e>>>0>57){break L}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=y[e+25184|0];break L}x[d+244>>2]=f+u;e=x[Gb(d+244|0,d+220|0)>>2];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){j=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[i|0]=j;v[i+1|0]=j>>>8;v[i+2|0]=j>>>16;v[i+3|0]=j>>>24;j=y[g+4|0]|y[g+5|0]<<8;v[i+4|0]=j;v[i+5|0]=j>>>8;f=f+1|0;i=D(y[d+1218|0],6)+i|0;continue}break}f=e;continue K}e=N()|0;break A}e=y[e|0];v[d+290|0]=2;v[d+292|0]=e>>>2}j=j+1|0;continue}}break}e=N()|0;break A}e=N()|0;break A}h=h+1|0;continue}}i=z[a+480192>>1];h=0;break E}e=N()|0;break A}if(!(z[E>>1]==4&k)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}i=0;h=!((y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24))&512)}x[31725]=0;o=P(563,d+1120|0,i|0)|0;f=x[31725];x[31725]=0;ma:{na:{oa:{pa:{qa:{if((f|0)!=1){i=m>>>0<5;j=1;ra:{while(1){g=j&65535;if(g>>>0>z[a+480192>>1]){break ra}sa:{ta:{ua:{va:{if(!h){x[31725]=0;e=U(253,a|0,g|0,0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break va}if(e){break ua}}while(1){x[31725]=0;f=R(199,n|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break na}if(f){continue}break}if(!i){while(1){x[31725]=0;f=R(199,n|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){e=N()|0;break ma}if(f){continue}break}}x[31725]=0;P(185,n|0,826)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break ta}}e=N()|0;break ma}f=Fb(d+220|0);x[31725]=0;S(360,n|0,f|0,-1);k=x[31725];x[31725]=0;if((k|0)==1){break sa}zc(e+492|0,f);if(!i){x[31725]=0;S(360,n|0,f|0,-1);k=x[31725];x[31725]=0;if((k|0)==1){break sa}zc(e+524|0,f)}x[31725]=0;k=d+288|0;q=P(564,n|0,k|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break oa}if(!q){break qa}q=x[a+480180>>2];x[31725]=0;S(565,k|0,e|0,q|0);e=x[31725];x[31725]=0;if((e|0)==1){break oa}if(x[a+480180>>2]==4){e=yb(x[o>>2],g-1|0);g=y[d+1090|0]|y[d+1091|0]<<8|(y[d+1092|0]<<16|y[d+1093|0]<<24);v[e|0]=g;v[e+1|0]=g>>>8;v[e+2|0]=g>>>16;v[e+3|0]=g>>>24}tb(f)}j=j+1|0;continue}break}break oa}if(!h){break pa}w[a+480192>>1]=0;break pa}e=N()|0;break A}tb(f)}h=z[a+480190>>1];x[31725]=0;q=P(566,d+276|0,h|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){B=y[d+1703|0];L=!(v[d+1233|0]&1)|B>>>0>4;t=c&2;j=1;c=0;while(1){h=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{k=j&65535;if(k>>>0<=z[a+480190>>1]){i=Fb(d+264|0);x[31725]=0;S(360,n|0,i|0,-1);c=x[31725];x[31725]=0;Ra:{Sa:{if((c|0)!=1){zc(((k<<5)+a|0)+946304|0,i);c=B>>>0<5;if(c){break Sa}x[31725]=0;S(360,n|0,i|0,-1);f=x[31725];x[31725]=0;if((f|0)!=1){break Ra}}e=N()|0;break za}tf(i)}x[31725]=0;f=d+288|0;e=P(567,n|0,f|0)|0;g=x[31725];x[31725]=0;Ta:{Ua:{if((g|0)==1){break Ua}if(!e){break Ta}g=x[a+480180>>2];x[31725]=0;l=f;e=D(k,104)+a|0;f=e+484380|0;V(568,l|0,f|0,g|0,L|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ua}ze(e+484423|0,i);r=0;Va:{if(((y[d+308|0]|y[d+309|0]<<8)&61440)!=28672|c){break Va}x[31725]=0;r=R(569,n|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break Va}e=N()|0;break za}if(!t){break xa}g=y[d+323|0]|y[d+324|0]<<8|(y[d+325|0]<<16|y[d+326|0]<<24);c=y[d+308|0]|y[d+309|0]<<8;m=c&61440;if(!(g|m)){c=Xc(d+220|0,c&1?16:8,c&1024?3:1,0,0);x[31725]=0;U(217,c|0,f|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break xa}e=N()|0;break za}if((g|0)<0){c=g+k|0;if((c|0)<=0){break xa}GY(f,(D(c,104)+a|0)+484380|0);break xa}if((g|0)<=0){break xa}if(c&1){l=e+484414|0;w[l>>1]=z[l>>1]|1}if(c&1024){l=e+484414|0;w[l>>1]=z[l>>1]|64}x[31725]=0;l=d+220|0;S(187,l|0,b|0,g|0);g=x[31725];x[31725]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((g|0)!=1){g=ic(d+244|0,l);ub(l);l=_d(z[f+34>>1]);K=(m|0)==16384;if(!K&(m|0)!=8192){break Za}u=x[g>>2];x[31725]=0;u=R(156,u|0)|0;F=x[31725];x[31725]=0;if((F|0)==1){break Wa}F=4/(l>>>0)|0;nva(F,0,u,0);wc(f,hb?-1:D(u,F));if((m|0)==8192){break $a}if(!K){break Za}if(!Fh(f)){break Ya}c=x[e+484400>>2];f=x[f>>2];if(!(v[d+308|0]&1)){break _a}x[31725]=0;V(570,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}e=N()|0;break za}if(!Fh(f)){break Ya}c=x[e+484400>>2];f=x[f>>2];if(v[d+308|0]&1){x[31725]=0;V(571,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)!=1){break Xa}break Ba}x[31725]=0;V(572,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}x[31725]=0;V(573,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}if((c&45056)==12288){c=FY(d+220|0,g,y[d+327|0]|y[d+328|0]<<8,r);M=hd(wf(x[q>>2],k-1|0),c),T=x[c+20>>2],x[M+20>>2]=T;ub(c);break Ya}if((m|0)!=32768){c=1;if((m|0)!=4096){break Xa}m=Ge(d+220|0,g);x[31725]=0;c=P(574,d+214|0,g|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){ab:{bb:{if(!y[d+219|0]){break bb}r=y[d+327|0]|y[d+328|0]<<8;l=z[d+216>>1]<<1;if(r>>>0<(l&65535)>>>0){break bb}l=r-l|0;v[d+327|0]=l;v[d+328|0]=l>>>8;c=z[c>>1];x[31725]=0;P(151,g|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}x[31725]=0;l=R(204,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}x[31725]=0;c=d+172|0;S(187,c|0,g|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break ab}l=ic(d+192|0,c);hd(m,l);ub(l);ub(c)}x[31725]=0;k=U(575,a|0,k|0,m|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}c=1;if(k){c=y[d+327|0]|y[d+328|0]<<8;cb:{if(!c){break cb}k=z[f+34>>1];l=Wk(x[f>>2],k);if(l>>>0<=c>>>0){break cb}k=dl(k);e=x[e+484400>>2];ml(e,c+e|0,l-c|0);x[f>>2]=x[f>>2]-((c>>>0)/(k>>>0)|0)}wc(f,y[d+296|0]|y[d+297|0]<<8|(y[d+298|0]<<16|y[d+299|0]<<24));c=h}ub(m);break Xa}}e=N()|0;ub(m);break Aa}x[31725]=0;c=P(430,g|0,d+220|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=y[d+228|0]|y[d+229|0]<<8|(y[d+230|0]<<16|y[d+231|0]<<24);c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);x[d+72>>2]=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);x[d+76>>2]=c;Zk(f,1,d+72|0)}c=h}ub(g);break wa}e=N()|0;break Aa}e=N()|0;break za}tb(i)}db:{if(!t){break db}m=1;while(1){c=m&65535;if(c>>>0>z[a+480190>>1]){break db}b=wf(x[q>>2],c-1|0);f=x[b>>2];x[31725]=0;f=R(174,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Pa}eb:{fb:{if(!f){break fb}f=c+w[b+22>>1]|0;f=((f|0)>0?f:m)&65535;j=z[b+20>>1];g=(f|0)!=(c|0)&(f|0)!=0&f>>>0<=z[a+480190>>1]&(j|0)!=0;gb:{if(g){f=wf(x[q>>2],f-1|0);break gb}f=x[b>>2];x[31725]=0;j=R(156,f|0)|0;e=x[31725];x[31725]=0;f=b;if((e|0)==1){break Oa}}xc(f);hb:{if(g){e=x[f+8>>2];i=x[f>>2];k=z[b+20>>1];x[31725]=0;e=U(152,i|0,e|0,k|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break Oa}if(!e){break fb}x[d+220>>2]=0;x[d+244>>2]=0;x[31725]=0;e=d+288|0;S(188,e|0,f|0,j|0);i=x[31725];x[31725]=0;ib:{if((i|0)!=1){k=ZC($e(e),uh(x[d+288>>2]),d+220|0,d+244|0);x[31725]=0;P(185,f|0,x[d+220>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break ib}Kc(e);break hb}e=N()|0;break ya}e=N()|0;Kc(d+288|0);break ya}k=0;x[d+220>>2]=0;x[d+244>>2]=0}x[31725]=0;f=d+288|0;O(576,f|0,b|0);e=x[31725];x[31725]=0;jb:{kb:{if((e|0)!=1){e=$e(f);j=x[d+288>>2];if(!g){k=ZC(e,uh(j),d+220|0,d+244|0);x[31725]=0;f=x[d+220>>2];P(185,b|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break eb}j=j-f|0;e=e+f|0}if(k){break kb}h=1;break jb}e=N()|0;break ya}c=D(c,104)+a|0;l=c+484380|0;Fh(l);u=c+484400|0;f=0;i=x[d+244>>2];while(1){lb:{if(!j|(i|0)!=1?i:0){break lb}c=x[l>>2];if(c>>>0<=f>>>0){break lb}if(!je(c,x[l+20>>2])){break lb}x[d+192>>2]=0;x[d+172>>2]=0;c=d+172|0;i=EY(k,e,uh(j),d+192|0,d+264|0,c);x[31725]=0;x[d+220>>2]=i;P(185,b|0,i|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ca}Ai(c,uh(x[l>>2]-f|0));c=x[d+172>>2];mb:{if((c|0)<=0){break mb}g=x[d+192>>2];B=z[l+34>>1];if((_d(B)|0)!=(g|0)){break mb}t=D(f,g);r=x[u>>2];if(B&1){x[d+168>>2]=c;x[d+156>>2]=c;x[d- -64>>2]=c;x[d+48>>2]=c;x[d+152>>2]=g;x[d+148>>2]=x[d+264>>2];x[d+164>>2]=g;x[d+160>>2]=r+(t<<1);x[31725]=0;g=x[d+152>>2];x[d+40>>2]=x[d+148>>2];x[d+44>>2]=g;g=x[d+164>>2];x[d+56>>2]=x[d+160>>2];x[d+60>>2]=g;O(577,d+56|0,d+40|0);g=x[31725];x[31725]=0;if((g|0)!=1){break mb}break Ca}x[d+144>>2]=c;x[d+132>>2]=c;x[d+32>>2]=c;x[d+16>>2]=c;x[d+128>>2]=g;x[d+124>>2]=x[d+264>>2];x[d+140>>2]=g;x[d+136>>2]=r+t;x[31725]=0;g=x[d+128>>2];x[d+8>>2]=x[d+124>>2];x[d+12>>2]=g;g=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=g;O(578,d+24|0,d+8|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ca}}j=j-i|0;e=e+i|0;i=DY(k);x[d+244>>2]=i;f=c+f|0;continue}break}CY(k)}Kc(d+288|0)}m=m+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}i=0;while(1){if(z[a+480192>>1]<=i>>>0){break nb}b=yb(x[o>>2],i);c=y[b+3|0];f=y[b+2|0];e=y[b+1|0];b=y[b|0];x[31725]=0;i=i+1|0;ja(402,a|0,i&65535,b|0,e|0,f|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){continue}break}e=N()|0;break ya}if(!(y[d+1235|0]&16)){break Ka}b=x[n+8>>2];c=x[n>>2];x[31725]=0;b=U(152,c|0,b|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ma}if(!b){break Ka}i=0;x[31725]=0;b=R(199,n|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=i>>>0){break La}x[31725]=0;b=R(153,n|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){v[((i<<5)+a|0)+480288|0]=b;i=i+1|0;continue}break}e=N()|0;break ya}e=N()|0;break Aa}e=N()|0;break ya}e=N()|0;break ya}e=N()|0;break ya}e=N()|0;break ya}e=a+906300|0;while(1){b=x[n+8>>2];c=x[n>>2];x[31725]=0;b=U(152,c|0,b|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Da}if(!b){break Ka}x[31725]=0;b=R(199,n|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[31725]=0;c=R(153,n|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ja}x[31725]=0;f=d+220|0;S(187,f|0,n|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break Ja}c=ic(d+288|0,f);ub(f);ob:{if(b>>>0<=250){b=vd(e,b-1|0);x[31725]=0;O(452,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break ob}}ub(c);continue}break}e=N()|0;ub(c);break ya}j=a+901404|0;c=Fb(d+192|0);f=0;k=0;while(1){b=x[n+8>>2];e=x[n>>2];x[31725]=0;b=U(152,e|0,b|0,8)|0;e=x[31725];x[31725]=0;pb:{qb:{rb:{sb:{tb:{if((e|0)!=1){if(b){x[31725]=0;e=R(153,n|0)|0;b=x[31725];x[31725]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[31725]=0;b=R(153,n|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Bb}x[31725]=0;g=d+288|0;S(187,g|0,n|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ab}b=ic(d+220|0,g);ub(g);if((e|0)==1229211981){break xb}if((e|0)==1229476432){break yb}if((e|0)==1397900630){break zb}if((e|0)!=1414548815){break pb}x[31725]=0;e=P(414,b|0,13890)|0;i=x[31725];x[31725]=0;if((i|0)==1){break Ha}if(!e){break qb}x[31725]=0;e=R(153,b|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;S(187,g|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break wb}}e=N()|0;break Ga}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}Cb:{Db:{Eb:{e=x[a+480180>>2];switch(e-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((e|0)==16){break Cb}if((e|0)!=32){break pb}x[31725]=0;f=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}x[31725]=0;k=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break pb}break Ha}e=Fc(d+120|0,4);x[d+288>>2]=32;g=x[b>>2];x[31725]=0;g=R(156,g|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[d+244>>2]=g;e=x[e>>2];g=x[Gb(d+288|0,d+244|0)>>2];x[31725]=0;V(579,b|0,c|0,e|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){break pb}}e=N()|0;break Ga}x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ub}x[31725]=0;g=d+244|0;O(580,g|0,4211);i=x[31725];x[31725]=0;Fb:{if((i|0)!=1){x[d+264>>2]=e>>>4;x[31725]=0;x[d+104>>2]=e&15;e=d+288|0;V(309,e|0,g|0,d+264|0,d+104|0);i=x[31725];x[31725]=0;if((i|0)==1){break Fb}Ab(c,e);tb(e);Eb(g);break pb}e=N()|0;break Ga}e=N()|0;Eb(d+244|0);break Ga}x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}x[a+480216>>2]=e;x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}x[a+480220>>2]=e;break pb}x[31725]=0;P(425,b|0,j|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}zD(j);break pb}e=d+288|0;g=ic(d+244|0,e);ub(e);i=x[g>>2];x[31725]=0;i=R(156,i|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break rb}w[d+288>>1]=i>>>5;M=d,T=ek(x[a+484344>>2],x[a+484348>>2]),w[M+264>>1]=T;e=z[Nc(e,d+264|0)>>1];i=0;while(1){if((e|0)==(i|0)){ub(g);break qb}x[31725]=0;m=d+288|0;O(581,g|0,m|0);l=x[31725];x[31725]=0;Gb:{if((l|0)==1){break Gb}l=x[J>>2];x[31725]=0;O(582,Wb(l,i)|0,m|0);m=x[31725];x[31725]=0;if((m|0)==1){break Gb}i=i+1|0;continue}break}break rb}x[31725]=0;f=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}break pb}e=N()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}e=f&65535;if(e>>>0<256){break Jb}if(e>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}e=f&65535;if(e>>>0<12544){break Kb}if(e>>>0<12820){break Ib}}if(b){break Hb}b=f&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}rr(j)}i=1;Lb:{if(!(v[d+1235|0]&1)){break Lb}f=x[a+1074308>>2];if(!f){while(1){b=i&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){f=x[a+480180>>2];x[31725]=0;O(583,Zh(b,2)|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}i=i+1|0;continue}break}f=x[a+1074308>>2]}if(f>>>0<=18350079){x[31725]=0;b=P(269,a+1074312|0,27)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Fa}x[31725]=0;P(269,b|0,57)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}f=x[a+1074308>>2]}if(f>>>0<=19070975){x[31725]=0;P(269,a+1074312|0,73)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}f=x[a+1074308>>2]}if(f>>>0>19267583){break Lb}x[31725]=0;P(269,a+1074312|0,50)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(Ad(x[c+4>>2],y[c+11|0])){x[31725]=0;f=d+220|0;W(584,f|0);b=x[31725];x[31725]=0;_b:{if((b|0)!=1){x[31725]=0;e=d+288|0;S(552,e|0,f|0,d+1703|0);b=x[31725];x[31725]=0;if((b|0)==1){break _b}break Zb}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}x[31725]=0;f=d+220|0;W(585,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break Yb}x[31725]=0;e=d+288|0;V(586,e|0,f|0,d+1703|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break Xb}}Ab(c,e);tb(e);Eb(f);x[31725]=0;f=d+220|0;O(551,f|0,3977);b=x[31725];x[31725]=0;if((b|0)==1){break Vb}x[31725]=0;b=d+288|0;S(552,b|0,f|0,d+1703|0);e=x[31725];x[31725]=0;if((e|0)==1){break Ub}Ab(a+1298344|0,b);tb(b);Eb(f);x[31725]=0;b=P(1,b|0,14997)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Tb}Ab(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[31725]=0;b=P(1,d+220|0,10124)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Nb}Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,13852)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Mb}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10129)|0;f=x[31725];x[31725]=0;$b:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,8365)|0;f=x[31725];x[31725]=0;if((f|0)==1){break $b}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,12386)|0;f=x[31725];x[31725]=0;ac:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,14248)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ac}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10102)|0;f=x[31725];x[31725]=0;bc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,15291)|0;f=x[31725];x[31725]=0;if((f|0)==1){break bc}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10474)|0;f=x[31725];x[31725]=0;cc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,15032)|0;f=x[31725];x[31725]=0;if((f|0)==1){break cc}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,6127)|0;f=x[31725];x[31725]=0;dc:{ec:{fc:{gc:{hc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);if(!(k&65535)){break dc}x[31725]=0;b=d+264|0;O(270,b|0,4314);f=x[31725];x[31725]=0;if((f|0)==1){break hc}x[d+116>>2]=(k&65280)>>>8;x[31725]=0;x[d+100>>2]=k&255;f=d+104|0;O(446,f|0,d+100|0);e=x[31725];x[31725]=0;if((e|0)==1){break gc}x[31725]=0;e=d+244|0;V(432,e|0,b|0,d+116|0,f|0);g=x[31725];x[31725]=0;if((g|0)==1){break fc}Ab(a+1298380|0,e);tb(e);tb(f);Eb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break ec}e=N()|0;tb(d+104|0)}Eb(d+264|0);break Ea}x[31725]=0;b=P(1,d+244|0,8557)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}Ab(a+1298368|0,c);ic:{if(x[a+1074308>>2]){M=a,T=x[Fc(d+264|0,22)>>2],x[M+1298404>>2]=T;break ic}if(x[a+480180>>2]==1){M=a,T=x[Fc(d+264|0,28)>>2],x[M+1298404>>2]=T;break ic}M=a,T=x[Fc(d+264|0,4)>>2],x[M+1298404>>2]=T}i=1;jc:{kc:{if(h&1){x[31725]=0;b=P(1,d+264|0,16662)|0;h=x[31725];x[31725]=0;if((h|0)==1){break kc}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,2,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break jc}tb(b)}tb(c);BY(q);uc(o);Qc(s);ub(I);ub(H);break c}e=N()|0;break Ea}e=N()|0;tb(b);break Ea}e=N()|0;ub(g);break Ga}x[31725]=0;e=P(414,b|0,13895)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}lc:{if(!e){break lc}x[31725]=0;e=R(153,b|0)|0;g=x[31725];x[31725]=0;mc:{if((g|0)!=1){x[31725]=0;S(187,d+244|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break mc}}e=N()|0;break Ga}e=d+244|0;g=ic(d+288|0,e);ub(e);i=x[g>>2];x[31725]=0;i=R(156,i|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){w[d+244>>1]=(i>>>0)/20;w[d+264>>1]=z[E>>1];e=z[Nc(e,d+264|0)>>1];i=0;while(1){if((e|0)==(i|0)){ub(g);break lc}x[31725]=0;S(426,g|0,((i<<5)+a|0)+480289|0,20);m=x[31725];x[31725]=0;if((m|0)!=1){i=i+1|0;continue}break}}e=N()|0;ub(g);break Ga}x[31725]=0;P(437,a|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}x[31725]=0;ba(438,a|0,b|0,1,0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}if((f-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[31725]=0;S(450,a|0,b|0,f&65535);e=x[31725];x[31725]=0;if((e|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[31725]=0;g=P(1,d+172|0,18237)|0;e=x[31725];x[31725]=0;nc:{oc:{pc:{if((e|0)!=1){i=x[a+1074308>>2];x[31725]=0;e=d+244|0;O(136,e|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break pc}x[31725]=0;i=d+288|0;S(2,i|0,g|0,e|0);m=x[31725];x[31725]=0;if((m|0)==1){break oc}Ab(c,i);tb(i);tb(e);tb(g);break pb}e=N()|0;break Ga}e=N()|0;break nc}e=N()|0;tb(d+244|0)}tb(g);break Ga}ub(b);continue}}e=N()|0;break ya}e=N()|0;break ya}e=N()|0}ub(b);break Ea}e=N()|0}tb(c);break ya}e=N()|0;break ya}e=N()|0;Kc(d+288|0);break ya}e=N()|0}ub(g)}tb(i)}BY(q);break ma}c=h}tb(i);j=j+1|0;continue}}e=N()|0;break ma}e=N()|0;tb(f);break ma}e=N()|0}uc(o);break A}q=q+1|0;continue}}Qc(s);break z}e=N()|0}ub(I);break y}e=N()|0}ub(H);break e}e=N()|0;break e}e=N()|0;break e}else{qc:{rc:{if(!g){v[d+288|0]=y[(d+i|0)+1240|0];v[d+220|0]=64;M=((i<<5)+a|0)+480286|0,T=y[Rb(d+288|0,d+220|0)|0],w[M>>1]=T;break rc}if(j){break qc}}sc:{h=y[(d+i|0)+1304|0];if((h|0)!=255){if((h|0)!=127){break sc}x[((i<<5)+a|0)+480280>>2]=256;break qc}w[((i<<5)+a|0)+480284>>1]=256;break qc}w[((i<<5)+a|0)+480284>>1]=h}i=i+1|0;continue}}e=N()|0;break d}e=N()|0;break d}e=N()|0}ub(n)}dc(C);Q(e|0);p()}ub(n)}dc(C)}fb=d+1712|0;return i|0}function Ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=fb-944|0;fb=e;xc(b);f=e+892|0;a:{if(!TY(b,f)){break a}if(!XY(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(WY(f),hb))){break a}if(!c){d=1;break a}Bd(a,8);gg(a);k=y[e+895|0]-48|0;v[e+891|0]=k;cd(b,$b(y[e+900|0]|y[e+901|0]<<8|(y[e+902|0]<<16|y[e+903|0]<<24)));f=e+584|0;fe(f,b,504);L=ic(e+868|0,f);ub(f);x[31725]=0;O(525,b|0,f|0);f=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+867|0]>63){break b}if(Bb(z[e+584>>1])<<16>>16<0){break b}f=e+504|0;Sb(f,0,80);h:{d=$b(y[e+924|0]|y[e+925|0]<<8|(y[e+926|0]<<16|y[e+927|0]<<24));if(!d){break h}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){if(!d){break h}x[31725]=0;O(526,b|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){break h}}h=N()|0;break e}x[31725]=0;f=e+500|0;S(527,f|0,b|0,k&255);d=x[31725];x[31725]=0;if((d|0)!=1){X=af(f);d=0;f=z[e+500>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;H=Nb(e+488|0);f=$b(y[e+916|0]|y[e+917|0]<<8|(y[e+918|0]<<16|y[e+919|0]<<24));i:{if(f){x[31725]=0;P(151,b|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}x[31725]=0;S(528,b|0,H|0,y[e+867|0]);f=x[31725];x[31725]=0;if((f|0)==1){break g}g=y[e+867|0];break i}g=y[e+867|0];if(g){break c}}F=a+480188|0;g=g&255;w[a+480192>>1]=g;w[a+480190>>1]=g;Y=(k&255)>>>0<2|v[e+848|0]>=0;B=!Y;u=c&2;m=1;s=1;while(1){j:{k:{l:{m:{n:{o:{d=s&65535;if(d>>>0<=(g&65535)>>>0){x[31725]=0;o=m&65535;f=U(253,a|0,d|0,o|0)|0;g=x[31725];x[31725]=0;p:{if((g|0)!=1){if(f){break p}break d}h=N()|0;break f}f=x[((d<<2)+a|0)+900380>>2];w[e+92>>1]=0;x[e+88>>2]=0;x[31725]=0;l=R(170,e+468|0)|0;g=x[31725];x[31725]=0;q:{if((g|0)!=1){d=yb(x[H>>2],d-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}if(!d){break r}x[31725]=0;O(529,b|0,e+88|0);d=x[31725];x[31725]=0;if((d|0)==1){break k}g=x[e+88>>2];k=w[e+92>>1];x[31725]=0;d=e+128|0;j=$b(g);g=xe(k);S(187,d|0,b|0,j<<(g>>>5&1&(g|0)>0));g=x[31725];x[31725]=0;if((g|0)==1){break k}g=ic(e+188|0,d);hd(l,g);ub(g);ub(d)}g=xe(w[e+92>>1]);d=g&15;if((g|0)>=0){break q}Jv(f,0);$=1;break o}h=N()|0;break f}if(d>>>0>6){break o}k=y[d+25062|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+k|0)-1;i=f+108|0;t=f+236|0;q=k-2|0;h=4;s:while(1){j=1;if((h|0)==10){break n}j=D(h,12);d=(q<<3)+h|0;n=y[d+25068|0]+m|0;r=y[d+25116|0];d=0;while(1)if((d|0)==12){h=h+1|0;continue s}else{A=d+j|0;ia=_b(t,A),ja=n,w[ia>>1]=ja;A=xb(i,A);v[A|0]=r+y[A|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{f=$b(x[e+508>>2]);if(!f){break D}if(!Bb(z[e+512>>1])){break D}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(!f){break D}ia=e,ja=Bb(z[e+512>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];l=z[Nc(e+188|0,e+128|0)>>1];f=e+136|0;i=e+132|0;k=Bb(z[e+514>>1]);m=k>>>0<5;s=k>>>0<19;o=k>>>0<21;q=k>>>0<15;B=k>>>0<6;g=0;while(1){if((g|0)==(l|0)){break D}x[31725]=0;S(530,b|0,e+188|0,k|0);d=x[31725];x[31725]=0;E:{F:{G:{if((d|0)!=1){g=g+1|0;d=x[((g<<2)+a|0)+900380>>2];j=y[e+188|0];if(j){t=em(e+128|0,0,64);em(i,j-1&65535,64);h=y[e+189|0];if(h){h=64/(h>>>0)|0}else{h=0}em(f,h+j|0,0);x[31725]=0;j=d+48|0;S(531,j|0,t|0,3);h=x[31725];x[31725]=0;if((h|0)==1){break G}if(y[e+188|0]==1){h=x[vb(e+464|0,wb(x[j>>2]))>>2];t=wb(x[j>>2]);h=x[j>>2]+(Hv(h,t)<<2)|0;Ih(j,Wg(h+4|0,x[j+4>>2],h));wb(h)}j=y[e+189|0];x[d>>2]=j?j<<9:32767;v[d+60|0]=y[d+60|0]|1;t=1}H:{if(m){break H}j=y[e+192|0];if(j){ia=xb(d+108|0,24),ja=j+24|0,v[ia|0]=ja;t=1}if(s){break H}x[d+4>>2]=y[e+206|0]+1>>>1;if(o){break H}w[d+28>>1]=y[e+208|0]|y[e+209|0]<<8}d=D(z[_b(d+236|0,61)>>1],104)+a|0;v[d+484417|0]=y[e+191|0]<<4;if(q){break F}j=$b(y[e+198|0]|y[e+199|0]<<8|(y[e+200|0]<<16|y[e+201|0]<<24));x[d+484384>>2]=j;ia=d+484388|0,ja=$b(y[e+202|0]|y[e+203|0]<<8|(y[e+204|0]<<16|y[e+205|0]<<24))+j|0,x[ia>>2]=ja;break E}h=N()|0;break f}h=N()|0;break f}if(B){continue}}j=d+484414|0;h=j;n=z[j>>1]&65529;j=y[e+193|0];w[h>>1]=n|j<<1&2|j>>>1&4;if(!(j&4)){continue}w[d+484412>>1]=0;continue}}I:{f=$b(x[e+524>>2]);if(!f){break I}if(!Bb(z[e+528>>1])){break I}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(!f){break I}ia=e,ja=Bb(z[e+528>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];j=z[Nc(e+188|0,e+128|0)>>1];h=Bb(z[e+530>>1]);d=0;J:while(1){if((d|0)==(j|0)){break I}x[31725]=0;f=e+188|0;S(532,b|0,f|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break t}g=e+88|0;Q_(g,f);x[31725]=0;f=e+128|0;O(220,f|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break u}d=d+1|0;k=((d<<2)+a|0)+900380|0;zc(x[k>>2]+492|0,f);tb(f);g=x[k>>2];x[31725]=0;O(391,f|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break v}ia=e,ja=_i(x[e+128>>2]),x[ia+88>>2]=ja;l=Rf(f);while(1){f=x[e+88>>2];if(Ib(f,l)){g=(z[ip(f)>>1]<<5)+a|0;i=g+946328|0;f=x[k>>2];m=x[f+520>>2];x[i>>2]=x[f+516>>2];x[i+4>>2]=m;m=x[f+512>>2];i=g+946320|0;x[i>>2]=x[f+508>>2];x[i+4>>2]=m;m=x[f+504>>2];i=g+946312|0;x[i>>2]=x[f+500>>2];x[i+4>>2]=m;i=x[f+496>>2];g=g+946304|0;x[g>>2]=x[f+492>>2];x[g+4>>2]=i;ah(e+88|0);continue}else{Sv(e+128|0);continue J}}}}rr(a+901404|0);f=qc(e+456|0,4940);sf(Oe(a+901692|0,0),x[f>>2],x[f+4>>2]);xc(b);aa=c&1;q=a+484344|0;B=a+1298332|0;Z=a+1298308|0;M=a+484360|0;k=0;m=0;while(1){K:{c=k&255;if(c>>>0>=y[X|0]){break K}x[31725]=0;V(533,b|0,e+892|0,e+504|0,e+584|0);f=x[31725];x[31725]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((f|0)==1){break X}Y:{if(!c){d=0;break Y}x[31725]=0;c=R(276,M|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break X}d=k;if((c|0)==255){break d}}l=Vj(x[M>>2],d&255);s=qg(e+444|0);kj(l);if(y[e+891|0]<=1){c=Bb(z[e+586>>1]);if(c>>>0>256){break Q}f=e+188|0;RY(f,e+584|0);x[31725]=0;S(534,l|0,f|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break W}ia=e,ja=wb(x[l>>2]),x[ia+188>>2]=ja;f=wb(x[l+4>>2]);while(1){c=x[e+188>>2];if(Ib(c,f)){w[c>>1]=z[c>>1]+m;Md(e+188|0);continue}break}Xh(a,1);w[e+188>>1]=16;c=z[Nc(F,e+188|0)>>1];d=0;while(1)if((c|0)==(d|0)){c=32;break M}else{v[e+188|0]=y[(d+e|0)+850|0];v[e+128|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Rb(e+188|0,e+128|0)|0],w[ia>>1]=ja;d=d+1|0;continue}}RY(e+188|0,e+584|0);c=Bb(z[e+200>>1]);if(!c|c>>>0>64|z[F>>1]>64){break Q}j=$b(x[e+208>>2]);c=Bb(z[e+212>>1]);if(c){w[e+128>>1]=c;w[e+88>>1]=800;c=Bc(((z[Nc(e+128|0,e+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{c=32}f=x[e+196>>2];x[31725]=0;f=P(151,b|0,$b(f)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break V}d=0;Z:{if(!f){break Z}while(1){if(z[F>>1]<=d>>>0){break Z}x[31725]=0;f=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){v[e+128|0]=f;v[e+88|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Rb(e+128|0,e+88|0)|0],w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break w}_:{$:{f=$b(x[e+204>>2]);if(!f){break $}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break V}d=0;if(!f){break $}while(1){if(z[F>>1]<=d>>>0){break _}x[31725]=0;f=R(535,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){ia=((d<<5)+a|0)+480284|0,ja=(Yb(f,-16,16)<<3)+128|0,w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break w}Xh(a,1)}f=Nb(e+176|0);d=x[e+192>>2];x[31725]=0;h=P(151,b|0,$b(d)|0)|0;d=x[31725];x[31725]=0;aa:{if((d|0)==1){break aa}g=33;d=0;if(!h){break N}h=z[e+586>>1];i=x[b+8>>2];o=x[b>>2];x[31725]=0;h=U(152,o|0,i|0,Bb(h)<<1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break aa}if(!h){break N}h=z[e+586>>1];x[31725]=0;h=U(536,b|0,f|0,Bb(h)|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break aa}if(!h){break N}ia=e,ja=wb(x[f>>2]),x[ia+172>>2]=ja;o=wb(x[e+180>>2]);u=x[e+188>>2];n=z[e+202>>1];while(1){d=x[e+172>>2];if(!Ib(d,o)){g=0;d=1;break N}d=Bb(y[d|0]|y[d+1|0]<<8);ba:{if(Bb(n)>>>0<d>>>0){break ba}x[31725]=0;P(151,b|0,$b(u)+(d<<2)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break U}x[31725]=0;d=R(283,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}if(!d){break ba}d=x[b+8>>2];g=x[b>>2];x[31725]=0;d=U(152,g|0,d|0,42)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}if(!d){break ba}x[31725]=0;O(537,b|0,e+128|0);d=x[31725];x[31725]=0;ca:{if((d|0)!=1){if(lc(x[l>>2],x[l+4>>2])){break ca}x[31725]=0;O(538,l|0,65534);d=x[31725];x[31725]=0;if((d|0)!=1){break ca}}h=N()|0;break O}d=Bb(y[e+168|0]|y[e+169|0]<<8);x[e+124>>2]=d;g=x[b+8>>2];h=x[b>>2];x[31725]=0;d=U(152,h|0,g|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break T}if(!d){x[31725]=0;d=R(204,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break T}wc(e+124|0,d)}wc(e+124|0,65534);g=x[l+4>>2];h=x[l>>2];d=0;x[31725]=0;i=x[e+124>>2];r=Zc(h,g);O(539,l|0,i+r|0);g=x[31725];x[31725]=0;if((g|0)==1){break P}while(1){da:{if((d|0)==(i|0)){if(y[e+128|0]){Ln(e+88|0,e+128|0);x[31725]=0;d=e+112|0;S(540,d|0,x[e+88>>2],x[e+92>>2]);g=x[31725];x[31725]=0;if((g|0)==1){break S}vp(l,d);tb(d)}d=$b(y[e+160|0]|y[e+161|0]<<8|(y[e+162|0]<<16|y[e+163|0]<<24));if(!d){break ba}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break da}break P}x[31725]=0;g=R(275,b|0)|0;h=x[31725];x[31725]=0;ea:{if((h|0)!=1){g=g<<16>>16;if((g|0)<0){break ea}x[31725]=0;O(538,l|0,g+m&65535);g=x[31725];x[31725]=0;if((g|0)!=1){break ea}}h=N()|0;break O}d=d+1|0;continue}break}if(!d){break ba}while(1){fa:{x[31725]=0;d=P(541,b|0,e+108|0)|0;g=x[31725];x[31725]=0;ga:{ha:{ia:{ja:{if((g|0)!=1){if(!d){break ba}x[31725]=0;d=e+68|0;S(187,d|0,b|0,y[e+111|0]);g=x[31725];x[31725]=0;if((g|0)==1){break ja}g=ic(e+88|0,d);ub(d);h=Bb(z[e+108>>1]);d=km(h+r|0);w[e+68>>1]=d;if((h|0)==65535){break fa}h=x[l>>2];if(Zc(h,x[l+4>>2])>>>0<=d>>>0){break fa}i=65535;switch(y[e+110|0]-1|0){case 0:break ha;case 1:break ia;default:break ga}}h=N()|0;break O}h=N()|0;break O}x[31725]=0;d=R(275,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break R}x[31725]=0;h=P(542,s|0,e+68|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break R}w[h>>1]=d;h=x[l>>2];i=65534;d=z[e+68>>1]}ia=_b(h,d),ja=i,w[ia>>1]=ja}ub(g);continue}break}ub(g)}Md(e+172|0);continue}}h=N()|0;break O}h=N()|0;break f}h=N()|0;break w}h=N()|0;break w}h=N()|0;break O}h=N()|0;break O}h=N()|0;break O}h=N()|0;ub(g);break O}cD(s);break d}h=N()|0}md(f);break w}md(f);if(!d){break L}c=c>>>(j>>>1&1)|0}j=Bb(z[e+844>>1]);g=y[e+847|0];_=g&64;f=y[e+848|0];T=f&32;I=(f&31)+1|0;ia=a,ja=OY(j,_>>>6|0,T>>>5|0,I),x[ia+480204>>2]=ja;ia=a,ja=Kd(y[e+849|0],1,32),x[ia+480196>>2]=ja;if(T){x[a+480216>>2]=I;x[a+480220>>2]=I<<2}f=y[e+866|0];if(f){v[e+188|0]=f;v[e+128|0]=64;ia=a,ja=y[Rb(e+188|0,e+128|0)|0]<<2,x[ia+480200>>2]=ja}x[a+480228>>2]=c;x[a+480232>>2]=c;x[a+480208>>2]=x[a+480208>>2]&-3|(g^-1)>>>4&2;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{c=$b(x[e+548>>2]);ua:{if(!c){break ua}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ua}c=x[e+552>>2];x[31725]=0;S(272,b|0,Z|0,$b(c)|0);c=x[31725];x[31725]=0;if((c|0)==1){break ta}if(y[X|0]<2){break ua}x[31725]=0;c=e+56|0;S(260,c|0,28,Z|0);f=x[31725];x[31725]=0;if((f|0)==1){break ta}vp(l,c);tb(c)}va:{if($b(x[e+520>>2])>>>0<2){break va}c=x[e+516>>2];x[31725]=0;c=P(151,b|0,$b(c)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break va}c=x[e+520>>2];x[31725]=0;V(338,B|0,b|0,$b(c)-1|0,4);c=x[31725];x[31725]=0;if((c|0)==1){break ta}}c=$b(x[e+560>>2]);if(!c){break ka}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ka}c=x[b+8>>2];f=x[b>>2];x[31725]=0;c=U(152,f|0,c|0,12)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ka}x[31725]=0;P(185,b|0,6)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ta}x[31725]=0;c=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if((c|0)!=1){break ka}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ra}if(!c){break ka}f=x[b+8>>2];d=x[b>>2];x[31725]=0;f=U(152,d|0,f|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ra}if(f){break sa}break ka}h=N()|0;break w}f=_G(e+188|0,B);x[31725]=0;V(338,B|0,b|0,c|0,4);c=x[31725];x[31725]=0;if((c|0)==1){break ma}if(!Ad(x[e+192>>2],y[e+199|0])){x[31725]=0;c=U(543,e+32|0,2,13)|0;d=x[31725];x[31725]=0;if((d|0)==1){break qa}x[31725]=0;d=e+128|0;S(544,d|0,f|0,c|0);j=x[31725];x[31725]=0;if((j|0)==1){break pa}x[31725]=0;j=e+44|0;S(545,j|0,d|0,B|0);h=x[31725];x[31725]=0;if((h|0)==1){break oa}Ab(B,j);tb(j);tb(d);tb(c)}tb(f);break ka}h=N()|0;break w}h=N()|0;break la}h=N()|0;break na}h=N()|0;tb(e+128|0)}tb(c);break la}h=N()|0}tb(f);break w}wa:{J=y[e+891|0];if(J>>>0<2){break wa}h=0;if(!$b(x[e+572>>2])){break wa}while(1){if(z[F>>1]<=h>>>0){break wa}c=x[e+572>>2];x[31725]=0;c=P(151,b|0,$b(c)+(h<<2)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}xa:{if(!c){break xa}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}i=0;d=0;if(!c){break xa}while(1){ya:{c=x[b+8>>2];f=x[b>>2];x[31725]=0;c=U(152,f|0,c|0,8)|0;f=x[31725];x[31725]=0;za:{Aa:{Ba:{if((f|0)!=1){if(!c){break ya}x[31725]=0;O(546,b|0,e+188|0);c=x[31725];x[31725]=0;if((c|0)==1){break Ba}c=$b(x[e+188>>2]);if(!c){break ya}switch((c&536870911)-1|0){case 1:break za;case 0:break Aa;default:continue}}h=N()|0;break w}h=N()|0;break w}i=$b(x[e+192>>2]);continue}d=$b(x[e+192>>2]);continue}break}if(!i|!d){break xa}x[31725]=0;c=P(151,b|0,i|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}if(!c){break xa}x[31725]=0;S(426,b|0,((h<<5)+a|0)+480289|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break y}}h=h+1|0;continue}}ia=e,ja=Bb(z[e+584>>1]),w[ia+172>>1]=ja;Gf(e+172|0,(m^-1)&65535);x[31725]=0;u=z[e+172>>1];O(225,q|0,u+m&65535);c=x[31725];x[31725]=0;Ca:{if((c|0)==1){break Ca}ba=g&16;ca=m&65535;n=0;Da:{Ea:{while(1){if((n|0)==(u|0)){ia=e,ja=_i(x[s>>2]),x[ia+128>>2]=ja;g=Rf(s);while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{c=x[e+128>>2];if(!Zg(c,g)){c=$b(x[e+504>>2]);if(c){break Ka}g=31;break Ja}c=ip(c);f=af(c);d=z[c>>1];if(!d){d=0;break Ia}j=d-1&65535;if(!bj(l,j)){break Ia}x[31725]=0;d=P(370,l|0,j|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fa}break Ha}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ca}g=c?0:31}m=m+u|0;break L}if(z[f>>1]==(d+1|0)){break Ga}x[31725]=0;d=P(369,q|0,1)|0;j=x[31725];x[31725]=0;if((j|0)==1){break Fa}if((d|0)==65535){break Ga}ia=_b(x[l>>2],z[c>>1]),ja=d,w[ia>>1]=ja}c=Wb(x[q>>2],d);ye(c,Fn(Ye(Ne(e+188|0,12,_v(z[f>>1])),x[c+12>>2]-1|0)));u=(u&65535)>>>0>d>>>0?u:d+1|0}ah(e+128|0);continue}break}h=N()|0;break w}La:{Ma:{if(!aa){break Ma}c=y[e+908|0]|y[e+909|0]<<8|(y[e+910|0]<<16|y[e+911|0]<<24);x[31725]=0;c=P(151,b|0,$b(c)+(n<<2)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}if(!c){break Ma}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}if(!c){break Ma}A=Fb(e+68|0);x[31725]=0;c=v[e+846|0];K=R(170,e+12|0)|0;f=x[31725];x[31725]=0;Na:{Oa:{if((f|0)!=1){j=c+48|0;if(J){break Oa}x[31725]=0;O(547,b|0,e+188|0);c=x[31725];x[31725]=0;if((c|0)==1){break La}w[e+124>>1]=y[e+188|0];r=y[e+189|0]+1|0;break Na}h=N()|0;break z}x[31725]=0;O(548,b|0,e+176|0);f=x[31725];x[31725]=0;Pa:{Qa:{if((f|0)!=1){d=Bb(z[e+176>>1]);w[e+124>>1]=d;r=Bb(z[e+178>>1])+1|0;f=$b(z[e+180>>1]|z[e+182>>1]<<16);if(!f){break Pa}g=x[b+8>>2];x[31725]=0;P(151,b|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}x[31725]=0;O(549,b|0,e+188|0);f=x[31725];x[31725]=0;if((f|0)==1){break A}f=y[e+192|0]|y[e+193|0]<<8|(y[e+194|0]<<16|y[e+195|0]<<24);x[31725]=0;f=P(151,b|0,$b(f)|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!f){break Qa}f=y[e+196|0]|y[e+197|0]<<8|(y[e+198|0]<<16|y[e+199|0]<<24);x[31725]=0;S(272,b|0,A|0,$b(f)|0);f=x[31725];x[31725]=0;if((f|0)!=1){break Qa}break A}break A}f=$b(y[e+204|0]|y[e+205|0]<<8|(y[e+206|0]<<16|y[e+207|0]<<24));Ra:{if(!f){break Ra}x[31725]=0;f=P(151,b|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!f){break Ra}x[31725]=0;f=R(283,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}x[31725]=0;f=P(151,b|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!f){break Ra}x[31725]=0;f=e+88|0;S(187,f|0,b|0,D(d,r)|0);d=x[31725];x[31725]=0;if((d|0)==1){break A}d=ic(e+128|0,f);hd(K,d);ub(d);ub(f)}x[31725]=0;P(151,b|0,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}}j=J>>>0>2?c+24|0:j}x[31725]=0;c=n+ca|0;f=U(198,q|0,c&65535,r|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}Sa:{if(!f){break Sa}f=x[q>>2];x[31725]=0;o=Wb(f,c);O(285,o|0,A|0);c=x[31725];x[31725]=0;if((c|0)==1){break Da}Gf(e+124|0,z[F>>1]);da=r-1|0;c=0;ea=z[e+124>>1];Ta:while(1){if((c|0)==(r|0)){break Sa}f=c+1|0;fa=c-1|0;h=0;d=jd(x[o>>2],x[x[o+48>>2]+12>>2],c,0);while(1){G=h&65535;if(ea>>>0<=G>>>0){c=f;continue Ta}vD(e+128|0,y[d+3|0],d+5|0);Ua:{if(!J){x[31725]=0;g=e+188|0;O(550,g|0,b|0);i=x[31725];x[31725]=0;if((i|0)!=1){i=y[e+188|0];C=Jc(g);v[d+1|0]=i>>>3&16|y[C|0]>>>4|i>>>1&32;C=y[C|0];ia=d,ja=y[af(g)|0],v[ia+5|0]=ja;g=i&63;g=g?g+j|0:0;i=C&15;break Ua}break A}x[31725]=0;g=e+188|0;O(359,g|0,b|0);i=x[31725];x[31725]=0;Va:{Wa:{if((i|0)!=1){i=Jc(g);C=af(g);W=ej(g);x[31725]=0;g=R(199,K|0)|0;E=x[31725];x[31725]=0;if((E|0)==1){break A}v[d+4|0]=g;E=y[e+188|0];g=E&127;if(!g){break Wa}g=g+j|0;break Va}break A}g=0;if((E|0)!=128){break Va}v[d|0]=254}v[d+1|0]=y[i|0]&63;i=y[C|0];v[d+5|0]=y[W|0]}if(g-1>>>0<=119){v[d|0]=g}W=(g|0)>84;C=e+188|0;E=(_|0)!=0;ga=(T|0)!=0;ha=(ba|0)!=0;g=fb-16|0;fb=g;v[d+3|0]=0;Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{i=i&255;switch(i-4|0){case 4:case 10:break Ya;case 42:break _a;case 37:break $a;case 28:break ab;case 27:break bb;case 26:break cb;case 25:break db;case 24:break eb;case 23:break fb;case 22:break gb;case 21:break hb;case 20:break ib;case 18:break jb;case 17:break kb;case 16:break lb;case 14:break mb;case 13:break nb;case 12:break ob;case 11:break pb;case 9:break qb;case 8:break rb;case 5:break sb;case 0:break tb;default:break Za}}v[d+3|0]=5;i=y[d+5|0];v[g+15|0]=i>>>3;v[g+14|0]=15;E=y[Rb(g+15|0,g+14|0)|0];v[g+13|0]=i<<1&30;v[g+12|0]=15;ia=d,ja=y[Rb(g+13|0,g+12|0)|0]|E<<4,v[ia+5|0]=ja;break Ya}if((y[d+5|0]-1&255)>>>0>19){break Ya}v[d+3|0]=16;break Ya}v[d+3|0]=13;i=y[d+5|0];ub:{if(!ha){if(i>>>0>152){break ub}v[d+5|0]=D((i&240)>>>4|0,10)+(i&15);break Ya}v[d+5|0]=(i&127)+1>>>1;break Ya}v[d+3|0]=0;break Ya}v[d+3|0]=11;break Ya}i=y[d+5|0];if(!i){v[d+3|0]=14;break Ya}if(i>>>0>240){break Ya}v[d+3|0]=17;if(i>>>0<=2){v[d+5|0]=112;break Ya}i=HD(+(OY(i,E,ga,I)>>>0)/1e4);if(i>>>0<=255){v[d+5|0]=i;break Ya}v[d+5|0]=i>>>8;v[g+11|0]=i;de(C,34,g+11|0);break Xa}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Ya}v[d+3|0]=19;v[g+10|0]=15;ia=d,ja=y[Rb(d+5|0,g+10|0)|0]|16,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+9|0]=15;ia=d,ja=y[Rb(d+5|0,g+9|0)|0]|32,v[ia+5|0]=ja;break Ya}v[d+3|0]=5;i=y[d+5|0];v[g+8|0]=(i>>>4|0)+1;v[g+7|0]=15;ia=d,ja=i&15|y[Rb(g+8|0,g+7|0)|0]<<4,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Ya}v[d+3|0]=19;v[g+6|0]=15;ia=d,ja=y[Rb(d+5|0,g+6|0)|0]|96,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+5|0]=15;ia=d,ja=y[Rb(d+5|0,g+5|0)|0]|192,v[ia+5|0]=ja;break Ya}v[d+3|0]=10;break Ya}v[d+3|0]=19;v[g+4|0]=15;ia=d,ja=y[Rb(d+5|0,g+4|0)|0]|160,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+3|0]=15;ia=d,ja=y[Rb(d+5|0,g+3|0)|0]|176,v[ia+5|0]=ja;break Ya}i=y[d+5|0]-1<<24>>24;if((i|0)<0){break Ya}v[d+5|0]=i;v[d+3|0]=31;break Ya}v[d+3|0]=14;break Ya}v[d+3|0]=19;v[g+2|0]=15;ia=d,ja=y[Rb(d+5|0,g+2|0)|0]|224,v[ia+5|0]=ja;break Ya}i=y[d+5|0];if(i>>>0>=16){v[d+3|0]=19;v[d+5|0]=i>>>4|208;break Ya}if(!i){break Ya}v[d+3|0]=19;v[d+5|0]=i|144;break Ya}if(y[d+5|0]|y[d+4|0]){break Ya}if(!Tc(y[d|0])){break Ya}v[d+5|0]=159;v[d+3|0]=20;break Ya}i=y[d+4|0];if(!i){break Ya}v[d+3|0]=44;ia=d,ja=yi(Bc(((y[d+5|0]<<8&65280)>>>0)/(i>>>0)|0,0)),v[ia+5|0]=ja;break Ya}i=y[d+5|0];if((i+16&255)>>>0>32){break Ya}v[d+3|0]=9;ia=d,ja=Dh(((i^128)<<3)-896|0),v[ia+5|0]=ja;break Ya}if(i>>>0>15){break Ya}Bf(d,i,y[d+5|0])}v[g+1|0]=0;vD(C,0,g+1|0)}fb=g+16|0;vb:{if(y[e+128|0]!=34){break vb}if(!y[d+3|0]){g=z[e+128>>1];v[d+3|0]=g;v[d+5|0]=g>>>8;break vb}if(!c){break vb}ia=jd(x[o>>2],x[x[o+48>>2]+12>>2],fa,G),ja=255,v[ia+5|0]=ja}g=W&Y;wb:{if(!y[e+188|0]){break wb}if(c>>>0<da>>>0){i=jd(x[o>>2],x[x[o+48>>2]+12>>2],f,G);G=z[e+188>>1];v[i+3|0]=G;v[i+5|0]=G>>>8;break wb}v[d+5|0]=255}t=g|t;d=d+6|0;h=h+1|0;continue}}}ub(K);tb(A)}n=n+1|0;continue}break}break A}h=N()|0;break w}break A}h=N()|0;break w}cD(s);d=0;xb:{switch(g-31|0){default:if(g){break c}break;case 2:break xb;case 1:break c;case 0:break K}}k=k+1|0;continue}break}ck(M,0);d=1;if(t&1){break B}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break B}b=((b<<2)+a|0)+900380|0;c=x[b>>2];if(c){Db(Iv(c))}x[b>>2]=0;d=d+1|0;continue}}h=N()|0;break f}yb:{if(!$){break yb}x[31725]=0;b=P(1,e+188|0,16403)|0;c=x[31725];x[31725]=0;zb:{if((c|0)!=1){c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break zb}tb(b);break yb}h=N()|0;break f}h=N()|0;tb(b);break f}g=22267;Ab:{Bb:{switch(y[e+891|0]){case 0:g=z[F>>1]>4?17291:17277;break Ab;case 1:g=17259;break Ab;case 2:g=17241;break Ab;case 3:break Bb;default:break Ab}}g=17214}x[31725]=0;b=e+88|0;O(551,b|0,16813);c=x[31725];x[31725]=0;Cb:{Db:{Eb:{if((c|0)!=1){x[31725]=0;c=e+128|0;S(552,c|0,b|0,e+891|0);f=x[31725];x[31725]=0;if((f|0)==1){break Eb}Ab(a+1298344|0,c);tb(c);Eb(b);x[31725]=0;c=P(1,c|0,12706)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Db}Ab(a+1298356|0,c);tb(c);x[31725]=0;O(132,a+1298368|0,g|0);c=x[31725];x[31725]=0;if((c|0)==1){break Cb}ia=a+1298404|0,ja=x[Fc(b,28)>>2],x[ia>>2]=ja;d=1;break c}h=N()|0;break f}h=N()|0;Eb(e+88|0);break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;ub(K)}tb(A);break w}h=N()|0;break w}h=N()|0}cD(s);break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;break f}k=1;if((d|0)!=7){break m}d=f+108|0;j=NC(d);while(1){if((d|0)!=(j|0)){ia=d,ja=jm(y[d|0]-24|0),v[ia|0]=ja;d=d+1|0;continue}break}j=0}t=1;break l}j=0;Fb:{if(B|(g|0)<0){break Fb}i=f+108|0;h=7;Gb:while(1){if((h|0)==10){break Fb}q=D(h,12);n=D(h,-12)+72|0;d=0;while(1)if((d|0)==12){h=h+1|0;continue Gb}else{r=xb(i,d+q|0);v[r|0]=n+y[r|0];d=d+1|0;continue}}}}x[31725]=0;O(553,L|0,e+188|0);d=x[31725];x[31725]=0;if((d|0)!=1){Hb:{d=y[e+192|0];if((d-1&255)>>>0<=15){v[f+31|0]=d;t=1}d=y[e+193|0];if(d-1<<24>>24>=0){v[f+30|0]=d}d=0;Ib:{while(1){if((d|0)==(k|0)){if(!u){break j}if((g|0)>=0){break Ib}break j}x[31725]=0;f=D(d+o|0,104)+a|0;O(281,f+484380|0,8);h=x[31725];x[31725]=0;if((h|0)!=1){v[e+128|0]=y[e+194|0];v[e+68|0]=64;ia=f+484410|0,ja=y[Rb(e+128|0,e+68|0)|0]<<2,w[ia>>1]=ja;v[f+484416|0]=y[e+195|0];d=d+1|0;continue}break}break k}f=Xc(e+128|0,8,1,1,0);q=Bb(z[e+190>>1]);h=Bb(z[e+188>>1]);d=x[l>>2];x[31725]=0;g=R(156,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=xe(w[e+92>>1]);if(d&16){fd(f,16);g=g>>>1|0}if(d&32){Cp(f,3);g=g>>>1|0}if(d&64){yg(f,2)}g=j?(g>>>0)/((-1<<k^-1)>>>0)|0:g;i=h+q|0;d=0;while(1){if((d|0)==(k|0)){break j}j=D(d+o|0,104)+a|0;n=j+484380|0;x[n>>2]=g;x[31725]=0;U(217,f|0,n|0,l|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break Hb}h=h<<1;i=i<<1;if(q>>>0>=2){x[j+484388>>2]=i;x[j+484384>>2]=h;j=j+484414|0;w[j>>1]=z[j>>1]|2}d=d+1|0;g=g<<1;continue}}}}}h=N()|0;ub(l);break f}ub(l);s=s+1|0;m=k+m|0;g=z[a+480192>>1];continue}}h=N()|0;break e}h=N()|0;break e}h=N()|0}uc(H)}ub(L);Q(h|0);p()}d=0}uc(H)}ub(L)}fb=e+944|0;return d|0}function dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,F=E(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=E(0),ea=0,fa=0,ga=0,ia=0,ja=0;e=fb-608|0;fb=e;xc(b);a:{b:{c:{f=e+600|0;if(!Bi(b,f)){break c}if(!DW(f)){break c}if((up(b)|0)>=0){break c}if(!c){d=1;break c}Bd(a,16777216);x[a+480208>>2]=x[a+480208>>2]|1681e4;xr(e+256|0,32);f=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=f;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;dg(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);u=Nb(e+564|0);k=Nb(e+552|0);Gh(b,4);i=a+480190|0;K=c&1;H=a+1298332|0;s=2500;I=!(c&2);d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,4)|0;d=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[31725]=0;c=R(713,b|0)|0;d=x[31725];x[31725]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ia=a,ja=Yb(512/(d>>>0)|0,16,128),x[ia+480228>>2]=ja;continue}c=N()|0;break a;case 19:x[31725]=0;M=R(283,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ia=a,ja=_e(+A[Gb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ia+480204>>2]=ja;continue}c=N()|0;break a;case 31:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break o}Z=1;s=Kd(c,0,1e4);continue;case 32:case 33:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[31725]=0;d=P(1,e+540|0,12615)|0;c=x[31725];x[31725]=0;if((c|0)==1){break t}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31725]=0;P(185,b|0,4)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!lc(x[q>>2],x[q+4>>2])){break q}x[31725]=0;c=e+256|0;O(714,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){if(x[q>>2]){jY(q);d=x[q>>2];bp(q);Db(d);ia=zb(q),ja=0,x[ia>>2]=ja;x[q>>2]=0;x[q+4>>2]=0}x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=zb(c);ia=zb(q),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Xi(c);continue}c=N()|0;break a;case 3:case 4:case 10:f=Sh(x[k>>2],x[k+4>>2]);d=z[i>>1];if(f>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!ui(d)){break q}d=d+1|0;w[i>>1]=d;t=Nb(e+528|0);x[31725]=0;m=R(170,e+508|0)|0;g=x[31725];x[31725]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[31725]=0;g=R(283,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}x[31725]=0;c=e+152|0;S(187,c|0,b|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break u}g=ic(e+256|0,c);hd(m,g);ub(g);break g}c=N()|0;break d}x[31725]=0;c=e+256|0;O(715,c|0,b|0);g=x[31725];x[31725]=0;x:{if((g|0)!=1){g=En(t,c);dc(c);oe(e+480|0,x[g>>2],x[e+532>>2]);c=Nd(e+472|0);x[31725]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=jg(329,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[31725];x[31725]=0;if((g|0)==1){break x}hd(m,c);break g}c=N()|0;break e}c=N()|0;break e}x[31725]=0;c=e+256|0;O(716,c|0,b|0);g=x[31725];x[31725]=0;y:{if((g|0)!=1){g=En(t,c);dc(c);oe(e+440|0,x[g>>2],x[e+532>>2]);c=Nd(e+432|0);x[31725]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=jg(329,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[31725];x[31725]=0;if((g|0)==1){break y}hd(m,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[i>>1];if(!ui(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!lc(x[u>>2],x[u+4>>2])){break q}x[31725]=0;c=e+256|0;O(717,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){CW(u,c);uc(c);continue}c=N()|0;break a;case 7:if(!lc(x[k>>2],x[k+4>>2])){break q}x[31725]=0;c=e+256|0;O(718,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){if(x[k>>2]){YV(k);d=x[k>>2];lC(k);Db(d);ia=zb(k),ja=0,x[ia>>2]=ja;x[k>>2]=0;x[k+4>>2]=0}x[k>>2]=x[c>>2];x[k+4>>2]=x[c+4>>2];d=zb(c);ia=zb(k),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;sv(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!lc(x[r>>2],x[r+4>>2])){break q}x[31725]=0;c=e+256|0;O(719,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){if(x[r>>2]){bW(r);d=x[r>>2];hv(r);Db(d);ia=zb(r),ja=0,x[ia>>2]=ja;x[r>>2]=0;x[r+4>>2]=0}x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=zb(c);ia=zb(r),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;qn(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[31725]=0;d=e+256|0;O(720,d|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];f=x[e+260>>2];if(lc(c,f)){break z}x[31725]=0;V(345,H|0,c|0,Sc(c,f)|0,1);c=x[31725];x[31725]=0;if((c|0)!=1){break z}c=N()|0;dc(d);break a}dc(e+256|0);continue}x[31725]=0;n=R(283,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}}x[31725]=0;P(185,b|0,n|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[k>>2];c=x[k+4>>2];if(lc(b,c)){break m}if(K){if(lc(x[q>>2],x[q+4>>2])){break m}if(lc(x[u>>2],x[u+4>>2])){break m}if(lc(x[r>>2],x[r+4>>2])){break m}}b=Sh(b,c);if(b>>>0>=256){x[31725]=0;O(721,k|0,255);b=x[31725];x[31725]=0;if((b|0)==1){break b}b=Sh(x[k>>2],x[k+4>>2])}w[a+480192>>1]=b;n=a+480192|0;ia=a,ja=z[qe(i,n)>>1],w[ia+480190>>1]=ja;if(g&1){x[31725]=0;b=P(1,e+528|0,16492)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}tb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){h=d&65535;if(h>>>0>z[n>>1]){g=g+1|0;continue A}B:{f=on(x[k>>2],h-1|0);if(!y[f|0]|v[f+128|0]<0){break B}if((nv(f)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!nv(f)){break F}if(Bb(y[f+6|0]|y[f+7|0]<<8)){break F}if(Bb(y[f+14|0]|y[f+15|0]<<8)>>>0>20){break F}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==4}G:{H:{if(c){c=y[f+23|0];b=y[f+140|0];x[31725]=0;b=ha(722,f|0,a|0,(b&2)>>>1|0,(D(h,104)+a|0)+484380|0,s&65535)|0;l=x[31725];x[31725]=0;I:{J:{if((l|0)!=1){if(!b){break I}x[31725]=0;b=P(36,e+384|0,10755)|0;l=x[31725];x[31725]=0;if((l|0)==1){break J}zc(((h<<5)+a|0)+946304|0,b);tb(b);l=x[k>>2];b=d;if(Sh(l,x[k+4>>2])>>>0<=c>>>0){break G}ia=f,ja=y[f+143|0]+y[on(l,c)+143|0]|0,v[ia+143|0]=ja;break H}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break G}c=0;K:{if(!nv(f)){break K}if((Bb(y[f+6|0]|y[f+7|0]<<8)|0)!=1){break K}if((Bb(y[f+14|0]|y[f+15|0]<<8)|0)!=2){break K}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==10}b=d;if(!c){break G}c=e+256|0;tW(c,f);b=Bb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[i>>1]){break H}x[31725]=0;l=R(711,e+152|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break E}m=y[e+292|0]|y[e+293|0]<<8;o=z[a+480190>>1];x[31725]=0;t=c;C=D(b,104);b=a+484380|0;c=Bb(m);b=ba(723,t|0,(C+b|0)+104|0,(c>>>0<o>>>0?(b+D(c,104)|0)+104|0:l)|0,b+D(h,104)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}if(!b){break H}x[31725]=0;b=P(36,e+140|0,11253)|0;c=x[31725];x[31725]=0;if((c|0)==1){break C}zc(((h<<5)+a|0)+946304|0,b);tb(b);v[f+139|0]=y[f+139|0]+12}b=d}x[31725]=0;b=b&65535;c=U(253,a|0,h|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[31725]=0;V(724,f|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}I=qg(e+128|0);t=qg(e+116|0);b=oc(x[u>>2],x[u+4>>2]);_=D(z[a+480188>>1],M);$=km((b>>>0)/(_>>>0)|0);x[31725]=0;X=a+484344|0;O(225,X|0,$|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}kj(Xb(x[a+484360>>2],y[a+484376|0]));b=z[a+480188>>1];x[31725]=0;C=P(725,e+104|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}ia=e,ja=wb(x[r>>2]),x[ia+52>>2]=ja;ea=a+902204|0;fa=wb(x[r+4>>2]);while(1){L:{M:{N:{m=x[e+52>>2];if(!Ib(m,fa)){break N}b=xe((y[m+6|0]|y[m+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Bb(y[m|0]|y[m+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=Lg(b,f);if(g>>>0>=c>>>0){break L}d=Bb(y[m+2|0]|y[m+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Lg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];gc(e+76|0,b+(Bb(y[m|0]|y[m+1|0]<<8)<<5)|0,Bb(y[m+2|0]|y[m+3|0]<<8));O:{G=Xb(x[a+484360>>2],y[a+484376|0]);if(lc(x[G>>2],x[G+4>>2])){break O}x[31725]=0;O(538,G|0,65534);b=x[31725];x[31725]=0;if((b|0)!=1){break O}break M}ia=e,ja=wb(x[e+76>>2]),x[ia+40>>2]=ja;b=fb-16|0;fb=b;ga=x[vb(b+12|0,x[e+76>>2]+(x[e+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[e+40>>2];if(!Ib(i,ga)){break L}b=xe(xe((y[m+8|0]|y[m+9|0]<<8)<<16>>16)+xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=ce(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!jv(i,d)){c=1;if(!jv(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31725]=0;b=P(726,I|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}H=z[b>>1];break S}H=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31725]=0;H=P(369,X|0,Bb(b)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break M}if((H|0)==65535){break L}x[31725]=0;b=P(726,I|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}w[b>>1]=H;if(Bb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Bb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}l=Bb(y[i+14|0]|y[i+15|0]<<8);c=Lk(wb(x[u>>2]),D(Bb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ia=e,ja=Lk(c,D(b,Bb(y[i+10|0]|y[i+11|0]<<8))),x[ia+28>>2]=ja;T=0;x[e+100>>2]=0;o=bh(e- -64|0);T:while(1){U:{d=Bb(y[i+12|0]|y[i+13|0]<<8);c=Wb(x[X>>2],H);if(d>>>0<=T>>>0){break U}n=0;Y=jd(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){T=T+1|0;continue T}b=wb(x[u+4>>2]);d=x[e+28>>2];h=Ib(d,b)?d:e+100|0;b=wb(x[u+4>>2]);if(Ib(x[e+28>>2],b)){AW(e+28|0)}d=Y+D(n,6)|0;g=y[h+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[k>>2];L=Sh(f,x[k+4>>2]);J=y[h+3|0];V:{if(L>>>0<=J>>>0){break V}s=J+1|0;if(v[on(f,J)+142|0]&1|(b|0)<0){break V}b=jm(xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!y[d|0]|!(y[h|0]|(g|0)!=255|J|y[h+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[on(f,g-1|0)+132|0]!=2){break W}$o(d)}f=pv(x[C>>2],n);X:{Y:{if(!(c&1)){g=y[h|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[pv(x[C>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[h|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[h+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((l&255)>>>0<2){break $}l=l-1|0;break aa;case 7:if((l&255)==255){l=255;break $}l=l+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[h+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){break $}ia=f,ja=fm(+(b>>>0)*.64),v[ia+19|0]=ja;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Rb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0]>>>3;ia=f,ja=y[Rb(e+256|0,e+96|0)|0]|b<<4,v[ia+24|0]=ja;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=Dh((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+96>>2]=D(b,(l&255)-1|0);ia=f,ja=c-x[ud(e+256|0,e+96|0)>>2]|0,w[ia+32>>1]=ja;break _;case 13:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Rb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0];ia=f,ja=y[Rb(e+256|0,e+96|0)|0]|b<<4,v[ia+23|0]=ja;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=ce(t);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!lv(h,g)){c=1;if(!lv(g,h)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31725]=0;b=P(727,t|0,h|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[zb(t)>>2];if(b>>>0>127){break _}x[e+92>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=Oe(ea,b&255);g=x[a+480208>>2];x[31725]=0;x[e+24>>2]=x[e+92>>2];c=U(728,e+24|0,c|0,g|0)|0;g=x[31725];x[31725]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[31725]=0;c=P(727,t|0,h|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;aa=(y[h|0]&254)==24|aa;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+96>>2]=y[h+3|0]+1;ia=d,ja=x[ud(e+256|0,e+96|0)>>2],v[ia+5|0]=ja;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];l=b?b:4;v[d+5|0]=l;break _;case 19:ia:{b=y[h+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[h+3|0]:g;v[e+91|0]=g;v[e+256|0]=y[h+2|0];v[e+96|0]=100;b=e+256|0;s=e+96|0;c=y[Rb(b,s)|0];x[e+256>>2]=128;x[e+96>>2]=256-(g&255);g=x[ud(b,s)>>2];v[e+256|0]=128;b=y[Rb(b,e+91|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Bc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;h=pv(x[C>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){ca=(Wi(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ia=d,ja=fm(ca+ +(c+y[h+2|0]|0)),v[ia+5|0]=ja}w[f+32>>1]=0;break _}v[d+5|0]=l;v[d+3|0]=16}b=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[k>>2];if(Sh(b,x[k+4>>2])>>>0<=J>>>0){break _}if(y[on(b,J)+132|0]!=1){break _}g=n+1|0;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=pv(x[C>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=l&255;w[e+256>>1]=b;c=f+30|0;ia=c,ja=z[qe(c,e+256|0)>>1]-b|0,w[ia>>1]=ja;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=l&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;F=E(g|0);if(!(F<=j)){break pa}v[e+256|0]=15;ia=e,ja=Ah(E(j/F)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+256|0]=15;ia=e,ja=Ah(E(E(-j)/F)),v[ia+96|0]=ja;c=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+256|0]=14;ia=e,ja=Ah(E(-j)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+256|0]=15;ia=e,ja=Ah(j),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=l&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;F=E(c|0);if(!(F<=j)){break ta}v[e+256|0]=223;ia=e,ja=Ah(E(j/F)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[e+256|0]=223;ia=e,ja=Ah(E(E(-j)/F)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+256|0]=14;ia=e,ja=Ah(E(-j)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}da=E(j*E(.25));c=b-1|0;F=E(c|0);if(da>=F){v[e+256|0]=9;ia=e,ja=Ah(E(j/F))>>>2|0,v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(da<=E(1-b|0))){break qa}v[e+256|0]=9;ia=e,ja=Ah(E(E(-j)/F))>>>2|0,v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+256|0]=15;ia=e,ja=Ah(j),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(l&255)-1|0);ia=f,ja=z[f+32>>1]-z[Nc(c,e+256|0)>>1]|0,w[ia+32>>1]=ja}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],l&255)&1023;c=0;if(n&1){break X}b=y[f+18|0];if(!b){break X}g=x[k>>2];if(Sh(g,x[k+4>>2])>>>0<b>>>0){break X}g=on(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+65|0];if(!b|y[g+132|0]!=1){break X}v[e+65|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}ye(c,Yh(Ye(Ne(e+256|0,16,Bb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=lm(x[G>>2],x[G+4>>2]);ia=e,ja=Bb(y[i+4|0]|y[i+5|0]<<8),w[ia+256>>1]=ja;w[e+64>>1]=1;c=z[qe(e+256|0,e- -64|0)>>1];x[31725]=0;V(729,G|0,b|0,c|0,H&65535);b=x[31725];x[31725]=0;if((b|0)==1){break Q}b=xe((y[m+8|0]|y[m+9|0]<<8)<<16>>16);b=xe(xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}dr(e+40|0);continue}break}break M}d=aa&1;if(d){g=a+906300|0;b=vd(g,0);x[31725]=0;W(288,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+256>>2]=0;f=b+48|0;c=e+256|0;r0(b+32|0,f,c);x[31725]=0;c=P(36,c|0,9571)|0;h=x[31725];x[31725]=0;if((h|0)==1){break M}tE(f,c);tb(c);x[31725]=0;c=P(36,e+76|0,9564)|0;f=x[31725];x[31725]=0;if((f|0)==1){break M}lw(b+80|0,c);tb(c);x[31725]=0;b=P(36,e- -64|0,9556)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}tE(vd(g,1)+48|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){ZD(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[31725]=0;b=P(1,e+52|0,12165)|0;c=x[31725];x[31725]=0;Ca:{Da:{Ea:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,e+40|0,12383)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}Ab(a+1298356|0,b);tb(b);if(Z){break Ea}x[31725]=0;b=P(1,e+28|0,12165)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}break Da}break M}if(Sh(x[k>>2],x[k+4>>2])>>>0<=128){x[31725]=0;b=P(1,e+28|0,9298)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break Da}break M}x[31725]=0;b=P(1,e+28|0,14808)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ca}}Ab(a+1298368|0,b);tb(b);ia=a+1298404|0,ja=x[Fc(e+100|0,28)>>2],x[ia>>2]=ja;zW(C);nW(t);mW(I);d=1;break m}}c=N()|0;zW(C);break j}_o(e+52|0);continue}}c=N()|0;break a}c=N()|0;break a}sv(k);uc(u);qn(r);Xi(q);break c}c=N()|0;break j}c=N()|0}nW(t);mW(I);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31725]=0;c=d&65535;d=U(730,a|0,c|0,m|0)|0;g=x[31725];x[31725]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=U(731,a|0,c|0,m|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=U(732,a|0,c|0,m|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=P(733,(D(c,104)+a|0)+484380|0,m|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=P(1,e+420|0,16203)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}g=x[a+1298472>>2];x[31725]=0;S(387,g|0,2,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ga}tb(d);break Fa}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ja:{Ka:{La:{C=D(c,104)+a|0;if(y[C+484414|0]&64){d=z[i>>1];if(ui(d)){break La}}d=x[k>>2];if(Sh(d,x[k+4>>2])>>>0<=c>>>0){break Ka}if(y[on(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!ui(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[a+480190>>1]=c;G=D(c&65535,104)+a|0;o=G+484380|0;h=C+484380|0;d=x[h>>2];g=x[h+20>>2];Ma:{if(!je(d,g)){break Ma}c=(h|0)==(o|0);f=z[h+34>>1];if(c|(_d(f)|0)!=2){break Ma}if(!(je(x[o>>2],x[o+20>>2])?c:1)){break Ma}je(x[h>>2],x[h+20>>2]);if(!c){g=mv(d,Pn(f))}f=x[h+20>>2];if(!(f?g:0)){if(!c){aC(g)}break Ma}Na:{Oa:{switch(Pn(z[h+34>>1])-1|0){case 1:d=g;c=f;n=x[h+20>>2];l=x[h>>2];while(1){if(l){w[d>>1]=z[n>>1];w[c>>1]=z[n+2>>1];n=n+4|0;c=c+2|0;d=d+2|0;l=l-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=f;n=x[h+20>>2];l=x[h>>2];while(1){if(l){v[d|0]=y[n|0];v[c|0]=y[n+1|0];n=n+2|0;c=c+1|0;d=d+1|0;l=l-1|0;continue}break}}d=ap(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=ap(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}Qj(d,a);Qj(g,a)}x[31725]=0;c=P(36,e+408|0,6320)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Ja}ze(G+484423|0,c);tb(c);x[31725]=0;c=P(36,e+396|0,6223)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}ze(C+484423|0,c);tb(c)}ub(m);dc(t);g=0;continue}break}c=N()|0;break e}c=N()|0}ub(m)}dc(t);break a}fb=e+608|0;return d|0}c=N()|0}sv(k);uc(u);qn(r);Xi(q);Q(c|0);p()}function Cv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=E(0),la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,xa=0,ya=E(0);i=fb-192|0;fb=i;X=Nb(a);s=i+160|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;ea=x[d+16>>2];a=y[d+6|0];g=x[b+484360>>2];la=(ua=a,va=y[b+484376|0],xa=Oj(g,x[b+484364>>2])>>>0>a>>>0,xa?ua:va);a=la&255;K=Vj(g,a);x[31725]=0;t=P(604,i+128|0,b|0)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){l=x[t+4>>2];x[31725]=0;J=U(605,i+92|0,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}qa=b+484360|0;$=c&7;k=x[d>>2];a=z[d+4>>1];g=Zc(x[K>>2],x[K+4>>2]);while(1){f=a&65535;if(f>>>0>=g>>>0){break e}if(bj(K,f)){break e}a=a+1|0;k=0;continue}}a=N()|0;break c}a=N()|0;break d}x[d>>2]=k;w[d+4>>1]=a;x[l+52>>2]=k;x[l+48>>2]=k;x[s+16>>2]=k;w[l+74>>1]=a;w[l+72>>1]=a;w[s+24>>1]=a;ma=Nd(i+84|0);g:{if(($|0)!=7){break g}a=fb-16|0;fb=a;g=a+8|0;Kb(g,ma,1);gp(g);fb=a+16|0;if((ea|0)!=2){break g}a=x[K>>2];f=Zc(a,x[K+4>>2]);g=z[d+12>>1];if(f>>>0<=g>>>0){break g}f=x[b+484344>>2];k=x[b+484348>>2];a=z[_b(a,g)>>1];if(!He(f,k,a)){break g}g=Wb(f,a);f=x[d+8>>2];if(A[g+12>>2]<=f>>>0){break g}a=0;n=jd(x[g>>2],x[x[g+48>>2]+12>>2],f,0);g=x[t+8>>2];f=z[b+480188>>1];r=z[b+480192>>1];while(1){if((a|0)==(f|0)){break g}h:{i:{j:{k:{e=y[n|0];switch(e-253|0){case 1:case 2:break i;case 0:break k;default:break j}}if(r){break i}}if(!Tc(e)|!y[n+1|0]){break h}if(Ql(y[n+2|0],y[n+3|0])){break h}}ua=Ve(g,a),va=-1,x[ua>>2]=va}n=n+6|0;a=a+1|0;continue}}Y=c&1;if(Y){OT(l+223860|0)}M=l+74|0;L=l+48|0;ra=l+223872|0;R=l+80|0;sa=b+901692|0;ta=b+902204|0;ba=l+44|0;fa=l+223860|0;Z=l+20|0;I=b+1074312|0;na=l+616|0;ca=32768;oa=($|0)!=7;r=0;l:{m:{n:{o:{p:{q:{r:{s:{t:while(1){pa=C[d+8>>3];o(+pa);g=j(1)|0;a=j(0)|0;h=x[d+16>>2];f=a;u:{v:{w:{x:{while(1){NT(i+24|0,x[b+480180>>2],z[b+480188>>1],l,G&1);q=y[i+24|0];if((h|0)==3&C[t+24>>3]>=pa){break x}a=65535;e=x[K>>2];m=Zc(e,x[K+4>>2]);k=z[l+72>>1];if(m>>>0>k>>>0){a=z[_b(e,k)>>1]}w[l+70>>1]=a;m=x[b+484344>>2];e=x[b+484348>>2];n=a&65535;if(!(He(m,e,n)|(h|0)!=2|(n|0)==65535)&(k|0)==(g&65535)){break x}y:{while(1){H=ek(m,e);u=x[K>>2];while(1){k=a&65535;if(k>>>0<H>>>0){break y}a=z[l+72>>1];z:{A:{if((k|0)!=65535){k=Zc(u,x[K+4>>2]);if(a>>>0<k>>>0){break A}}n=z[K+28>>1];if((a|0)==(n|0)){break y}k=Zc(u,x[K+4>>2]);break z}n=a+1|0}w[l+72>>1]=n;a=65535;F=k;k=n&65535;if(F>>>0>k>>>0){a=z[_b(u,k)>>1]}w[l+74>>1]=n;w[l+70>>1]=a;if(He(m,e,a&65535)){continue}break}a=Nq(i+24|0,na);x[31725]=0;a=ha(606,J|0,n&65535,0,a|0,(q|0)!=0|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}if(!a){e=x[b+484348>>2];m=x[b+484344>>2];a=z[l+70>>1];continue}break}if(ea>>>0<=1){a=z[l+72>>1];x[s+8>>2]=0;w[s+20>>1]=a}if(!h){break y}if(!Vu(J,M,L)){break y}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}a=z[l+74>>1];w[l+72>>1]=a;ua=l,va=z[_b(x[K>>2],a)>>1],w[ua+70>>1]=va;x[l+52>>2]=x[l+48>>2]}if(z[M>>1]==65535){break m}a=x[b+484344>>2];e=z[l+70>>1];if(!He(a,x[b+484348>>2],e)){a=z[l+72>>1];if((a|0)==z[K+28>>1]){if(!h){break n}if(!Vu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[l+52>>2]=x[l+48>>2];continue}w[M>>1]=a+1;continue}break}k=x[L>>2];if(k>>>0>=A[Wb(a,e)+12>>2]){x[L>>2]=0;k=0}if((h|0)!=2){break w}if(z[l+72>>1]!=(g&65535)|(f|0)!=(k|0)){break v}}h=1;v[s+26|0]=1;break m}a=0;if((h|0)==3){break u}}a=0;if(A[J+28>>2]<ca>>>0){break u}x[t+24>>2]=0;x[t+28>>2]=2146435072;x[J+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;k=x[L>>2];a=1}g=z[l+72>>1];f=Nq(i+24|0,na);x[31725]=0;g=ha(606,J|0,g|0,k|0,f|0,(q|0)!=0|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}if((a|g)==1){if(ea>>>0<=1){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}if(!h){break n}if(!Vu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[l+52>>2]=x[l+48>>2];continue}w[s+22>>1]=z[l+72>>1];x[s+12>>2]=x[l+48>>2];MT(b,l,0);n=x[l+48>>2];g=Wb(x[b+484344>>2],z[l+70>>1]);if(n>>>0>=A[g+12>>2]){x[L>>2]=0;n=0}if(q){continue}a=0;n=jd(x[g>>2],x[x[g+48>>2]+12>>2],n,0);Kb(i+24|0,I,77);m=Hb(x[x[i+24>>2]>>2],x[i+28>>2]);B:{while(1){if(z[b+480188>>1]>a>>>0){C:{if(!(!yB(n)&(!m|!(y[((a<<5)+b|0)+480281|0]&4)))){$o((l+D(a,872)|0)+1404|0);break C}if(Vg(y[n|0])){D:{if(!Ed(y[l+223884|0])){break D}g=y[n+1|0];if(g-251>>>0<5|!g){break D}e=y[n+5|0];h=y[n+3|0];k=Kj(y[n+2|0],y[n+4|0]);f=i+24|0;v[f|0]=g-1;x[f+4>>2]=k&65535;x[31725]=0;g=P(609,ra|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}ua=g,ya=E(E(Kj(h,e)>>>0)/E(999)),B[ua>>2]=ya}$o((l+D(a,872)|0)+1404|0);break C}g=l+D(a,872)|0;f=g+1408|0;e=y[n+4|0]|y[n+5|0]<<8;v[f|0]=e;v[f+1|0]=e>>>8;f=g+1404|0;e=y[n|0]|y[n+1|0]<<8|(y[n+2|0]<<16|y[n+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;E:{F:{G:{H:{switch(y[n+3|0]-16|0){case 0:e=y[n+5|0];break G;case 3:break E;case 4:break F;case 1:break H;default:break C}}Kb(i+24|0,I,5);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break C}e=y[n+5|0];if(!e){break C}}KT(b,l,e&255);break C}f=g+1409|0;e=y[f|0];I:{if(!(e|!(x[b+480180>>2]&16777250))){v[f|0]=y[g+1449|0];break I}v[g+1449|0]=e}g=y[n+5|0];f=g&240;if((f|0)!=224){if((f|0)!=96){break C}x[l+24>>2]=x[l+24>>2]+(g&15);break C}if(x[Z>>2]){break C}g=g&15;if(g?0:y[b+480180|0]&2){break C}x[Z>>2]=g+1;break C}g=y[n+5|0];if((g&240)!=224){break C}x[Z>>2]=(g&15)+1}n=n+6|0;a=a+1|0;continue}break}g=Pl(l);x[i+24>>2]=1;a=x[ad(Z,i+24|0)>>2];w[l+68>>1]=65535;x[l+60>>2]=-1;x[l+64>>2]=-1;ia=g-1|0;a=g-a|0;T=D(a,1e4);n=0;while(1){J:{K:{L:{M:{N:{if(z[b+480188>>1]<=n>>>0){if(x[b+480180>>2]!=4|x[l+40>>2]!=65535){break N}x[l+52>>2]=x[l+48>>2];w[l+74>>1]=z[l+72>>1];continue t}h=l+D(n,872)|0;k=h+1404|0;if(yB(k)){break J}q=h+616|0;da=h+1409|0;e=y[da|0];_=h+1407|0;u=y[_|0];if(!Y){break L}H=y[k|0];f=H;m=h+1405|0;F=y[m|0];if(F){v[h+1415|0]=0;v[h+1419|0]=F;ua=Ve(x[t+8>>2],n),va=255,v[ua+5|0]=va;f=y[k|0]}O:{if(!Tc(f)){break O}v[h+1415|0]=H;vV(q);if(!oa){if(x[Ve(x[t+8>>2],n)>>2]!=-1){break O}}F=h+1272|0;f=y[h+1419|0];f=x[(f?f>>>0>z[b+480192>>1]?F:((f<<2)+b|0)+900380|0:F)>>2];if(!f){break O}F=y[f+21|0];if(Cd(F)){ua=h+1453|0,va=Vh(F),v[ua|0]=va}f=y[f+22|0];if(!Cd(f)){break O}ua=h+1454|0,va=Vh(f),v[ua|0]=va}P:{if(!(Tc(y[k|0])|y[m|0])){break P}F=h+1419|0;m=y[F|0];Q:{if(!m){m=0;break Q}if(z[b+480192>>1]<m>>>0){break Q}f=x[((m<<2)+b|0)+900380>>2];if(!f|!(v[f+15|0]&1)){break Q}Xq(q,x[f+8>>2],b);m=y[F|0]}f=wr(b,H,m&255);if(!f){break P}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break P}Xq(q,z[f+484408>>1],b)}R:{S:{T:{f=y[h+1406|0];switch(f-1|0){case 1:break L;case 2:case 3:break S;case 0:break T;default:break R}}ua=Ve(x[t+8>>2],n),va=y[h+1408|0],v[ua+5|0]=va;break L}f=y[h+1408|0];if(!f){break L}v[h+1450|0]=f;break L}if((f|0)==11){break M}break L}x[l+32>>2]=x[b+480216>>2];a=Wb(x[b+484344>>2],z[l+70>>1]);f=x[a+16>>2];if(JT(f,x[a+20>>2])){x[l+32>>2]=f}f=IT(b,l);a=D(f,g);C[t+24>>3]=C[t+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[l>>2]=a+x[l>>2];U:{V:{W:{if(oa){break W}n=0;ia=(r|0)!=0&(f|0)!=(r|0);while(1){if(z[b+480188>>1]<=n>>>0){break W}G=Ve(x[t+8>>2],n);X:{if(x[G>>2]==-1){break X}q=l+D(n,872)|0;H=q+1404|0;T=x[q+1316>>2];if(!T){if(yB(H)){break X}}u=q+1409|0;k=y[u|0];e=Ql(y[H+2|0],y[H+3|0]);if(y[q+1405|0]){x[q+1276>>2]=0}h=q+616|0;a=k&15;m=0;Y:{if(!Tc(y[H|0])){break Y}if(e&y[G+4|0]!=0){wB(i+24|0,b,h,T,0);m=x[i+28>>2];x[q+624>>2]=x[i+24>>2];x[q+628>>2]=m}v[q+1418|0]=y[q+1415|0];T=q+1308|0;da=x[T>>2];m=y[q+1419|0];if(m){Qo(b,h,m,e,1,1)}m=y[H|0];x[31725]=0;ga(610,b|0,h|0,m|0,e|0,1,0,65535);m=x[31725];x[31725]=0;if((m|0)==1){break V}k=k>>>4|0;HT(b,h);GT(x[b+480180>>2],z[b+480188>>1],l,n&65535);_=Ve(x[t+8>>2],n);v[_+4|0]=1;G=y[q+1407|0];Z:{if(!((y[u|0]&240)!=208|(G-19&255)>>>0>1)){m=a;if(a>>>0<g>>>0){break Z}}m=(G|0)==33?g>>>0>k>>>0?k:0:0}F=x[Z>>2];if(!(!(x[b+480180>>2]&16777250)|(!m|F>>>0<2))){m=D(F-1|0,x[l+24>>2]+x[l+40>>2]|0)+m|0}if(!e){x[_>>2]=0}_:{if((G|0)==9){break _}$:{if((G|0)!=19){if((G|0)!=20|(k|0)!=8){break $}break _}if((k|0)==8){break _}}if(y[q+1406|0]!=2){break Y}}x[T>>2]=da}aa:{if(!Tc(y[H|0])){Kb(i+24|0,I,114);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break aa}}ba:{ca:{da:{ea:{e=y[q+1407|0];switch(e-42|0){case 1:break ba;case 0:break ca;case 2:break da;default:break ea}}if((e|0)!=10){break ba}e=z[l+70>>1];k=x[l+48>>2];x[31725]=0;aa(611,b|0,h|0,n&65535,k|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break aa}break U}k=nva(y[u|0],0,x[q+692>>2],0);e=hb;G=e>>>8|0;Po(b,h,Bc((e&255)<<24|k>>>8,G));break aa}if(!x[q+720>>2]){break ba}x[31725]=0;V(612,t|0,n&65535,r|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break U}ET(h,y[u|0]);m=x[l+40>>2]-1|0;break aa}if(y[q+1406|0]!=15){break aa}k=x[q+720>>2];if(!k){break aa}e=y[q+1408|0];if(e>>>0>9){break aa}fa:{if(!e){e=x[q+1280>>2];break fa}e=x[yb(k+68|0,e-1|0)>>2];x[q+1280>>2]=e}Po(b,h,e)}ga:{ha:{ia:{switch(y[H|0]-253|0){case 0:if(z[b+480192>>1]){break ha}break;case 1:case 2:break ha;default:break ia}}e=y[q+1407|0];if(!((y[u|0]&240)!=192|(e-19&255)>>>0>1)&a>>>0<g>>>0){break ha}G=e&255;if((G|0)==25){break ha}k=0;if(!((G|0)==33&(a|0)!=0&g>>>0>a+m>>>0)){break ga}}e=y[q+1407|0];k=1}G=q+1304|0;ja:{ka:{la:{a=e&255;if((a|0)!=46){if((a|0)!=13){break la}F=y[u|0]<<2;break ka}F=y[u|0];break ka}if(y[q+1406|0]!=1){break ja}F=y[q+1408|0]<<2}x[G>>2]=F}G=q+1407|0;ma:{na:{oa:{if(k|(!x[q+720>>2]|a>>>0>46)){break oa}Kb(i+24|0,ma,a);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break na}e=y[G|0];if((e|0)!=19){break oa}a=y[u|0]&240;if((a|0)==16){break na}e=19;if((a|0)==32){break na}}if(!k){break ma}}wV(h);ua=Ve(x[t+8>>2],n),va=0,x[ua>>2]=va;break X}if(ia){x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}e=y[G|0]}pa:{qa:{ra:{sa:{ta:{a=e&255;if(a-6>>>0>=2){ua:{switch(a-19|0){case 1:break sa;case 0:break ta;default:break ua}}if(a-35>>>0<2){break qa}if((a|0)==45){break ra}if((a|0)!=11){break pa}}if(!y[u|0]&x[b+480180>>2]==1){break pa}a=q+1467|0;e=0;while(1){if((e|0)==(g|0)){break pa}v[a|0]=!e|y[a|0]&254;Oo(b,h,y[u|0]);e=e+1|0;continue}}e=y[u|0];a=e&15;if(!(a|x[b+480180>>2]&1048580)){break pa}k=q+1467|0;v[k|0]=y[k|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break pa}No(b,h,a,0);break pa}Mo(b,h,a,0);break pa}va:{wa:{xa:{a=y[u|0];switch(a-158|0){case 1:break wa;case 0:break xa;default:break va}}x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}x[q+704>>2]=x[q+704>>2]&-129;break pa}x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}a=x[q+704>>2];x[q+704>>2]=a|128;if(x[h+4>>2]){break pa}e=x[q+692>>2];if(!e){break pa}if(!(ua=Tc(y[H|0]),va=1,xa=a&2,xa?ua:va)){break pa}x[h>>2]=-1;x[h+4>>2]=e-1;break pa}if((a&240)!=112|a>>>0<115){break pa}tV(h,a,x[b+480180>>2]);break pa}DT(h,y[u|0]);break pa}x[31725]=0;a=n&65535;V(612,t|0,a|0,r|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break U}ua=q+1390|0,va=CT(b,z[l+70>>1],x[l+48>>2],a),w[ua>>1]=va}k=q+1467|0;a=y[k|0]|1;v[k|0]=a;ya:{za:{Aa:{Ba:{Ca:{u=q+1406|0;switch(y[u|0]-3|0){case 11:break za;case 0:case 1:break Aa;case 3:break Ba;case 2:break Ca;default:break ya}}a=y[q+1408|0];Kb(i+24|0,I,41);No(b,h,a,Hb(x[x[i+24>>2]>>2],x[i+28>>2]));break ya}a=y[q+1408|0];Kb(i+24|0,I,41);Mo(b,h,a,Hb(x[x[i+24>>2]>>2],x[i+28>>2]));break ya}e=y[q+1408|0];Da:{if(e){break Da}Kb(i+24|0,I,41);e=0;if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Da}e=y[q+1450|0];if(!e){break ya}}e=y[u|0]==3?e<<4:e;a=0;while(1){if((a|0)==(g|0)){break ya}v[k|0]=!a|y[k|0]&254;Oo(b,h,e&255);a=a+1|0;continue}}e=y[q+1408|0];if(e>>>0>1){break ya}v[k|0]=a&247|!e<<3}if(y[k|0]&8){break X}a=1;Ea:{Fa:{Ga:{e=y[H+3|0];if(e>>>0>28){break Ga}h=1<<e;if(h&92){break Ea}if(!(h&268959744)){break Ga}if((y[H+5|0]-16&255)>>>0<32){break Ea}break Fa}if(e-38>>>0<4){break Ea}}a=(y[H+2|0]-11&255)>>>0<3}if(a){e=Ve(x[t+8>>2],n);a=x[e>>2];x[e>>2]=a+g;x[31725]=0;V(612,t|0,n&65535,f|0,a+m|0);a=x[31725];x[31725]=0;if((a|0)!=1){break X}a=N()|0;break l}a=Ve(x[t+8>>2],n);x[a>>2]=x[a>>2]+(g-m|0)}n=n+1|0;continue}}G=BT(b,l,K,0);r=f;continue t}a=N()|0;break l}a=N()|0;break l}f=y[h+1408|0];if(!f){break L}m=i+24|0;vB(m,b,y[k+3|0],f,0);w[h+1384>>1]=z[i+24>>1];if(y[af(m)|0]){break K}}Ha:{Ia:{Ja:{Ka:{La:{switch(u-12|0){case 0:AT(b,l,n&65535);break Ha;case 2:f=zT(b,l,n&65535,e);if((f|0)==-1){break Ha}x[l+60>>2]=f;break Ha;case 5:Kb(i+24|0,I,5);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ha}k=D(Lo(b,z[l+70>>1],x[l+48>>2],n&65535,0),1e4);x[i+56>>2]=k;Ma:{if(!Y|!(x[b+480180>>2]&16777250)){break Ma}if(k>>>0>=1e4){v[h+1451|0]=(k>>>0)/1e4;break Ma}k=D(y[h+1451|0],1e4);x[i+56>>2]=k}f=x[b+8>>2];if(k>>>0>=32e4){x[i+24>>2]=D(x[f+24>>2],1e4);ua=ba,va=x[Gb(i+56|0,i+24|0)>>2],x[ua>>2]=va;break Ha}m=x[ba>>2];H=(k>>>0)/1e4|0;F=D(T,H&15);k=m-F|0;x[ba>>2]=(H&240)==16?m+F|0:k>>>0<=m>>>0?k:0;m=x[f+20>>2];f=x[f+24>>2];Kb(i+24|0,I,8);Lp(ba,D(m,1e4),Hb(x[x[i+24>>2]>>2],x[i+28>>2])?255e4:D(f,1e4));break Ha;case 8:Na:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break Ha}x[h+704>>2]=x[h+704>>2]&-257|((e|0)==145)<<8;break Ha;case 1:v[h+1452|0]=e&15;break Ha;case 2:break Ka;case 6:break Na;default:break Ha}}v[h+1460|0]=e&15;break Ha;case 1:case 3:case 4:case 6:break Ha;case 7:break La;default:break Ia}}f=e&240;if((f|0)==240){break Ja}if((f|0)!=96){break Ha}}uB(b,l,n&65535,e&15);break Ha}v[h+1460|0]=e&15;break Ha}if((u|0)!=28|(e&240)!=160){break Ha}Kb(i+24|0,I,58);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ha}v[h+1452|0]=e&15}if(!Y){break J}Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{switch(u-2|0){case 0:if(!e){break Oa}Kb(i+24|0,I,90);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1428|0]=e}v[h+1427|0]=e;break K;case 1:if(!e){break Oa}Kb(i+24|0,I,90);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1427|0]=e}v[h+1428|0]=e;break K;case 2:if(!e){break Oa}w[h+1384>>1]=e;break K;case 8:if(!e){break Oa}x[h+1280>>2]=e<<8;break K;case 4:case 9:if(!e){break Oa}v[h+1425|0]=e;break K;case 11:ua=Ve(x[t+8>>2],n),va=e,v[ua+5|0]=va;break K;case 44:ua=Ve(x[t+8>>2],n),va=e+3>>>2|0,v[ua+5|0]=va;break K;case 21:f=x[b+480180>>2];e=e<<(!(f&59593760)&e<<24>>24>=0);m=e&255;if(m>>>0<=128){x[R>>2]=m<<1;break K}if(f&16777250){break K}x[R>>2]=256;break K;case 22:Kb(i+24|0,I,9);Xa:{if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){f=h+1433|0;if(e){v[f|0]=e;break Xa}e=y[f|0];break Xa}if(e){v[l+1433|0]=e;break Xa}e=y[l+1433|0]}f=e&15;m=e&255;Ya:{if(!((f|0)!=15|m>>>0<16)){e=(e&240)>>>4<<!(x[b+480180>>2]&59593760);f=x[R>>2]+(e<<1)|0;break Ya}m=m&240;if(!(!f|(m|0)!=240)){e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-e|0;break Ya}if(m){e=(e>>>3&30)<<!(x[b+480180>>2]&59593760);f=x[R>>2]+D(a,e)|0;break Ya}e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-D(a,e)|0}x[R>>2]=f;Fe(R,0,256);break K;case 19:if(e>>>0>64){break K}x[h+1364>>2]=e;break K;case 20:f=h+1432|0;Za:{if(e){v[f|0]=e;break Za}e=y[f|0]}u=h+1364|0;f=x[u>>2];m=e&15;k=e&255;_a:{if(!((m|0)!=15|k>>>0<16)){x[i+24>>2]=f+(k>>>4|0);break _a}if(!(!m|(k&240)!=240)){x[i+24>>2]=f-m;break _a}if(m){x[i+24>>2]=f-D(a,m);break _a}x[i+24>>2]=f+D(a,k>>>4|0)}Fe(i+24|0,0,64);x[u>>2]=x[i+24>>2];break K;case 7:en(b,q,e,8);break K;case 29:case 30:break Pa;case 25:break Qa;case 6:break Ra;case 24:break Sa;case 3:break Ta;case 5:break Ua;case 18:break Va;case 17:break Wa;default:break K}}if(e>>>0>15){break Va}f=(e&1)<<14;m=z[b+480188>>1];k=0;while(1){if((k|0)==(m|0)){break Va}u=l+D(k,872)|0;x[u+704>>2]=(f|x[u+704>>2]&-16385)^16384;k=k+1|0;continue}}if((e&240)!=128){break K}en(b,q,e&15,4);break K}if(e){v[h+1425|0]=e}e=0}Ol(q,e);break K}yT(b,q,e);break K}xT(q,e);break K}wT(q,e);break K}$a:{if(e<<24>>24>=0){f=Oe(sa,y[h+1460|0]);break $a}f=Oe(ta,e&127)}m=y[da|0];x[31725]=0;ja(613,b|0,l|0,n&65535,0,f|0,m|0);f=x[31725];x[31725]=0;if((f|0)!=1){break K}a=N()|0;break l}e=0}ab:{bb:{switch(y[h+1406|0]-2|0){case 0:en(b,q,y[h+1408|0],6);break ab;case 5:Kb(i+24|0,I,53);f=y[h+1408|0];if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1439|0]=f&15;break ab}Ol(q,f<<4);break ab;case 6:break bb;default:break ab}}Ol(q,y[h+1408|0])}cb:{db:{eb:{fb:{gb:{f=y[_|0];switch(f-5|0){case 1:break cb;case 3:break eb;case 0:case 2:break fb;default:break gb}}switch(f-26|0){case 1:break db;case 0:break fb;default:break cb}}hb:{if(x[b+480180>>2]&16777248){f=g;if(!(y[b+480208|0]&4)){break hb}}f=a}m=y[h+1439|0];Kb(i+24|0,I,21);h=h+1435|0;k=y[h|0];f=D(f,m);ua=h,va=(Hb(x[x[i+24>>2]>>2],x[i+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break cb}ib:{if(x[b+480180>>2]&16777248){f=g;if(!(y[b+480208|0]&4)){break ib}}f=a}m=y[h+1442|0];Kb(i+24|0,I,21);h=h+1436|0;k=y[h|0];f=D(f,m);ua=h,va=(Hb(x[x[i+24>>2]>>2],x[i+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break cb}f=h+1437|0;v[f|0]=y[f|0]+D(ia,y[h+1445|0]);uT(b,q)}Kb(i+24|0,I,78);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break J}f=e&255;if(!f){break J}tT(q,f)}n=n+1|0;continue}}break}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}h=1;break m}h=0}jb:{if(($|0)!=7){break jb}a=0;while(1){if(z[b+480188>>1]<=a>>>0){break jb}kb:{if(x[Ve(x[t+8>>2],a)>>2]==-1){break kb}x[31725]=0;V(612,t|0,a&65535,r|0,-1);d=x[31725];x[31725]=0;if((d|0)!=1){break kb}a=N()|0;break l}a=a+1|0;continue}}if(y[s+26|0]){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;lb:{mb:{nb:{ob:{if((a|0)!=1){if(!Y){break a}if(!(h?y[s+26|0]:1)){break nb}f=iB(i+56|0);if(Ed(y[fa+24|0])){gT(f,fa)}tB(fa);a=yc(b+1074376|0,l,614);r=0;while(1){if((r|0)==256){En(a+223848|0,l+223848|0);d=a+223860|0;r=y[d+24|0];g=l+223860|0;pb:{if((Ed(y[g+24|0])|0)==(r|0)){if(!r){break pb}r=ec(d);Lu(d,x[r>>2]);x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];qb:{if(!x[zb(d)>>2]){x[d>>2]=r;break qb}x[x[r>>2]+8>>2]=r;r=ec(g);x[g>>2]=r;x[r>>2]=0;ua=zb(g),va=0,x[ua>>2]=va}d=d+12|0;r=ec(d);Ku(d,x[r>>2]);g=g+12|0;x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];rb:{if(!x[zb(d)>>2]){x[d>>2]=r;break rb}x[x[r>>2]+8>>2]=r;d=ec(g);x[g>>2]=d;x[d>>2]=0;ua=zb(g),va=0,x[ua>>2]=va}break pb}if(r){tB(d);break pb}gT(d,g)}}else{d=D(r,872);Lq((d+a|0)+616|0,(d+l|0)+616|0);r=r+1|0;continue}break}sB(a);x[b+1074400>>2]=0;v[b+1074476|0]=1;a=b+1074392|0;x[a>>2]=-2;x[a+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];a=x[b+1298300>>2];if(!Nj(a)){break ob}break mb}a=N()|0;break l}x[31725]=0;W(614,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break mb}break lb}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2];break b}r=($|0)==7;a=0;while(1){if(z[b+480188>>1]<=a>>>0){a=FC(i+24|0);ua=i,va=_i(x[f+12>>2]),x[ua+20>>2]=va;g=b+906300|0;m=Rf(f+12|0);while(1){d=x[i+20>>2];if(!Zg(d,m)){sb:{m=250;d=a;tb:{while(1){if(m>>>0>=32){if(x[a>>2]){a=1;break tb}else{m=m-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break sb}a=0;while(1){if((a|0)==250){break sb}Kb(i+12|0,d,a);ub:{if(!Hb(x[x[i+12>>2]>>2],x[i+16>>2])){break ub}r=x[vd(g,a)>>2];e=x[x[r>>2]+180>>2];x[31725]=0;W(e|0,r|0);r=x[31725];x[31725]=0;if((r|0)!=1){break ub}break lb}a=a+1|0;continue}}ua=i,va=_i(x[f>>2]),x[ua+12>>2]=va;a=Rf(f);while(1){d=x[i+12>>2];if(Zg(d,a)){d=td(d);ka=B[ec(d)>>2];ua=vd(g,y[d|0]),ya=ka,B[ua+144>>2]=ya;ah(i+12|0);continue}else{Mq(f);break b}}}r=td(d);h=zb(r);vb:{e=y[r|0];d=x[vd(g,e)>>2];if(d){Kb(i+12|0,a,e);if(!Hb(x[x[i+12>>2]>>2],x[i+16>>2])){x[31725]=0;P(615,a|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break vb}e=x[x[d>>2]+176>>2];x[31725]=0;O(e|0,d|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break vb}}ka=B[h>>2];r=x[r+4>>2];e=x[x[d>>2]+44>>2];x[31725]=0;wa(e|0,d|0,r|0,E(ka));d=x[31725];x[31725]=0;if((d|0)==1){break vb}}ah(i+20|0);continue}break}break lb}d=D(a,872)+b|0;g=y[d+1075791|0];if(g){v[d+1075794|0]=g}g=Ve(x[t+8>>2],a);if(!(y[g+5|0]==255|r)){v[i+24|0]=64;ua=d+1075680|0,va=y[Rb(g+5|0,i+24|0)|0]<<2,x[ua>>2]=va}wb:{g=x[d+1075096>>2];xb:{if(!g|!(y[g+35|0]&2)){break xb}e=x[b+1298300>>2];if(!Dd(e)){break xb}x[31725]=0;k=e;e=a&65535;S(616,k|0,e|0,g+68|0);g=x[31725];x[31725]=0;if((g|0)==1){break wb}g=x[b+1298300>>2];x[31725]=0;S(617,g|0,e|0,1);g=x[31725];x[31725]=0;if((g|0)==1){break wb}}x[d+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;Mq(f)}Pu(J)}sT(t)}Xi(X);Q(a|0);p()}a=la&255;if((a|0)==y[b+484376|0]){break a}ck(qa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){lU(a);b=x[a>>2];kl(a);Db(b);ua=zb(a),va=0,x[ua>>2]=va;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[J>>2];x[a+4>>2]=x[J+4>>2];b=zb(J);ua=zb(a),va=x[b>>2],x[ua>>2]=va;x[b>>2]=0;x[J>>2]=0;x[J+4>>2]=0;a=a+12|0;c=ec(a);Rq(a,x[c>>2]);b=J+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];yb:{if(!x[zb(a)>>2]){x[a>>2]=c;break yb}x[x[c>>2]+8>>2]=c;a=ec(b);x[b>>2]=a;x[a>>2]=0;ua=zb(b),va=0,x[ua>>2]=va}}Pu(J);sT(t);fb=i+192|0}function EY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0,s=E(0),t=0,u=E(0),C=0,F=0,G=E(0),H=0,I=0,J=E(0),K=0,L=E(0),M=0,N=E(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=E(0),V=E(0),W=0,X=0,Y=0,Z=E(0),$=E(0),aa=0,ba=E(0),ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;Y=fb-16|0;fb=Y;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;g=x[a+1420>>2];d=(g|0)>0?g:0;while(1){if((d|0)!=(h|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((g|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{e=b+d|0;if(y[e|0]!=79|(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))!=(y[125924]|y[125925]<<8|(y[125926]<<16|y[125927]<<24))){break f}i=d+26|0;if((i|0)>=(c|0)){break e}q=d+27|0;m=b+i|0;f=y[m|0];if((q+f|0)>=(c|0)){break e}j=f+27|0;h=0;while(1)if((f|0)==(h|0)){h=0;k=0;while(1){f=22;if((h|0)!=22){k=ez(k,y[(d+h|0)+b|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;k=ez(k,0);continue}break}x[a+1420>>2]=g+1;f=D(g,20)+a|0;x[f+1432>>2]=k;x[f+1428>>2]=j-26;x[f+1424>>2]=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);e=y[(i+y[m|0]|0)+b|0]==255?-1:y[e+6|0]|y[e+7|0]<<8|(y[e+8|0]<<16|y[e+9|0]<<24);x[f+1436>>2]=i;x[f+1440>>2]=e;g=x[a+1420>>2];if((g|0)!=4){break f}g=4;break d}else{j=y[(h+q|0)+b|0]+j|0;h=h+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){j=(d|0)>(g|0)?d:g;while(1){if((d|0)==(j|0)){break b}h=0;e=D(d,20)+a|0;n=e+1428|0;f=x[n>>2];q=x[e+1436>>2];m=c-q|0;i=(f|0)<(m|0)?f:m;Q=(i|0)>0?i:0;aa=e+1432|0;k=x[aa>>2];while(1){if((h|0)!=(Q|0)){k=ez(k,y[(h+q|0)+b|0]);h=h+1|0;continue}break}x[n>>2]=f-i;x[aa>>2]=k;if((f|0)<=(m|0)){e=e+1424|0;if(x[e>>2]==(k|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=i+q|0;break c}f=g-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];h=f+1432|0;g=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=g;f=f+1424|0;h=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=h;g=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!aM(a)){x[f>>2]=0;c=0;break a}aa=fb-16|0;fb=aa;ha=Y+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=hf(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((hf(a)|0)!=103){break j}if((hf(a)|0)!=103){break j}if((hf(a)|0)!=83){break j}if(!$L(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break i}h=bz(a);break i}fc(a,30)}if(!h){break h}if(rc(a,1)){fc(a,35);break h}m=aa;l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=rc(a,Om(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[aa+12>>2]=c;i=D(c,6)+a|0;if(!y[i+412|0]){g=x[a+112>>2];h=g>>1;break m}g=x[a+116>>2];h=g>>1;c=rc(a,1);k=(rc(a,1)|0)!=0;if(c|!y[i+412|0]){break m}x[ha>>2]=g-x[a+112>>2]>>2;c=x[a+112>>2]+g>>2;break l}_(6325,13258,3152,10763);p()}x[ha>>2]=0;c=h}x[m+8>>2]=c;n:{if(!(!y[i+412|0]|k)){c=D(g,3);x[Y+8>>2]=c-x[a+112>>2]>>2;g=c+x[a+112>>2]>>2;break n}x[Y+8>>2]=h}x[aa+4>>2]=g;g=1}if(g){Q=x[ha>>2];ka=x[Y+8>>2];ia=x[aa+4>>2];i=0;P=fb-2368|0;fb=P;o=x[a+404>>2];oa=D(x[aa+12>>2],6)+a|0;C=y[oa+413|0];S=o+D(C,40)|0;R=x[((y[oa+412|0]<<2)+a|0)+104>>2];da=R>>1;qa=0-da|0;o:{while(1){c=x[a+4>>2];if((c|0)>(i|0)){c=y[(x[S+4>>2]+D(i,3)|0)+2|0];h=i<<2;H=h+(P+1344|0)|0;x[H>>2]=0;g=y[(c+S|0)+9|0];if(z[((g<<1)+a|0)+132>>1]){q=x[a+260>>2];p:{q:{if(!rc(a,1)){break q}c=2;m=x[(a+h|0)+996>>2];q=q+D(g,1596)|0;F=x[(y[q+1588|0]<<2)+89132>>2];h=Om(F)-1|0;ra=m,sa=rc(a,h),w[ra>>1]=sa;ra=m,sa=rc(a,h),w[ra+2>>1]=sa;j=0;while(1){if(y[q|0]>j>>>0){K=y[(j+q|0)+1|0];h=K+q|0;r=y[h+49|0];n=-1<<r;k=y[h+33|0];r:{if(!r){h=0;break r}g=x[a+124>>2]+D(y[h+65|0],2096)|0;if(x[a+1396>>2]<=9){Dl(a)}h=x[a+1392>>2];I=w[(g+((h&1023)<<1)|0)+36>>1];s:{if((I|0)>=0){t=h;I=I&65535;h=y[I+x[g+8>>2]|0];x[a+1392>>2]=t>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:I;break s}h=Nm(a,g)}if(!y[g+23|0]){break r}h=x[x[g+2088>>2]+(h<<2)>>2]}I=n^-1;g=c+k|0;while(1){if((c|0)!=(g|0)){n=0;k=w[((q+(K<<4)|0)+((h&I)<<1)|0)+82>>1];t:{if((k|0)<0){break t}k=x[a+124>>2]+D(k&65535,2096)|0;if(x[a+1396>>2]<=9){Dl(a)}n=x[a+1392>>2];O=w[(k+((n&1023)<<1)|0)+36>>1];u:{if((O|0)>=0){t=n;O=O&65535;n=y[O+x[k+8>>2]|0];x[a+1392>>2]=t>>>n;n=x[a+1396>>2]-n|0;x[a+1396>>2]=(n|0)>0?n:0;n=(n|0)<0?-1:O;break u}n=Nm(a,k)}if(!y[k+23|0]){break t}n=x[x[k+2088>>2]+(n<<2)>>2]}h=h>>r;w[m+(c<<1)>>1]=n;c=c+1|0;continue}break}j=j+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[P+320>>1]=257;c=2;while(1){n=x[q+1592>>2];if((n|0)<=(c|0)){c=0;while(1){if((c|0)>=(n|0)){break p}if(!y[(P+320|0)+c|0]){w[m+(c<<1)>>1]=65535;n=x[q+1592>>2]}c=c+1|0;continue}}else{h=q+338|0;g=c<<1;n=g+q|0;r=y[n+1088|0];k=r<<1;j=z[h+k>>1];H=y[n+1089|0];K=H<<1;I=w[k+m>>1];n=w[K+m>>1]-I|0;k=n>>31;h=(D((k^n)-k|0,z[g+h>>1]-j|0)|0)/(z[h+K>>1]-j|0)|0;n=I+((n|0)<0?0-h|0:h)|0;k=g+m|0;g=z[k>>1];v:{w:{if(g){h=P+320|0;v[h+H|0]=1;v[h+r|0]=1;v[c+h|0]=1;h=g<<16>>16;j=F-n|0;if((h|0)>=((j|0)<(n|0)?j:n)<<1){if((j|0)>(n|0)){break v}n=F+(g^-1)|0;break w}if(h&1){n=n-(h+1>>>1|0)|0;break w}n=(h>>1)+n|0;break w}v[(P+320|0)+c|0]=0}w[k>>1]=n}c=c+1|0;continue}}}x[H>>2]=1}i=i+1|0;continue}else{fc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){yc(P+320|0,P+1344|0,c<<2);g=z[S>>1];c=0;while(1){if((c|0)==(g|0)){c=o+D(C,40)|0}else{i=x[S+4>>2]+D(c,3)|0;h=y[i+1|0];q=y[i|0]<<2;m=P+1344|0;i=m;q=q+i|0;n=h<<2;if(!(x[i+n>>2]?x[q>>2]:0)){x[n+i>>2]=0;x[q>>2]=0}c=c+1|0;continue}break}la=c;h=0;while(1){x:{if(y[la+8|0]>h>>>0){n=0;c=x[a+4>>2];q=(c|0)>0?c:0;c=0;while(1){if((c|0)==(q|0)){break x}if(y[(x[S+4>>2]+D(c,3)|0)+2|0]==(h|0)){m=n+P|0;i=c<<2;y:{if(x[i+(P+1344|0)>>2]){i=0;g=1;break y}i=x[(a+i|0)+800>>2];g=0}v[m|0]=g;x[(P+256|0)+(n<<2)>>2]=i;n=n+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){i=(da|0)>0?da:0;g=z[S>>1];h=a+800|0;z:while(1){if((g|0)<=0){K=da<<2;n=0;c=0;while(1){h=x[a+4>>2];if((h|0)<=(c|0)){while(1){if((h|0)>(n|0)){S=y[oa+412|0];H=R>>1;g=H<<2;la=x[a+92>>2];k=R>>3;O=R>>2;h=x[((n<<2)+a|0)+800>>2];c=H<<2;K=h+c|0;A:{if(x[a+80>>2]){q=to(a,g);break A}q=Fd(g)}g=(q+c|0)-8|0;m=x[((S<<2)+a|0)+1068>>2];j=m;c=h;while(1){if((c|0)!=(K|0)){B[g+4>>2]=E(B[c>>2]*B[j>>2])-E(B[j+4>>2]*B[c+8>>2]);B[g>>2]=E(B[c>>2]*B[j+4>>2])+E(B[c+8>>2]*B[j>>2]);c=c+16|0;j=j+8|0;g=g-8|0;continue}break}c=((H<<2)+h|0)-12|0;while(1){if(g>>>0>=q>>>0){B[g+4>>2]=E(B[c>>2]*B[j+4>>2])-E(B[c+8>>2]*B[j>>2]);B[g>>2]=E(E(-B[c+8>>2])*B[j+4>>2])-E(B[j>>2]*B[c>>2]);c=c-16|0;j=j+8|0;g=g-8|0;continue}break}c=O<<2;r=c+h|0;g=c+q|0;j=(m+(H<<2)|0)-32|0;c=q;i=h;while(1){if(j>>>0>=m>>>0){l=B[c>>2];s=B[g>>2];u=B[g+4>>2];G=B[c+4>>2];B[r+4>>2]=u+G;B[r>>2]=B[g>>2]+B[c>>2];u=E(u-G);l=E(s-l);B[i+4>>2]=E(u*B[j+16>>2])-E(B[j+20>>2]*l);B[i>>2]=E(l*B[j+16>>2])+E(u*B[j+20>>2]);l=B[c+8>>2];s=B[g+8>>2];u=B[g+12>>2];G=B[c+12>>2];B[r+12>>2]=u+G;B[r+8>>2]=B[g+8>>2]+B[c+8>>2];u=E(u-G);l=E(s-l);B[i+12>>2]=E(u*B[j>>2])-E(B[j+4>>2]*l);B[i+8>>2]=E(l*B[j>>2])+E(u*B[j+4>>2]);c=c+16|0;g=g+16|0;i=i+16|0;r=r+16|0;j=j-32|0;continue}break}g=Om(R);c=R>>4;i=H-1|0;j=0-k|0;YL(c,h,i,j,m);YL(c,h,i-O|0,j,m);I=R>>5;c=0-c|0;pq(I,h,i,c,m,16);pq(I,h,i-k|0,c,m,16);pq(I,h,i-(k<<1)|0,c,m,16);pq(I,h,i+D(k,-3)|0,c,m,16);c=g-4>>1;r=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(r|0)){ja=g-7|0;break D}j=0;k=2<<c;k=(k|0)>0?k:0;F=8<<c;C=R>>c+4;o=R>>c+2;X=0-(o>>1)|0;while(1){if((j|0)==(k|0)){break C}pq(C,h,i-D(j,o)|0,X,m,F);j=j+1|0;continue}}while(1){E:{if((r|0)<(ja|0)){ma=32<<r;F=2<<r;X=8<<r;j=R>>r+6;W=R>>r+2;ea=0-(W>>1)|0;g=i;c=m;while(1){if((j|0)<=0){break E}k=F;o=(g<<2)+h|0;C=o+(ea<<2)|0;T=D(X,12)+c|0;l=B[T>>2];M=(X<<3)+c|0;s=B[M>>2];t=(X<<2)+c|0;u=B[t>>2];G=B[T+4>>2];L=B[M+4>>2];U=B[t+4>>2];V=B[c+4>>2];ba=B[c>>2];T=0-W<<2;while(1){if((k|0)>0){M=C-4|0;N=B[M>>2];Z=B[o>>2];$=B[C>>2];B[o>>2]=Z+$;t=o-4|0;J=B[t>>2];B[t>>2]=J+B[M>>2];J=E(J-N);N=E(Z-$);B[M>>2]=E(J*ba)+E(V*N);B[C>>2]=E(N*ba)-E(V*J);M=C-12|0;Z=B[M>>2];t=o-8|0;J=B[t>>2];fa=t;t=C-8|0;$=B[t>>2];B[fa>>2]=J+$;ca=o-12|0;N=B[ca>>2];B[ca>>2]=N+B[M>>2];N=E(N-Z);J=E(J-$);B[M>>2]=E(N*u)+E(U*J);B[t>>2]=E(J*u)-E(U*N);M=C-20|0;Z=B[M>>2];t=o-16|0;J=B[t>>2];fa=t;t=C-16|0;$=B[t>>2];B[fa>>2]=J+$;ca=o-20|0;N=B[ca>>2];B[ca>>2]=N+B[M>>2];N=E(N-Z);J=E(J-$);B[M>>2]=E(N*s)+E(L*J);B[t>>2]=E(J*s)-E(L*N);M=C-28|0;Z=B[M>>2];t=o-24|0;J=B[t>>2];fa=t;t=C-24|0;$=B[t>>2];B[fa>>2]=J+$;ca=o-28|0;N=B[ca>>2];B[ca>>2]=N+B[M>>2];N=E(N-Z);J=E(J-$);B[M>>2]=E(N*l)+E(G*J);B[t>>2]=E(J*l)-E(G*N);k=k-1|0;C=C+T|0;o=o+T|0;continue}break}j=j-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(i<<2)+h|0;i=c-(I<<6)|0;l=B[m+(R>>3<<2)>>2];ba=E(-l);while(1){if(c>>>0>i>>>0){L=B[c>>2];g=c-32|0;U=B[g>>2];B[c>>2]=L+U;m=c-4|0;s=B[m>>2];t=m;m=c-36|0;V=B[m>>2];B[t>>2]=s+V;j=c-8|0;u=B[j>>2];t=j;j=c-40|0;J=B[j>>2];B[t>>2]=u+J;k=c-12|0;G=B[k>>2];t=k;k=c-44|0;N=B[k>>2];B[t>>2]=G+N;B[g>>2]=L-U;B[m>>2]=s-V;m=c-16|0;s=B[m>>2];t=m;m=c-48|0;Z=B[m>>2];B[t>>2]=s+Z;u=E(u-J);G=E(G-N);B[j>>2]=l*E(u+G);B[k>>2]=l*E(G-u);j=c-28|0;u=B[j>>2];k=c-60|0;G=B[k>>2];F=c-24|0;L=B[F>>2];r=c-56|0;U=B[r>>2];C=c-20|0;V=B[C>>2];t=C;C=c-52|0;J=B[C>>2];B[t>>2]=V+J;B[F>>2]=L+U;B[j>>2]=u+G;B[m>>2]=V-J;B[C>>2]=-E(s-Z);s=E(u-G);u=E(L-U);B[r>>2]=l*E(s-u);B[k>>2]=E(u+s)*ba;XL(c);XL(g);c=c+-64|0;continue}break}k=H-4|0;g=q+(k<<2)|0;j=(q+(O<<2)|0)-16|0;c=x[((S<<2)+a|0)+1100>>2];while(1){if(j>>>0>=q>>>0){i=(z[c>>1]<<2)+h|0;B[g+12>>2]=B[i>>2];B[g+8>>2]=B[i+4>>2];B[j+12>>2]=B[i+8>>2];B[j+8>>2]=B[i+12>>2];i=(z[c+2>>1]<<2)+h|0;B[g+4>>2]=B[i>>2];B[g>>2]=B[i+4>>2];B[j+4>>2]=B[i+8>>2];B[j>>2]=B[i+12>>2];c=c+4|0;g=g-16|0;j=j-16|0;continue}break}c=x[((S<<2)+a|0)+1084>>2];j=q;g=j+(H<<2)|0;i=g;while(1){m=i-16|0;if(m>>>0>j>>>0){l=B[j+4>>2];F=i-4|0;s=B[F>>2];u=E(l-s);G=B[c+4>>2];l=E(l+s);s=B[j>>2];r=i-8|0;L=B[r>>2];U=E(s-L);V=B[c>>2];ba=E(E(G*l)-E(U*V));B[j+4>>2]=u+ba;s=E(s+L);l=E(E(G*U)+E(l*V));B[j>>2]=s+l;B[F>>2]=ba-u;B[r>>2]=s-l;l=B[j+8>>2];s=B[m>>2];u=E(l+s);G=B[c+12>>2];l=E(l-s);s=B[j+12>>2];i=i-12|0;L=B[i>>2];U=E(s+L);V=B[c+8>>2];ba=E(E(G*l)+E(U*V));B[j+8>>2]=u+ba;s=E(s-L);l=E(E(G*U)-E(l*V));B[j+12>>2]=s+l;B[m>>2]=u-ba;B[i>>2]=l-s;j=j+16|0;c=c+16|0;i=m;continue}break}j=x[((S<<2)+a|0)+1076>>2]+(H<<2)|0;c=(k<<2)+h|0;i=((R<<2)+h|0)-16|0;while(1){m=g-32|0;if(m>>>0>=q>>>0){l=B[g-8>>2];s=B[j-4>>2];u=B[j-8>>2];G=B[g-4>>2];L=E(E(l*s)-E(u*G));B[h>>2]=L;B[c+12>>2]=-L;l=E(E(u*E(-l))-E(s*G));B[K>>2]=l;B[i+12>>2]=l;l=B[g-16>>2];s=B[j-12>>2];u=B[j-16>>2];G=B[g-12>>2];L=E(E(l*s)-E(u*G));B[h+4>>2]=L;B[c+8>>2]=-L;l=E(E(u*E(-l))-E(s*G));B[K+4>>2]=l;B[i+8>>2]=l;l=B[g-24>>2];s=B[j-20>>2];u=B[j-24>>2];G=B[g-20>>2];L=E(E(l*s)-E(u*G));B[h+8>>2]=L;B[c+4>>2]=-L;l=E(E(u*E(-l))-E(s*G));B[K+8>>2]=l;B[i+4>>2]=l;l=B[m>>2];s=B[j-28>>2];j=j-32|0;u=B[j>>2];G=B[g-28>>2];L=E(E(l*s)-E(u*G));B[h+12>>2]=L;B[c>>2]=-L;l=E(E(u*E(-l))-E(s*G));B[K+12>>2]=l;B[i>>2]=l;i=i-16|0;c=c-16|0;K=K+16|0;h=h+16|0;g=m;continue}break}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=la;break B}r=r+1|0;continue}}c=c+1|0;continue}break}n=n+1|0;h=x[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;m=x[g+800>>2];F:{if(x[h+(P+320|0)>>2]){Sb(m,0,K);break F}H=x[g+996>>2];G:{h=y[(S+y[(x[S+4>>2]+D(c,3)|0)+2|0]|0)+9|0];if(!z[((h<<1)+a|0)+132>>1]){fc(a,21);break G}F=R>>1;r=x[a+260>>2]+D(h,1596)|0;h=D(y[r+1588|0],w[H>>1]);j=1;g=0;while(1){if(x[r+1592>>2]>(j|0)){i=y[(j+r|0)+838|0]<<1;q=w[i+H>>1];if((q|0)>=0){q=D(y[r+1588|0],q&65535);i=z[(i+r|0)+338>>1];if((i|0)!=(g|0)){k=q-h|0;C=i-g|0;o=(k|0)/(C|0)|0;H:{I=(i|0)<(F|0)?i:F;if((I|0)<=(g|0)){break H}t=k;k=k>>31;O=o>>31;O=((t^k)-k|0)-D(C,(O^o)-O|0)|0;X=k|1;k=m+(g<<2)|0;B[k>>2]=B[((h&255)<<2)+89152>>2]*B[k>>2];I=I-1|0;k=0;while(1){if((g|0)==(I|0)){break H}g=g+1|0;T=m+(g<<2)|0;k=k+O|0;M=(k|0)<(C|0);h=(h+o|0)+(M?0:X)|0;B[T>>2]=B[((h&255)<<2)+89152>>2]*B[T>>2];k=k-(M?0:C)|0;continue}}g=i}h=q}j=j+1|0;continue}break}if((g|0)>=(F|0)){break G}h=(h<<2)+89152|0;while(1){if((g|0)==(F|0)){break G}i=m+(g<<2)|0;B[i>>2]=B[h>>2]*B[i>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}_L(a);I:{if(y[a+1377|0]){x[a+1060>>2]=qa;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=R-ia;break I}c=x[a+1412>>2];if(!c){break I}h=ka-Q|0;if((h|0)<=(c|0)){x[a+1412>>2]=c-h;x[ha>>2]=ka;Q=ka;break I}Q=c+Q|0;x[ha>>2]=Q;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];h=x[a+1060>>2];if(c>>>0>=h+(ia-Q|0)>>>0){break N}h=c-h|0;c=(c>>>0>=h>>>0?h:0)+Q|0;c=(c|0)<(ia|0)?c:ia;x[Y+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(Q-da|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ka-Q|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[Y+12>>2]=ia}c=1;break o}_(6325,13258,3451,5634);p()}g=g-1|0;c=x[S+4>>2]+D(g,3)|0;q=x[h+(y[c+1|0]<<2)>>2];m=x[h+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(i|0)){continue z}j=c<<2;n=j+q|0;u=B[n>>2];j=j+m|0;l=B[j>>2];O:{if(l>E(0)){if(u>E(0)){s=E(l-u);break O}s=l;l=E(l+u);break O}if(u>E(0)){s=E(l+u);break O}s=l;l=E(l-u)}B[j>>2]=l;B[n>>2]=s;c=c+1|0;continue}}}_(6325,13258,3335,5634);p()}X=P+256|0;H=fb-16|0;fb=H;j=x[a+4>>2];r=x[a+396>>2];g=y[(h+la|0)+24|0];F=r+D(g,24)|0;i=x[F+4>>2];ja=z[((g<<1)+a|0)+268>>1];c=da<<((ja|0)==2);m=c>>>0>i>>>0?i:c;i=x[F>>2];I=(m-(c>>>0>i>>>0?i:c)>>>0)/A[F+8>>2]|0;q=I<<2;c=D(j,q+4|0);M=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];ca=x[a+92>>2];P:{if(x[a+80>>2]){i=to(a,c);j=x[a+4>>2];break P}i=Fd(c)}m=(n|0)>0?n:0;C=da<<2;c=0;o=(j|0)>0?j:0;k=(j<<2)+i|0;while(1){if((c|0)!=(o|0)){x[(c<<2)+i>>2]=k;c=c+1|0;k=k+q|0;continue}break}q=i;c=0;while(1){if((c|0)!=(m|0)){if(!y[c+P|0]){Sb(x[X+(c<<2)>>2],0,C)}c=c+1|0;continue}break}Q:{if(!((n|0)==1|(ja|0)!=2)){c=0;while(1){R:{if((c|0)!=(m|0)){if(y[c+P|0]){break R}}else{c=m}if((c|0)==(n|0)){break Q}m=r+D(g,24)|0;r=(n|0)!=2;C=(n|0)<3;j=0;while(1){if((j|0)==8){break Q}S:{if(!r){k=0;i=0;while(1){if((i|0)>=(I|0)){break S}c=x[F>>2]+D(x[F+8>>2],i)|0;x[H+12>>2]=c&1;x[H+8>>2]=c>>1;if(!j){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Dl(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];T:{if((o|0)>=0){t=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=t>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break T}c=Nm(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[m+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(i|0)>=(I|0))){g=x[F+8>>2];o=w[(x[m+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(j<<1)>>1];U:{if((o|0)>=0){if(!ZL(a,x[a+124>>2]+D(o&65535,2096)|0,X,2,H+12|0,H+8|0,da,g)){break Q}i=i+1|0;break U}i=i+1|0;g=x[F>>2]+D(g,i)|0;x[H+8>>2]=g>>1;x[H+12>>2]=g&1}c=c+1|0;continue}break}k=k+1|0;continue}}if(C){break S}k=0;i=0;while(1){if((i|0)>=(I|0)){break S}g=x[F>>2]+D(x[F+8>>2],i)|0;c=(g|0)/(n|0)|0;x[H+12>>2]=g-D(c,n);x[H+8>>2]=c;if(!j){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Dl(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];V:{if((o|0)>=0){t=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=t>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break V}c=Nm(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[m+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(i|0)>=(I|0))){g=x[F+8>>2];o=w[(x[m+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(j<<1)>>1];W:{if((o|0)>=0){if(!ZL(a,x[a+124>>2]+D(o&65535,2096)|0,X,n,H+12|0,H+8|0,da,g)){break Q}i=i+1|0;break W}i=i+1|0;g=x[F>>2]+D(g,i)|0;o=(g|0)/(n|0)|0;x[H+8>>2]=o;x[H+12>>2]=g-D(n,o)}c=c+1|0;continue}break}k=k+1|0;continue}}j=j+1|0;continue}}c=c+1|0;continue}}ma=r+D(g,24)|0;j=0;while(1){if((j|0)==8){break Q}k=0;n=0;while(1){if((k|0)<(I|0)){X:{if(j){break X}c=0;while(1){if((c|0)==(m|0)){break X}if(!y[c+P|0]){i=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Dl(a)}g=x[a+1392>>2];r=w[(i+((g&1023)<<1)|0)+36>>1];Y:{if((r|0)>=0){t=g;r=r&65535;g=y[r+x[i+8>>2]|0];x[a+1392>>2]=t>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:r;break Y}g=Nm(a,i)}g=y[i+23|0]?x[x[i+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[q+(c<<2)>>2]+(n<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}i=0;while(1){Z:{if((i|0)>=(M|0)){break Z}c=0;if((k|0)>=(I|0)){break Z}while(1){if((c|0)!=(m|0)){_:{if(y[c+P|0]){break _}g=c<<2;r=w[(x[ma+20>>2]+(y[x[x[g+q>>2]+(n<<2)>>2]+i|0]<<4)|0)+(j<<1)>>1];if((r|0)<0){break _}K=x[a+124>>2]+D(r&65535,2096)|0;W=x[g+X>>2];T=x[F+8>>2];O=x[F>>2]+D(T,k)|0;$:{aa:{if(ja){r=0;while(1){g=1;if((r|0)>=(T|0)){break $}ea=W+(O<<2)|0;g=T-r|0;C=0;l=E(0);ba:{o=WL(a,K);if((o|0)<0){break ba}C=x[K>>2];g=(g|0)>(C|0)?C:g;t=D(o,C);if(y[K+22|0]){o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;l=E(l+B[x[K+28>>2]+(o+t<<2)>>2]);B[ga>>2]=B[ga>>2]+l;o=o+1|0;l=E(l+B[K+12>>2]);continue}}o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;B[ga>>2]=B[ga>>2]+E(B[x[K+28>>2]+(o+t<<2)>>2]+E(0));o=o+1|0;continue}}if(!C){break aa}g=x[K>>2];O=g+O|0;r=g+r|0;continue}}r=0;ea=(T|0)/x[K>>2]|0;t=(ea|0)>0?ea:0;ga=W+(O<<2)|0;g=1;while(1){if((r|0)==(t|0)){break $}C=r+O|0;o=r<<2;r=r+1|0;fa=o+ga|0;W=T-C|0;o=0;l=E(0);ca:{na=WL(a,K);if((na|0)<0){break ca}C=0;o=x[K>>2];W=(o|0)<(W|0)?o:W;W=(W|0)>0?W:0;na=D(o,na);o=1;while(1){if((C|0)==(W|0)){break ca}pa=fa+(D(C,ea)<<2)|0;s=E(l+B[x[K+28>>2]+(C+na<<2)>>2]);B[pa>>2]=B[pa>>2]+s;l=y[K+22|0]?s:l;C=C+1|0;continue}}if(o){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}break}k=k+1|0;i=i+1|0;continue}break}n=n+1|0;continue}break}j=j+1|0;continue}}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=ca;fb=H+16|0;h=h+1|0;continue}}_(6325,13258,3302,5634);p()}fb=P+2368|0}else{c=0}fb=aa+16|0;if(!c){da:{ea:{fa:{c=x[a+100>>2];switch(c-32|0){case 0:break ea;case 3:break fa;default:break da}}x[a+100>>2]=0;while(1){if((Oh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break da}x[a+100>>2]=0;while(1){if((Oh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}q=x[Y+12>>2];m=x[Y+4>>2];h=x[Y+8>>2];k=1;i=x[a+992>>2];ga:{if(i){g=i<<1;ha:{if((g|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=x[a+116>>2]){break ha}c=a+1096|0}c=x[c>>2]}g=0;if(!c){break ga}k=0;n=(i|0)>0?i:0;while(1){if(x[a+4>>2]>(k|0)){j=(k<<2)+a|0;g=0;while(1){if((g|0)!=(n|0)){Q=x[j+800>>2]+(g+m<<2)|0;t=Q;s=B[Q>>2];Q=g<<2;B[t>>2]=E(s*B[Q+c>>2])+E(B[Q+x[j+928>>2]>>2]*B[c+(i+(g^-1)<<2)>>2]);g=g+1|0;continue}break}k=k+1|0;continue}break}k=!x[a+992>>2]}x[a+992>>2]=q-h;j=(h|0)>(q|0);n=(j?h:q)-h|0;i=0;while(1){if(x[a+4>>2]>(i|0)){c=(i<<2)+a|0;g=0;while(1){if((g|0)!=(n|0)){B[x[c+928>>2]+(g<<2)>>2]=B[x[c+800>>2]+(g+h<<2)>>2];g=g+1|0;continue}break}i=i+1|0;continue}break}g=0;if(!k){g=(j?q:h)-m|0;x[a+1416>>2]=g+x[a+1416>>2]}}c=0;h=x[a+4>>2];i=(h|0)>0?h:0;while(1){if((c|0)!=(i|0)){q=(c<<2)+a|0;x[q+864>>2]=x[q+800>>2]+(m<<2);c=c+1|0;continue}break}if(d){x[d>>2]=h}x[f>>2]=g;x[e>>2]=a+864;c=x[a+32>>2]-b|0}fb=Y+16|0;return c}function wqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-1728|0;fb=f;xc(b);d=fb-16|0;fb=d;g=f+1602|0;_X(d+8|0,g);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){ZX(g)}a:{if(!d){break a}if(!$X(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(256,0))){break a}b:{if(!c){break b}Bd(a,1048576);gg(a);d=fb-16|0;fb=d;e=f+1344|0;g=tc(d+4|0,4230);_c(e,g);tb(g);fb=d+16|0;d=y[f+1610|0]|y[f+1611|0]<<8;x[f+144>>2]=d>>>8;x[31725]=0;x[f+12>>2]=d&255;g=f+72|0;O(446,g|0,f+12|0);d=x[31725];x[31725]=0;c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){x[31725]=0;d=f+256|0;V(432,d|0,e|0,f+144|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break i}Ab(a+1298344|0,d);tb(d);tb(g);Eb(e);g=tc(d,15121);Ab(a+1298356|0,g);tb(g);We(e,2,f+1612|0);Lr(d,22,e);Ab(a+1298368|0,d);tb(d);G=a+1298404|0,H=x[Fc(d,22)>>2],x[G>>2]=H;HC(e,2,f+1644|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);w[a+480188>>1]=y[f+1714|0]|y[f+1715|0]<<8;g=y[f+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;G=a,H=Kd(g,1,31),x[G+480196>>2]=H;w[a+480192>>1]=y[f+1724|0]|y[f+1725|0]<<8;w[a+480190>>1]=y[f+1726|0]|y[f+1727|0]<<8;g=Kd(y[f+1719|0],1,32);x[a+480216>>2]=g;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=g<<2;Cw(b,e);g=a+484376|0;Ur(Xb(x[a+484360>>2],y[g|0]),e,y[f+1708|0]|y[f+1709|0]<<8,65535,65535);bf(Xb(x[a+484360>>2],y[g|0]),y[f+1710|0]|y[f+1711|0]<<8);q=hh(b);fe(d,b,q?274:0);u=ic(f+1324|0,d);ub(d);x[31725]=0;e=R(153,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}x[31725]=0;S(187,d|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}t=ic(f+1304|0,d);ub(d);s=z[a+480188>>1];if(q){w[a+480188>>1]=s+8}B=c&1;if(!B){break f}x[31725]=0;O(225,a+484344|0,y[f+1712|0]|y[f+1713|0]<<8);d=x[31725];x[31725]=0;if((d|0)!=1){break f}h=N()|0;break e}h=N()|0;break h}h=N()|0;tb(f+72|0)}Eb(f+1344|0);break c}h=N()|0;break d}o=a+484344|0;h=0;j:{k:{while(1){l:{m:{n:{o:{p:{q:{if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=r>>>0){d=y[f+1716|0]|y[f+1717|0]<<8;if((d-2&65535)>>>0>=4998){break o}if(!(h&1)){break q}i=0;d=Gc(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break p}x[31725]=0;d=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}x[f+12>>2]=d;x[31725]=0;e=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}x[31725]=0;d=f+72|0;S(187,d|0,b|0,e+1&-2);e=x[31725];x[31725]=0;if((e|0)==1){break k}j=ic(f+256|0,d);ub(d);wc(f+12|0,1024);if(!B){break m}l=x[f+12>>2];if(!l){break m}x[31725]=0;d=U(198,o|0,r&65535,l|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(!d){break m}k=0;e=0;if(v[f+1720|0]&1){break n}r:while(1){if((k|0)==(l|0)){break m}d=Wb(x[o>>2],r);cf(f+72|0,x[d>>2],x[x[d+48>>2]+12>>2],k);e=0;while(1){if((e|0)==(s|0)){k=k+1|0;continue r}x[31725]=0;d=f+144|0;O(624,j|0,d|0);g=x[31725];x[31725]=0;if((g|0)!=1){h=YX(Wc(x[f+72>>2],e),d)|h;e=e+1|0;continue}break}break}break l}break l}i=2;d=_e(2646e3/+(D(d,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=i;x[a+480204>>2]=d}d=z[a+480188>>1];x[31725]=0;v[f+256|0]=0;r=U(625,f+1292|0,d|0,f+256|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){k=a+1298320|0;j=a+1298332|0;n=0;s:{t:{u:{v:{w:{x:{while(1){d=x[t+8>>2];e=x[t>>2];x[31725]=0;d=U(152,e|0,d|0,8)|0;e=x[31725];x[31725]=0;y:{if((e|0)!=1){if(d){break y}d=a+906300|0;i=x[r>>2];k=0;while(1){g=z[a+480188>>1];if(g>>>0<=k>>>0){x[f+248>>2]=0;x[f+252>>2]=0;x[f+240>>2]=0;x[f+244>>2]=0;x[f+232>>2]=0;x[f+236>>2]=0;x[f+224>>2]=0;x[f+228>>2]=0;z:{A:{if(!q){break A}e=0;x[31725]=0;O(626,u|0,f+256|0);d=x[31725];x[31725]=0;if((d|0)==1){break z}while(1){if((e|0)==8){e=0;x[31725]=0;k=P(216,f+212|0,z[f+256>>1])|0;d=x[31725];x[31725]=0;if((d|0)!=1){B:{C:{D:{E:{while(1){if(z[f+256>>1]<=e>>>0){x[31725]=0;j=U(627,f+200|0,y[f+1712|0]|y[f+1713|0]<<8,25288)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}g=0;break D}x[31725]=0;g=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;d=f+144|0;S(187,d|0,b|0,g<<5);g=x[31725];x[31725]=0;if((g|0)==1){break E}g=ic(f+72|0,d);hd(dh(x[k>>2],e),g);ub(g);e=e+1|0;ub(d);continue}break}h=N()|0;break B}h=N()|0;break B}while(1){if((y[f+1708|0]|y[f+1709|0]<<8)>>>0<=g>>>0){md(j);Qc(k);break A}F:{h=f+g|0;e=y[h+274|0];if(e>>>0>=z[f+256>>1]){break F}d=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g)>>1];if(d>>>0>=(y[f+1712|0]|y[f+1713|0]<<8)>>>0){break F}G:{i=_b(x[j>>2],d);l=z[i>>1];H:{if((l|0)==65535){w[i>>1]=e;break H}if((e|0)==(l|0)){break H}x[31725]=0;e=P(628,o|0,d|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break G}if((e|0)==65535){break H}G=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g),H=e,w[G>>1]=H;d=e}if(!He(x[a+484344>>2],x[a+484348>>2],d)){break F}l=dh(x[k>>2],y[h+274|0]);xc(l);e=x[l>>2];x[31725]=0;e=R(156,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break G}m=e>>>5|0;i=0;I:while(1){e=Wb(x[o>>2],d);if(A[e+12>>2]<=i>>>0){break F}h=0;e=jd(x[e>>2],x[x[e+48>>2]+12>>2],i,z[a+480188>>1]-8&65535);while(1){if((h|0)==8){i=i+1|0;continue I}v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;J:{if(i>>>0>=m>>>0){break J}x[31725]=0;P(629,l|0,f+72|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break G}if(v[f+72|0]>=0){break J}v[e|0]=61;v[e+1|0]=y[(f+240|0)+(h<<1)|0];q=y[f+72|0]&31;v[f+144|0]=q;if(q){Qf(f+144|0,15);v[e+3|0]=20;v[e+5|0]=y[f+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[f+73|0]+3>>>2}e=e+6|0;h=h+1|0;continue}}}h=N()|0;md(j);break B}g=g+1|0;continue}}h=N()|0}Qc(k);break s}h=N()|0;break s}g=e<<1;h=g+(f+240|0)|0;d=z[a+480192>>1]+1&65535;i=z[x[a+8>>2]+58>>1];while(1){K:{L:{k=d&65535;if(k>>>0<=i>>>0){if(x[((k<<2)+a|0)+900380>>2]){break L}}else{d=65535}d=d&65535;break K}d=d+1|0;continue}break}w[h>>1]=d;l=g+(f+224|0)|0;g=z[(f+g|0)+258>>1];w[l>>1]=g;M:{if((d|0)!=65535){x[31725]=0;d=U(253,a|0,d|0,g+1&65535)|0;g=x[31725];x[31725]=0;N:{O:{if((g|0)!=1){if(!d){break M}x[31725]=0;g=f+144|0;O(290,g|0,4475);h=x[31725];x[31725]=0;if((h|0)==1){break O}x[31725]=0;x[f+12>>2]=e+1;h=f+72|0;S(630,h|0,g|0,f+12|0);i=x[31725];x[31725]=0;if((i|0)==1){break N}zc(d+492|0,h);tb(h);Eb(g);break M}h=N()|0;break s}h=N()|0;break s}h=N()|0;Eb(f+144|0);break s}w[h>>1]=0}e=e+1|0;continue}}P:{Q:{d=y[f+1720|0]|y[f+1721|0]<<8|(y[f+1722|0]<<16|y[f+1723|0]<<24);if(!(d&2)){break Q}d=(((d&8?z[a+480188>>1]:s)&65535)+((y[f+1610|0]|y[f+1611|0]<<8)>>>0>591?n:0)|0)+(d>>>4&1)|0;g=0;R:while(1){e=0;if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=g>>>0){break Q}while(1){S:{if((d|0)!=(e|0)){h=x[b+8>>2];i=x[b>>2];x[31725]=0;h=U(152,i|0,h|0,4)|0;i=x[31725];x[31725]=0;if((i|0)==1){break P}if(h){break S}}g=g+1|0;continue R}x[31725]=0;O(631,y[f+1610|0]|y[f+1611|0]<<8,b|0);h=x[31725];x[31725]=0;if((h|0)==1){break P}e=e+1|0;continue}}}x[31725]=0;k=P(216,f+188|0,255)|0;d=x[31725];x[31725]=0;if((d|0)!=1){g=0;while(1){T:{d=g;U:{if((d|0)==255){n=FC(f+72|0);o=FC(f+144|0);h=0;while(1){V:{W:{X:{if((h|0)==256){i=0;break X}x[31725]=0;g=f+256|0;O(632,b|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break W}x[31725]=0;e=R(153,b|0)|0;d=x[31725];x[31725]=0;Y:{Z:{_:{if((d|0)!=1){x[31725]=0;d=f+12|0;S(187,d|0,b|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break _}j=ic(f+52|0,d);ub(d);if((y[f+1726|0]|y[f+1727|0]<<8)>>>0>h>>>0){i=f+40|0;We(i,2,g);x[31725]=0;O(220,d|0,i|0);g=x[31725];x[31725]=0;if((g|0)==1){break Y}zc(((h<<5)+a|0)+946336|0,d);tb(d)}if(!e){break V}if((y[f+1726|0]|y[f+1727|0]<<8)>>>0>h>>>0){break Z}break V}h=N()|0;break U}h=N()|0;break U}x[31725]=0;d=D(h+1|0,104)+a|0;e=d+484380|0;O(281,e|0,32);g=x[31725];x[31725]=0;$:{aa:{ba:{if((g|0)!=1){Dp(e);x[31725]=0;O(633,j|0,f+12|0);g=x[31725];x[31725]=0;if((g|0)==1){break Y}g=x[f+12>>2];x[e>>2]=g;x[d+484404>>2]=x[f+16>>2];if(y[f+20|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|1;g=g>>>1|0;x[e>>2]=g}if(y[f+21|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|64;x[e>>2]=g>>>1}i=2;switch(y[f+23|0]-1|0){case 0:break aa;case 1:break ba;default:break $}}break Y}i=6}e=d+484414|0;w[e>>1]=z[e>>1]|i}x[d+484384>>2]=x[f+24>>2];x[d+484388>>2]=x[f+28>>2];w[d+484410>>1]=z[f+32>>1]>>>7;e=y[f+34|0];ca:{if((e|0)==128){e=d+484414|0;g=z[e>>1]|256;w[e>>1]=g;break ca}w[d+484408>>1]=(e<<24>>24)+128;g=z[d+484414>>1]}i=d+484414|0;w[i>>1]=g|32;v[d+484416|0]=y[f+35|0];e=y[f+22|0];if(e&2){d=f+40|0;Kb(d,o,h);gp(d);e=y[f+22|0]}if(e&5){w[i>>1]=z[i>>1]|16384}if(!(e&8)){break V}d=f+40|0;Kb(d,n,h);gp(d);e=0;while(1){if((e|0)==8){break V}d=e<<1;da:{if(z[d+(f+224|0)>>1]!=(h|0)){break da}d=x[((z[d+(f+240|0)>>1]<<2)+a|0)+900380>>2];if(!d){break da}v[d+14|0]=0}e=e+1|0;continue}}h=N()|0;ub(j);break U}while(1){ea:{fa:{if((y[f+1724|0]|y[f+1725|0]<<8)>>>0<=i>>>0){if(!(c&2)){break fa}h=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{while(1){if(z[a+480190>>1]<=h>>>0){break fa}h=h+1|0;d=D(h,104)+a|0;e=d+484380|0;c=d+484416|0;gm(e,(+(v[c|0]-49|0)+ +v[d+484417|0]*-.0078125)/-12);w[c>>1]=0;c=z[d+484414>>1];if(!(c&16384)){c=Xc(f+256|0,c&1?16:8,c&64?3:1,0,11);x[31725]=0;U(217,c|0,e|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}h=N()|0;break U}x[31725]=0;e=R(153,b|0)|0;c=x[31725];x[31725]=0;oa:{if((c|0)==1){break oa}x[31725]=0;P(185,b|0,12)|0;c=x[31725];x[31725]=0;if((c|0)==1){break oa}c=Fb(f+256|0);x[31725]=0;S(272,b|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break na}ze(d+484423|0,c);x[31725]=0;d=f+52|0;O(385,d|0,16450);e=x[31725];x[31725]=0;if((e|0)==1){break ma}x[f+8>>2]=h;g=x[a+1298404>>2];x[31725]=0;e=f+40|0;S(634,e|0,g|0,c|0);g=x[31725];x[31725]=0;if((g|0)==1){break la}x[31725]=0;g=f+12|0;V(432,g|0,d|0,f+8|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break ka}i=x[a+1298472>>2];x[31725]=0;S(387,i|0,2,g|0);i=x[31725];x[31725]=0;if((i|0)==1){break ja}tb(g);tb(e);Eb(d);tb(c);continue}break}h=N()|0;break U}h=N()|0;break ga}h=N()|0;break ga}h=N()|0;break ha}h=N()|0;break ia}h=N()|0;tb(f+12|0)}tb(f+40|0)}Eb(f+52|0)}tb(c);break U}d=x[dh(x[k>>2],i)>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;pa:{qa:{if((e|0)!=1){if(!d){i=i+1|0;continue}d=dh(x[k>>2],i);xc(d);x[31725]=0;O(635,d|0,f+256|0);d=x[31725];x[31725]=0;if((d|0)==1){break qa}j=Nb(f+12|0);x[31725]=0;S(636,b|0,j|0,z[f+256>>1]);d=x[31725];x[31725]=0;if((d|0)==1){break pa}i=i+1|0;d=x[((i<<2)+a|0)+900380>>2];if(!d|y[d+34|0]){break ea}x[d+4>>2]=32;e=0;Jv(d,0);s=d+108|0;m=d+236|0;while(1){if((e|0)==96){break ea}g=y[(f+e|0)+258|0];ra:{if(g>>>0>=z[f+256>>1]){break ra}l=Ve(x[j>>2],g);g=y[l|0];h=g+1|0;q=e+12|0;G=_b(m,q),H=h,w[G>>1]=H;if(g>>>0>=z[a+480190>>1]){break ra}g=D(h,104)+a|0;v[g+484418|0]=y[f+354|0]&3;v[g+484419|0]=y[f+355|0];v[g+484420|0]=y[f+356|0];v[g+484421|0]=y[f+357|0];w[g+484412>>1]=y[l+1|0]<<1;v[g+484417|0]=y[l+2|0];g=h-1|0;Kb(f+52|0,n,g);if(Hb(x[x[f+52>>2]>>2],x[f+56>>2])){v[d+14|0]=0}Kb(f+52|0,o,g);if(!Hb(x[x[f+52>>2]>>2],x[f+56>>2])){break ra}G=xb(s,q),H=61,v[G|0]=H}e=e+1|0;continue}}h=N()|0;break U}h=N()|0;break U}h=N()|0;Ae(j);break U}Qc(k);dc(r);ub(t);ub(u);break b}Ae(j);continue}}h=N()|0;break U}ub(j);h=h+1|0;continue}}x[31725]=0;O(632,b|0,f+144|0);e=x[31725];x[31725]=0;sa:{ta:{ua:{va:{if((e|0)!=1){x[31725]=0;e=R(153,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break va}x[31725]=0;h=f+72|0;e=(e|0)==32?428:e;j=e?(y[f+1610|0]|y[f+1611|0]<<8)>>>0>513?e+4|0:e:e;S(187,h|0,b|0,j|0);e=x[31725];x[31725]=0;if((e|0)==1){break ua}e=ic(f+256|0,h);i=Ge(f+12|0,hd(dh(x[k>>2],d),e));ub(e);g=d+1|0;ub(h);if(d>>>0>=(y[f+1724|0]|y[f+1725|0]<<8)>>>0){break T}x[31725]=0;d=g&65535;h=U(253,a|0,d|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break ta}break sa}h=N()|0;break U}h=N()|0;break U}h=N()|0;break U}if(!h){break T}e=f+72|0;We(e,2,f+144|0);x[31725]=0;d=f+256|0;O(220,d|0,e|0);e=x[31725];x[31725]=0;wa:{if((e|0)!=1){zc(h+492|0,d);tb(d);if(!j){break T}x[31725]=0;O(635,i|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){o=3;j=0;if((y[f+1610|0]|y[f+1611|0]<<8)>>>0<513){n=0;break wa}x[31725]=0;n=R(191,i|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break sa}if((y[f+1610|0]|y[f+1611|0]<<8)>>>0<514){break wa}x[31725]=0;o=R(153,i|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break wa}break sa}break sa}break sa}x[h>>2]=y[f+358|0]|y[f+359|0]<<8;v[h+16|0]=y[((y[f+360|0]|y[f+361|0]<<8)&3)+25290|0];v[h+17|0]=y[(y[f+361|0]&3)+25290|0];v[h+18|0]=y[((y[f+360|0]|y[f+361|0]<<8)>>>12&3)+25294|0];while(1){xa:{ya:{if((j|0)==4){if(!(v[h+60|0]&1|y[h+16|0]==3)){x[h>>2]=32767}kk(h,127,1);jk(h,0,1);if(!n){break T}x[31725]=0;O(637,i|0,f+72|0);d=x[31725];x[31725]=0;if((d|0)==1){break sa}if(n&2){kk(h,GD(x[a+480208>>2],+((y[f+74|0]|y[f+75|0]<<8)>>>0)),1);jk(h,y[f+76|0],1)}v[h+25|0]=y[f+73|0]==1;if(!(n&4)){break T}v[h+31|0]=y[f+79|0]+1;d=v[f+80|0];v[h+34|0]=d+1;if((d|0)<0){v[h+30|0]=y[f+87|0]+1}if(!y[f+84|0]){break ya}j=h+108|0;e=0;while(1){if((e|0)==128){break ya}d=e+1|0;x[f+52>>2]=d+v[f+84|0];VX(f+52|0);n=x[f+52>>2];G=xb(j,e),H=n,v[G|0]=H;e=d;continue}}if(!(o&1)){break xa}x[31725]=0;O(638,i|0,f+72|0);d=x[31725];x[31725]=0;za:{if((d|0)!=1){d=Zh(h,y[j+25298|0]);Aa:{if((j|0)!=3){e=y[f+72|0];l=y[d+12|0]&-17;break Aa}e=y[f+72|0];l=e<<4&16|y[d+12|0]&-17}v[d+12|0]=e>>>1&2|(e<<1&4|(l&248|e&1));v[f+52|0]=y[f+73|0];v[f+40|0]=16;e=y[Rb(f+52|0,f+40|0)|0];x[31725]=0;O(295,d|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break za}e=y[f+74|0];v[d+15|0]=e;v[d+16|0]=e;v[d+13|0]=y[f+75|0];v[d+14|0]=y[f+76|0];e=0;l=x[d>>2];s=Sd(l,x[d+4>>2]);while(1){if((e|0)==(s|0)){break xa}m=yb(l,e);d=(f+72|0)+(e<<2)|0;w[m>>1]=y[d+8|0]|y[d+9|0]<<8;G=m,H=Kd(y[d+10|0]|y[d+11|0]<<8,0,64),v[G+2|0]=H;e=e+1|0;continue}}break sa}break sa}Jv(h,0);break T}j=j+1|0;o=o>>>1|0;continue}}h=N()|0;ub(i)}Qc(k);break s}ub(i);continue}}h=N()|0;break s}h=N()|0;break s}h=N()|0;break s}else{e=v[xb(i,k)|0];Ba:{if((e|0)<=(k|0)|(e|0)>=(g|0)){break Ba}e=y[((e<<5)+a|0)+480288|0];if(!e){break Ba}g=((k<<5)+a|0)+480288|0;h=y[g|0];if(!h){v[g|0]=e;break Ba}h=h-1|0;while(1){g=h&255;h=um(x[vd(d,g)+28>>2]);g=vd(d,g);if((h|0)==255){e=e-1&255;x[g+28>>2]=e>>>0<250?e+128|0:0}else{h=um(x[g+28>>2]);continue}break}}k=k+1|0;continue}}}h=N()|0;break s}x[31725]=0;g=R(153,t|0)|0;d=x[31725];x[31725]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){x[31725]=0;d=R(153,t|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ka}x[31725]=0;e=f+256|0;S(187,e|0,t|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ka}d=ic(f+72|0,e);ub(e);if((g|0)==4674381){break Ga}if((g|0)==5068115){break Fa}if((g|0)==726487106){break Ja}if((g|0)==844387158){break Ea}e=0;if((g|0)==1280004692){break Ia}if((g|0)==1314144592){break Ha}if((g|0)!=1397445204){break Da}x[31725]=0;e=R(191,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[a+480188>>1]<=e>>>0){break Da}x[31725]=0;g=P(639,d|0,f+256|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break x}if(g){w[((e<<5)+a|0)+480286>>1]=z[f+256>>1]>>>10;G=xb(x[r>>2],e),H=y[f+259|0],v[G|0]=H}e=e+1|0;continue}}h=N()|0;break s}h=N()|0;break s}if(h&1){break Da}v[a+480224|0]=2;x[31725]=0;C=+ia(640,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break Ca}if(!(C>1e-8)){break Da}G=a,H=_e(2646e3/(C*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[G+480204>>2]=H;break Da}while(1){La:{if(z[a+480188>>1]<=e>>>0){break Da}g=x[d>>2];x[31725]=0;g=U(152,g|0,x[f+80>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break w}if(!g){break Da}g=Fb(f+256|0);x[31725]=0;S(360,d|0,g|0,-1);i=x[31725];x[31725]=0;if((i|0)!=1){l=f+12|0;wg(l,3,Jb(g),Yc(x[f+260>>2],y[f+267|0]));x[31725]=0;i=f+144|0;O(220,i|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break La}om(((e<<5)+a|0)+480289|0,i);tb(i);tb(g);e=e+1|0;continue}}break}h=N()|0;tb(g);break t}while(1){if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=e>>>0){break Da}g=x[d>>2];x[31725]=0;g=U(152,g|0,x[f+80>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break v}if(!g){break Da}if(!xp(x[a+484344>>2],x[a+484348>>2],e&65535)){break Da}g=Fb(f+256|0);x[31725]=0;S(360,d|0,g|0,-1);i=x[31725];x[31725]=0;Ma:{if((i|0)==1){break Ma}i=x[o>>2];x[31725]=0;O(285,Wb(i,e)|0,g|0);i=x[31725];x[31725]=0;if((i|0)==1){break Ma}tb(g);e=e+1|0;continue}break}h=N()|0;tb(g);break t}x[31725]=0;P(185,d|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}x[31725]=0;e=R(204,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}x[31725]=0;V(338,j|0,d|0,e|0,2);e=x[31725];x[31725]=0;if((e|0)!=1){break Da}break u}x[31725]=0;P(641,d|0,f+12|0)|0;e=x[31725];x[31725]=0;Na:{if((e|0)!=1){e=Fb(f+256|0);x[31725]=0;S(360,d|0,e|0,-1);g=x[31725];x[31725]=0;if((g|0)==1){break Na}if(!Ld(e,12682)){x[31725]=0;g=f+144|0;S(260,g|0,22,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break Na}Ab(k,g);tb(g)}tb(e);break Da}h=N()|0;break t}h=N()|0;tb(e);break t}x[31725]=0;n=R(153,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}}ub(d);continue}break}h=N()|0;break t}h=N()|0;break t}h=N()|0;break t}h=N()|0;break t}h=N()|0}ub(d)}dc(r);break e}h=N()|0;break e}while(1){d=x[j>>2];x[31725]=0;d=U(152,d|0,x[f+264>>2],1)|0;g=x[31725];x[31725]=0;Oa:{if((g|0)!=1){if(!d){break m}x[31725]=0;i=R(199,j|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break l}n=0;if((i|0)!=255){break Oa}x[31725]=0;n=R(199,j|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;i=R(199,j|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break Oa}}break l}break l}if(i&127){d=Wb(x[o>>2],r);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],e,k&65535);DE(f+72|0);if(i&1){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+72|0]=d}if(i&2){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+73|0]=d}if(i&4){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+74|0]=d}if(i&8){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+75|0]=d}if(i&16){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+76|0]=d}if(i&32){x[31725]=0;d=R(199,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}v[f+77|0]=d}if(i&64){x[31725]=0;d=R(199,j|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break l}v[f+78|0]=d}E=YX(g,f+72|0);x[f+144>>2]=n;x[f+52>>2]=l+(e^-1);F=x[Gb(f+144|0,f+52|0)>>2];i=0;d=g;while(1){if((i|0)!=(F|0)){d=D(z[a+480188>>1],6)+d|0;m=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=m;v[d+1|0]=m>>>8;v[d+2|0]=m>>>16;v[d+3|0]=m>>>24;m=y[g+4|0]|y[g+5|0]<<8;v[d+4|0]=m;v[d+5|0]=m>>>8;i=i+1|0;continue}break}h=h|E}e=(e+n|0)+1|0;while(1){if(e>>>0>=l>>>0){k=k+1|0;e=e-l|0;continue}break}if(s>>>0>(k&65535)>>>0){continue}break}}ub(j);r=r+1|0;continue}break}h=N()|0;ub(j);break e}h=N()|0;break e}h=N()|0}ub(t)}ub(u)}Q(h|0);p()}e=1}fb=f+1728|0;return e|0}function qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=fb-1120|0;fb=d;xc(b);e=fb-16|0;fb=e;g=d+884|0;v_(e+8|0,g);o=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(o|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(i|0)==(o|0);if(!e){u_(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!x_(g)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(w_(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}if(!c){f=1;break o}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16809984;e=d+448|0;xr(e,32);g=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=g;f=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=f;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);f=qp(d+840|0);C=f,E=Kd(y[d+1084|0],1,31),x[C+8>>2]=E;C=f,E=Kd(y[d+1085|0],1,12),x[C+4>>2]=E;C=f,E=Bb(y[d+1086|0]|y[d+1087|0]<<8),x[C>>2]=E;iE(a+1298412|0,f);w[a+480188>>1]=32;f=d+36|0;s_(f,3,d+1088|0);Lr(e,1,f);Ab(a+1298368|0,e);tb(e);p:{if(y[d+887|0]<=5){ig(f,3924);break p}e=fb-16|0;fb=e;f=tc(e+4|0,3993);_c(d+36|0,f);tb(f);fb=e+16|0}x[31725]=0;e=d+448|0;f=d+36|0;S(372,e|0,f|0,y[d+887|0]);g=x[31725];x[31725]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((g|0)!=1){Ab(a+1298344|0,e);tb(e);Eb(f);g=tc(e,15125);Ab(a+1298356|0,g);tb(g);C=a+1298404|0,E=x[Fc(e,26)>>2],x[C>>2]=E;We(f,3,d+892|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}C=d,E=Bb(y[d+1112|0]|y[d+1113|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=z[qe(e,f)>>1],x[C+480196>>2]=E;C=d,E=Bb(y[d+1114|0]|y[d+1115|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=D(z[qe(e,f)>>1],1e4),x[C+480204>>2]=E;C=d,E=Bc(((Bb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[C+448>>2]=E;x[d+36>>2]=256;C=a,E=x[Gb(e,f)>>2],x[C+480200>>2]=E;C=d,E=Bb(y[d+1118|0]|y[d+1119|0]<<8),w[C+448>>1]=E;Gf(e,127);f=0;e=z[d+448>>1];while(1){if((e|0)==(f|0)){break G}C=d,E=Bc(((Vk(b)<<8)+2047>>>0)/4095|0,0),w[C+36>>1]=E;w[d+344>>1]=256;C=((f<<5)+a|0)+480284|0,E=z[Nc(d+36|0,d+344|0)>>1],w[C>>1]=E;f=f+1|0;continue}}cd(b,$b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));o=Ge(d+820|0,b);x[31725]=0;e=d+808|0;O(377,e|0,o|0);b=x[31725];x[31725]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31725]=0;b=d+448|0;S(378,b|0,e|0,1346458707);f=x[31725];x[31725]=0;if((f|0)==1){break H}x[31725]=0;f=U(152,x[d+448>>2],x[d+456>>2],2)|0;g=x[31725];x[31725]=0;if((g|0)==1){break K}if(!f){break I}x[31725]=0;f=R(275,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break K}if((f-1&65535)>>>0>126){break I}w[a+480188>>1]=f;ub(b);x[31725]=0;S(378,b|0,e|0,1397706311);b=x[31725];x[31725]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}if(!b){break I}x[31725]=0;b=d+448|0;e=R(275,b|0)|0;f=x[31725];x[31725]=0;M:{if((f|0)==1){break M}w[d+36>>1]=e;e=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;g=R(275,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break M}bf(Xb(f,e),g);x[31725]=0;e=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break M}Gf(d+36|0,km(e>>>1|0));e=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;S(278,Xb(f,e)|0,b|0,z[d+36>>1]);b=x[31725];x[31725]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1480806221);b=x[31725];x[31725]=0;if((b|0)==1){break F}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],3)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(b){break D}b=160;while(1){N:{f=b;if(!b){f=0;break N}b=f-1|0;if(y[(d+b|0)+924|0]==32){continue}}break}x[31725]=0;V(345,a+1298332|0,d+924|0,f|0,4);b=x[31725];x[31725]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31725]=0;b=d+448|0;e=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;V(338,a+1298332|0,b|0,e|0,4);b=x[31725];x[31725]=0;if((b|0)!=1){break C}}break B}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1413697073);e=x[31725];x[31725]=0;if((e|0)==1){break A}x[31725]=0;e=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}if(e){break z}x[31725]=0;e=P(151,b|0,2648)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}if(!e){break z}f=0;x[31725]=0;b=R(283,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}while(1){if((f|0)==32){break z}e=((f<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}e=d+448|0;ub(e);x[31725]=0;S(378,e|0,d+808|0,1413697074);b=x[31725];x[31725]=0;if((b|0)==1){break x}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],12)|0;f=x[31725];x[31725]=0;if((f|0)==1){break w}O:{if(!b){break O}x[31725]=0;b=d+36|0;O(379,b|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break w}f=af(b);g=ec(b);i=r_(b);h=zb(b);l=q_(b);b=D(Kd(Bb(y[f|0]|y[f+1|0]<<8),32,999),1e4);g=nva(Bb(y[g|0]|y[g+1|0]<<8),0,1e4,0);f=hb;g=g+32768|0;f=g>>>0<32768?f+1|0:f;C=a,E=((Bc((f&65535)<<16|g>>>16,f>>>16|0)>>>0)%1e4|0)+b|0,x[C+480204>>2]=E;C=a,E=Kd(Bb(y[i|0]|y[i+1|0]<<8),1,255),x[C+480196>>2]=E;b=16/(Kd(Bb(y[l|0]|y[l+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;C=a,E=D(Kd(Bb(y[h|0]|y[h+1|0]<<8),1,16),b),x[C+480220>>2]=E;if(!Bb(z[d+36>>1])){break O}x[31725]=0;b=R(275,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]&-17|!b<<4}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1414942540);e=x[31725];x[31725]=0;if((e|0)==1){break v}x[31725]=0;e=U(152,x[d+448>>2],x[d+456>>2],2)|0;f=x[31725];x[31725]=0;if((f|0)==1){break t}if(!e){break u}x[31725]=0;b=R(275,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break t}w[d+36>>1]=b;w[d+344>>1]=z[a+480188>>1];b=z[Nc(d+36|0,d+344|0)>>1];f=0;while(1){if((b|0)==(f|0)){break u}x[31725]=0;e=R(275,d+448|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break t}w[d+36>>1]=e;w[d+344>>1]=4096;C=((f<<5)+a|0)+480286|0,E=z[Nc(d+36|0,d+344|0)>>1]>>>6&255,w[C>>1]=E;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+448|0;ub(b);x[31725]=0;e=d+36|0;S(378,e|0,d+808|0,1296652368);f=x[31725];x[31725]=0;if((f|0)==1){break s}x[31725]=0;f=U(152,x[d+36>>2],x[d+44>>2],56)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!f){break r}x[31725]=0;O(380,e|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}if((Bb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Bb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}C=d,E=Bb(y[d+488|0]|y[d+489|0]<<8),w[C+344>>1]=E;w[d+796>>1]=16384;e=z[Nc(d+344|0,d+796|0)>>1];b=e>>>24|0;f=(e<<8)+2048|0;b=f>>>0<2048?b+1|0:b;C=a,E=Bc((b&4095)<<20|f>>>12,b>>>12|0),x[C+480200>>2]=E;f=0;while(1){if(Bb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(f&65535)>>>0){break r}x[31725]=0;O(381,d+36|0,d+344|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}P:{if(y[d+344|0]){break P}b=Bb(y[d+346|0]|y[d+347|0]<<8);if(b>>>0>=z[a+480188>>1]){break P}b=(b<<5)+a|0;C=b+480284|0,E=Bc(((Bb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[C>>1]=E;h=b+480286|0;e=Bb(y[d+348|0]|y[d+349|0]<<8);b=e>>>26|0;g=(e<<6)+2048|0;b=g>>>0<2048?b+1|0:b;C=h,E=Bc((b&4095)<<20|g>>>12,b>>>12|0)&255,w[C>>1]=E}f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31725]=0;S(382,b|0,d+808|0,1396788530);b=x[31725];x[31725]=0;if((b|0)==1){break e}C=d,E=wb(x[d+36>>2]),x[C+760>>2]=E;f=c&2;h=d+450|0;l=wb(x[d+40>>2]);Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){e=x[d+760>>2];if(!Ib(e,l)){b=d+36|0;Qc(b);x[31725]=0;S(382,b|0,d+808|0,1396788560);b=x[31725];x[31725]=0;if((b|0)==1){break f}C=d,E=wb(x[d+36>>2]),x[C+784>>2]=E;g=d+450|0;i=wb(x[d+40>>2]);break Q}x[31725]=0;b=P(383,e|0,d+448|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break S}_:{$:{if(!b){break $}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Bb(z[d+496>>1])>>>0>1){break $}if(Bb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31725]=0;g=D(b,104)+a|0;i=g+484380|0;O(384,d+448|0,i|0);b=x[31725];x[31725]=0;aa:{ba:{ca:{if((b|0)==1){break ca}j=d+796|0;aj(j,3,h);x[31725]=0;b=d+344|0;O(220,b|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break ba}zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,b);tb(b);if(!f){break $}j=z[d+522>>1]|z[d+524>>1]<<16;x[31725]=0;j=P(151,e|0,$b(j)-8|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break ca}if(!j){break $}if(Bb(z[d+478>>1])){break aa}Xc(b,(Bb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Bb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Bb(y[d+482|0]|y[d+483|0]<<8),0);x[31725]=0;U(217,b|0,i|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}b=Fb(d+344|0);i=z[d+498>>1];x[31725]=0;S(272,e|0,b|0,Bb(i)|0);e=x[31725];x[31725]=0;if((e|0)==1){break U}ze(g+484423|0,b);if((Bb(z[d+478>>1])|0)==1){x[31725]=0;e=d+784|0;O(385,e|0,16450);g=x[31725];x[31725]=0;if((g|0)==1){break _}x[31725]=0;g=d+772|0;S(260,g|0,0,b|0);i=x[31725];x[31725]=0;if((i|0)==1){break Z}x[31725]=0;i=d+796|0;V(386,i|0,e|0,z[d+448>>1],g|0);j=x[31725];x[31725]=0;if((j|0)==1){break Y}j=x[a+1298472>>2];x[31725]=0;S(387,j|0,2,i|0);j=x[31725];x[31725]=0;if((j|0)==1){break X}tb(i);tb(g);Eb(e)}tb(b)}Sf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(b);break R}a=N()|0}Qc(d+36|0);break c}da:{while(1){ea:{e=x[d+784>>2];if(!Ib(e,i)){Qc(d+36|0);x[31725]=0;S(382,d+796|0,d+808|0,1447382614);b=x[31725];x[31725]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31725]=0;b=P(388,e|0,d+448|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ea}fa:{ga:{if(!b){break ga}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Bb(z[d+502>>1])){break ga}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31725]=0;h=(D(b,104)+a|0)+484380|0;O(389,d+448|0,h|0);b=x[31725];x[31725]=0;if((b|0)==1){break ea}l=d+796|0;aj(l,3,g);x[31725]=0;b=d+344|0;O(220,b|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break ea}zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,b);tb(b);if(!f){break ga}l=z[d+478>>1];Xc(b,(Bb(z[d+482>>1])|0)==8?8:16,Bb(l)&1?2:1,1,0);x[31725]=0;U(217,b|0,h|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break fa}}Sf(d+784|0);continue}}break}a=N()|0;Qc(d+36|0);break c}x[31725]=0;b=d+808|0;S(382,d+784|0,b|0,1413828182);e=x[31725];x[31725]=0;if((e|0)==1){break h}x[31725]=0;S(382,d+772|0,b|0,1346719318);e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;S(382,d+760|0,b|0,1229869908);b=x[31725];x[31725]=0;if((b|0)==1){break l}C=d,E=wb(x[d+760>>2]),x[C+12>>2]=E;l=d+394|0;j=d+346|0;q=d+450|0;k=wb(x[d+764>>2]);while(1){ha:{ia:{ja:{ka:{g=x[d+12>>2];if(!Ib(g,k)){Qc(d+760|0);x[31725]=0;S(382,d+344|0,d+808|0,1346458692);b=x[31725];x[31725]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31725]=0;b=P(390,g|0,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}if(!b){break ha}if(Bb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31725]=0;e=U(253,a|0,Bb(b)|0,0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break n}if(!e){break ha}b=Bb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}f=d+344|0;aj(f,3,q);x[31725]=0;b=d+36|0;O(220,b|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break ja}zc(e+492|0,b);tb(b);v[e+33|0]=2;if((xe(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;f=xe(w[d+482>>1]);b=f>>>24|0;i=(f<<8&-256)+2047|0;f=b&255;C=e,E=Bc(pva(i,i>>>0<2047?f+1|0:f,4095,0),hb),x[C+8>>2]=E}i=e+108|0;n=e+236|0;b=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;f=b&255;h=d+36|0;if(f>>>0>=A[Gb(h,d+344|0)>>2]){x[31725]=0;O(391,h|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break la}C=d,E=_i(x[d+36>>2]),x[C+344>>2]=E;b=Rf(h);f=z[a+480190>>1];i=z[d+480>>1];while(1){h=x[d+344>>2];if(Ib(h,b)){h=z[ip(h)>>1];if(f>>>0>(h-1&65535)>>>0){C=(D(h,104)+a|0)+484410|0,E=Bb(i),w[C>>1]=E}ah(d+344|0);continue}break}Sv(d+36|0);kk(e,127,1);jk(e,0,1);b=Bb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31725]=0;V(392,e|0,0,Bb(b)|0,d+796|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31725]=0;V(392,e|0,1,Bb(b)|0,d+772|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31725]=0;V(392,e|0,2,Bb(b)|0,d+784|0);b=x[31725];x[31725]=0;if((b|0)!=1){break ha}break n}x[31725]=0;S(393,g|0,d+344|0,((b|0)==1?98:102)|0);b=x[31725];x[31725]=0;ma:{na:{oa:{if((b|0)!=1){b=Bb(z[d+344>>1]);i=b&1;if(!i){break ia}f=b&24;if(f){break oa}f=0;break na}a=N()|0;break m}if((f|0)!=8){break ma}f=1}v[e+25|0]=f}pa:{qa:{ra:{sa:{if(!(b&2)){break sa}x[31725]=0;b=U(394,d+332|0,j|0,24)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ra}x[31725]=0;s=+ia(395,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break qa}tb(b);if(!(s>20)){break sa}kk(e,GD(x[a+480208>>2],s),1)}if(Bb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(b);break m}x[31725]=0;b=U(394,d+320|0,l|0,24)|0;f=x[31725];x[31725]=0;ta:{if((f|0)!=1){x[31725]=0;s=+ia(395,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break ta}tb(b);jk(e,fm(s*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(b);break m}else{h=(d+448|0)+(f<<1)|0;m=y[h+52|0];C=_b(n,f),E=m,w[C>>1]=E;m=xb(i,f);h=jm(v[h+53|0]+y[m|0]|0);C=xb(i,f),E=h,v[C|0]=E;b=b+1|0;continue}}break}a=N()|0;break m}b=x[d+348>>2];e=x[d+344>>2];x[31725]=0;i=a+484344|0;O(225,i|0,Uf(e,b)&65535);b=x[31725];x[31725]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];C=d,E=wb(x[d+344>>2]),x[C+24>>2]=E;n=c&1;m=wb(x[d+348>>2]);while(1){va:{wa:{xa:{ya:{za:{Aa:{c=x[d+24>>2];if(!Ib(c,m)){x[31725]=0;S(378,d+36|0,d+808|0,1414414669);b=x[31725];x[31725]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!n){break va}b=x[c+8>>2];e=x[c>>2];x[31725]=0;b=U(152,e|0,b|0,24)|0;e=x[31725];x[31725]=0;if((e|0)==1){break za}if(!b){break va}x[31725]=0;h=R(275,c|0)|0;b=x[31725];x[31725]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31725]=0;b=d+448|0;O(396,c|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break Ea}x[31725]=0;q=R(275,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Da}x[31725]=0;l=R(275,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ca}x[31725]=0;j=R(275,c|0)|0;e=x[31725];x[31725]=0;Fa:{if((e|0)==1){break Fa}e=x[c+8>>2];f=x[c>>2];x[31725]=0;e=U(152,f|0,e|0,D(D(j,l),5)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Fa}if(!(e&q>>>0<2)){break va}x[31725]=0;e=U(198,i|0,h|0,l|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Fa}if(!e){break va}e=x[i>>2];x[31725]=0;O(397,Wb(e,h)|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=de(d+36|0,0,d+12|0);x[31725]=0;e=U(373,d+760|0,j|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break wa}g=0;Ga:while(1){if((g|0)==(l|0)){md(e);break va}b=Wb(x[i>>2],h);cf(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],g);f=0;while(1){if((f|0)==(j|0)){g=g+1|0;continue Ga}b=bh(d+12|0);if(z[a+480188>>1]>f>>>0){b=Wc(x[d+36>>2],f)}x[31725]=0;O(398,c|0,d|0);k=x[31725];x[31725]=0;Ha:{if((k|0)==1){break Ha}k=y[d|0];if((k-1&255)>>>0<=119){k=k+1|0;v[b|0]=k;C=_b(x[e>>2],f),E=k,v[C|0]=E}k=y[d+1|0];if(k){v[b+1|0]=k;C=_b(x[e>>2],f),E=k,v[C+1|0]=E}k=y[d+4|0];if(k){v[b+2|0]=1;v[b+4|0]=q?k-16|0:k>>>2|0}k=y[d+887|0];t=y[d+3|0];u=y[d+2|0];r=_b(x[e>>2],f);B=y[r+1|0];r=y[r|0];x[31725]=0;ya(375,a|0,b|0,u|0,t|0,k|0,r|0,B|0,d+32|0,d+28|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ha}f=f+1|0;continue}break}break}a=N()|0;md(e);break ua}x[31725]=0;b=U(152,x[d+36>>2],x[d+44>>2],38)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(!b){break xa}x[31725]=0;c=R(275,d+36|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ya}e=d+452|0;f=0;Ia:{while(1){if(c>>>0<=(f&65535)>>>0){break xa}x[31725]=0;b=U(152,x[d+36>>2],x[d+44>>2],36)|0;g=x[31725];x[31725]=0;Ja:{if((g|0)!=1){if(b){break Ja}break xa}break ya}x[31725]=0;O(399,d+36|0,d+448|0);b=x[31725];x[31725]=0;if((b|0)!=1){Ka:{if(Bb(z[d+448>>1])){break Ka}if(Bb(z[d+450>>1])>>>0>=z[a+480188>>1]){break Ka}We(d,3,e);x[31725]=0;b=d+12|0;O(220,b|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ia}om(((Bb(z[d+450>>1])<<5)+a|0)+480289|0,b);tb(b)}f=f+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Qc(d+344|0);Qc(d+772|0);Qc(d+784|0);Qc(d+796|0);f=1;break q}a=N()|0;break ua}Sf(d+24|0);continue}}a=N()|0}Qc(d+344|0);break k}a=N()|0;break m}f=0;while(1){if(y[d+445|0]<=f>>>0){break ha}x[31725]=0;h=d+36|0;O(400,g|0,h|0);b=x[31725];x[31725]=0;La:{Ma:{if((b|0)!=1){x[d>>2]=33620480;C=d,E=(Bb(z[d+484>>1])|0)!=0,v[C+32|0]=E;C=d,E=(Bb(z[d+486>>1])|0)!=0,v[C+33|0]=E;C=d,E=(Bb(z[d+488>>1])|0)!=0,v[C+34|0]=E;C=d,E=i&(Bb(z[d+490>>1])|0)!=0,v[C+35|0]=E;if(!y[(d+32|0)+f|0]|f>>>0>3){break La}b=(f|0)!=3;if(!b&(v[e+100|0]&1)){break La}x[31725]=0;m=h;h=y[d+f|0];S(401,m|0,e|0,h|0);n=x[31725];x[31725]=0;if((n|0)==1){break Ma}if(!b){v[e+100|0]=y[e+100|0]|16}Na:{switch(h|0){case 0:if(Bb(y[d+48|0]|y[d+49|0]<<8)&1){b=Bb(y[d+46|0]|y[d+47|0]<<8)&32767}else{b=0}x[e>>2]=b;break La;case 2:break Na;default:break La}}if(!(Bb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}C=d,E=Bb(y[d+42|0]|y[d+43|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;b=z[qe(d+28|0,d+24|0)>>1];h=yi(Bc(((Bb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));C=d,E=Bb(y[d+40|0]|y[d+41|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;n=Dh(256/z[qe(d+28|0,d+24|0)>>1]|0);m=z[d+448>>1];t=y[d+44|0]|y[d+45|0]<<8;x[31725]=0;r=Bb(m);m=Bb(t);ja(402,a|0,r|0,y[(m>>>0<6?m:0)+24960|0],255/(b>>>0)|0,h|0,n|0);b=x[31725];x[31725]=0;if((b|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}f=f+1|0;continue}}Sf(d+12|0);continue}}ie(d+808|0);ub(o)}fb=d+1120|0;return f|0}a=N()|0}Qc(d+760|0);break k}a=N()|0}Qc(d+772|0);break i}a=N()|0}Qc(d+784|0);break g}a=N()|0}Qc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}ie(d+808|0)}ub(o)}Q(a|0);p()}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0;l=fb-1168|0;fb=l;xc(b);a:{d=l+1144|0;if(!rs(b,d)){break a}if(!ER(d)){break a}if((y[l+1152|0]|y[l+1153|0]<<8|(y[l+1154|0]<<16|y[l+1155|0]<<24))!=(kh(x[b>>2])|0)){break a}if((y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24))!=(lf(b)|0)){break a}if(!c){g=1;break a}d=l+1088|0;Sb(d,0,56);e=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;h=x[d+32>>2];if(!h){x[d+32>>2]=1172;h=1172}if(!x[d+36>>2]){x[d+36>>2]=1173}h=ib[h|0](x[d+40>>2],1,43784)|0;e=-4;if(!h){break b}x[d+28>>2]=h;x[h+43780>>2]=1;x[h+10992>>2]=0;x[h+10996>>2]=0;x[h>>2]=0;x[h+11008>>2]=15;x[h+11e3>>2]=1;x[h+11004>>2]=0;e=0}if(e){break a}g=y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24);x[l+1084>>2]=g;K=y[l+1164|0]|y[l+1165|0]<<8|(y[l+1166|0]<<16|y[l+1167|0]<<24);T=UZ(l+1072|0,K);c:{d:{while(1){if(!(!K|!g|(f|0)==1)){x[l+32>>2]=1024;h=l+48|0;f=l+32|0;V=x[Gb(f,l+1084|0)>>2];d=gc(l+40|0,h,V);g=x[d>>2];d=x[d+4>>2];x[31725]=0;bo(161,f,b,g,d);f=x[31725];x[31725]=0;if((f|0)==1){break d}g=h;f=V;d=aa^-1;while(1){if(f>>>0<4){while(1){if(f){d=x[(((y[g|0]^d)&255)<<2)+79568>>2]^d>>>8;f=f-1|0;g=g+1|0;continue}break}aa=d^-1}else{d=x[(((y[g|0]^d)&255)<<2)+79568>>2]^d>>>8;d=d>>>8^x[(((d^y[g+1|0])&255)<<2)+79568>>2];d=d>>>8^x[(((d^y[g+2|0])&255)<<2)+79568>>2];d=d>>>8^x[(((d^y[g+3|0])&255)<<2)+79568>>2];f=f-4|0;g=g+4|0;continue}break}x[l+1092>>2]=V;x[l+1088>>2]=h;x[l+1104>>2]=K;x[l+1100>>2]=x[T>>2]+ba;B=fb-16|0;fb=B;d=-2;q=l+1088|0;e:{if(!q){break e}i=x[q+28>>2];if(!i){break e}da=x[q+4>>2];x[i+11e3>>2]=0;f:{if(x[i+43780>>2]<0){break f}if(x[i+11004>>2]){break e}g=x[i+11008>>2];d=0;x[i+11004>>2]=0;f=x[i+10996>>2];if(!f){X=(g|0)>0?11:10;I=i+11012|0;h=x[q+4>>2];g=x[i+10992>>2];while(1){x[B+12>>2]=h;x[B+8>>2]=32768-g;F=x[q>>2];h=0;C=0;E=0;J=0;L=0;W=0;M=0;Y=0;Z=fb-144|0;fb=Z;g:{h:{O=g+I|0;if(O>>>0>=I>>>0){G=x[B+8>>2]+O|0;r=G-I|0;$=(I^-1)+G|0;if(!(r&$)){break h}}x[B+8>>2]=0;x[B+12>>2]=0;n=-3;break g}o=x[B+12>>2];u=o+F|0;P=x[i+60>>2];t=x[i+40>>2];f=x[i+36>>2];s=x[i+32>>2];g=x[i+56>>2];e=x[i+4>>2];n=-1;m=O;j=F;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{k=x[i>>2];switch(k|0){case 36:break k;case 39:break m;case 10:break n;case 35:break o;case 17:break p;case 21:break q;case 34:break r;case 2:break w;case 53:break A;case 26:break C;case 25:break D;case 24:break E;case 23:break F;case 18:break G;case 16:break H;case 14:break I;case 51:break L;case 6:break M;case 3:break N;case 37:break O;case 42:break P;case 41:break Q;case 32:break R;case 27:break S;case 11:break T;case 38:break U;case 9:break V;case 52:break W;case 7:break X;case 5:break Y;case 1:break Z;case 0:break _;default:break j}}x[i+28>>2]=1;g=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;t=0;f=0;s=0;e=0;if(X&1){break Z}break v}if((o|0)<=0){n=1;x[i>>2]=1;break i}x[i+8>>2]=y[F|0];j=F+1|0;break w}if((o|0)<=0){break x}W=e+8|0;j=F+1|0;g=y[F|0]<<e|g;d=2;break u}d=4;break u}M=g;break K}d=7;break u}d=8;break u}C=f;break J}E=g;break B}n=1;if((o|0)<=0){break y}e=e+8|0;j=F+1|0;break t}h=f;d=e;break z}k=2;break s}k=37;break k}d=1;break u}d=3;break u}d=5;break u}d=6;break u}d=9;break u}d=10;break u}d=11;break u}d=12;break u}d=13;break u}d=14;break u}d=15;break u}d=16;break u}d=17;break u}d=18;break u}k=1;break s}x[i>>2]=32;break i}x[i>>2]=5;n=1;break i}if(j>>>0>=u>>>0){x[i>>2]=2;n=1;break i}f=y[j|0];x[i+12>>2]=f;j=j+1|0;k=36;d=x[i+8>>2];h=256<<(d>>>4);if(h>>>0>32768|h>>>0>r>>>0|(((f|d<<8)>>>0)%31|f&32)){break l}f=0;if((d&15)!=8){break l}}d=0}$:while(1){aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(d|0){case 0:if(e>>>0>2){break Ga}d=1;continue;case 3:break Ea;case 2:break Fa;case 1:break Ha;case 9:break la;case 10:break ma;case 11:break na;case 12:break oa;case 13:break pa;case 14:break qa;case 15:break ra;case 16:break sa;case 17:break ta;case 8:break za;case 7:break Aa;case 6:break Ba;case 5:break Ca;case 4:break Da;default:break ua}}while(1){if(j>>>0>=u>>>0){x[i>>2]=3;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=g&7;x[i+20>>2]=d;h=d>>>1|0;x[i+24>>2]=h;e=e-3|0;g=g>>>3|0;if(d>>>0>=2){break ya}W=e;break va}e=W&-8;g=g>>>(W&7)|0;f=0;d=0;break xa}while(1){if(j>>>0>=u>>>0){x[i>>2]=6;n=1;break i}g=y[j|0]<<e|g;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}d=1;break xa}if(j>>>0>=u>>>0){x[i>>2]=7;n=1;break i}v[(f+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break xa}while(1){if(j>>>0>=u>>>0){x[i>>2]=51;n=1;break i}g=y[j|0]<<e|g;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}break da}if(m>>>0<G>>>0){v[m|0]=s;f=f-1|0;m=m+1|0;g=M;break ea}n=2;k=52;g=M;break k}if(m>>>0<G>>>0){break wa}n=2;k=9;break k}if(j>>>0<u>>>0){d=G-m|0;h=u-j|0;d=d>>>0<h>>>0?d:h;d=d>>>0<f>>>0?d:f;f=f-d|0;m=yc(m,j,d)+d|0;j=d+j|0;break ca}x[i>>2]=38;n=1;break i}C=0;Ia:{switch(h-1|0){case 0:x[i+44>>2]=288;x[i+48>>2]=32;d=i+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;h=0;while(1){k=144;if((h|0)==144){while(1){h=256;if((k|0)==256){while(1){k=280;if((h|0)==280){while(1){if((k|0)==288){break ia}v[d|0]=8;k=k+1|0;d=d+1|0;continue}}else{v[d|0]=7;h=h+1|0;d=d+1|0;continue}}}else{v[d|0]=9;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=8;h=h+1|0;d=d+1|0;continue}};case 2:break n;default:break Ia}}d=0;break ka}while(1){Ja:{Ka:{La:{Ma:{Na:{Oa:{switch(d|0){case 0:if(f>>>0>3){break Na}if(!e){e=0;break Ma}if(e>>>0>7){break Ka}d=3;continue $;case 1:v[(f+i|0)+10528|0]=g;e=e-8|0;g=g>>>8|0;break Ja;default:break Oa}}f=f+1|0;break La}f=z[i+10528>>1];if((f|0)==(z[i+10530>>1]^65535)){break ea}break m}d=4;continue $}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(m>>>0<G>>>0){v[m|0]=y[(P-s&$)+I|0];m=m+1|0;P=P+1|0;d=7;break fa}n=2;k=53;break k}while(1){if(j>>>0>=u>>>0){x[i>>2]=27;n=1;g=E;break i}E=y[j|0]<<e|E;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=6;break fa}if(j>>>0>=u>>>0){x[i>>2]=26;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=4;if(e>>>0<15){break fa}d=5;break fa}while(1){if(j>>>0>=u>>>0){x[i>>2]=25;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=3;break fa}if(m>>>0>=G>>>0){n=2;k=24;break k}v[m|0]=f;m=m+1|0;break ga}if(j>>>0>=u>>>0){x[i>>2]=23;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=0;if(e>>>0<15){break fa}d=1;break fa}while(1){if(j>>>0>=u>>>0){x[i>>2]=18;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}Y=s-16|0;d=3;break ha}if(j>>>0>=u>>>0){x[i>>2]=16;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=1;if(e>>>0<15){break ha}d=2;break ha}while(1){if(j>>>0>=u>>>0){x[i>>2]=14;n=1;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break ja}d=C+22248|0;while(1){if(j>>>0>=u>>>0){x[i>>2]=11;n=1;f=C;break i}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){Pa:{Qa:{Ra:{if(!d){if(C>>>0>2){break Ra}L=v[C+22248|0];if(L>>>0<=e>>>0){break Pa}d=9;continue $}d=C<<2;x[(d+i|0)+44>>2]=x[d+81104>>2]+((-1<<L^-1)&g);C=C+1|0;e=e-L|0;g=g>>>L|0;break Qa}f=0;Sb(i+7040|0,0,288);d=0;break ja}d=0;continue}d=1;continue}}while(1){Sa:{Ta:{Ua:{if(!d){if(A[i+52>>2]<=f>>>0){break Ua}if(e>>>0>2){break Sa}d=10;continue $}v[(y[f+81120|0]+i|0)+7040|0]=g&7;f=f+1|0;e=e-3|0;g=g>>>3|0;break Ta}x[i+52>>2]=19;break ia}d=0;continue}d=1;continue}}J=x[i+24>>2];d=0}while(1){Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{switch(d|0){case 0:d=0;if((J|0)<0){break ga}R=Sb(Z,0,64);h=D(J,3488)+i|0;Sb(h+352|0,0,3200);ca=h- -64|0;H=x[i+24>>2];k=x[((H<<2)+i|0)+44>>2];while(1){if((d|0)!=(k|0)){h=(y[d+ca|0]<<2)+R|0;x[h>>2]=x[h>>2]+1;d=d+1|0;continue}break};x[R+64>>2]=0;x[R+68>>2]=0;r=0;d=1;h=0;while(1){if((d|0)!=16){o=d<<2;d=d+1|0;o=x[o+R>>2];h=o+h<<1;x[(R- -64|0)+(d<<2)>>2]=h;r=o+r|0;continue}break};S=0;o=-1;if((h|0)!=65536&r>>>0>=2){break o}while(1){if(k>>>0>S>>>0){r=y[S+ca|0];cb:{if(!r){break cb}d=(R- -64|0)+(r<<2)|0;h=x[d>>2];x[d>>2]=h+1;d=0;k=r;while(1){if(k){d=h&1|d<<1;h=h>>>1|0;k=k-1|0;continue}break}if(r>>>0<=10){h=1<<r;r=r<<9|S;k=D(J,3488)+i|0;while(1){if(d>>>0>1023){break cb}w[(k+(d<<1)|0)+352>>1]=r;d=d+h|0;continue}}H=D(J,3488)+i|0;h=H+((d&1023)<<1)|0;k=w[h+352>>1];db:{if(k){h=o;o=k;break db}w[h+352>>1]=o;h=o-2|0}d=d>>>9|0;while(1){d=d>>>1|0;k=d&1;if(r>>>0>=12){k=(H+(k+(o^-1)<<1)|0)+2400|0;o=w[k>>1];if(!o){w[k>>1]=h;o=h;h=h-2|0}r=r-1|0;continue}break}w[((D(J,3488)+i|0)+(k+(o^-1)<<1)|0)+2400>>1]=S;o=h}S=S+1|0;H=x[i+24>>2];k=x[((H<<2)+i|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Wa}break _a;case 1:d=w[(((g&1023)<<1)+i|0)+7328>>1];eb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break eb}break Za}if(e>>>0<11){break eb}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break Za}}d=11;continue $;case 2:s=w[(((g&1023)<<1)+i|0)+7328>>1];if((s|0)>=0){break ab}d=10;while(1){h=g>>>d|0;d=d+1|0;s=w[(((h&1)+(s^-1)<<1)+i|0)+9376>>1];if((s|0)<0){continue}break};break $a;default:break bb}}d=v[Y+18443|0]+((-1<<t^-1)&g)|0;e=e-t|0;g=g>>>t|0;h=f+i|0;Sb(h+10532|0,(s|0)==16?y[h+10531|0]:0,d);d=d+f|0;break _a}d=s>>>9|0;s=s&511}e=e-d|0;g=g>>>d|0;if(s>>>0>15){break Ya}v[(f+i|0)+10532|0]=s;d=f+1|0}h=x[i+48>>2];f=x[i+44>>2];o=h+f|0;if(o>>>0<=d>>>0){break Xa}if(e>>>0<=14){if((u-j|0)<=1){f=d;d=1;continue}g=y[j|0]<<e|y[j+1|0]<<e+8|g;j=j+2|0;e=e+16|0}f=d}d=2;continue}if(!((s|0)!=16|f)){f=0;s=16;break p}Y=s-16|0;t=v[s+22228|0];if(t>>>0<=e>>>0){break Va}d=12;continue $}if((d|0)!=(o|0)){f=d;break q}o=i+10532|0;yc(i- -64|0,o,f);yc(i+3552|0,f+o|0,h);H=x[i+24>>2];f=d}J=H-1|0;x[i+24>>2]=J;d=0;continue}d=3;continue}}d=2}fb:while(1){gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{switch(d|0){case 0:d=w[(((g&1023)<<1)+i|0)+352>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break gb}if(e>>>0<11){break wb}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break gb}}d=13;continue $;case 1:f=w[(((g&1023)<<1)+i|0)+352>>1];if((f|0)>=0){break ub}d=10;while(1){h=g>>>d|0;d=d+1|0;f=w[(((h&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break};break tb;case 3:break jb;case 4:break kb;case 5:break pb;case 6:break qb;case 2:break vb;default:break rb}}while(1){d=u-j|0;if(!((G-m|0)>1&(d|0)>=4)){if(e>>>0>14){break gb}if((d|0)<=1){d=0;continue fb}g=y[j|0]<<e|y[j+1|0]<<e+8|g;e=e+16|0;j=j+2|0;break gb}if(!(e>>>0>14)){g=(y[j|0]|y[j+1|0]<<8)<<e|g;j=j+2|0;e=e+16|0}r=e;f=w[(((g&1023)<<1)+i|0)+352>>1];xb:{if((f|0)<0){d=10;while(1){h=g>>>d|0;d=d+1|0;f=w[(((h&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break}break xb}d=f>>>9|0}e=r-d|0;g=g>>>d|0;if(f&256){break sb}if(!(e>>>0>14)){g=(y[j|0]|y[j+1|0]<<8)<<e|g;j=j+2|0;e=e+16|0}r=e;k=w[(((g&1023)<<1)+i|0)+352>>1];yb:{if((k|0)<0){d=10;while(1){h=g>>>d|0;d=d+1|0;k=w[(((h&1)+(k^-1)<<1)+i|0)+2400>>1];if((k|0)<0){continue}break}break yb}d=k>>>9|0}v[m|0]=f;e=r-d|0;g=g>>>d|0;if(!(k&256)){v[m+1|0]=k;m=m+2|0;continue}break}m=m+1|0;f=k;break sb}d=f>>>9|0;f=f&511}e=e-d|0;g=g>>>d|0;if(f>>>0>255){break sb}d=14;continue $}h=f&511;f=256;if((h|0)==256){break ba}d=h-257<<2;f=x[d+80592>>2];t=0;if(h-285>>>0<4294967276){break ib}t=x[d+80720>>2];if(t>>>0>e>>>0){d=15;continue $}d=3;continue}if(!f){f=-1;break nb}f=f-1|0;d=18;continue $}e=e-t|0;g=E>>>t|0;s=((-1<<t^-1)&E)+s|0;break ob}d=w[(((g&1023)<<1)+i|0)+3840>>1];zb:{if((d|0)<0){k=10;while(1){h=g>>>k|0;k=k+1|0;d=w[(((h&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break zb}k=d>>>9|0;d=d&511}e=e-k|0;E=g>>>k|0;h=d<<2;s=x[h+80848>>2];t=0;if(d-30>>>0<4294967270){g=E;break ob}t=x[h+80976>>2];if(t>>>0<=e>>>0){break mb}d=17;continue $}P=m-I|0;d=(P-s&$)+I|0;if((d>>>0<m>>>0?m:d)+f>>>0>G>>>0){break lb}while(1){if(f>>>0>=3){v[m|0]=y[d|0];v[m+1|0]=y[d+1|0];v[m+2|0]=y[d+2|0];f=f-3|0;d=d+3|0;m=m+3|0;continue}break}if(!f){f=0;break nb}v[m|0]=y[d|0];if((f|0)!=1){v[m+1|0]=y[d+1|0]}m=f+m|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((g&1023)<<1)+i|0)+3840>>1];Ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break Ab}break hb}if(e>>>0<11){break Ab}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break hb}}d=16;continue $}e=e-t|0;f=((-1<<t^-1)&g)+f|0;g=g>>>t|0}if(e>>>0>14){break hb}if((u-j|0)<=1){d=4;continue}g=y[j|0]<<e|y[j+1|0]<<e+8|g;e=e+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!f|!e){break ca}if(e>>>0>7){break da}d=5;continue}e=e-8|0;M=g>>>8|0;s=g&255;d=6;continue}if(f){break aa}f=0}if(v[i+20|0]&1){break t}d=0;continue}d=7;continue}}g=0;d=e>>>3|0;h=j-F|0;h=h>>>0<=j>>>0?h:0;d=d>>>0<h>>>0?d:h;if((e&-8)==d<<3){j=j-d|0;h=0;d=0;e=0;if(!(X&1)){break r}k=0;break s}_(6874,13236,2797,6884);p()}while(1){Bb:{Cb:{Db:{Eb:{Fb:{switch(k|0){case 0:if(h>>>0>3){f=h;e=d;break r}e=0;if(!d){f=h;break Bb}if(d>>>0>7){break Eb}k=1;continue;case 1:break Fb;default:break Db}}while(1){if(j>>>0>=u>>>0){x[i>>2]=41;n=1;f=h;e=d;break i}g=y[j|0]<<d|g;o=d>>>0>4294967287;j=j+1|0;d=d+8|0;if(o){continue}break}}k=g&255;g=g>>>8|0;d=d-8|0;break Cb}if(j>>>0>=u>>>0){x[i>>2]=42;n=1;break i}k=y[j|0];j=j+1|0;h=f;d=e}x[i+16>>2]=x[i+16>>2]<<8|k;h=h+1|0;k=0;continue}k=2;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}f=1}x[i>>2]=k}d=e>>>3|0;h=j-F|0;h=h>>>0<=j>>>0?h:0;d=d>>>0<h>>>0?d:h;j=j-d|0;e=e-(d<<3)|0}x[i+4>>2]=e;x[i+60>>2]=P;x[i+40>>2]=t;x[i+36>>2]=f;x[i+32>>2]=s;x[i+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&g;x[B+12>>2]=j-F;e=m-O|0;x[B+8>>2]=e;if((n|0)<0){break g}j=(e>>>0)%5552|0;f=x[i+28>>2];g=f>>>16|0;k=f&65535;while(1){h=0;if(e){d=O;while(1){if((h|7)>>>0<j>>>0){f=y[d|0]+k|0;o=f+y[d+1|0]|0;r=o+y[d+2|0]|0;E=r+y[d+3|0]|0;M=E+y[d+4|0]|0;C=M+y[d+5|0]|0;m=C+y[d+6|0]|0;k=m+y[d+7|0]|0;g=k+(m+(C+(M+(E+(r+(o+(g+f|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;h=h+8|0;continue}break}h=j&8184;while(1){if((h|0)!=(j|0)){h=h+1|0;k=y[d|0]+k|0;g=k+g|0;d=d+1|0;continue}break}e=e-j|0;g=(g>>>0)%65521|0;k=(k>>>0)%65521|0;O=j+O|0;j=5552;continue}break}f=g<<16|k;x[i+28>>2]=f;if(n){break g}n=0;if(!(X&1)){break g}n=(f|0)!=x[i+16>>2]?-2:0}fb=Z+144|0;x[i+43780>>2]=n;f=x[B+12>>2];x[q>>2]=f+x[q>>2];x[q+4>>2]=x[q+4>>2]-f;x[q+8>>2]=f+x[q+8>>2];x[q+48>>2]=x[i+28>>2];f=x[B+8>>2];x[i+10996>>2]=f;d=x[q+16>>2];f=d>>>0>f>>>0?f:d;yc(x[q+12>>2],x[i+10992>>2]+I|0,f);x[q+12>>2]=f+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-f;x[q+20>>2]=f+x[q+20>>2];e=x[i+10996>>2];x[i+10996>>2]=e-f;g=f+x[i+10992>>2]&32767;x[i+10992>>2]=g;if((n|0)<0){break f}if(!((n|0)!=1|da)){d=-5;break e}if(n){d=0;h=x[q+4>>2];if(!h|!x[q+16>>2]){break e}if((e|0)==(f|0)){continue}break e}break}d=(e|0)==(f|0);break e}g=x[q+16>>2];f=g>>>0>f>>>0?f:g;yc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,f);x[q+12>>2]=f+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-f;x[q+20>>2]=f+x[q+20>>2];g=x[i+10996>>2];x[i+10996>>2]=g-f;x[i+10992>>2]=f+x[i+10992>>2]&32767;if(x[i+43780>>2]){break e}d=(g|0)==(f|0);break e}d=-3}fb=B+16|0;f=d;g=x[l+1084>>2]-V|0;x[l+1084>>2]=g;d=K+ba|0;K=x[l+1104>>2];ba=d-K|0;continue}break}b=l+1088|0;Gb:{if(!b){break Gb}d=x[b+28>>2];if(!d){break Gb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}g=0;Hb:{Ib:{if(!((y[l+1156|0]|y[l+1157|0]<<8|(y[l+1158|0]<<16|y[l+1159|0]<<24))!=(aa|0)|(f|0)!=1|K)){oe(l+24|0,x[T>>2],x[T+4>>2]);b=Nd(l+16|0);x[31725]=0;f=x[b+4>>2];x[l+8>>2]=x[b>>2];x[l+12>>2]=f;b=jg(556,l+48|0,x[l+24>>2],x[l+28>>2],l+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break Ib}x[31725]=0;g=U(917,a|0,b|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break Hb}ub(b)}dc(T);break a}a=N()|0;break c}a=N()|0;ub(b);break c}a=N()|0}dc(T);Q(a|0);p()}fb=l+1168|0;return g|0}function Xqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=E(0),O=E(0),P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=E(0),na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=E(0);s=fb-96|0;fb=s;xc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}h=s+76|0;d=fb-16|0;fb=d;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){eh(h+F|0);F=F+1|0;continue}break}break c}_w(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d:{e:{if(!kd(h,15024,3)){h=s+32|0;d=fb-16|0;fb=d;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){eh(h+F|0);F=F+1|0;continue}break}break f}Qr(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;F=0;h=3;while(1){if((h|0)==7){break d}d=v[(s+32|0)+h|0];if((d|0)<0){break e}h=h+1|0;F=d&255|F<<7;continue}}g:{if(kd(s+76|0,14195,3)){break g}if(!nY(c,13675)){break g}Vb(c,Pg(c)+16|0);continue}d=s+76|0;if(!kd(d,28590,3)){continue}if(!kd(d,28594,3)){continue}if(!y[s+76|0]){Gh(c,2);continue}if(AV(s+76|0)){break b}}h=0;break a}Vb(c,F);continue}break}xc(c);d=s+76|0;rD(d,c);W=x[s+76>>2];c=$e(d);P=Nb(s- -64|0);x[31725]=0;ba=R(593,s+60|0)|0;d=x[31725];x[31725]=0;h:{i:{j:{if((d|0)!=1){JB(Sb(x[ba>>2],0,6668));x[s+48>>2]=0;x[s+52>>2]=0;x[s+40>>2]=0;x[s+44>>2]=0;x[s+32>>2]=0;x[s+36>>2]=0;x[31725]=0;ca=R(594,s+20|0)|0;d=x[31725];x[31725]=0;k:{if((d|0)!=1){F=0;while(1){G=x[ba>>2];g=Gc(W,da);Z=x[ca>>2];L=s+32|0;d=0;m=0;r=fb-17152|0;fb=r;x[r+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(g|0)<5){break n}if(!tq(G+6152|0,c)){break n}h=kz(y[c+1|0],y[c+2|0],x[G+6148>>2])+sq(c)|0;x[r+17148>>2]=h;if((g|0)==(h|0)){h=g;break m}o:{if((g|0)>=(h+4|0)){if(tq(c,c+h|0)){break o}}x[r+17148>>2]=0;break n}if(h){break m}}e=c;A=Sb(G,0,6668)+6148|0;q=r+17148|0;n=g-4|0;I=(n|0)>0?n:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=g;break s}if(!gM(e)){break q}k=kz(y[e+1|0],y[e+2|0],x[A>>2]);h=k+sq(e)|0;i=4;l=m+4|0;t:{while(1){if(!(i>>>0>2303|k)){if((n|0)<=((i<<1)+m|0)){break t}k=0;j=e+i|0;u:{if(!tq(e,j)){break u}f=i-sq(e)|0;o=sq(j)+f|0;if((g|0)<(o+(i+l|0)|0)){break u}if(!tq(e,j+o|0)){break u}x[A>>2]=f;k=f;h=i}i=i+1|0;continue}break}if(!k|(g|0)<(h+m|0)){break t}l=g-m|0;i=0;f=0;while(1){v:{w:{if((f|0)!=10){j=(f|0)!=0;K=i;i=e+i|0;i=(K+kz(y[i+1|0],y[i+2|0],k)|0)+sq(i)|0;if((l|0)<(i+4|0)){break v}if(tq(e,e+i|0)){break w}j=0}else{j=1}break v}f=f+1|0;continue}break}if(!j){break t}d=h;break s}if((g|0)!=(h|0)|m){break r}m=0;d=g}x[q>>2]=d;d=m;break p}x[A>>2]=0}e=e+1|0;m=m+1|0;continue}break}h=x[r+17148>>2];if((g|0)>=(d+h|0)?h:0){break m}x[L>>2]=d;o=0;break l}C=c+d|0;x[G+6152>>2]=y[C|0]|y[C+1|0]<<8|(y[C+2|0]<<16|y[C+3|0]<<24);x[L+4>>2]=d;x[L>>2]=d+h;x[L+8>>2]=y[C+3|0]>191?1:2;sa=L,ta=jM(y[C+1|0],y[C+2|0]),x[sa+12>>2]=ta;x[L+16>>2]=4-(y[C+1|0]>>>1&3);sa=L,ta=jz(y[C+1|0],y[C+2|0]),x[sa+20>>2]=ta;if(!Z){o=iz(y[C+1|0]);break l}d=r+17136|0;iM(d,C+4|0,h-4|0);if(!(v[C+1|0]&1)){ue(d,16)}x:{if(x[L+16>>2]==3){o=0;d=r+17136|0;ja=r+3728|0;e=ja;m=0;h=y[C+1|0];f=D((h>>>3&1)+(h>>>4&1)|0,3)+(y[C+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;i=y[C+3|0]>191?1:2;y:{if(h&8){j=ue(d,9);i=i<<1;m=ue(d,i+7|0);break y}j=ue(d,i|8)>>>i|0}h=D(f,40);A=h+81440|0;n=h+81760|0;q=D(f,23)+81248|0;h=-1;f=0;z:{while(1){g=y[C+3|0];I=ue(d,12);w[e+4>>1]=I;k=ue(d,9);w[e+6>>1]=k;if((k&65535)>>>0>288){break z}k=g>>>0>191?m<<4:m;sa=e,ta=ue(d,8),v[sa+10|0]=ta;g=ue(d,y[C+1|0]&8?4:9);v[e+13|0]=22;v[e+14|0]=0;x[e>>2]=q;w[e+8>>1]=g;A:{if(ue(d,1)){g=ue(d,2);v[e+11|0]=g;if(!(g&255)){break z}g=ue(d,1);w[e+18>>1]=65287;v[e+12|0]=g;if(y[e+11|0]==2){B:{if(!(g&255)){x[e>>2]=A;v[e+18|0]=8;m=0;g=39;break B}x[e>>2]=n;m=y[C+1|0]&8?8:6;g=30}v[e+14|0]=g;v[e+13|0]=m;k=k&3855}g=ue(d,10);sa=e,ta=ue(d,3),v[sa+21|0]=ta;sa=e,ta=ue(d,3),v[sa+22|0]=ta;sa=e,ta=ue(d,3),v[sa+23|0]=ta;m=g<<5;break A}v[e+11|0]=0;v[e+12|0]=0;m=ue(d,15);sa=e,ta=ue(d,4),v[sa+18|0]=ta;g=ue(d,3);v[e+20|0]=255;v[e+19|0]=g}v[e+17|0]=m&31;v[e+15|0]=m>>>10;v[e+16|0]=m>>>5&31;f=(I&65535)+f|0;C:{if(y[C+1|0]&8){g=ue(d,1);break C}g=z[e+8>>1]>499}v[e+24|0]=g;sa=e,ta=ue(d,1),v[sa+25|0]=ta;g=ue(d,1);v[e+27|0]=k>>>12&15;v[e+26|0]=g;e=e+28|0;m=k<<4;i=i-1|0;if(i){continue}break}h=(x[d+4>>2]+f|0)>(x[d+8>>2]+(j<<3)|0)?-1:j}if(!((h|0)<0|x[r+17140>>2]>x[r+17144>>2])){g=x[d+4>>2];m=x[d+8>>2];i=r+900|0;e=x[G+6144>>2];f=e-h|0;e=(e|0)<(h|0)?e:h;f=yc(i+12|0,(((f|0)>0?f:0)+G|0)+6156|0,e);k=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(m-g|0)/8|0;yc(e+f|0,k,d);iM(i,f,d+e|0);D:{h=x[G+6144>>2]>=(h|0);if(!h){break D}na=G+2304|0;oa=r+8608|0;pa=r+3840|0;while(1){if((y[C+1|0]&8?2:1)>>>0<=o>>>0){break D}qa=Sb(pa,0,4608);e=x[L+8>>2];m=D(D(e,o),28)+ja|0;d=0;ka=(e|0)>0?e:0;A=r+900|0;I=A+7548|0;_=G+6152|0;while(1){if((d|0)!=(ka|0)){g=D(d,28)+m|0;K=z[g+4>>1];V=x[A+4>>2];t=(A+D(d,39)|0)+16156|0;e=I;n=d;f=fb-48|0;fb=f;d=g;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+82080|0;E:{if(y[_+1|0]&8){j=y[d+27|0];g=y[z[d+8>>1]+82176|0];i=g&3;v[f+47|0]=i;v[f+46|0]=i;g=g>>>2|0;v[f+45|0]=g;v[f+44|0]=g;break E}g=(y[_+3|0]&16)>>>4&(n|0)!=0;l=g?12:0;q=z[d+8>>1]>>>g|0;while(1){if((q|0)>=0){j=3;i=1;while(1){if((j|0)>=0){g=y[(j+l|0)+82192|0];v[(f+44|0)+j|0]=((q|0)/(i|0)|0)%(g|0);j=j-1|0;i=D(g,i);continue}break}l=l+4|0;q=q-i|0;continue}break}H=l+H|0;j=-16}i=f;ea=f+44|0;q=0;while(1){F:{G:{H:{if((q|0)==4){break H}g=y[q+H|0];if(!g){break H}if(j&8){yc(i,t,g);break G}l=y[q+ea|0];if(!l){Sb(i,0,g);Sb(t,0,g);break G}fa=(j|0)>=0?-1:-1<<l^-1;k=0;while(1){if((g|0)==(k|0)){break G}S=ue(A,l);v[k+t|0]=(S|0)==(fa|0)?-1:S;v[i+k|0]=S;k=k+1|0;continue}}v[i+2|0]=0;v[i|0]=0;v[i+1|0]=0;break F}j=j<<1;q=q+1|0;i=g+i|0;t=g+t|0;continue}break}I:{i=y[d+14|0];if(i){g=2-J|0;k=y[d+23|0]<<g;q=y[d+22|0]<<g;l=y[d+21|0]<<g;t=y[d+13|0];j=0;while(1){if(j>>>0>=i>>>0){break I}g=f+(j+t|0)|0;v[g|0]=l+y[g|0];v[g+1|0]=q+y[g+1|0];v[g+2|0]=k+y[g+2|0];j=j+3|0;continue}}if(!y[d+24|0]){break I}j=0;while(1){if((j|0)==10){break I}g=f+j|0;v[g+11|0]=y[g+11|0]+y[j+82216|0];j=j+1|0;continue}}g=J+1|0;j=0;u=hz(E(2048),((((y[_+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(i&255)>>>0>j>>>0){sa=e+(j<<2)|0,ua=hz(u,y[f+j|0]<<g),B[sa>>2]=ua;j=j+1|0;i=y[d+14|0];continue}break}fb=f+48|0;k=(A+D(n,2304)|0)+2940|0;j=e;ea=K+V|0;u=E(0);g=x[A+4>>2];e=x[A>>2]+((g|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(g&7);l=g|-8;t=e+4|0;q=d;H=x[d>>2];J=z[d+6>>1];d=0;while(1){J:{K:{if((J|0)>0){g=d+1|0;e=d+q|0;d=y[e+15|0];fa=(w[(d<<1)+86640>>1]<<1)+82256|0;S=y[e+18|0];if(d>>>0>=16){ga=y[d+86704|0];ra=32-ga|0;while(1){ha=y[H|0]>>>1|0;ia=(J|0)<(ha|0)?J:ha;u=B[j>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[fa+(e<<1)>>1];if((e|0)<0){f=f<<d;i=e&7;e=(f>>>32-i|0)-(e>>3)|0;l=d+l|0;d=i;continue}break}d=e>>>8|0;l=d+l|0;f=f<<d;i=0;while(1){if((i|0)!=2){K=e&15;L:{if((K|0)==15){l=l+ga|0;d=f<<ga;while(1){if((l|0)>=0){d=y[t|0]<<l|d;t=t+1|0;l=l-8|0;continue}break}K=(f>>>ra|0)+15|0;f=K;M:{if((f|0)<=128){M=B[(f<<2)+86800>>2];break M}la=f>>>0<1024;f=la?f<<3:f;V=f<<1&64;O=E(E((f&63)-V|0)/E(V+(f&2147483584)|0));M=E((la?E(16):E(256))*E(E(E(O*E(E(O*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+V>>>4&268435452)+86800>>2]))}M=E(E(u*M)*E(d>>31|1));break L}d=f;M=E(u*B[(((d>>>27&16|K)^16)<<2)+86736>>2])}B[k>>2]=M;e=e>>>4|0;k=k+4|0;i=i+1|0;f=(K|0)!=0;l=f+l|0;f=d<<f;continue}break}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}ia=ia-1|0;if(ia){continue}break}j=j+4|0;H=H+1|0;J=J-ha|0;if((J|0)<=0){break K}d=(S|0)>0;S=S-1|0;if(d){continue}break}break K}while(1){V=y[H|0]>>>1|0;K=(J|0)<(V|0)?J:V;u=B[j>>2];while(1){d=f>>>27|0;e=5;while(1){d=w[fa+(d<<1)>>1];if((d|0)<0){f=f<<e;i=d&7;d=(f>>>32-i|0)-(d>>3)|0;l=e+l|0;e=i;continue}break}e=d>>>8|0;l=e+l|0;f=f<<e;e=0;while(1){if((e|0)!=2){i=d&15;B[k>>2]=u*B[(((i|f>>>27&16)^16)<<2)+86736>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;i=(i|0)!=0;l=i+l|0;f=f<<i;continue}break}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}K=K-1|0;if(K){continue}break}j=j+4|0;H=H+1|0;J=J-V|0;if((J|0)<=0){break K}d=(S|0)>0;S=S-1|0;if(d){continue}break}break K}e=1-J|0;while(1){N:{g=y[q+26|0]?86624:86592;d=y[g+(f>>>28|0)|0];if(!(d&8)){d=y[g+((f<<4>>>32-(d&3))+(d>>>3)|0)|0]}g=d&7;l=g+l|0;if(((l+(t-x[A>>2]<<3)|0)-24|0)>(ea|0)){break N}e=e-1|0;if(!e){e=y[H|0];if(e>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;e=e>>>1|0}f=f<<g;if(d>>>0>=128){B[k>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}if(d&64){B[k+4>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}e=e-1|0;if(!e){e=y[H|0];if(e>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;e=e>>>1|0}if(d&32){B[k+8>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}if(d&16){B[k+12>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}x[A+4>>2]=ea;break J}d=g;continue}break}d=n+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){j=A+16195|0;d=0;g=fb-16|0;fb=g;i=A+2940|0;k=i+2304|0;I=x[m>>2];l=y[m+14|0];t=y[m+13|0];n=l+t|0;e=g+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(n|0)){H=d+I|0;q=y[H|0];f=0;P:{while(1){if(f>>>0>=q>>>0){break P}J=f<<2;if(B[J+k>>2]==E(0)){f=f+2|0;if(B[(J|4)+k>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;q=y[H|0]}d=d+1|0;k=(q<<2)+k|0;continue}break}if(t){d=x[g+4>>2];e=x[g+8>>2];d=(d|0)>(e|0)?d:e;e=x[g+12>>2];d=(d|0)>(e|0)?d:e;x[g+12>>2]=d;x[g+8>>2]=d;x[g+4>>2]=d}e=l?3:1;k=n-e|0;d=0;while(1){if((d|0)!=(e|0)){n=d+k|0;f=n-e|0;if((f|0)<=x[(g+4|0)+(d<<2)>>2]){f=y[_+1|0]<<28>>31&3}else{f=y[f+j|0]}v[j+n|0]=f;d=d+1|0;continue}break}n=x[m>>2];q=g+4|0;I=w[m+36>>1]&1;k=0;l=y[_+1|0]&8?7:64;while(1){t=k+n|0;e=y[t|0];if(e){f=y[_+3|0]&32;Q:{R:{if(x[q+((k>>>0)%3<<2)>>2]>=(k|0)){break R}d=y[j+k|0];if(d>>>0>=l>>>0){break R}M=f?E(1.4142135381698608):E(1);S:{if(y[_+1|0]&8){d=d<<3;u=B[d+87332>>2];O=B[d+87328>>2];break S}O=hz(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):O;O=d?O:E(1)}O=E(M*O);M=E(M*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+i|0;u=B[f>>2];B[f+2304>>2]=u*M;B[f>>2]=u*O;d=d+1|0;continue}break}break Q}if(!f){break Q}fM(i,e)}k=k+1|0;i=(y[t|0]<<2)+i|0;continue}break}fb=g+16|0;break O}if((d&224)!=96){break O}fM(A+2940|0,576)}i=A+7708|0;d=0;while(1){if((d|0)!=(ka|0)){e=y[G+6153|0];e=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);f=A+D(d,2304)|0;k=f+2940|0;j=k;if(y[m+14|0]){q=x[m>>2]+y[m+13|0]|0;t=(f+D(e,72)|0)+2940|0;g=t;f=i;while(1){n=y[q|0];if(n){l=n<<1;I=0;while(1){if((n|0)!=(I|0)){B[f>>2]=B[g>>2];B[f+4>>2]=B[(n<<2)+g>>2];B[f+8>>2]=B[(l<<2)+g>>2];g=g+4|0;I=I+1|0;f=f+12|0;continue}break}q=q+3|0;g=(l<<2)+g|0;continue}break}yc(t,i,f-i|0);f=e-1|0}else{f=31}while(1){g=0;if((f|0)>0){while(1){if((g|0)!=8){n=g<<2;q=n+j|0;u=B[q+72>>2];O=B[n+87392>>2];M=B[n+87424>>2];n=(17-g<<2)+j|0;ma=B[n>>2];B[q+72>>2]=E(u*O)-E(M*ma);B[n>>2]=E(u*M)+E(ma*O);g=g+1|0;continue}break}j=j+72|0;f=f-1|0;continue}break}g=k;f=D(d,1152)+G|0;j=y[m+11|0];if(e){dM(g,f,87456,e);g=D(e,72)+g|0;f=D(e,36)+f|0}T:{if((j|0)==2){j=32-e|0;e=fb-80|0;fb=e;q=e|8;I=e|4;while(1){if((j|0)>0){n=yc(e,g,72);l=x[f+20>>2];x[g+16>>2]=x[f+16>>2];x[g+20>>2]=l;l=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=l;l=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=l;K=n;n=f+24|0;gz(K,g+24|0,n);gz(I,g+48|0,n);gz(q,f,n);g=g+72|0;f=f+36|0;j=j-1|0;continue}break}fb=e+80|0;break T}dM(g,f,D((j|0)==3,72)+87456|0,32-e|0)}e=0;k=k+72|0;while(1){g=1;if(e>>>0<=31){while(1){if(g>>>0<=17){f=(g<<2)+k|0;B[f>>2]=-B[f>>2];g=g+2|0;continue}break}k=k+144|0;e=e+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}hM(na,qa,18,x[L+8>>2],Z,oa);o=o+1|0;Z=D(x[L+8>>2],1152)+Z|0;continue}}e=r+900|0;g=x[e+8>>2]>>>3|0;m=x[e+4>>2]+7>>>3|0;d=g-m|0;f=(d|0)>=511?511:d;if((d|0)>0){ml(G+6156|0,(e+(d>>>0>511?g-511|0:m)|0)+12|0,f)}x[G+6144>>2]=f;break x}JB(G);break l}f=r+17136|0;o=0;m=0;k=0;g=r;d=0;U:{V:{W:{h=y[C+3|0];i=h>>>6|0;switch(i-1|0){case 2:break U;case 0:break W;default:break V}}d=(h>>>2&12)+4|0;break U}d=32}h=y[C+1|0];X:{if((h&6)==6){h=32;e=88860;break X}if(!(h&8)){h=30;e=88863;break X}j=y[C+2|0];e=j>>>2&3;h=jz(h,j)>>>((i|0)!=3)|0;h=h?h:192;if(h>>>0<=55){h=(e|0)==2?12:8;e=88884;break X}h=h>>>0<=95?27:(e|0)!=1?30:27;e=88872}v[g+768|0]=h;v[g+769|0]=(d|0)<(h|0)?d:h;h=e;i=88768;while(1){d=y[g+768|0];if(o>>>0>=d>>>0){o=0;while(1){e=d<<1&510;if(e>>>0>o>>>0){e=g+o|0;Y:{if(!y[e+770|0]){h=6;break Y}h=2;if((y[C+1|0]&6)==6){break Y}h=ue(f,2);d=y[g+768|0]}v[e+834|0]=h;o=o+1|0;continue}break}m=g+770|0;i=g+834|0;h=0;j=e;while(1){if((h|0)!=(j|0)){k=y[m|0];e=k?19>>>y[h+i|0]&3|4:0;m=m+1|0;k=D(k,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&e){A=ue(f,6);n=(A|0)/3|0;u=E(B[(k+(D(n,-3)+A|0)<<2)+88896>>2]*E(2097152>>>n|0))}B[g>>2]=u;d=d>>>1|0;g=g+4|0;continue}break}h=h+1|0;continue}break}o=y[r+769|0];d=y[r+768|0];d=d>>>0<o>>>0?o:d;while(1){if((d|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((k|0)==(o|0)){i=y[h|0]+88768|0;k=y[h+2|0]+o|0;m=y[h+1|0];h=h+3|0}e=o<<1;d=y[ue(f,m)+i|0];v[(e+g|0)+770|0]=d;j=y[g+769|0];if(o>>>0<j>>>0){d=y[ue(f,m)+i|0];j=y[g+769|0]}v[((e|1)+g|0)+770|0]=j?d:0;o=o+1|0;continue}break}h=0;g=Sb(r+3840|0,0,4608);I=G+2304|0;l=r+8608|0;o=0;Z:{while(1){if((o|0)==3){break Z}C=g+(h<<2)|0;n=r+17136|0;e=0;A=x[L+16>>2]|1;q=(A|0)>0?A:0;f=576;while(1){if((e|0)!=4){m=C+(D(e,A)<<2)|0;i=0;while(1){if(y[r+768|0]<<1>>>0>i>>>0){_:{j=y[(i+r|0)+770|0];if(!j){break _}if(j>>>0<=16){k=(-1<<j-1)+1|0;d=0;while(1){if((d|0)==(q|0)){break _}sa=(d<<2)+m|0,ua=E(ue(n,j)+k|0),B[sa>>2]=ua;d=d+1|0;continue}}d=2<<j-17;k=ue(n,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;j=d|1;d=0;while(1){if((d|0)==(q|0)){break _}K=k;k=(k>>>0)/(j>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(j,k)|0)|0;d=d+1|0;continue}}i=i+1|0;m=(f<<2)+m|0;f=18-f|0;continue}break}e=e+1|0;continue}break}h=(A<<2)+h|0;if((h|0)==12){d=(o<<2)+r|0;h=g;e=y[r+769|0];f=g+D(e,72)|0;yc(f+2304|0,f,D(y[r+768|0]-e|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){e=0;while(1){if((e|0)!=12){f=(e<<2)+h|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];e=e+1|0;continue}break}d=d+24|0;h=h+72|0;m=m+1|0;continue}break}hM(I,g,12,x[L+8>>2],Z,l);Sb(g,0,4608);Z=D(x[L+8>>2],768)+Z|0;h=0}o=o+1|0;if(x[r+17140>>2]<=x[r+17144>>2]){continue}break}JB(G);o=0;break l}h=1}o=D(iz(y[G+6153|0]),h)}fb=r+17152|0;d=x[s+32>>2];if((d|0)<0|!d){break h}h=x[s+44>>2];if((h|0)!=(aa|0)?aa:0){break h}d=x[s+40>>2];if((d|0)!=(F|0)?F:0){break h}if(d-3>>>0<4294967294|(h|0)<=0){break i}x[s+16>>2]=0;sa=s,ta=Gc(W,da),x[sa+12>>2]=ta;e=s+16|0;f=s+12|0;F=x[fk(L,e,f)>>2];x[s+16>>2]=0;sa=s,ta=Gc(W,da),x[sa+12>>2]=ta;e=x[fk(L,e,f)>>2];g=e>>31;$:{if(!o){break $}f=x[ca>>2];x[31725]=0;U(595,P|0,f|0,f+(D(d,o)<<1)|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break $}c=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(c|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;F=d;aa=h;if((c|0)!=1){break h}c=N()|0}md(ca);break k}if((Zc(x[P>>2],x[P+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+F|0;aa=h;F=d;h=da-(g+(e>>>0>W>>>0)|0)|0;da=h;W=W-e|0;if(!!W&(h|0)>=0|(h|0)>0){continue}break}break h}c=N()|0}$T(ba);break j}c=N()|0}md(P);Kc(s+76|0);Q(c|0);p()}F=d;aa=h}h=0;aa:{if(!aa|!F){break aa}c=x[P>>2];d=x[P+4>>2];if(lc(c,d)){break aa}if((Zc(c,d)>>>0)/(F>>>0)>>>0>268435456){break aa}Uu(a,b);b=D(b,104)+a|0;a=b+484380|0;sa=a,ta=(Zc(x[P>>2],x[P+4>>2])>>>0)/(F>>>0)|0,x[sa>>2]=ta;d=b+484414|0;c=z[d>>1];w[d>>1]=(F|0)==2?c|65:c&65470|1;Fh(a);c=b+484400|0;h=je(x[a>>2],x[c>>2]);if(!h){break aa}d=wb(x[P>>2]);h=wb(x[P+4>>2]);b=fb-16|0;fb=b;jV(b+8|0,d,h,x[c>>2]);fb=b+16|0;h=je(x[a>>2],x[a+20>>2])}md(ca);$T(ba);md(P);Kc(s+76|0)}fb=s+96|0;return h|0}function ZC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=E(0),K=E(0),L=0,M=0,N=0,O=E(0);C=fb-1520|0;fb=C;e=C+8|0;M=Sb(e,0,1512),N=-1,x[M+1420>>2]=N;v[C+56|0]=1;x[C+48>>2]=a+b;x[C+40>>2]=a;b=0;q=fb-1024|0;fb=q;v[e+1377|0]=1;a:{if(!Ot(e)){break a}f=y[e+1375|0];if(!(f&2)){fc(e,34);break a}if(f&4){fc(e,34);break a}if(f&1){fc(e,34);break a}if(x[e+1116>>2]!=1){fc(e,34);break a}f=y[e+1120|0];if((f|0)!=30){b:{if((f|0)!=64){break b}if(!cz(e,q+1018|0,6)|y[q+1018|0]!=102|(y[q+1019|0]!=105|y[q+1020|0]!=115)){break b}if(y[q+1021|0]!=104|y[q+1022|0]!=101|y[q+1023|0]!=97){break b}if((hf(e)|0)!=100){break b}if(hf(e)){break b}fc(e,38);break a}fc(e,34);break a}if((hf(e)|0)!=1){fc(e,34);break a}if(!cz(e,q+1018|0,6)){fc(e,10);break a}if(!az(q+1018|0)){fc(e,34);break a}if(Aj(e)){fc(e,34);break a}f=hf(e);x[e+4>>2]=f;if(!f){fc(e,34);break a}if(f>>>0>=17){fc(e,5);break a}f=Aj(e);x[e>>2]=f;if(!f){fc(e,34);break a}Aj(e);Aj(e);Aj(e);g=hf(e);f=g>>>4|0;x[e+116>>2]=1<<f;h=g&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){fc(e,20);break a}if(g+32<<24>>24>=0){fc(e,20);break a}c:{if(f>>>0<h>>>0){fc(e,20);break c}if(!(hf(e)&1)){fc(e,34);break c}if(!Ot(e)){break a}if(!bz(e)){break a}if(!dz(e)){break a}d:{e:{if((Oh(e)|0)==3){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Oh(e),v[M|0]=N;b=b+1|0;continue}break}if(!az(q+1018|0)){fc(e,20);break c}g=$y(e);b=te(e,g+1|0);x[e+20>>2]=b;if(!b){break e}b=0;h=(g|0)>0?g:0;while(1){if((b|0)!=(h|0)){f=Oh(e);v[x[e+20>>2]+b|0]=f;b=b+1|0;continue}break}v[g+x[e+20>>2]|0]=0;b=$y(e);x[e+28>>2]=0;x[e+24>>2]=b;if((b|0)<=0){break d}b=te(e,b<<2);x[e+28>>2]=b;if(b){break d}fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}while(1){f:{g:{if(x[e+24>>2]>(m|0)){j=$y(e);b=te(e,j+1|0);g=m<<2;x[g+x[e+28>>2]>>2]=b;if(!x[g+x[e+28>>2]>>2]){break g}b=0;h=(j|0)>0?j:0;while(1){if((b|0)==(h|0)){break f}f=Oh(e);v[x[g+x[e+28>>2]>>2]+b|0]=f;b=b+1|0;continue}}if(!(Oh(e)&1)){fc(e,20);break c}VL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=dz(e);VL(e,b);v[e+1376|0]=0;if(b){continue}break}b=0;if(!bz(e)){break a}if(!aM(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}h=0;while(1){if((h|0)!=256){i=h<<24;f=0;while(1){if((f|0)!=8){i=i>>31&79764919^i<<1;f=f+1|0;continue}break}x[(h<<2)+495792>>2]=i;h=h+1|0;continue}break}if((Oh(e)|0)==5){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Oh(e),v[M|0]=N;b=b+1|0;continue}break}if(!az(q+1018|0)){fc(e,20);break c}b=rc(e,8)+1|0;x[e+120>>2]=b;b=te(e,D(b,2096));x[e+124>>2]=b;if(!b){fc(e,3);break c}Sb(b,0,D(x[e+120>>2],2096));h:{i:{while(1){j:{k:{if(x[e+120>>2]>(k|0)){b=x[e+124>>2];if((rc(e,8)&255)!=66){fc(e,20);break c}if((rc(e,8)&255)!=67){fc(e,20);break c}if((rc(e,8)&255)!=86){fc(e,20);break c}g=D(k,2096)+b|0;M=g,N=rc(e,8)&255|rc(e,8)<<8,x[M>>2]=N;M=g,N=rc(e,8)&255|(rc(e,8)<<8&65280|rc(e,8)<<16),x[M+4>>2]=N;t=g+4|0;b=0;f=rc(e,1);if(!f){b=rc(e,1)}v[g+23|0]=b;h=x[t>>2];if(!(x[g>>2]|!h)){fc(e,20);break c}l:{if(b&255){i=to(e,h);break l}i=te(e,h);x[g+8>>2]=i}if(!i){fc(e,3);break c}r=0;if(f){break k}b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}m:{n:{if(y[g+23|0]){if(!rc(e,1)){break n}}f=rc(e,5)+1|0;v[b+i|0]=f;if((f&255)!=32){r=r+1|0;break m}fc(e,20);break c}v[b+i|0]=255}b=b+1|0;continue}}f=rc(e,6)+1&255;b=0;o:{while(1){if((b|0)==(f|0)){break o}b=b+1|0;if(!rc(e,16)){continue}break}fc(e,20);break c}b=rc(e,6)+1|0;x[e+128>>2]=b;b=te(e,D(b,1596));x[e+260>>2]=b;p:{q:{if(b){r=0;h=0;r:while(1){if(x[e+128>>2]<=(h|0)){break q}b=rc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(e,20);break c}if(!b){f=x[e+260>>2]+D(h,1596)|0;M=f,N=rc(e,8),v[M|0]=N;M=f,N=rc(e,16),w[M+2>>1]=N;M=f,N=rc(e,16),w[M+4>>1]=N;M=f,N=rc(e,6),v[M+6|0]=N;M=f,N=rc(e,8),v[M+7|0]=N;k=rc(e,4)+1|0;v[f+8|0]=k;b=0;while(1){if((k&255)>>>0>b>>>0){M=b+f|0,N=rc(e,8),v[M+9|0]=N;b=b+1|0;k=y[f+8|0];continue}break}fc(e,4);break c}n=x[e+260>>2]+D(h,1596)|0;f=rc(e,5);v[n|0]=f;i=0;k=-1;while(1)if((f&255)>>>0<=i>>>0){g=k+1|0;f=0;while(1){if((f|0)!=(g|0)){j=f+n|0;M=j,N=rc(e,3)+1|0,v[M+33|0]=N;b=rc(e,2);v[j+49|0]=b;if(b&255){b=rc(e,8);v[j+65|0]=b;if(x[e+120>>2]<=(b&255)){break p}}i=0;while(1){if(1<<y[j+49|0]>(i|0)){b=rc(e,8)-1|0;w[((n+(f<<4)|0)+(i<<1)|0)+82>>1]=b;i=i+1|0;if(x[e+120>>2]>b<<16>>16){continue}break p}break}f=f+1|0;continue}break}k=2;M=n,N=rc(e,2)+1|0,v[M+1588|0]=N;b=rc(e,4);x[n+1592>>2]=2;m=0;w[n+338>>1]=0;v[n+1589|0]=b;w[n+340>>1]=1<<b;G=n+338|0;l=0;while(1){if(y[n|0]>l>>>0){f=n+y[(l+n|0)+1|0]|0;i=0;while(1){if(y[f+33|0]>i>>>0){b=rc(e,y[n+1589|0]);w[(n+(x[n+1592>>2]<<1)|0)+338>>1]=b;k=x[n+1592>>2]+1|0;x[n+1592>>2]=k;i=i+1|0;continue}break}l=l+1|0;continue}break}while(1){if((k|0)>(m|0)){f=z[(n+(m<<1)|0)+338>>1];b=(q+16|0)+(m<<2)|0;w[b+2>>1]=m;w[b>>1]=f;m=m+1|0;k=x[n+1592>>2];continue}break}UL(q+16|0,k,1174);k=x[n+1592>>2];g=((k|0)<=1?1:k)-1|0;i=0;f=0;while(1){if((f|0)!=(g|0)){b=q+16|0;j=z[b+(f<<2)>>1];f=f+1|0;if((j|0)!=z[b+(f<<2)>>1]){continue}break p}break}while(1){if((i|0)<(k|0)){v[(i+n|0)+838|0]=y[((q+16|0)+(i<<2)|0)+2|0];i=i+1|0;k=x[n+1592>>2];continue}break}i=2;while(1){if((i|0)<(k|0)){x[q+12>>2]=0;x[q+8>>2]=0;f=0;b=(i|0)>0?i:0;o=G+(i<<1)|0;k=65536;j=-1;while(1){if((b|0)!=(f|0)){g=G+(f<<1)|0;l=z[g>>1];if(!((j|0)>=(l|0)|z[o>>1]<=l>>>0)){x[q+12>>2]=f;l=z[g>>1];j=l}if(!((k|0)<=(l|0)|z[o>>1]>=l>>>0)){x[q+8>>2]=f;k=z[g>>1]}f=f+1|0;continue}break}b=n+(i<<1)|0;v[b+1088|0]=x[q+12>>2];v[b+1089|0]=x[q+8>>2];i=i+1|0;k=x[n+1592>>2];continue}break}r=(k|0)>(r|0)?k:r;h=h+1|0;continue r}else{b=rc(e,4);v[(i+n|0)+1|0]=b;b=b&255;k=(b|0)>(k|0)?b:k;i=i+1|0;f=y[n|0];continue}}}fc(e,3);break c}b=rc(e,6)+1|0;x[e+264>>2]=b;b=te(e,D(b,24));x[e+396>>2]=b;if(!b){fc(e,3);break c}f=0;Sb(b,0,D(x[e+264>>2],24));s:{t:{while(1){if(x[e+264>>2]>(f|0)){h=x[e+396>>2];b=rc(e,16);w[((f<<1)+e|0)+268>>1]=b;k=20;if((b&65535)>>>0>2){break s}o=D(f,24)+h|0;M=o,N=rc(e,24),x[M>>2]=N;b=rc(e,24);x[o+4>>2]=b;if(b>>>0<A[o>>2]){break s}M=o,N=rc(e,24)+1|0,x[M+8>>2]=N;M=o,N=rc(e,6)+1|0,v[M+12|0]=N;b=rc(e,8);v[o+13|0]=b;if(x[e+120>>2]<=(b&255)){break s}b=0;while(1){h=y[o+12|0];if(h>>>0>b>>>0){j=(q+16|0)+b|0;l=rc(e,3);if(rc(e,1)){h=rc(e,5)}else{h=0}v[j|0]=l+(h<<3);b=b+1|0;continue}break}b=te(e,h<<4);x[o+20>>2]=b;if(!b){break t}h=0;while(1){if(y[o+12|0]>h>>>0){i=y[(q+16|0)+h|0];b=0;while(1){if((b|0)!=8){u:{if(i>>>b&1){l=rc(e,8);g=b<<1;j=h<<4;w[g+(j+x[o+20>>2]|0)>>1]=l;if(x[e+120>>2]<=w[g+(j+x[o+20>>2]|0)>>1]){break s}break u}w[(x[o+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;continue}break}h=h+1|0;continue}break}b=te(e,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);x[o+16>>2]=b;if(!b){break t}l=0;Sb(b,0,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);while(1){b=x[e+124>>2]+D(y[o+13|0],2096)|0;if(x[b+4>>2]>(l|0)){b=x[b>>2];h=te(e,b);g=l<<2;x[g+x[o+16>>2]>>2]=h;i=l;if(!x[g+x[o+16>>2]>>2]){break t}while(1){if((b|0)>0){b=b-1|0;v[b+x[g+x[o+16>>2]>>2]|0]=(i|0)%y[o+12|0];i=(i|0)/y[o+12|0]|0;continue}break}l=l+1|0;continue}break}f=f+1|0;continue}break}b=rc(e,6)+1|0;x[e+400>>2]=b;b=te(e,D(b,40));x[e+404>>2]=b;if(!b){fc(e,3);break c}Sb(b,0,D(x[e+400>>2],40));h=0;while(1){v:{if(x[e+400>>2]>(h|0)){b=x[e+404>>2];if(rc(e,16)){fc(e,20);break c}f=D(h,40)+b|0;b=te(e,D(x[e+4>>2],3));x[f+4>>2]=b;if(!b){fc(e,3);break c}if(rc(e,1)){b=rc(e,4)+1|0}else{b=1}v[f+8|0]=b;w:{if(rc(e,1)){g=rc(e,8)+1|0;w[f>>1]=g;b=0;k=x[e+4>>2];if((k|0)<(g&65535)){fc(e,20);break c}while(1){if(z[f>>1]<=b>>>0){break w}g=rc(e,Om(k-1|0));j=D(b,3);v[j+x[f+4>>2]|0]=g;g=rc(e,Om(x[e+4>>2]-1|0));v[(j+x[f+4>>2]|0)+1|0]=g;k=x[e+4>>2];g=j+x[f+4>>2]|0;j=y[g|0];if((k|0)<=(j|0)){fc(e,20);break c}g=y[g+1|0];if((g|0)>=(k|0)){fc(e,20);break c}b=b+1|0;if((g|0)!=(j|0)){continue}break}fc(e,20);break c}w[f>>1]=0}if(rc(e,2)){fc(e,20);break c}b=0;if(y[f+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break v}j=rc(e,4);g=D(b,3);v[(g+x[f+4>>2]|0)+2|0]=j;b=b+1|0;if(y[(g+x[f+4>>2]|0)+2|0]<y[f+8|0]){continue}break}fc(e,20);break c}while(1){if(x[e+4>>2]<=(b|0)){break v}v[(x[f+4>>2]+D(b,3)|0)+2|0]=0;b=b+1|0;continue}}M=e,N=rc(e,6)+1|0,x[M+408>>2]=N;f=e+412|0;i=0;x:{while(1){if(x[e+408>>2]<=(i|0)){break x}h=f+D(i,6)|0;M=h,N=rc(e,1),v[M|0]=N;M=h,N=rc(e,16),w[M+2>>1]=N;M=h,N=rc(e,16),w[M+4>>1]=N;b=rc(e,8);v[h+1|0]=b;if(z[h+2>>1]){fc(e,20);break c}if(z[h+4>>1]){fc(e,20);break c}i=i+1|0;if(x[e+400>>2]>(b&255)){continue}break}fc(e,20);break c}_L(e);x[e+992>>2]=0;g=r<<1;b=0;while(1){if(x[e+4>>2]>(b|0)){j=(b<<2)+e|0;M=j,N=te(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=j,N=te(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=te(e,g);x[j+996>>2]=h;f=x[j+800>>2];if(h?!f|!x[j+928>>2]:1){fc(e,3);break c}Sb(f,0,x[e+116>>2]<<2);b=b+1|0;continue}break}b=0;if(!TL(e,0,x[e+112>>2])){break a}if(!TL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];j=x[e+116>>2];x[e+108>>2]=j;f=x[e+264>>2];h=(f|0)>0?f:0;l=(j|0)/2|0;k=0;while(1){if((b|0)!=(h|0)){g=x[e+396>>2]+D(b,24)|0;f=x[g+4>>2];i=f>>>0<l>>>0?f:l;f=x[g>>2];f=(i-(f>>>0<l>>>0?f:l)>>>0)/A[g+8>>2]|0;k=(f|0)>(k|0)?f:k;b=b+1|0;continue}break}f=j<<1&2147483646;b=D(x[e+4>>2],(k<<2)+4|0);f=b>>>0<f>>>0?f:b;x[e+12>>2]=f;y:{z:{if(!x[e+80>>2]){break z}b=x[e+92>>2];if((b|0)!=x[e+84>>2]){break y}if(b>>>0>=(f+x[e+88>>2]|0)+1512>>>0){break z}fc(e,3);break c}A:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break A}x[e+52>>2]=0}b=1;break a}_(7344,13258,4196,8829);p()}b=0;B:{while(1){if(y[f+8|0]<=b>>>0){break B}rc(e,8);j=b+f|0;M=j,N=rc(e,8),v[M+9|0]=N;g=rc(e,8);v[j+24|0]=g;if(x[e+128>>2]<=y[j+9|0]){fc(e,20);break c}b=b+1|0;if(x[e+264>>2]>(g&255)){continue}break}fc(e,20);break c}h=h+1|0;continue}}k=3}fc(e,k);break c}fc(e,20);break c}m=rc(e,5);b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}h=rc(e,Om(f-b|0));m=m+1|0;if((m|0)>=32){fc(e,20);break c}f=b+h|0;if((f|0)>x[t>>2]){fc(e,20);break c}else{Sb(b+i|0,m,h);b=f;continue}}}C:{D:{E:{F:{G:{H:{if(y[g+23|0]){if(f>>2>(r|0)){break H}if(x[e+16>>2]<(f|0)){x[e+16>>2]=f;f=x[t>>2]}b=te(e,f);x[g+8>>2]=b;if(!b){fc(e,3);break c}yc(b,i,x[t>>2]);zj(e,i,x[t>>2]);i=x[g+8>>2];v[g+23|0]=0;f=x[t>>2]}m=0;h=(f|0)>0?f:0;b=0;while(1){if((b|0)==(h|0)){break G}m=((y[b+i|0]-11&255)>>>0<244)+m|0;b=b+1|0;continue}}x[g+2092>>2]=r;l=g+2092|0;if(r){break F}b=0;h=0;break E}x[g+2092>>2]=m;b=te(e,f<<2);x[g+32>>2]=b;if(b){l=g+2092|0;b=0;break D}fc(e,3);break c}b=te(e,r);x[g+8>>2]=b;if(!b){fc(e,3);break c}b=to(e,x[l>>2]<<2);x[g+32>>2]=b;if(!b){fc(e,3);break c}b=to(e,x[l>>2]<<2);if(!b){break C}f=x[t>>2];h=x[l>>2]}f=(h<<3)+f|0;if(f>>>0<=A[e+16>>2]){break D}x[e+16>>2]=f}s=x[t>>2];f=0;h=fb-128|0;fb=h;u=Sb(h,0,128);h=(s|0)>0?s:0;while(1){I:{J:{if((f|0)!=(h|0)){if(y[f+i|0]==255){break J}h=f}if((h|0)==(s|0)){f=1;if(!x[g+2092>>2]){break I}_(15771,13258,1103,7588);p()}j=h+i|0;f=y[j|0];if(f>>>0<32){QL(g,0,h,0,f,b);n=1;j=y[j|0]+1|0;f=1;K:{while(1){if((f|0)==(j|0)){L:while(1){M:{f=1;h=h+1|0;if((s|0)<=(h|0)){break I}G=h+i|0;j=y[G|0];if((j|0)==255){continue}f=j;if(f>>>0>=32){break M}while(1){if((f|0)<=0){f=0;break I}o=u+(f<<2)|0;r=x[o>>2];if(!r){f=f-1|0;continue}break}x[o>>2]=0;QL(g,Mm(r),h,n,j,b);n=n+1|0;m=y[G|0];if((m|0)==(f|0)){continue}while(1){if((f|0)>=(m|0)){continue L}j=u+(m<<2)|0;if(x[j>>2]){break K}x[j>>2]=r+(1<<32-m);m=m-1|0;continue}}break}}else{x[u+(f<<2)>>2]=1<<32-f;f=f+1|0;continue}break}_(15236,13258,1118,7588);p()}_(15815,13258,1133,7588);p()}_(15243,13258,1104,7588);p()}f=f+1|0;continue}break}fb=u+128|0;if(!f){if(y[g+23|0]){zj(e,b,0)}fc(e,20);break c}f=x[l>>2];if(f){f=te(e,(f<<2)+4|0);x[g+2084>>2]=f;if(!f){fc(e,3);break c}f=te(e,(x[l>>2]<<2)+4|0);x[g+2088>>2]=f;if(!f){fc(e,3);break c}x[g+2088>>2]=f+4;x[f>>2]=-1;f=0;m=0;N:{O:{P:{if(y[g+23|0]){while(1){m=x[g+2092>>2];if((m|0)<=(f|0)){break P}h=f<<2;M=h+x[g+2084>>2]|0,N=Mm(x[h+x[g+32>>2]>>2]),x[M>>2]=N;f=f+1|0;continue}}while(1){if(x[g+4>>2]>(f|0)){if(PL(y[g+23|0],y[f+i|0])){M=x[g+2084>>2]+(m<<2)|0,N=Mm(x[x[g+32>>2]+(f<<2)>>2]),x[M>>2]=N;m=m+1|0}f=f+1|0;continue}break}if(x[g+2092>>2]!=(m|0)){break O}}UL(x[g+2084>>2],m,1175);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;f=x[g+(y[g+23|0]?2092:4)>>2];r=(f|0)>0?f:0;Q:{while(1){if((h|0)!=(r|0)){f=h;j=y[g+23|0];f=j?x[(f<<2)+b>>2]:f;G=y[f+i|0];R:{if(!PL(j,G)){break R}o=h<<2;s=Mm(x[o+x[g+32>>2]>>2]);f=x[g+2092>>2];m=0;while(1){if((f|0)>=2){u=f>>>1|0;j=u+m|0;n=s>>>0<A[x[g+2084>>2]+(j<<2)>>2];f=n?u:f-u|0;m=n?m:j;continue}break}f=m<<2;if((s|0)!=x[f+x[g+2084>>2]>>2]){break Q}if(y[g+23|0]){x[f+x[g+2088>>2]>>2]=x[b+o>>2];v[x[g+8>>2]+m|0]=G;break R}x[f+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break N}_(12299,13258,1230,9982);p()}_(7529,13258,1200,9982);p()}}if(y[g+23|0]){zj(e,b,x[l>>2]<<2);zj(e,x[g+32>>2],x[l>>2]<<2);zj(e,i,x[t>>2]);x[g+32>>2]=0}b=0;h=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;f=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){S:{if(y[x[g+8>>2]+h|0]>10){break S}T:{if(y[g+23|0]){b=Mm(x[x[g+2084>>2]+(h<<2)>>2]);break T}b=x[x[g+32>>2]+(h<<2)>>2]}while(1){if(b>>>0>1023){break S}w[(g+(b<<1)|0)+36>>1]=h;b=(1<<y[x[g+8>>2]+h|0])+b|0;continue}}h=h+1|0;continue}break}b=rc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){fc(e,20);break c}if(b){M=g,O=RL(rc(e,32)),B[M+12>>2]=O;M=g,O=RL(rc(e,32)),B[M+16>>2]=O;M=g,N=rc(e,4)+1|0,v[M+20|0]=N;M=g,N=rc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[t>>2];U:{if(y[g+21|0]==1){H=J(wt(+E(E(rq(+E(h|0)))/E(f|0))));V:{if(F(H)<2147483648){b=~~H;break V}b=-2147483648}L=+(f|0);H=J(uk(+E(E(b|0)+E(1)),L));W:{if(F(H)<2147483648){f=~~H;break W}f=-2147483648}b=((f|0)<=(h|0))+b|0;I=E(b|0);if(uk(+E(I+E(1)),L)<=+(h|0)){b=-1}else{H=J(uk(+I,L));X:{if(F(H)<2147483648){f=~~H;break X}f=-2147483648}b=(f|0)>(h|0)?-1:b}if((b|0)>=0){break U}fc(e,20);break c}b=D(f,h)}x[g+24>>2]=b;if(!b){fc(e,20);break c}s=to(e,b<<1);if(!s){break i}b=0;while(1){i=x[g+24>>2];if((i|0)>(b|0)){f=rc(e,y[g+20|0]);if((f|0)==-1){zj(e,s,x[g+24>>2]<<1);fc(e,20);break c}else{w[s+(b<<1)>>1]=f;b=b+1|0;continue}}break}Y:{Z:{if(y[g+21|0]==1){n=y[g+23|0];_:{if(n){b=x[l>>2];if(b){break _}break Y}b=x[t>>2]}b=te(e,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){zj(e,s,x[g+24>>2]<<1);fc(e,3);break c}h=0;b=x[(n?l:t)>>2];r=(b|0)>0?b:0;G=g+2088|0;K=E(0);while(1){if((h|0)==(r|0)){break Z}f=h;f=n?x[x[G>>2]+(f<<2)>>2]:f;i=x[g>>2];b=0;l=1;while(1){if((b|0)<(i|0)){I=E(K+E(E(E(z[s+(((f>>>0)/(l>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(D(h,i)+b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;i=x[g>>2];if((b|0)>=(i|0)){continue}u=x[g+24>>2];nva(u,0,l,0);if(hb){zj(e,s,u<<1);fc(e,20);break c}else{l=D(l,u);continue}}break}h=h+1|0;continue}}b=te(e,i<<2);x[g+28>>2]=b;if(!b){break h}b=0;K=E(0);while(1){i=x[g+24>>2];if((i|0)<=(b|0)){break Y}I=E(K+E(E(E(z[s+(b<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}zj(e,s,i<<1)}k=k+1|0;continue}break}fc(e,3);break c}fc(e,3);break c}zj(e,s,x[g+24>>2]<<1);fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}v[j+x[g+x[e+28>>2]>>2]|0]=0;m=m+1|0;continue}}b=0}fb=q+1024|0;$:{aa:{if(!b){x[d>>2]=x[C+104>>2]?1:x[C+108>>2];fz(e);break aa}f=C+8|0;b=te(f,1512);if(b){M=c,N=x[yc(b,f,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break $}fz(C+8|0)}b=0}fb=C+1520|0;return b}function PK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;s=fb-48|0;fb=s;a:{if(c>>>0<=2){c=c<<2;I=x[c+95724>>2];J=x[c+95712>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=sd(b)}if(yl(c)){continue}break}w=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}w=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=sd(b)}e:{f:{while(1){if(v[g+4952|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=sd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){f=(g|0)==8;if(f){break f}if(!d|g>>>0<4){break e}if(f){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=fb-16|0;fb=l;k=(q(E(E(w|0)*E(Infinity))),j(2));b=k&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=k<<25;d=k>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);bg(l,c,0,0,0,b+81|0);i=x[l>>2];h=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[s>>2]=i;x[s+4>>2]=h;x[s+8>>2]=c;x[s+12>>2]=k&-2147483648|d;fb=l+16|0;i=x[s+8>>2];h=x[s+12>>2];k=x[s>>2];m=x[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9978|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=sd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=sd(b)}if((g&-33)==88){f=fb-432|0;fb=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=sd(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=sd(b)}K=1;continue}break}g=sd(b)}r=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=sd(b)}if((g|0)==48){continue}break}K=1}m=1073676288;u:{while(1){v:{c=g|32;w:{x:{z=g-48|0;if(z>>>0<10){break x}L=(g|0)!=46;if(L&c-97>>>0>5){break u}if(L){break x}if(r){break v}r=1;t=i;u=h;break w}c=(g|0)>57?c-87|0:z;y:{if((h|0)<=0&i>>>0<=7|(h|0)<0){n=c+(n<<4)|0;break y}if(!h&i>>>0<=28){mh(f+48|0,c);Vd(f+32|0,F,H,k,m,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];k=x[f+40>>2];m=x[f+44>>2];Vd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,k,m);Sg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,B,C);B=x[f+8>>2];C=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break y}if(!c|M){break y}Vd(f+80|0,F,H,k,m,0,0,0,1073610752);Sg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,B,C);B=x[f+72>>2];C=x[f+76>>2];M=1;l=x[f+64>>2];p=x[f+68>>2]}i=i+1|0;h=i?h:h+1|0;K=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=sd(b)}continue}break}g=46}z:{if(!K){c=x[b+116>>2];A:{B:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break B}x[b+4>>2]=c-2;if(!r){break A}x[b+4>>2]=c-3;break A}if(d){break A}}Ii(b,0,0)}mj(f+96|0,+(w|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break z}if((h|0)<=0&i>>>0<=7|(h|0)<0){k=i;m=h;while(1){n=n<<4;k=k+1|0;m=k?m:m+1|0;if((k|0)!=8|m){continue}break}}C:{D:{E:{if((g&-33)==80){k=OK(b,d);c=hb;m=c;if(k|(c|0)!=-2147483648){break C}if(d){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break E}break D}l=0;p=0;Ii(b,0,0);c=0;b=0;break z}k=0;m=0;if(x[b+116>>2]<0){break C}}x[b+4>>2]=x[b+4>>2]-1}k=0;m=0}if(!n){mj(f+112|0,+(w|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break z}b=r?t:i;h=(r?u:h)<<2|b>>>30;c=k+(b<<2)|0;b=h+m|0;i=c-32|0;h=(c>>>0<k>>>0?b+1|0:b)-(c>>>0<32)|0;b=h;if(i>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[31600]=68;mh(f+160|0,w);Vd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Vd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break z}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=i>>>0|(c|0)<(h|0)){if((n|0)>=0){while(1){Sg(f+416|0,l,p,B,C,0,0,0,-1073807360);b=bV(l,p,B,C,1073610752);c=(b|0)>=0;b=c;Sg(f+400|0,l,p,B,C,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:B,b?x[f+428>>2]:C);b=i;i=b-1|0;h=h-!b|0;B=x[f+408>>2];C=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];n=c|n<<1;if((n|0)>=0){continue}break}}b=h-((I>>31)+(i>>>0<I>>>0)|0)|0;c=(i-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;F:{if((c|0)>=113){mh(f+384|0,w);t=x[f+392>>2];u=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];k=0;b=0;break F}mj(f+352|0,rk(1,144-c|0));mh(f+336|0,w);F=x[f+336>>2];H=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];RK(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,t,u);o=x[f+376>>2];e=x[f+380>>2];k=x[f+372>>2];b=x[f+368>>2]}d=!(n&1)&((ln(l,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);_n(f+320|0,d+n|0);Vd(f+304|0,F,H,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Sg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,k,o,e);b=d;Vd(f+288|0,F,H,t,u,b?0:l,b?0:p,b?0:B,b?0:C);Sg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);qz(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,k,o,e);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];k=x[f+252>>2];if(!ln(b,d,c,k,0,0,0,0)){x[31600]=68}QK(f+224|0,b,d,c,k,i);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break z}x[31600]=68;mh(f+208|0,w);Vd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Vd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[s+16>>2]=l;x[s+20>>2]=p;x[s+24>>2]=b;x[s+28>>2]=c;fb=f+432|0;i=x[s+24>>2];h=x[s+28>>2];k=x[s+16>>2];m=x[s+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;n=c;f=d;d=0;e=fb-8976|0;fb=e;M=0-I|0;L=M-J|0;G:{H:{while(1){if((n|0)!=48){I:{if((n|0)!=46){break G}b=x[g+4>>2];if((b|0)==x[g+104>>2]){break I}x[g+4>>2]=b+1;n=y[b|0];break H}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0]}else{n=sd(g)}d=1;continue}break}n=sd(g)}K=1;if((n|0)!=48){break G}while(1){b=i;i=b-1|0;h=h-!b|0;b=x[g+4>>2];J:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0];break J}n=sd(g)}if((n|0)==48){continue}break}d=1}x[e+784>>2]=0;K:{L:{b=(n|0)==46;c=n-48|0;M:{N:{O:{if(b|c>>>0<=9){while(1){P:{if(b&1){if(!K){i=k;h=m;K=1;break P}b=!d;break O}k=k+1|0;m=k?m:m+1|0;if((r|0)<=2044){z=(n|0)==48?z:k;b=(e+784|0)+(r<<2)|0;if(o){c=(D(x[b>>2],10)+n|0)-48|0}x[b>>2]=c;d=1;c=o+1|0;b=(c|0)==9;o=b?0:c;r=b+r|0;break P}if((n|0)==48){break P}x[e+8960>>2]=x[e+8960>>2]|1;z=18396}b=x[g+4>>2];Q:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0];break Q}n=sd(g)}b=(n|0)==46;c=n-48|0;if(b|c>>>0<10){continue}break}}i=K?i:k;h=K?h:m;if(!(!d|(n&-33)!=69)){l=OK(g,f);b=hb;p=b;R:{if(l|(b|0)!=-2147483648){break R}if(!f){break M}l=0;p=0;if(x[g+116>>2]<0){break R}x[g+4>>2]=x[g+4>>2]-1}h=h+p|0;i=i+l|0;h=i>>>0<l>>>0?h+1|0:h;break L}b=!d;if((n|0)<0){break N}}if(x[g+116>>2]<0){break N}x[g+4>>2]=x[g+4>>2]-1}if(!b){break L}x[31600]=28}Ii(g,0,0);i=0;h=0;c=0;b=0;break K}b=x[e+784>>2];if(!b){mj(e,+(w|0)*0);i=x[e+8>>2];h=x[e+12>>2];c=x[e+4>>2];b=x[e>>2];break K}if(!((i|0)!=(k|0)|(h|0)!=(m|0)|(k>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){mh(e+48|0,w);_n(e+32|0,b);Vd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);i=x[e+24>>2];h=x[e+28>>2];c=x[e+20>>2];b=x[e+16>>2];break K}if(i>>>0>M>>>1>>>0&(h|0)>=0|(h|0)>0){x[31600]=68;mh(e+96|0,w);Vd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Vd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);i=x[e+72>>2];h=x[e+76>>2];c=x[e+68>>2];b=x[e+64>>2];break K}b=I-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){x[31600]=68;mh(e+144|0,w);Vd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Vd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);i=x[e+120>>2];h=x[e+124>>2];c=x[e+116>>2];b=x[e+112>>2];break K}if(o){if((o|0)<=8){b=(e+784|0)+(r<<2)|0;g=x[b>>2];while(1){g=D(g,10);o=o+1|0;if((o|0)!=9){continue}break}x[b>>2]=g}r=r+1|0}o=i;S:{if((i|0)<(z|0)|(z|0)>=9|(i|0)>17){break S}if((i|0)==9){mh(e+192|0,w);_n(e+176|0,x[e+784>>2]);Vd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);i=x[e+168>>2];h=x[e+172>>2];c=x[e+164>>2];b=x[e+160>>2];break K}if((o|0)<=8){mh(e+272|0,w);_n(e+256|0,x[e+784>>2]);Vd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);mh(e+224|0,x[(0-o<<2)+95712>>2]);sR(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);i=x[e+216>>2];h=x[e+220>>2];c=x[e+212>>2];b=x[e+208>>2];break K}b=(D(o,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break S}mh(e+352|0,w);_n(e+336|0,c);Vd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);mh(e+304|0,x[(o<<2)+95640>>2]);Vd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);i=x[e+296>>2];h=x[e+300>>2];c=x[e+292>>2];b=x[e+288>>2];break K}while(1){b=r;r=b-1|0;if(!x[(e+784|0)+(r<<2)>>2]){continue}break}z=0;d=(o|0)%9|0;T:{if(!d){c=0;break T}c=0;d=(o|0)<0?d+9|0:d;U:{if(!b){b=0;break U}i=x[(0-d<<2)+95712>>2];l=1e9/(i|0)|0;n=0;g=0;while(1){k=n;h=e+784|0;m=h+(g<<2)|0;n=x[m>>2];r=(n>>>0)/(i>>>0)|0;k=k+r|0;x[m>>2]=k;k=!k&(c|0)==(g|0);c=k?c+1&2047:c;o=k?o-9|0:o;n=D(l,n-D(i,r)|0);g=g+1|0;if((g|0)!=(b|0)){continue}break}if(!n){break U}x[h+(b<<2)>>2]=n;b=b+1|0}o=(o-d|0)+9|0}while(1){g=(e+784|0)+(c<<2)|0;V:{while(1){W:{if((o|0)<36){break W}if((o|0)!=36){break V}if(A[g>>2]<=10384592){break W}o=36;break V}r=b+2047|0;d=0;while(1){k=b;l=r&2047;n=(e+784|0)+(l<<2)|0;b=x[n>>2];m=b>>>3|0;i=d;d=b<<29;i=i+d|0;b=m;h=d>>>0>i>>>0?b+1|0:b;if(!h&i>>>0<1000000001){d=0}else{d=pva(i,h,1e9,0);b=nva(d,hb,-1e9,-1);i=b+i|0}x[n>>2]=i;b=(c|0)==(l|0)?k:i?k:l;i=k-1&2047;b=(i|0)!=(l|0)?k:b;r=l-1|0;if((c|0)!=(l|0)){continue}break}z=z-29|0;b=k;if(!d){continue}break}c=c-1&2047;if((c|0)==(b|0)){g=(b+2046&2047)<<2;b=e+784|0;k=g+b|0;x[k>>2]=x[k>>2]|x[b+(i<<2)>>2];b=i}o=o+9|0;x[(e+784|0)+(c<<2)>>2]=d;continue}break}X:{Y:while(1){i=b+1&2047;l=(e+784|0)+((b-1&2047)<<2)|0;while(1){k=(o|0)>45?9:1;Z:{while(1){d=c;g=0;_:{while(1){$:{c=d+g&2047;if((c|0)==(b|0)){break $}c=x[(e+784|0)+(c<<2)>>2];h=x[(g<<2)+95664>>2];if(c>>>0<h>>>0){break $}if(c>>>0>h>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if((o|0)!=36){break _}g=0;i=0;h=0;k=0;m=0;while(1){c=d+g&2047;if((c|0)==(b|0)){b=b+1&2047;x[((b<<2)+e|0)+780>>2]=0}_n(e+768|0,x[(e+784|0)+(c<<2)>>2]);Vd(e+752|0,i,h,k,m,0,0,1342177280,1075633366);Sg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);k=x[e+744>>2];m=x[e+748>>2];i=x[e+736>>2];h=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}mh(e+720|0,w);Vd(e+704|0,i,h,k,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);k=x[e+712>>2];m=x[e+716>>2];i=0;h=0;l=x[e+704>>2];p=x[e+708>>2];r=z+113|0;g=r-I|0;n=(g|0)<(J|0);c=n?(g|0)>0?g:0:J;if((c|0)<=112){break Z}break X}z=k+z|0;c=b;if((b|0)==(d|0)){continue}break}m=1e9>>>k|0;n=-1<<k^-1;g=0;c=d;while(1){h=g;r=e+784|0;g=r+(d<<2)|0;f=x[g>>2];h=h+(f>>>k|0)|0;x[g>>2]=h;h=!h&(c|0)==(d|0);c=h?c+1&2047:c;o=h?o-9|0:o;g=D(m,f&n);d=d+1&2047;if((d|0)!=(b|0)){continue}break}if(!g){continue}if((c|0)!=(i|0)){x[r+(b<<2)>>2]=g;b=i;continue Y}x[l>>2]=x[l>>2]|1;continue}break}break}mj(e+656|0,rk(1,225-c|0));RK(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,k,m);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];mj(e+640|0,rk(1,113-c|0));NQ(e+672|0,l,p,k,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);i=x[e+672>>2];h=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];qz(e+624|0,l,p,k,m,i,h,t,u);Sg(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);k=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}o=d+4&2047;aa:{if((o|0)==(b|0)){break aa}o=x[(e+784|0)+(o<<2)>>2];ba:{if(o>>>0<=499999999){if(!o&(d+5&2047)==(b|0)){break ba}mj(e+496|0,+(w|0)*.25);Sg(e+480|0,i,h,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];i=x[e+480>>2];h=x[e+484>>2];break ba}if((o|0)!=5e8){mj(e+592|0,+(w|0)*.75);Sg(e+576|0,i,h,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];i=x[e+576>>2];h=x[e+580>>2];break ba}N=+(w|0);if((d+5&2047)==(b|0)){mj(e+528|0,N*.5);Sg(e+512|0,i,h,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];i=x[e+512>>2];h=x[e+516>>2];break ba}mj(e+560|0,N*.75);Sg(e+544|0,i,h,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];i=x[e+544>>2];h=x[e+548>>2]}if((c|0)>111){break aa}NQ(e+464|0,i,h,t,u,0,0,0,1073676288);if(ln(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break aa}Sg(e+448|0,i,h,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];i=x[e+448>>2];h=x[e+452>>2]}Sg(e+432|0,l,p,k,m,i,h,t,u);qz(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);k=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ca:{if((L-2|0)>=(r&2147483647)){break ca}x[e+408>>2]=k;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Vd(e+384|0,l,p,k,m,0,0,0,1073610752);d=bV(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(d|0)>=0;k=b?x[e+392>>2]:k;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;z=b+z|0;if(!(n&((c|0)!=(g|0)|(d|0)<0)&(ln(i,h,t,u,0,0,0,0)|0)!=0)&(z+110|0)<=(L|0)){break ca}x[31600]=68}QK(e+368|0,l,p,k,m,z);i=x[e+376>>2];h=x[e+380>>2];c=x[e+372>>2];b=x[e+368>>2]}x[s+40>>2]=i;x[s+44>>2]=h;x[s+32>>2]=b;x[s+36>>2]=c;fb=e+8976|0;i=x[s+40>>2];h=x[s+44>>2];k=x[s+32>>2];m=x[s+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}da:{c=x[b+4>>2];ea:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ea}c=sd(b)}if((c|0)==40){g=1;break da}h=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];fa:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break fa}c=sd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g){continue}break}break a}x[31600]=28;Ii(b,0,0)}h=0}x[a>>2]=k;x[a+4>>2]=m;x[a+8>>2]=i;x[a+12>>2]=h;fb=s+48|0}function Qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=fb-416|0;fb=e;xc(b);f=e+411|0;d=zE(b,f);if(!d){iZ(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!d){break j}if(!jZ(f)){break j}if(!c){q=1;break j}H=Ge(e+388|0,b);x[31725]=0;d=e+376|0;O(509,d|0,H|0);b=x[31725];x[31725]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31725]=0;f=e+356|0;S(510,f|0,d|0,20041);b=x[31725];x[31725]=0;if((b|0)==1){break t}x[31725]=0;d=R(174,x[e+356>>2])|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!d){break k}x[31725]=0;d=P(511,f|0,e+265|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!d){break k}x[31725]=0;O(248,a|0,16384);b=x[31725];x[31725]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31725]=0;d=U(268,a+1074312|0,9,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;d=U(268,d|0,114,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;d=P(269,d|0,21)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;P(269,d|0,30)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;d=P(1,e+252|0,8280)|0;b=x[31725];x[31725]=0;if((b|0)==1){break q}Ab(a+1298344|0,d);tb(d);x[31725]=0;d=P(1,e+240|0,10751)|0;b=x[31725];x[31725]=0;if((b|0)==1){break p}Ab(a+1298356|0,d);tb(d);x[31725]=0;f=P(1,e+228|0,18124)|0;b=x[31725];x[31725]=0;if((b|0)==1){break o}d=15047;b=y[e+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}h=N()|0;break a}h=N()|0;break b}d=15028;break m}if(!b){break n}d=22267;break m}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}d=13322}x[31725]=0;d=P(1,e+216|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;i=e+192|0;S(2,i|0,f|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break f}Ab(a+1298368|0,i);tb(i);tb(d);tb(f);I=a+1298404|0,J=x[Fc(i,4)>>2],x[I>>2]=J;d=e+84|0;We(d,3,e+265|0);x[31725]=0;O(220,i|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}Ab(a+1298308|0,i);tb(i);vi(d,3,e+297|0);x[31725]=0;S(371,i|0,4,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}Ab(a+1298320|0,i);tb(i);x[a+480200>>2]=y[e+321|0]+1;I=a,J=Kd(y[e+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Kd(y[e+323|0],4,255),1e4),x[I+480204>>2]=J;d=y[a+484376|0];b=x[a+484360>>2];x[31725]=0;aa(350,Xb(b,d)|0,e+356|0,y[e+317|0]|y[e+318|0]<<8,65535,65535);b=x[31725];x[31725]=0;if((b|0)==1){break l}bf(Xb(x[a+484360>>2],y[a+484376|0]),y[e+319|0]|y[e+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[31725]=0;g=e+192|0;f=e+376|0;S(510,g|0,f|0,17741);b=x[31725];x[31725]=0;if((b|0)!=1){i=hd(e+356|0,g);ub(g);b=x[i>>2];x[31725]=0;d=R(156,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;V(338,a+1298332|0,i|0,d|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;S(510,g|0,f|0,21321);b=x[31725];x[31725]=0;if((b|0)!=1){k=hd(i,g);ub(g);b=x[k>>2];x[31725]=0;d=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}u:{v:{if(d){x[31725]=0;S(510,g|0,f|0,16723);b=x[31725];x[31725]=0;if((b|0)==1){break u}x[31725]=0;g=R(199,k|0)|0;b=x[31725];x[31725]=0;w:{if((b|0)!=1){i=c&2;f=0;while(1){if(g>>>0<=(f&255)>>>0){break w}x[31725]=0;j=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(!j){break w}d=x[k+8>>2];b=x[k>>2];x[31725]=0;d=U(152,b|0,d|0,56)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(!d){break w}if(j>>>0>z[a+480190>>1]){w[a+480190>>1]=j}x[31725]=0;q=D(j,104)+a|0;m=q+484380|0;O(281,m|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break v}mp(m);x[31725]=0;S(319,k|0,((j<<5)+a|0)+946304|0,32);b=x[31725];x[31725]=0;if((b|0)==1){break v}x[31725]=0;O(322,k|0,q+484423|0);b=x[31725];x[31725]=0;if((b|0)==1){break v}x:{if(y[e+415|0]<=15){x[31725]=0;h=R(191,k|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break x}break v}x[31725]=0;h=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}}x[q+484404>>2]=h<<1;x[31725]=0;d=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}x[m>>2]=d;x[31725]=0;d=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}C=q+484384|0;x[C>>2]=d;x[31725]=0;d=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}E=q+484388|0;x[E>>2]=d;if(d){b=q+484414|0;w[b>>1]=z[b>>1]|2;x[E>>2]=d+x[C>>2]}x[31725]=0;d=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(y[e+415|0]<=15){w[q+484410>>1]=d}x[31725]=0;j=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}b=q+484414|0;d=z[b>>1];o=8;if(j&1){d=d|1;w[b>>1]=d;x[m>>2]=x[m>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[E>>2]=x[E>>2]>>>1;o=16}w[b>>1]=d&65531|j<<1&4;b=Xc(e+84|0,o,1,0,((j&12)!=0)<<3);y:{if(!i){break y}x[31725]=0;U(217,b|0,m|0,e+192|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break y}break v}f=f+1|0;continue}}break v}ub(e+192|0)}x[31725]=0;d=e+192|0;f=e+376|0;S(510,d|0,f|0,18761);b=x[31725];x[31725]=0;z:{if((b|0)!=1){n=hd(k,d);ub(d);b=x[n>>2];x[31725]=0;d=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!d){break z}r=Nb(e+84|0);u=Nb(e+180|0);s=Nb(e+168|0);x[31725]=0;S(510,e+148|0,f|0,17750);b=x[31725];x[31725]=0;A:{if((b|0)==1){break A}b=x[e+160>>2];x[e+56>>2]=x[e+156>>2];x[e+60>>2]=b;x[e- -64>>2]=x[e+164>>2];x[31725]=0;b=x[e+152>>2];x[e+48>>2]=x[e+148>>2];x[e+52>>2]=b;O(512,e+48|0,r|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;S(510,e+128|0,f|0,17744);b=x[31725];x[31725]=0;if((b|0)==1){break A}b=x[e+140>>2];x[e+32>>2]=x[e+136>>2];x[e+36>>2]=b;x[e+40>>2]=x[e+144>>2];x[31725]=0;b=x[e+132>>2];x[e+24>>2]=x[e+128>>2];x[e+28>>2]=b;O(512,e+24|0,u|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;S(510,e+108|0,f|0,17734);b=x[31725];x[31725]=0;if((b|0)==1){break A}b=x[e+120>>2];x[e+8>>2]=x[e+116>>2];x[e+12>>2]=b;x[e+16>>2]=x[e+124>>2];x[31725]=0;b=x[e+112>>2];x[e>>2]=x[e+108>>2];x[e+4>>2]=b;O(512,e|0,s|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;q=R(199,n|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}o=0;while(1){if(q>>>0<=(o&255)>>>0){cp(s);cp(u);cp(r);break z}x[31725]=0;d=e+72|0;O(200,d|0,n|0);b=x[31725];x[31725]=0;B:{if((b|0)!=1){F=Jc(d);C:{D:{if(!y[e+72|0]){break D}f=x[n+8>>2];d=x[n>>2];b=y[F|0];x[31725]=0;d=U(152,d|0,f|0,D(b,14)+32|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}if(!d){break D}x[31725]=0;l=U(253,a|0,y[e+72|0],0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}if(l){break C}}b=y[F|0];x[31725]=0;P(185,n|0,D(b,14)+32|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break B}break A}x[31725]=0;S(319,n|0,l+492|0,32);b=x[31725];x[31725]=0;if((b|0)==1){break A}m=l+88|0;C=l+68|0;E=l+48|0;j=l+236|0;b=0;f=0;while(1){if(y[F|0]<=(f&255)>>>0){break B}x[31725]=0;O(513,n|0,e+192|0);d=x[31725];x[31725]=0;if((d|0)==1){break A}d=y[e+192|0];E:{if(!d|d>>>0>z[a+480190>>1]){break E}if(y[e+193|0]>=129){v[e+193|0]=128}while(1){i=b&255;g=y[e+193|0];if(i>>>0>g>>>0){d=x[r+4>>2];b=x[r>>2];x[31725]=0;V(514,E|0,y[e+195|0],b|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}d=x[u+4>>2];b=x[u>>2];x[31725]=0;V(514,C|0,y[e+197|0],b|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}d=x[s+4>>2];b=x[s>>2];x[31725]=0;V(514,m|0,y[e+205|0],b|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[l>>2]=(y[e+198|0]|y[e+199|0]<<8)+1>>>1;d=y[e+192|0];F:{if(y[e+195|0]&64){w[(D(d,104)+a|0)+484410>>1]=y[e+194|0];break F}b=(D(d,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[e+106>>1]=y[e+196|0]<<1;w[e+104>>1]=254;t=D(d,104)+a|0;I=t+484408|0,J=z[Nc(e+106|0,e+104|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[e+203|0]&3)+25028|0];d=t+484419|0;k=y[e+202|0];v[d|0]=k;i=y[e+201|0]+3>>>2|0;v[t+484420|0]=i;v[t+484421|0]=y[e+200|0];b=g+1|0;if(k){i=yi(Bc(((i<<8|k>>>1)>>>0)/(k>>>0)|0,0))}else{i=255}v[d|0]=i;if(!(y[e+197|0]&64)){break E}d=t+484414|0;w[d>>1]=z[d>>1]|32}else{d=y[e+192|0];I=_b(j,i),J=d,w[I>>1]=J;b=b+1|0;continue}break}}f=f+1|0;continue}}break A}o=o+1|0;continue}}h=N()|0;cp(s);cp(u);cp(r);break c}h=N()|0;break c}q=1;G=Nb(e+180|0);G:{if(!(c&1)){break G}x[31725]=0;d=e+192|0;S(510,d|0,e+376|0,21076);b=x[31725];x[31725]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){g=hd(n,d);b=x[g>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;N:{O:{P:{if((b|0)!=1){ub(d);if(!c){break N}x[31725]=0;d=R(191,g|0)|0;c=x[31725];x[31725]=0;b=1;if((c|0)==1){break P}x[31725]=0;f=d+1|0;O(515,G|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break P}while(1){if((b|0)==(f|0)){break N}x[31725]=0;d=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break O}x[31725]=0;i=e+84|0;S(187,i|0,g|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break O}c=ic(e+192|0,i);hd(dh(x[G>>2],b),c);ub(c);b=b+1|0;ub(i);continue}}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0;break H}x[31725]=0;d=e+192|0;S(510,d|0,e+376|0,16720);b=x[31725];x[31725]=0;if((b|0)==1){break J}B=hd(g,d);b=x[B>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break K}ub(d);if(!c){break M}x[31725]=0;F=R(199,B|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break I}l=0;Q:{R:{S:while(1){T:{if(F>>>0<=(l&65535)>>>0){x[31725]=0;P(151,B|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break T}break I}f=32;U:{if(y[e+415|0]<16){break U}x[31725]=0;O(516,B|0,e+192|0);b=x[31725];x[31725]=0;if((b|0)==1){break Q}f=y[e+192|0];if(f>>>0<=z[a+480188>>1]|f>>>0>32){break U}w[a+480188>>1]=f}b=0;while(1){i=b&65535;if(i>>>0>=f>>>0){l=l+1|0;continue S}x[31725]=0;d=R(191,B|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break R}if(!(!d|i>>>0>31|i>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31725]=0;r=a+484344|0;O(225,r|0,F|0);b=x[31725];x[31725]=0;if((b|0)==1){break I}C=e+194|0;n=0;while(1){if((n|0)==(F|0)){break M}u=Fb(e+84|0);V:{if(y[e+415|0]<16){c=32;i=64;break V}x[31725]=0;O(516,B|0,e+192|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}d=y[e+193|0];c=y[e+192|0];b=e+72|0;df(b,C,16,3);x[31725]=0;f=e+168|0;O(220,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}Ab(u,f);tb(f);i=d+1|0}x[31725]=0;d=U(198,r|0,n&65535,i|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}W:{if(!d){x[31725]=0;P(185,B|0,c<<1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break W}break L}b=x[r>>2];x[31725]=0;O(285,Wb(b,n)|0,u|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}E=i-1|0;k=0;while(1){s=k&65535;if(s>>>0>=c>>>0){break W}x[31725]=0;d=R(191,B|0)|0;b=x[31725];x[31725]=0;X:{if((b|0)!=1){if(!d){break X}b=x[G>>2];if(Uf(b,x[G+4>>2])>>>0<=d>>>0|s>>>0>=z[a+480188>>1]){break X}A=dh(b,d);xc(A);f=0;Y:while(1){d=f;if(i>>>0<=d>>>0){break X}g=x[A+8>>2];b=x[A>>2];x[31725]=0;g=U(152,b|0,g|0,1)|0;b=x[31725];x[31725]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!g){break X}b=Wb(x[r>>2],n);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],d,s);x[31725]=0;g=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}m=g<<24>>24;h=(m&252)>>>2|0;switch((m&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}f=(d+h|0)+1|0;continue}f=0;if(!d){continue}f=Wb(x[r>>2],n);j=jd(x[f>>2],x[x[f+48>>2]+12>>2],d-1|0,s);while(1){f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[j+4|0]|y[j+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;f=d+1|0;if((d|0)==(E|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;g=h&255;d=f;h=h-1|0;if(g){continue}break}continue}if(d>>>0<=h>>>0){break Z}f=Wb(x[r>>2],n);g=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,s);f=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[g+4|0]|y[g+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;break Z}if(h&1){x[31725]=0;g=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}v[b|0]=g>>>0>120?-1:g}if(h&2){x[31725]=0;g=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}v[b+1|0]=g}l=0;f=0;ca:{if(h&4){x[31725]=0;f=R(199,A|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ca}}t=0;if(h&8){x[31725]=0;j=R(199,A|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ca}l=j&15;t=j>>>4|0}o=0;j=0;if(h&16){x[31725]=0;j=R(199,A|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ca}}if((m|0)<0){x[31725]=0;o=R(199,A|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ca}}h=fb-16|0;fb=h;g=h+14|0;gZ(g,l,j);l=Jc(g);g=h+12|0;gZ(g,((t-1&255)>>>0<6?t+15|0:t)&255,o);m=Jc(g);da:{ea:{fa:{if(y[h+14|0]==10){j=y[m|0];g=y[l|0]&15;v[l|0]=g?-1:j;o=j|g<<8;g=y[h+12|0];if((g|0)!=10){break fa}g=0;v[h+12|0]=0;break fa}if(y[h+12|0]!=10){break ea}g=y[m|0]&15;v[m|0]=g?-1:0;o=g<<8;g=y[h+14|0]}if(o-256>>>0>4294967038){break ea}if(xi(g)>>>0>=xi(10)>>>0){break ea}v[b+5|0]=o;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=o>>>8;break da}if(f){v[b+2|0]=1;v[b+4|0]=f+2>>>2}GE(h+14|0,l,h+12|0,m);j=y[h+14|0];g=y[h+12|0];if((j|0)==20|(g|0)!=(j|0)?j:0){if(!g){v[b+5|0]=y[l|0];v[b+3|0]=j;break da}if(!f){Gn(h+10|0,b,j,y[l|0],g,y[m|0]);break da}if(xi(j)>>>0>xi(g)>>>0){v[b+5|0]=y[l|0];v[b+3|0]=j;break da}}v[b+5|0]=y[m|0];v[b+3|0]=g}fb=h+16|0;break Z}break L}f=d+1|0;continue}}break L}k=k+1|0;continue}}tb(u);n=n+1|0;continue}}h=N()|0;break H}h=N()|0;break H}h=N()|0;break H}x[31725]=0;d=e+192|0;S(510,d|0,e+376|0,20048);b=x[31725];x[31725]=0;ga:{ha:{if((b|0)!=1){f=hd(B,d);b=x[f>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ha}ub(d);if(!c){break G}while(1){if(!ek(x[a+484344>>2],x[a+484348>>2])){break G}c=x[f+8>>2];b=x[f>>2];x[31725]=0;c=U(152,b|0,c|0,16)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ga}if(!c){break G}x[31725]=0;c=e+192|0;O(396,f|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+484344>>2];x[31725]=0;O(397,Wb(b,0)|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}h=N()|0;break H}h=N()|0;break H}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0;tb(u);break H}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0}Qc(G);break c}Qc(G);break k}h=N()|0;ub(e+192|0);break c}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}g=(b<<5)+a|0;i=g+480280|0;Xe(i);f=v[(b+e|0)+324|0];d=f<<1&254;w[g+480284>>1]=(d|0)==254?256:d;ia:{if((f|0)<0){x[i>>2]=x[i>>2]|1024;break ia}w[a+480188>>1]=b+1}x[31725]=0;O(517,e+356|0,g+480289|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}b=b+1|0;continue}}h=N()|0;break c}ub(e+356|0);ie(e+376|0);ub(H)}fb=e+416|0;return q|0}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}h=N()|0;tb(d);break d}h=N()|0}tb(f)}ub(e+356|0)}ie(e+376|0)}ub(H);Q(h|0);p()}function Uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;e=fb-240|0;fb=e;xc(b);f=fb-16|0;fb=f;g=e+218|0;Yv(f+8|0,g);h=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);k=x[f+4>>2];if((k|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(k|0);if(!f){$_(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!a$(g)){break n}if(!c){d=1;break n}Bd(a,1024);gg(a);x[a+480208>>2]=x[a+480208>>2]|12;dg(a+1074312|0,21);d=Bb(y[e+234|0]|y[e+235|0]<<8);if(d){x[a+480204>>2]=D(d,1e4)}d=Bb(y[e+232|0]|y[e+233|0]<<8);if(d){x[a+480196>>2]=d}if(!y[e+228|0]){Xh(a,1)}wE(b,a+1298308|0,$b(y[e+222|0]|y[e+223|0]<<8|(y[e+224|0]<<16|y[e+225|0]<<24))-14|0);d=e+112|0;b=Ge(d,b);x[31725]=0;f=e+204|0;O(348,f|0,b|0);g=x[31725];x[31725]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){ub(b);x[31725]=0;S(349,d|0,f|0,1395544366);b=x[31725];x[31725]=0;if((b|0)==1){break s}x[31725]=0;b=R(279,x[e+112>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}if(!b){break r}x[31725]=0;b=R(275,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}x[31725]=0;f=R(275,d|0)|0;g=x[31725];x[31725]=0;A:{if((g|0)==1){break A}x[31725]=0;P(185,d|0,4)|0;g=x[31725];x[31725]=0;if((g|0)==1){break A}g=y[a+484376|0];h=x[a+484360>>2];x[31725]=0;aa(350,Xb(h,g)|0,d|0,b|0,65535,65535);b=x[31725];x[31725]=0;if((b|0)!=1){break z}}break y}d=N()|0;ub(b);break a}bf(Xb(x[a+484360>>2],y[a+484376|0]),f);f=e+112|0;ub(f);x[31725]=0;S(349,f|0,e+204|0,1346458708);b=x[31725];x[31725]=0;if((b|0)==1){break x}x[31725]=0;g=R(279,x[e+112>>2])|0;b=x[31725];x[31725]=0;if((b|0)==1){break w}d=0;b=0;if(!g){break t}x[31725]=0;g=R(275,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break w}w[a+480188>>1]=g;if((g-33&65535)>>>0<65504){break t}x[31725]=0;b=R(275,f|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break w}x[31725]=0;O(225,a+484344|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}b=0;x[31725]=0;m=R(283,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+112|0);break b}if(m){break t}}b=1}f=e+112|0;ub(f);if(!b){break o}x[31725]=0;d=e+184|0;S(349,d|0,e+204|0,1398157625);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;b=R(279,x[e+184>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}if(!b){break q}x[31725]=0;P(185,d|0,2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;b=R(283,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}G=a,H=_e((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[G+480204>>2]=H;b=0;x[31725]=0;P(351,d|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=e,H=Bb(z[(e+112|0)+(b<<1)>>1]),x[G+48>>2]=H;x[e+32>>2]=180;d=x[ud(e+48|0,e+32|0)>>2];h=d>>31<<7|d>>>25;d=d<<7;G=((b<<5)+a|0)+480284|0,H=Gc(ova(d-11475|0,h-(d>>>0<11475)|0,90,0),hb)+128|0,w[G>>1]=H;b=b+1|0;continue}else{B:{x[31725]=0;P(185,e+184|0,16)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break B}break c}}break}x[31725]=0;b=U(152,x[e+184>>2],x[e+192>>2],2)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}C:{if(b){x[31725]=0;b=R(275,e+184|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}w[e+48>>1]=b;w[e+32>>1]=256;G=a,H=z[Nc(e+48|0,e+32|0)>>1],x[G+480200>>2]=H}x[31725]=0;b=e+184|0;P(185,b|0,128)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}x[31725]=0;b=P(351,b|0,e+48|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){if(!b){break q}d=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(d|0)){G=e,H=Bb(z[(e+48|0)+(b<<1)>>1]),x[G+32>>2]=H;x[e+20>>2]=128;G=((b<<5)+a|0)+480286|0,H=x[ud(e+32|0,e+20|0)>>2]/2&255,w[G>>1]=H;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}d=N()|0;break b}ub(e+112|0);break p}ub(e+184|0);x[31725]=0;b=e+112|0;S(349,b|0,e+204|0,1413830740);d=x[31725];x[31725]=0;D:{E:{if((d|0)!=1){x[31725]=0;d=R(279,x[e+112>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}if(!d){break D}x[31725]=0;O(352,b|0,e+48|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}if((Bb(y[e+58|0]|y[e+59|0]<<8)|0)!=65535){break E}x[31725]=0;P(185,b|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break E}break e}d=N()|0;break b}x[31725]=0;b=e+112|0;d=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;V(338,a+1298332|0,b|0,d|0,2);b=x[31725];x[31725]=0;if((b|0)==1){break e}}ub(e+112|0);x[31725]=0;b=e+48|0;S(349,b|0,e+204|0,1229869908);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;d=R(279,x[e+48>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break l}F:{if(!d){break F}x[31725]=0;b=R(275,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31725]=0;d=U(152,x[e+48>>2],x[e+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}if(!d){break H}w[a+480190>>1]=f;g=a+480190|0;h=e+130|0;k=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31725]=0;b=R(275,e+48|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break I}break g}M:{if(k){j=b}else{x[31725]=0;d=R(275,e+48|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break M}j=d+1|0}w[e+20>>1]=j;x[31725]=0;d=e+112|0;O(353,e+48|0,d|0);i=x[31725];x[31725]=0;if((i|0)==1){break L}i=z[e+20>>1];if((i-4e3&65535)>>>0>=61537){G=a,H=z[qe(g,e+20|0)>>1],w[G+480190>>1]=H;l=y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24);x[31725]=0;V(354,d|0,(D(i,104)+a|0)+484380|0,$b(l)|0,m|0);d=x[31725];x[31725]=0;if((d|0)==1){break K}i=e+32|0;Yk(i,2,h);x[31725]=0;d=e+184|0;O(220,d|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break J}zc(((z[e+20>>1]<<5)+a|0)+946304|0,d);tb(d)}b=b+1|0;continue}break}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}if((b|0)!=4){break F}w[e+112>>1]=z[a+480190>>1];w[e+184>>1]=255;b=e+184|0;G=a,H=z[Nc(e+112|0,b)>>1],w[G+480192>>1]=H;x[31725]=0;S(349,b|0,e+204|0,1229278806);b=x[31725];x[31725]=0;if((b|0)==1){break j}N:while(1){O:{x[31725]=0;b=U(152,x[e+48>>2],x[e+56>>2],15)|0;d=x[31725];x[31725]=0;if((d|0)==1){break O}if(!b){break G}x[31725]=0;O(355,e+48|0,e+32|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=Bb(z[e+32>>1]);if(b>>>0>=z[a+480192>>1]){continue}d=D(b,104)+a|0;v[d+484524|0]=y[e+40|0];f=y[e+39|0];v[d+484523|0]=255;v[d+484525|0]=f;x[31725]=0;b=b+1&65535;d=U(253,a|0,b|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break k}if(!d){continue}G=e,H=Bb(y[e+37|0]|y[e+38|0]<<8),w[G+112>>1]=H;w[e+20>>1]=4095;b=e+112|0;f=e+20|0;G=d,H=z[Nc(b,f)>>1],x[G>>2]=H;g=y[e+35|0];if((g|0)==255){continue}x[31725]=0;h=e+184|0;g=P(151,h|0,D(g,34)+2|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break k}if(!g){continue}x[31725]=0;O(356,h|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}v[d+60|0]=y[d+60|0]|1;b=z[e+112>>1];x[e+24>>2]=16;x[e+28>>2]=240;G=e,H=Bb(b),x[G+20>>2]=H;b=sE(f);x[31725]=0;O(295,d+48|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=0;f=x[d+48>>2];h=x[d+52>>2];g=Sd(f,h);while(1)if(b>>>0>=g>>>0){b=y[e+36|0];if((b|0)!=255){v[d- -64|0]=b;v[d+63|0]=b;v[d+60|0]=y[d+60|0]|4}if(lc(f,h)){continue N}b=g-1|0;v[d+62|0]=b;v[d+61|0]=b;v[d+60|0]=y[d+60|0]|2;continue N}else{v[e+20|0]=64;k=(e+112|0)+(b<<1)|0;v[e+16|0]=y[k+2|0];i=Rb(e+20|0,e+16|0);l=yb(f,b);v[l+2|0]=y[i|0];w[l>>1]=y[k+3|0];b=b+1|0;continue}}break}break k}ub(e+48|0);break p}ub(e+184|0)}b=e+48|0;ub(b);x[31725]=0;S(357,e+184|0,e+204|0,1145131092);d=x[31725];x[31725]=0;if((d|0)==1){break m}G=e,H=wb(x[e+184>>2]),x[G+20>>2]=H;k=a+484344|0;t=c&1;q=b|4;u=wb(x[e+188>>2]);r=(m|0)!=841887798;B=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{f=x[e+20>>2];if(!Ib(f,u)){Qc(e+184|0);x[31725]=0;S(349,e+112|0,e+204|0,1346458702);b=x[31725];x[31725]=0;if((b|0)!=1){break aa}d=N()|0;break b}x[31725]=0;P(185,f|0,4)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;i=R(275,f|0)|0;b=x[31725];x[31725]=0;ba:{if((b|0)!=1){x[31725]=0;l=R(275,f|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break R}l=r?l:(l>>>0)/A[a+480196>>2]|0;if(!t|i>>>0>255){break P}x[31725]=0;b=U(198,k|0,i|0,l|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break R}if(b){break ba}break P}d=N()|0;break Q}if(!r){o=0;x[31725]=0;P(185,f|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break R}while(1){s=o&65535;if(s>>>0>=z[a+480188>>1]){break P}x[31725]=0;b=R(275,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break $}x[31725]=0;d=e+48|0;S(187,d|0,f|0,b+(b&1)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break S}g=ic(e+112|0,d);ub(d);x[e+48>>2]=0;x[e+52>>2]=0;d=0;ca:{while(1){b=x[g>>2];x[31725]=0;b=U(152,b|0,x[e+120>>2],6)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}j=b;b=x[e+48>>2];if(j&b>>>0<l>>>0){h=Wb(x[k>>2],i);b=jd(x[h>>2],x[x[h+48>>2]+12>>2],b,s);x[31725]=0;h=e+32|0;O(358,h|0,g|0);j=x[31725];x[31725]=0;da:{ea:{if((j|0)!=1){j=Jc(h);C=af(h);E=ej(h);F=ec(h);n=v[e+32|0];if((n-1&255)>>>0>95){break ea}v[b|0]=n+13;if(!x[e+52>>2]){break da}v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[ud(q,e+16|0)|0]|208,v[G+5|0]=H;break da}break T}if((n|0)>=0){break da}if(x[e+52>>2]){v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[ud(q,e+16|0)|0]|192,v[G+5|0]=H;break da}v[b|0]=254}if(y[j|0]){v[b+2|0]=1;v[e+16|0]=64;G=b,H=y[Rb(j,e+16|0)|0],v[G+4|0]=H}j=y[C|0];if(j){v[b+1|0]=j}j=y[E|0];n=y[F|0];if(j|n){Bf(b,j,n)}h=v[h+5|0];b=h&255;j=e+48|0;if((h|0)<0){x[31725]=0;h=R(199,g|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break T}b=h|b<<8&32512}d=b+d|0;dE(j,d,x[a+480196>>2]);continue}break}ub(g);o=o+1|0;continue}break}break T}b=Wb(x[k>>2],i);G=e,H=wb(x[b>>2]),x[G+48>>2]=H;l=wb(x[b+4>>2]);while(1){b=x[e+48>>2];if(!Ib(b,l)){break P}x[31725]=0;O(359,e+32|0,f|0);d=x[31725];x[31725]=0;if((d|0)!=1){v[e+15|0]=0;fa:{if(!B){d=x[e+32>>2];x[e+112>>2]=d;g=e+112|0;h=Jc(g);i=af(g);g=ej(g);if(d<<24>>24>0){v[b|0]=(D((d&240)>>>4|0,12)+(d&15)|0)+12}d=y[h|0];if(d>>>0>=4){v[b+2|0]=1;v[b+4|0]=(d>>>2|0)-1;d=y[h|0]}v[b+1|0]=d<<4&48|y[i|0]>>>4;d=y[i|0]&15;v[e+15|0]=d;g=y[g|0];v[b+5|0]=g;break fa}d=x[e+32>>2];x[e+8>>2]=d;x[e+4>>2]=d;d=e+16|0;kp(d,e+4|0,b);g=e+112|0;VD(g,e+15|0,b+5|0);UD(g,d);d=xb(e+32|0,0);v[b+1|0]=y[b+1|0]|y[d|0]&48;g=y[b+5|0];d=y[e+15|0]}Bf(b,d&255,g);d=y[b+3|0];ga:{if(d>>>0>11){break ga}d=1<<d;ha:{if(!(d&2240)){if(!(d&12)){break ga}if(!y[b+5|0]){break ha}break ga}d=y[b+5|0];g=d&240;if(g){v[b+5|0]=g;break ga}if(d){break ga}}v[b+3|0]=0}vg(e+48|0);continue}break}d=N()|0;break Q}d=N()|0;break Q}x[31725]=0;b=R(279,x[e+112>>2])|0;d=x[31725];x[31725]=0;ia:{ja:{ka:{la:{ma:{if((d|0)!=1){if(b){f=Fb(e+48|0);b=0;na:{while(1){oa:{x[31725]=0;d=U(152,x[e+112>>2],x[e+120>>2],1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break oa}if(!d){break na}if(ek(x[a+484344>>2],x[a+484348>>2])>>>0<=b>>>0){break na}x[31725]=0;S(360,e+112|0,f|0,32);d=x[31725];x[31725]=0;if((d|0)==1){break oa}d=x[k>>2];x[31725]=0;O(285,Wb(d,b)|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break oa}b=b+1|0;continue}break}d=N()|0;tb(f);break ma}tb(f)}b=e+112|0;ub(b);x[31725]=0;S(349,b|0,e+204|0,1414679374);b=x[31725];x[31725]=0;if((b|0)==1){break la}x[31725]=0;b=R(279,x[e+112>>2])|0;d=x[31725];x[31725]=0;if((d|0)==1){break V}if(!b){break ia}f=Fb(e+48|0);b=0;while(1){x[31725]=0;d=U(152,x[e+112>>2],x[e+120>>2],1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ka}if(!(z[a+480188>>1]>b>>>0&d)){break ja}x[31725]=0;S(360,e+112|0,f|0,32);d=x[31725];x[31725]=0;if((d|0)==1){break ka}om(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}d=N()|0}ub(e+112|0);break b}d=N()|0;break b}d=N()|0;tb(f);break U}tb(f)}b=e+112|0;ub(b);x[31725]=0;S(357,b|0,e+204|0,1145129300);b=x[31725];x[31725]=0;if((b|0)==1){break W}G=e,H=wb(x[e+112>>2]),x[G+48>>2]=H;d=c&2;f=wb(x[e+116>>2]);pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=x[e+48>>2];if(!Ib(b,f)){c=e+112|0;Qc(c);b=Fb(e+48|0);if((m|0)!=841887798){break ta}x[31725]=0;c=P(1,c|0,9490)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ua}Ab(b,c);tb(c);break sa}x[31725]=0;c=R(275,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break X}va:{if(!(!d|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;g=z[c+484518>>1];g=Xc(e+184|0,g&1?16:8,g&64?2:1,1,0);x[31725]=0;U(217,g|0,c+484484|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break va}}Sf(e+48|0);continue}break}break X}d=N()|0;break Y}x[31725]=0;c=e+112|0;S(349,c|0,e+204|0,1447383635);d=x[31725];x[31725]=0;wa:{xa:{ya:{za:{Aa:{if((d|0)!=1){x[31725]=0;d=R(279,x[e+112>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break ra}if(!d){break xa}x[31725]=0;c=R(283,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Aa}x[31725]=0;d=e+32|0;O(270,d|0,4292);f=x[31725];x[31725]=0;if((f|0)==1){break za}x[e+20>>2]=c>>>4;x[31725]=0;x[e+16>>2]=c&15;c=e+184|0;V(361,c|0,d|0,e+20|0,e+16|0);f=x[31725];x[31725]=0;if((f|0)==1){break ya}Ab(b,c);tb(c);Eb(d);break wa}d=N()|0;break Y}d=N()|0;break Z}d=N()|0;break Z}d=N()|0;Eb(e+32|0);break Z}x[31725]=0;c=P(1,e+184|0,8509)|0;d=x[31725];x[31725]=0;if((d|0)==1){break _}Ab(b,c);tb(c)}ub(e+112|0)}x[31725]=0;c=P(1,e+32|0,8509)|0;d=x[31725];x[31725]=0;if((d|0)==1){break qa}Ab(a+1298344|0,c);tb(c);x[31725]=0;c=P(1,e+20|0,10133)|0;d=x[31725];x[31725]=0;if((d|0)==1){break pa}Ab(a+1298356|0,c);tb(c);Ab(a+1298368|0,b);G=a+1298404|0,H=x[Fc(e+16|0,28)>>2],x[G>>2]=H;tb(b);d=1;break o}d=N()|0;break Z}d=N()|0;break Y}d=N()|0;break Y}d=N()|0;break Q}d=N()|0}ub(e+112|0)}tb(b);break b}d=N()|0;Qc(e+112|0);break b}d=N()|0;break b}d=N()|0}ub(e+112|0);break b}d=N()|0;ub(g);break Q}d=N()|0;break Q}d=N()|0}Qc(e+184|0);break b}Sf(e+20|0);continue}}d=0}ie(e+204|0)}fb=e+240|0;return d|0}d=N()|0;break b}d=N()|0;break f}d=N()|0;ub(e+184|0);break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break b}d=N()|0}ub(e+48|0);break b}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+184|0)}ie(e+204|0)}Q(d|0);p()}function Rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-336|0;fb=d;xc(b);j=d+324|0;a:{if(!np(b,j)){break a}if(!FX(j)){break a}q=Ge(d+304|0,b);n=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!c){x[31725]=0;e=d+40|0;O(665,e|0,q|0);b=x[31725];x[31725]=0;if((b|0)==1){break v}break x}x[31725]=0;e=d+40|0;O(666,e|0,q|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}}yv(n,e);ie(e);x[31725]=0;b=d+40|0;S(667,b|0,n|0,1413891155);e=x[31725];x[31725]=0;y:{z:{if((e|0)!=1){x[31725]=0;e=P(668,b|0,14138)|0;j=x[31725];x[31725]=0;if((j|0)==1){break z}ub(b);if((c|0)!=0&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31725]=0;O(248,a|0,4194304);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31725]=0;b=d+272|0;S(667,b|0,n|0,1280592212);e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;e=R(156,x[d+272>>2])|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}x[31725]=0;S(457,b|0,a+1298308|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}kj(Xb(x[a+484360>>2],y[a+484376|0]));j=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31725]=0;S(669,d+244|0,n|0,1196314451);b=x[31725];x[31725]=0;if((b|0)==1){break i}m=a+484360|0;t=d,u=wb(x[d+244>>2]),x[t+240>>2]=u;l=d+228|0;i=wb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,i)){break A}k=Ge(d+40|0,b);x[31725]=0;e=d+28|0;g=P(670,k|0,e|0)|0;b=x[31725];x[31725]=0;B:{C:{if((b|0)!=1){b=1;if(!(g&y[d+37|0]==1)){break B}t=a,u=Kd(y[d+38|0],z[a+480188>>1],127),w[t+480188>>1]=u;x[31725]=0;g=R(671,d+184|0)|0;b=x[31725];x[31725]=0;D:{E:{F:{if((b|0)!=1){h=d+172|0;df(h,e,9,1);x[31725]=0;b=d+136|0;O(220,b|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break F}e=d+16|0;gc(e,l,10);tm(e,b);tb(b);b=Xb(x[a+484360>>2],y[a+484376|0]);if(lc(x[b>>2],x[b+4>>2])){break D}x[31725]=0;b=R(276,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31725]=0;e=d+160|0;O(672,e|0,l|0);h=x[31725];x[31725]=0;if((h|0)==1){break m}vp(b,e);tb(e);x[31725]=0;O(666,d+172|0,k|0);b=x[31725];x[31725]=0;if((b|0)!=1){t=d,u=wb(x[d+172>>2]),x[t+156>>2]=u;r=wb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,r)){sp(d+136|0,b);wi(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31725]=0;h=U(152,x[d+136>>2],x[d+144>>2],2)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}if(!h){break G}x[31725]=0;h=d+8|0;O(200,h|0,d+136|0);f=x[31725];x[31725]=0;if((f|0)!=1){DC(g,e,y[d+8|0],y[Jc(h)|0],d+259|0,j);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;W(673,Xb(e,b)|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=0;x[31725]=0;O(674,j|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31725]=0;P(185,d+136|0,2)|0;b=x[31725];x[31725]=0;h=65535;L:{if((b|0)!=1){while(1){x[31725]=0;b=U(152,x[d+136>>2],x[d+144>>2],1)|0;f=x[31725];x[31725]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((f|0)!=1){if(!b){break G}x[31725]=0;f=R(199,d+136|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break I}b=4;switch(f|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Xb(x[a+484360>>2],y[a+484376|0]);if(z[d+220>>1]==65535){t=d,u=lm(x[b>>2],x[b+4>>2]),w[t+220>>1]=u}b=lm(x[b>>2],x[b+4>>2]);x[31725]=0;w[d+222>>1]=b;b=P(675,d+136|0,d+258|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}f=y[a+484376|0];o=x[a+484360>>2];x[31725]=0;O(538,Xb(o,f)|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break I}h=(h&65535)==65535?e:h;break M}x[31725]=0;b=R(191,d+136|0)|0;o=x[31725];x[31725]=0;if((o|0)!=1){_:{if(b>>>0<(h&65535)>>>0){b=z[d+224>>1];break _}b=b-h|0;w[d+224>>1]=b}bf(Xb(x[a+484360>>2],y[a+484376|0]),b&65535);if((f|0)!=3){break M}x[31725]=0;P(185,d+136|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break M}}break I}x[31725]=0;b=d+8|0;O(200,b|0,d+136|0);f=x[31725];x[31725]=0;if((f|0)!=1){DC(g,y[d+8|0],y[Jc(b)|0],-1,d+259|0,j);break M}break I}b=1}x[31725]=0;P(185,d+136|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break M}break I}x[31725]=0;b=R(199,d+136|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}v[d+227|0]=b;break M}x[31725]=0;b=R(199,d+136|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}v[d+226|0]=b;break M}x[31725]=0;b=P(641,d+136|0,d+8|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31725]=0;b=d+8|0;O(550,b|0,d+136|0);f=x[31725];x[31725]=0;if((f|0)!=1){f=Jc(b);DC(g,y[d+8|0],y[af(b)|0],y[f|0],d+259|0,j);break M}break I}x[31725]=0;b=d+8|0;O(200,b|0,d+136|0);f=x[31725];x[31725]=0;if((f|0)==1){break L}f=x[d+196>>2];s=Sc(f,x[d+200>>2]);o=y[d+8|0];if(s>>>0<=o>>>0){break M}b=Jc(b);t=xb(f,o),u=(y[b|0]>>>2|0)+1|0,v[t|0]=u}e=e+1|0;continue}}break I}break I}ie(d+172|0);break C}b=N()|0;ub(d+136|0)}ie(d+172|0);break l}ub(d+136|0);mm(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}gr(g)}ub(k);if(!b){Sf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;ck(m,0);b=x[j>>2];if(lc(b,x[j+4>>2])){break s}if(!(c&2)){break t}x[31725]=0;S(669,d+136|0,n|0,1347244868);b=x[31725];x[31725]=0;$:{if((b|0)!=1){t=d,u=wb(x[d+136>>2]),x[t+16>>2]=u;e=a+480190|0;h=d+53|0;k=d+57|0;m=wb(x[d+140>>2]);l=y[d+258|0];while(1){b=x[d+16>>2];if(!Ib(b,m)){Qc(d+136|0);b=x[j>>2];break t}aa:{ba:{ca:{if(!l){x[31725]=0;g=d+40|0;f=P(676,b|0,g|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break aa}if(!f){break ba}f=y[d+92|0]|y[d+93|0]<<8;i=f+1|0;w[d+8>>1]=i;if(f>>>0>3998){break ca}t=a,u=z[qe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31725]=0;O(677,g|0,(D(i&65535,104)+a|0)+484380|0);g=x[31725];x[31725]=0;if((g|0)==1){break aa}f=d+28|0;DX(f,h);x[31725]=0;g=d+172|0;O(220,g|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break u}zc(((z[d+8>>1]<<5)+a|0)+946304|0,g);tb(g);break ca}x[31725]=0;g=d+40|0;f=P(678,b|0,g|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break u}if(!f){break ba}f=y[d+96|0]|y[d+97|0]<<8;i=f+1|0;w[d+8>>1]=i;if(f>>>0>3998){break ca}t=a,u=z[qe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31725]=0;O(679,g|0,(D(i&65535,104)+a|0)+484380|0);g=x[31725];x[31725]=0;if((g|0)==1){break u}f=d+28|0;DX(f,k);x[31725]=0;g=d+172|0;O(220,g|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break $}zc(((z[d+8>>1]<<5)+a|0)+946304|0,g);tb(g)}g=z[d+8>>1];if((g-1&65535)>>>0>3998){break ba}f=Xc(d+40|0,8,1,0,2);x[31725]=0;U(217,f|0,(D(g,104)+a|0)+484380|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break ba}break u}Sf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Qc(d+136|0);break j}b=CC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);bf(Xb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;Xe(g);h=CC(x[j>>2],0);t=e+480286|0,u=y[xb(x[h+12>>2],b)|0],w[t>>1]=u;t=e+480284|0,u=y[xb(x[h>>2],b)|0],w[t>>1]=u;Kb(d+40|0,x[h+24>>2],b);t=g,u=x[g>>2]&-257|(Hb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[t>>2]=u;b=b+1|0;continue}break}x[31725]=0;b=P(1,d+172|0,(y[d+258|0]?17157:17014)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+28|0,10137)|0;e=x[31725];x[31725]=0;if((e|0)==1){break o}Ab(a+1298356|0,b);tb(b);t=a+1298404|0,u=x[Fc(d+40|0,4)>>2],x[t>>2]=u;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31725]=0;S(669,d+16|0,n|0,1146045008);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31725]=0;h=a+484344|0;O(225,h|0,Uf(c,b)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break r}t=d,u=wb(x[d+16>>2]),x[t+240>>2]=u;f=wb(x[d+20>>2]);while(1){g=x[d+240>>2];if(!Ib(g,f)){da:{ea:{b=x[j>>2];e=x[j+4>>2];if(xv(b,e)>>>0<2){break ea}m=y[d+259|0];c=0;while(1){if(xv(b,e)>>>0<=c>>>0){break ea}f=x[a+484344>>2];i=x[a+484348>>2];k=Vj(x[a+484360>>2],c&255);o=x[k>>2];g=CC(b,c);l=z[g+36>>1];if(He(f,i,z[_b(o,l)>>1])){x[31725]=0;e=P(370,k|0,l|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break da}fa:{if(!m){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}l=BC(x[g+24>>2],b);k=Wb(x[h>>2],e);ga:{if(l){ye(k,Yh(op(Ye(Ne(d+40|0,20,145),0),b&65535)));break ga}ye(k,Yh(op(Ye(Ne(d+40|0,9,y[xb(x[g>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ye(Wb(x[h>>2],e),Yh(Ye(Ne(b,16,y[g+43|0]),0)));ye(Wb(x[h>>2],e),Yh(Ye(Ne(b,17,y[g+42|0]),0)));e=x[j+4>>2];b=x[j>>2]}c=c+1|0;continue}}Qc(d+16|0);e=1;break s}b=N()|0;break q}b=x[g>>2];x[31725]=0;b=R(156,b|0)|0;c=x[31725];x[31725]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31725]=0;c=R(153,g|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[g>>2];x[31725]=0;b=P(680,b|0,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break na}if(!b){break ha}x[31725]=0;m=P(675,g|0,d+258|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ia}x[31725]=0;l=R(191,g|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ja}x[31725]=0;b=U(198,h|0,m|0,l|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ja}if(!b){break ha}k=0;while(1){if((k|0)==(l|0)){break ha}b=Wb(x[h>>2],m);cf(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],k);x[31725]=0;b=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31725]=0;c=d+136|0;S(187,c|0,g|0,b-2|0);b=x[31725];x[31725]=0;if((b|0)==1){break ka}e=ic(d+40|0,c);ub(c);while(1){b=x[e>>2];x[31725]=0;b=U(152,b|0,x[d+48>>2],3)|0;c=x[31725];x[31725]=0;if((c|0)==1){break oa}if(b){x[31725]=0;b=d+136|0;O(200,b|0,e|0);c=x[31725];x[31725]=0;pa:{qa:{ra:{sa:{if((c|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;t=d,u=y[Jc(b)|0],w[t+6>>1]=u;c=Wc(x[d+8>>2],z[Nc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31725]=0;b=R(199,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31725]=0;b=R(199,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31725]=0;b=R(199,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break la}v[d+156|0]=b;v[c+2|0]=1;v[d+6|0]=127;t=c,u=y[Rb(d+156|0,d+6|0)|0]+1>>>1|0,v[t+4|0]=u;b=y[d+136|0]}if(!(b&16)){continue}x[31725]=0;b=d+156|0;O(200,b|0,e|0);i=x[31725];x[31725]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((i|0)!=1){b=y[Jc(b)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;t=c,u=wv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=2;t=c,u=wv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=wv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=wv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31725]=0;b=R(199,e|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31725]=0;P(185,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}k=k+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Sf(d+240|0);continue}}Qc(d+244|0);CX(j);ub(d+272|0);break b}b=N()|0}Qc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}gr(g)}ub(k)}Qc(d+244|0);break h}b=N()|0}CX(j);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}ie(n);ub(q);Q(b|0);p()}ie(n);ub(q)}fb=d+336|0;return e|0}function Wua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-416|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{f=d+408|0;s:{if(!Bi(b,f)){break s}if(!y0(f)){break s}if(!c){o=1;break s}q=Ge(d+388|0,b);x[31725]=0;f=d+376|0;O(265,f|0,q|0);b=x[31725];x[31725]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){x[31725]=0;b=d+208|0;S(266,b|0,f|0,1229866575);f=x[31725];x[31725]=0;if((f|0)==1){break K}x[31725]=0;o=P(267,b|0,d+366|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break M}ub(b);if(!o){break t}x[31725]=0;O(248,a|0,524288);f=x[31725];x[31725]=0;N:{if((f|0)==1){break N}gg(a);x[a+480208>>2]=12;B=a,C=Kd(Bb(z[d+374>>1]),1,127),w[B+480188>>1]=C;B=d,C=Bb(z[d+366>>1]),w[B+208>>1]=C;w[d+320>>1]=255;f=d+320|0;B=a,C=z[Nc(b,f)>>1],w[B+480192>>1]=C;B=d,C=Bb(z[d+368>>1]),w[B+208>>1]=C;w[d+320>>1]=3999;B=a,C=z[Nc(b,f)>>1],w[B+480190>>1]=C;x[31725]=0;b=U(268,a+1074312|0,6,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break N}x[31725]=0;b=P(269,b|0,21)|0;f=x[31725];x[31725]=0;if((f|0)==1){break N}x[31725]=0;P(269,b|0,13)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break L}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31725]=0;b=P(1,d+352|0,9282)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+340|0,10317)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}Ab(a+1298356|0,b);tb(b);x[31725]=0;b=d+320|0;O(270,b|0,4336);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;f=d+300|0;O(271,f|0,d+412|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;g=d+264|0;O(271,g|0,d+413|0);e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;e=d+208|0;V(91,e|0,b|0,f|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break j}Ab(a+1298368|0,e);tb(e);tb(g);tb(f);Eb(b);B=a+1298404|0,C=x[Fc(e,28)>>2],x[B>>2]=C;x[31725]=0;e=d+376|0;S(266,b|0,e|0,1312902469);g=x[31725];x[31725]=0;if((g|0)==1){break k}x[31725]=0;g=R(156,x[d+320>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}x[31725]=0;h=a+1298308|0;S(272,b|0,h|0,g|0);b=x[31725];x[31725]=0;if((b|0)==1){break m}x[31725]=0;S(266,f|0,e|0,1397706311);b=x[31725];x[31725]=0;if((b|0)==1){break n}kj(Xb(x[a+484360>>2],y[a+484376|0]));e=a+484360|0;j=Bb(z[d+370>>1]);f=0;O:{while(1){P:{if(j>>>0<=(f&65535)>>>0){break P}x[31725]=0;b=U(152,x[d+300>>2],x[d+308>>2],46)|0;g=x[31725];x[31725]=0;Q:{if((g|0)!=1){if(!b){break P}x[31725]=0;b=d+208|0;O(273,d+300|0,b|0);g=x[31725];x[31725]=0;if((g|0)!=1){if(!Ad(x[a+1298312>>2],y[a+1298319|0])){break Q}x[31725]=0;O(274,h|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break Q}}b=N()|0;break o}b=N()|0;break o}x[31725]=0;i=R(275,d+300|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break O}b=Xb(x[a+484360>>2],y[a+484376|0]);if(!lc(x[b>>2],x[b+4>>2])){x[31725]=0;b=R(276,e|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break O}if((b|0)==255){break P}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31725]=0;g=d+288|0;O(277,g|0,d+208|0);k=x[31725];x[31725]=0;if((k|0)==1){break O}vp(b,g);tb(g);b=y[a+484376|0];g=x[a+484360>>2];x[31725]=0;S(278,Xb(g,b)|0,d+300|0,i|0);b=x[31725];x[31725]=0;if((b|0)==1){break O}f=f+1|0;continue}break}ck(e,0);x[31725]=0;S(266,d+264|0,d+376|0,1229869908);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;b=R(279,x[d+264>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break p}R:{S:{if(!b){break S}f=1;T:{while(1){b=f&65535;if(b>>>0>z[a+480192>>1]){x[31725]=0;S(266,d+188|0,d+376|0,1447382614);b=x[31725];x[31725]=0;if((b|0)!=1){break T}break p}x[31725]=0;h=d+208|0;O(280,d+264|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break p}e=y[d+238|0]|y[d+239|0]<<8;x[31725]=0;b=U(253,a|0,b|0,Bb(e)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break R}U:{V:{if(!b){break V}if(Bb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break V}g=d+112|0;vE(g,2,h);x[31725]=0;e=d+132|0;O(220,e|0,g|0);j=x[31725];x[31725]=0;if((j|0)==1){break U}zc(b+492|0,e);tb(e);vE(g,2,h);x[31725]=0;O(220,e|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break p}zc(((Bb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,e);tb(e);x[b>>2]=0;B=b,C=xe((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[B+8>>2]=C;wc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31725]=0;b=D(Bb(b),104)+a|0;O(281,b+484380|0,0);h=x[31725];x[31725]=0;if((h|0)==1){break p}B=d,C=Bb(y[d+240|0]|y[d+241|0]<<8),w[B+132>>1]=C;w[d+112>>1]=64;B=b+484410|0,C=z[Nc(e,g)>>1]<<2,w[B>>1]=C;g=b+484404|0;e=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));h=nva(e,e>>31,8303,0);e=hb;h=h+4181|0;e=h>>>0<4181?e+1|0:e;B=g,C=Gc(ova(h,e,8363,0),hb),x[B>>2]=C;e=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!e){break V}g=Bb(y[d+256|0]|y[d+257|0]<<8);if(!(g&3)){break V}h=e;e=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=h+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(g&2)){break V}w[b>>1]=e|6}f=f+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31725]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(282,d+24|0,0,a|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break p}x[31725]=0;S(266,d+168|0,d+376|0,1346719318);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31725]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(282,d|0,1,a|0,y[d+412|0]>2|0);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break S}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}b=d+264|0;ub(b);x[31725]=0;f=d+376|0;S(266,d+208|0,f|0,1346458708);e=x[31725];x[31725]=0;if((e|0)==1){break x}x[31725]=0;e=R(174,x[d+208>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break y}if(!(c&1)|e^1){break J}x[31725]=0;S(266,b|0,f|0,1347305805);f=x[31725];x[31725]=0;if((f|0)==1){break z}x[31725]=0;P(185,b|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break B}b=z[d+372>>1];x[31725]=0;k=a+484344|0;O(225,k|0,Bb(b)|0);b=x[31725];x[31725]=0;if((b|0)==1){break B}j=Nb(d+152|0);i=0;W:{while(1){if(Bb(z[d+372>>1])>>>0<=i>>>0){md(j);ub(d+264|0);if(c&4){f=0;if(!t){break w}f=z[a+480188>>1];b=0;while(1)if((b|0)==(f|0)){f=1;break w}else{e=(b<<5)+a|0;v[e+480288|0]=1;e=e+480280|0;x[e>>2]=x[e>>2]|67108864;b=b+1|0;continue}}if(!r){break u}break v}x[31725]=0;f=d+208|0;b=R(275,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break D}x[31725]=0;g=R(283,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}x[31725]=0;e=d+112|0;S(187,e|0,f|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break F}h=ic(d+132|0,e);ub(e);x[31725]=0;f=U(198,k|0,i&65535,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break H}X:{if(f){n=Fb(d+100|0);x[31725]=0;O(284,d+264|0,n|0);f=x[31725];x[31725]=0;if((f|0)==1){break I}f=x[k>>2];x[31725]=0;O(285,Wb(f,i)|0,n|0);f=x[31725];x[31725]=0;if((f|0)==1){break I}l=0;f=Wb(x[k>>2],i);cf(d+88|0,x[f>>2],x[x[f+48>>2]+12>>2],0);kj(j);u=(b>>>0<=1?1:b)-1|0;Y:while(1){b=x[h>>2];x[31725]=0;b=U(152,b|0,x[d+140>>2],1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break X}Z:{if(!b){break Z}x[31725]=0;b=R(199,h|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break I}if(!b){B=d,C=wb(x[j>>2]),x[B+84>>2]=C;f=wb(x[j+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,f)){ye(Wb(x[k>>2],i),Ye(Ne(d+112|0,y[b|0],y[b+1|0]),l));Md(d+84|0);continue}else{kj(j);if((l|0)==(u|0)){break Z}b=Wb(x[k>>2],i);l=l+1|0;cf(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],l);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue Y}}}w[d+116>>1]=0;x[d+112>>2]=0;g=d+112|0;if(b>>>0<=z[a+480188>>1]){g=Wc(x[d+88>>2],b-1|0)}x[31725]=0;b=R(199,h|0)|0;f=x[31725];x[31725]=0;_:{$:{if((f|0)!=1){aa:{if(!(b&1)){break aa}x[31725]=0;f=R(199,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break I}if((f|0)!=31){if((f-1&255)>>>0>252){break aa}e=(D(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}v[g|0]=e}if(!(b&2)){break _}x[31725]=0;f=R(199,h|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break $}}break I}v[g+1|0]=f}if(!(b&60)){continue}f=0;m=0;if(b&4){x[31725]=0;m=R(199,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break I}}if(b&8){x[31725]=0;f=R(199,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break I}}s=0;e=0;if(b&16){x[31725]=0;e=R(199,h|0)|0;A=x[31725];x[31725]=0;if((A|0)==1){break I}}if(b&32){x[31725]=0;s=R(199,h|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break I}}b=d+84|0;v0(b,e,s);e=Jc(b);b=d+82|0;v0(b,m,f);f=Jc(b);b=y[d+82|0];ba:{if((b|0)!=13){if(b){break ba}b=0;if(y[d+84|0]==13){break ba}}tg(d+84|0,d+82|0);tg(e,f);b=y[d+82|0]}m=d+80|0;Gn(m,g,y[d+84|0],y[e|0],b&255,y[f|0]);if(u0(y[d+80|0],y[d+81|0])){b=x[vb(d+76|0,wb(x[j>>2]))>>2];x[31725]=0;S(286,j|0,b|0,m|0);b=x[31725];x[31725]=0;if((b|0)==1){break W}}b=y[g+3|0];if((b|0)==43){t=1;continue}if((b|0)!=31){continue}r=1;continue}break}tb(n)}ub(h);i=i+1|0;continue}break}break I}break I}break p}b=N()|0;break o}b=N()|0;break o}b=N()|0;break b}f=0;if(c&4){break w}break u}b=N()|0;tb(n);break G}b=N()|0}ub(h);break C}b=N()|0;break C}b=N()|0;break C}b=N()|0}md(j);break A}b=N()|0}ub(d+264|0);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[31725]=0;S(266,d+264|0,d+376|0,1146310725);b=x[31725];x[31725]=0;ca:{da:{if((b|0)!=1){x[31725]=0;b=R(279,x[d+264>>2])|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(!b){e=f;break ca}x[31725]=0;h=R(275,d+264|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break da}b=0;e=f;while(1){if((b|0)==(h|0)){x[31725]=0;O(287,d+264|0,d+152|0);b=x[31725];x[31725]=0;if((b|0)!=1){break ca}break da}x[31725]=0;g=R(199,d+264|0)|0;j=x[31725];x[31725]=0;ea:{fa:{if((j|0)!=1){if(z[a+480188>>1]<=b>>>0){break ea}if(!f){break fa}j=((b<<5)+a|0)+480280|0;x[j>>2]=x[j>>2]&-67108865|((g|0)!=0)<<26;break ea}break da}if(g){break ea}e=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}}break da}b=N()|0;break q}b=N()|0;ub(d+264|0);break q}f=d+264|0;ub(f);ga:{ha:{if(e&1){b=vd(a+906300|0,0);x[31725]=0;W(288,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break r}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+264>>2]=0;g=b+48|0;r0(b+32|0,g,f);x[31725]=0;e=P(36,d+132|0,9571)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ha}tE(g,e);tb(e);x[31725]=0;e=P(36,d+112|0,9535)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ga}lw(b+80|0,e);tb(e);x[31725]=0;O(289,b+4|0,8);e=x[31725];x[31725]=0;if((e|0)==1){break r}q0(f,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);f=x[d+268>>2];b=x[b+4>>2];e=x[d+264>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(r){break v}break u}b=N()|0;break q}b=N()|0;break q}h=a+902204|0;b=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{while(1){if((b|0)==32){break u}x[d+88>>2]=D(b,127)>>>5;x[31725]=0;f=d+152|0;O(290,f|0,4093);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;e=d+100|0;j=d+88|0;O(291,e|0,j|0);g=x[31725];x[31725]=0;if((g|0)==1){break wa}x[31725]=0;g=d+264|0;S(292,g|0,f|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break va}ee(d+68|0,g);sf(Oe(h,b),x[d+68>>2],x[d+72>>2]);tb(g);tb(e);Eb(f);x[31725]=0;O(290,f|0,4075);i=x[31725];x[31725]=0;if((i|0)==1){break ta}x[31725]=0;O(291,e|0,j|0);i=x[31725];x[31725]=0;if((i|0)==1){break sa}x[31725]=0;S(292,g|0,f|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break ra}ee(d+60|0,g);sf(Oe(h,b+32|0),x[d+60>>2],x[d+64>>2]);tb(g);tb(e);Eb(f);x[31725]=0;O(290,f|0,4066);i=x[31725];x[31725]=0;if((i|0)==1){break pa}x[31725]=0;O(291,e|0,j|0);i=x[31725];x[31725]=0;if((i|0)==1){break oa}x[31725]=0;S(292,g|0,f|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break na}ee(d+52|0,g);sf(Oe(h,b- -64|0),x[d+52>>2],x[d+56>>2]);tb(g);tb(e);Eb(f);x[31725]=0;O(290,f|0,4039);i=x[31725];x[31725]=0;if((i|0)==1){break la}x[31725]=0;O(291,e|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break ka}x[31725]=0;S(292,g|0,f|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break ja}ee(d+44|0,g);sf(Oe(h,b+96|0),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(d+264|0);tb(d+100|0);Eb(f);continue}break}b=N()|0;break q}b=N()|0;break ua}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break qa}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break ma}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break ia}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}x[31725]=0;S(266,d+264|0,d+376|0,1397575756);b=x[31725];x[31725]=0;xa:{if((b|0)!=1){x[31725]=0;b=R(174,x[d+264>>2])|0;f=x[31725];x[31725]=0;if((f|0)!=1){ya:{f=1;if(!(c&2)|b^1){break xa}while(1){e=f&65535;if(e>>>0>z[a+480190>>1]){break xa}x[31725]=0;c=d+264|0;b=R(283,c|0)|0;g=x[31725];x[31725]=0;za:{if((g|0)!=1){x[31725]=0;g=R(283,c|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ya}if(!(b&7)){break za}e=(D(e,104)+a|0)+484380|0;x[e>>2]=g;b=Xc(d+152|0,b&4?32:b&2?16:8,1,1,0);x[31725]=0;U(217,b|0,e|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=N()|0;ub(d+264|0);break q}b=N()|0;break q}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}ie(d+376|0);ub(q)}fb=d+416|0;return o|0}b=N()|0}ub(d+208|0);break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}ie(d+376|0)}ub(q);Q(b|0);p()}function xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-304|0;fb=e;xc(b);f=e+208|0;a:{if(!zv(b,f)){break a}if(!lX(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(kX(f),hb))){break a}b:{if(!c){break b}Bd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Fb(e+196|0);d=y[e+248|0]|y[e+249|0]<<8;n=(d|0)==20479?y[e+262|0]|y[e+263|0]<<8:d-16464|0;c:{d:{e:{f:{g:{h:{i:{j:{switch(d>>>12|0){case 0:f=0;if((d|0)!=520){break e}x[31725]=0;d=P(1,e+184|0,12377)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);break f}f=N()|0;break c;case 1:k:{if((d|0)!=4896){break k}d=y[e+270|0]|y[e+271|0]<<8;if(d){break k}if(!((y[e+246|0]|y[e+247|0]<<8)&65455|(y[e+260|0]|y[e+240|0]&15))){l:{if(v[e+259|0]<0){x[a+1074308>>2]=18219008;x[31725]=0;d=P(1,e+184|0,14777)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break l}f=N()|0;break c}x[a+1074308>>2]=16777216;x[31725]=0;d=P(1,e+184|0,13445)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}}Ab(j,d);tb(d);x[31725]=0;f=1;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;g=1;if((d|0)!=1){break e}break d}if(y[e+260|0]|d|(y[e+261|0]|(y[e+246|0]|y[e+247|0]<<8))){break k}f=0;x[31725]=0;d=P(1,e+184|0,9476)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);break f}f=N()|0;break c}x[31725]=0;d=P(1,e+184|0,8494)|0;f=x[31725];x[31725]=0;h=1;if((f|0)!=1){Ab(j,d);tb(d);break g}f=N()|0;break c;case 2:x[31725]=0;d=P(1,e+184|0,6808)|0;f=x[31725];x[31725]=0;g=1;if((f|0)!=1){Ab(j,d);tb(d);break g}f=N()|0;break c;case 3:m:{n:{o:{p:{if(d>>>0<=12820){x[31725]=0;g=P(1,e+184|0,8557)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(j,g);tb(g);break p}f=N()|0;break c}x[31725]=0;g=e+184|0;O(447,g|0,4015);f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;x[e+172>>2]=(y[e+248|0]|y[e+249|0]<<8)-12820;f=e+48|0;S(448,f|0,g|0,e+172|0);i=x[31725];x[31725]=0;if((i|0)==1){break n}Ab(j,f);tb(f);Eb(g)}g=y[e+248|0]|y[e+249|0]<<8;if(g>>>0<12807){break h}f=y[e+264|0]|y[e+265|0]<<8|(y[e+266|0]<<16|y[e+267|0]<<24);if(f){break m}break h}f=N()|0;break c}f=N()|0;Eb(e+184|0);break c}g=GF(g,f);f=qp(e+48|0);x[f+32>>2]=g;x[31725]=0;O(449,a+1298412|0,f|0);g=x[31725];x[31725]=0;if((g|0)!=1){break h}f=N()|0;break c;case 4:if((d|0)==16640){f=0;x[31725]=0;d=P(1,e+184|0,8340)|0;h=x[31725];x[31725]=0;g=1;if((h|0)!=1){Ab(j,d);tb(d);x[31725]=0;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;h=0;if((d|0)==1){break d}break e}f=N()|0;break c}x[31725]=0;g=e+48|0;S(444,g|0,d|0,y[e+262|0]|y[e+263|0]<<8);d=x[31725];x[31725]=0;q:{r:{s:{if((d|0)!=1){Ab(j,g);tb(g);x[a+480260>>2]=1;if((n|0)<4201){break s}x[31725]=0;U(268,a+1074312|0,7,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}break r}f=N()|0;break c}if((n|0)<2386){break q}}x[31725]=0;U(268,a+1074312|0,38,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}}f=0;x[31725]=0;P(269,a+1074312|0,118)|0;d=x[31725];x[31725]=0;g=1;i=1;if((d|0)==1){break d}break e;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+262|0]|y[e+263|0]<<8:0)&65535;x[31725]=0;d=P(1,e+184|0,18237)|0;g=x[31725];x[31725]=0;t:{u:{v:{if((g|0)!=1){f=x[a+1074308>>2];x[31725]=0;g=e+172|0;O(136,g|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break v}f=0;x[31725]=0;h=e+48|0;S(2,h|0,d|0,g|0);i=x[31725];x[31725]=0;if((i|0)==1){break u}Ab(j,h);tb(h);tb(g);break f}f=N()|0;break c}f=N()|0;break t}f=N()|0;tb(e+172|0)}tb(d);break c}f=0;x[31725]=0;d=P(1,e+184|0,8541)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);break f}f=N()|0;break c;case 6:f=0;x[31725]=0;d=P(1,e+184|0,8340)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);tb(d);x[31725]=0;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;g=0;if((d|0)==1){break d}break e}f=N()|0;break c;case 7:f=0;x[31725]=0;d=P(1,e+184|0,8352)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);break f}f=N()|0;break c;default:break j}}f=0;if((d|0)!=51712){break e}x[31725]=0;d=P(1,e+184|0,9275)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(j,d);break f}f=N()|0;break c}f=N()|0;break c}x[31725]=0;g=U(268,a+1074312|0,7,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;g=U(268,g|0,23,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;g=U(268,g|0,38,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;U(268,g|0,107,1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}g=1;x[a+480260>>2]=1;f=0;i=0;if(d>>>0>12820){break e}}x[31725]=0;d=e+172|0;W(696,d|0);f=x[31725];x[31725]=0;w:{x:{y:{if((f|0)!=1){f=y[e+248|0]|y[e+249|0]<<8;x[e+148>>2]=f>>>8&15;x[31725]=0;x[e+132>>2]=f&255;i=e+160|0;O(446,i|0,e+132|0);f=x[31725];x[31725]=0;if((f|0)==1){break y}f=0;x[31725]=0;k=e+48|0;aa(697,k|0,d|0,j|0,e+148|0,i|0);q=x[31725];x[31725]=0;if((q|0)==1){break x}Ab(j,k);tb(k);tb(i);Eb(d);i=0;break e}f=N()|0;break c}f=N()|0;break w}f=N()|0;tb(e+160|0)}Eb(e+172|0);break c}tb(d);g=0;h=0;i=0}x[31725]=0;d=P(1,e+172|0,15032)|0;k=x[31725];x[31725]=0;z:{A:{B:{C:{D:{E:{F:{G:{if((k|0)!=1){Ab(a+1298344|0,d);tb(d);x[31725]=0;d=P(1,e+160|0,10474)|0;k=x[31725];x[31725]=0;if((k|0)==1){break G}Ab(a+1298356|0,d);tb(d);r=Ab(a+1298368|0,j);A=a+1298404|0,B=x[Fc(e+48|0,x[a+1074308>>2]?22:4)>>2],x[A>>2]=B;if(g){x[31725]=0;d=P(269,a+1074312|0,77)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,78)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,79)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,80)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,82)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,96)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;P(269,d|0,113)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}}d=y[e+248|0]|y[e+249|0]<<8;if(d>>>0<=4865){x[31725]=0;P(269,a+1074312|0,118)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=y[e+248|0]|y[e+249|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31725]=0;d=a+901404|0;W(698,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!f){rr(d)}g=e+148|0;aj(g,1,e+208|0);x[31725]=0;d=e+48|0;O(220,d|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break D}Ab(a+1298308|0,d);tb(d);d=y[e+246|0]|y[e+247|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}g=y[e+248|0]|y[e+249|0]<<8;if(!(!(d&64)&(g|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+257|0];x[a+480196>>2]=d;if(!(!h|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+258|0];x[a+480204>>2]=d>>>0<33?h?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+256|0];v[e+148|0]=64;d=y[Rb(e+48|0,e+148|0)|0];x[a+480200>>2]=d<<2;if(!(d|g>>>0>4895)){x[a+480200>>2]=256}f=y[e+259|0];if((y[e+250|0]|y[e+251|0]<<8)!=1|f>>>0>7){break F}x[e+48>>2]=(f<<4)+16;x[e+148>>2]=127;d=x[ud(e+48|0,e+148|0)>>2];break E}f=N()|0;break c}f=N()|0;break c}d=32;if((f|16)==18){break E}g=f&127;d=48;if(!g){break E}x[e+48>>2]=g;x[e+148>>2]=16;d=x[Ze(e+48|0,e+148|0)>>2]}g=d;x[a+480228>>2]=g;d=0;k=x[a+1074308>>2]!=0|f<<24>>24<0;if(!k){A=a,B=Bc(pva(g<<3|5,g>>>29|0,11,0),hb),x[A+480228>>2]=B}w[a+480188>>1]=4;x[a+480232>>2]=i?(n|0)<3299?64:36:36;g=sc(e+144|0);while(1){if((d|0)==32){if(!z[a+480188>>1]){w[a+480188>>1]=1}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;aa(350,Xb(f,d)|0,b|0,y[e+240|0]|y[e+241|0]<<8,255,254);d=x[31725];x[31725]=0;if((d|0)!=1){k=Nb(e+148|0);x[31725]=0;U(215,b|0,k|0,y[e+242|0]|y[e+243|0]<<8)|0;d=x[31725];x[31725]=0;if((d|0)!=1){q=Nb(e+132|0);x[31725]=0;U(215,b|0,q|0,y[e+244|0]|y[e+245|0]<<8)|0;d=x[31725];x[31725]=0;H:{if((d|0)!=1){if(y[e+261|0]!=252){break C}d=0;x[31725]=0;O(699,b|0,e+48|0);f=x[31725];x[31725]=0;if((f|0)==1){break H}while(1){if((d|0)==32){break C}f=y[(e+48|0)+d|0];I:{if(!(f&32)){break I}if(h){Pc(e+36|0,g,d);if(Hb(x[x[e+36>>2]>>2],x[e+40>>2])){break I}}w[((d<<5)+a|0)+480284>>1]=(((f&15)<<8|8)>>>0)/15}d=d+1|0;continue}}f=N()|0;break B}f=N()|0;break B}f=N()|0;break A}f=N()|0;break c}f=(d<<5)+a|0;n=f+480280|0;Xe(n);i=y[(d+e|0)+272|0];q=i&126;J:{if((i|0)!=255){i=i<<24>>24;w[a+480188>>1]=d+1;if(k){w[f+480284>>1]=i&8?204:51}if((i|0)>=0){break J}}x[n>>2]=1024}if((q-16&255)>>>0<=13){w[f+480284>>1]=128;f=e+48|0;Pc(f,g,d);gp(f)}d=d+1|0;continue}}f=N()|0;break c}w[e+48>>1]=y[e+242|0]|y[e+243|0]<<8;w[e+36>>1]=3999;f=z[Nc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;t=c&2;u=e+96|0;d=0;i=0;g=0;n=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{while(1){if((f&65535)>>>0<=d>>>0){d=n&65535;if(!(d|!(h&i))&(y[e+248|0]|y[e+249|0]<<8)!=4864){break Q}if(!h){break P}x[31725]=0;f=U(268,a+1074312|0,79,d>>>0>1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}x[31725]=0;l=f;f=d>>>0<2;h=U(268,l|0,107,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break N}x[31725]=0;U(268,h|0,38,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}x[31725]=0;P(129,r|0,(d>>>0>1?17201:17208)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break N}if(f){break P}x[a+480228>>2]=48;break P}f=_b(x[k>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31725]=0;f=P(151,b|0,f<<4)|0;m=x[31725];x[31725]=0;if((m|0)==1){break L}T:{U:{if(!f){break U}x[31725]=0;m=e+48|0;f=P(700,b|0,m|0)|0;o=x[31725];x[31725]=0;if((o|0)==1){break L}if(!f){break U}x[31725]=0;o=d+1|0;l=(D(o,104)+a|0)+484380|0;S(701,m|0,l|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break L}s=e+24|0;aj(s,1,u);x[31725]=0;f=e+36|0;O(220,f|0,s|0);s=x[31725];x[31725]=0;if((s|0)==1){break T}zc(((o<<5)+a|0)+946304|0,f);tb(f);if(y[e+48|0]>1){break U}V:{if(!t|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break V}m=iX(m);x[31725]=0;m=P(151,b|0,m|0)|0;o=x[31725];x[31725]=0;if((o|0)==1){break S}if(!m){break V}hX(f,y[e+78|0],y[e+79|0],(y[e+250|0]|y[e+251|0]<<8)==1);x[31725]=0;U(217,f|0,l|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break R}g=y[e+39|0]==10|g;i=1}n=y[e+88|0]|y[e+89|0]<<8|n}d=d+1|0;f=z[a+480190>>1];continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}x[31725]=0;d=P(1,e+48|0,9750)|0;f=x[31725];x[31725]=0;if((f|0)==1){break O}Ab(r,d);tb(d)}if(g&1){break M}break K}f=N()|0;break B}f=N()|0;break B}x[31725]=0;d=P(1,e+36|0,17141)|0;g=x[31725];x[31725]=0;W:{if((g|0)!=1){x[31725]=0;P(76,r|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break W}tb(d);break K}f=N()|0;break B}f=N()|0;tb(d);break B}f=N()|0;break B}if(!(c&1)){break z}c=y[e+248|0]|y[e+249|0]<<8;w[e+24>>1]=y[e+244|0]|y[e+245|0]<<8;w[e+16>>1]=255;t=z[Nc(e+24|0,e+16|0)>>1];x[31725]=0;f=a+484344|0;O(225,f|0,t|0);d=x[31725];x[31725]=0;if((d|0)!=1){u=c>>>0<4896;i=0;r=0;m=0;X:{Y:{while(1){if((i|0)==(t|0)){if(!u){break z}a=z[a+480188>>1];if((a|0)>(m+r|0)|(a|0)<=(r-m|0)){break z}c=fb-16|0;fb=c;a=wb(x[f>>2]);x[c+12>>2]=a;d=wb(x[f+4>>2]);while(1){if(Ib(a,d)){b=wb(x[a>>2]);g=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,g)){if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}b=x[vg(a+12|0)>>2];continue}break}fb=a+16|0;a=x[am(c+12|0)>>2];continue}else{fb=c+16|0}break}break z}x[31725]=0;c=U(198,f|0,i&65535,64)|0;d=x[31725];x[31725]=0;Z:{if((d|0)==1){break Z}_:{if(!c){break _}c=_b(x[q>>2],i);c=y[c|0]|y[c+1|0]<<8;if(!c){break _}x[31725]=0;c=P(151,b|0,c<<4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Z}if(!c){break _}x[31725]=0;P(185,b|0,2)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Z}d=0;c=Wb(x[f>>2],i);cf(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break _}c=d;x[31725]=0;d=R(199,b|0)|0;g=x[31725];x[31725]=0;$:{if((g|0)!=1){d=d<<24>>24;if(d){break $}d=64;if(c>>>0>62){continue}d=Wb(x[f>>2],i);l=x[d>>2];g=x[x[d+48>>2]+12>>2];d=c+1|0;cf(e+16|0,l,g,d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}f=N()|0;break B}g=bh(e+16|0);o=d&31;if(o>>>0<z[a+480188>>1]){g=Wc(x[e+24>>2],o)}l=d&255;if(l&32){x[31725]=0;h=e+14|0;O(200,h|0,b|0);s=x[31725];x[31725]=0;aa:{ba:{ca:{if((s|0)!=1){s=Jc(h);h=y[e+14|0];if(h>>>0>239){break ca}h=gX((D(h>>>4|0,12)+(h&15)|0)+13|0);break ba}f=N()|0;break B}da:{switch(h-254|0){case 0:break ba;case 1:break da;default:break aa}}h=0}v[g|0]=h}v[g+1|0]=y[s|0]}if(l&64){x[31725]=0;h=R(199,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break Y}h=h<<24>>24;v[e+14|0]=h;ea:{if((h|0)<=-64){v[g+2|0]=2;l=h^-128;break ea}v[g+2|0]=1;v[e+13|0]=64;l=y[Rb(e+14|0,e+13|0)|0]}v[g+4|0]=l}fa:{if((d|0)>=0){break fa}x[31725]=0;d=e+14|0;O(200,d|0,b|0);h=x[31725];x[31725]=0;if((h|0)==1){break X}xD(g,y[e+14|0],y[Jc(d)|0],0);d=y[g+3|0];ga:{if((d|0)!=10){if((d|0)!=31){if((d|0)!=20){break fa}d=y[g+5|0];if((d&240)!=160|(y[e+248|0]|y[e+249|0]<<8)>>>0>4895){break fa}if((n&65535)>>>0>1){break ga}h=y[(e+o|0)+272|0]&127;if(h>>>0>=16){break ga}ha:{switch(d-160|0){case 0:case 2:v[g+5|0]=h&8?-116:-125;break fa;case 1:case 3:v[g+5|0]=h&8?-125:-116;break fa;default:break ha}}if(d>>>0>167){break ga}v[g+5|0]=136;break fa}d=y[g+5|0];if(d>>>0>15){u=0;break fa}if(d>>>0<=7){m=m+1|0;break fa}r=((d|0)!=8)+r|0;break fa}if(y[g+5|0]|(y[e+248|0]|y[e+249|0]<<8)>>>0>4865){break fa}}v[g+3|0]=37}d=c;continue}}i=i+1|0;continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}f=N()|0}md(q)}md(k);break c}md(q);md(k);tb(j);break b}f=N()|0}tb(j);Q(f|0);p()}d=1}fb=e+304|0;return d|0}function mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0;e=fb-480|0;fb=e;xc(b);d=fb-16|0;fb=d;l=e+276|0;SW(d+8|0,l);i=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(i|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){RW(l)}a:{if(!d){break a}if(!TW(l)){break a}if(!c){f=1;break a}Bd(a,134217728);l=e+8|0;ig(l,3953);x[31725]=0;d=e+116|0;S(704,d|0,l|0,y[e+280|0]|y[e+281|0]<<8);i=x[31725];x[31725]=0;b:{c:{d:{if((i|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(l);l=tc(d,8974);Ab(a+1298356|0,l);tb(l);T=a+1298404|0,V=x[Fc(d,28)>>2],x[T>>2]=V;x[a+480188>>2]=4;T=a,V=Bb(y[e+412|0]|y[e+413|0]<<8),x[T+480196>>2]=V;d=y[e+416|0]|y[e+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;T=a,V=QW(Bb(d)),x[T+480204>>2]=V;iw(Xb(x[a+484360>>2],y[a+484376|0]),e+284|0,y[e+282|0]);n=a+480190|0;m=a+480188|0;o=Nb(e+264|0);t=Nb(e+252|0);e:{while(1){f:{g:{h:{i:{j:{k:{l:{if(Bb(y[e+476|0]|y[e+477|0]<<8)>>>0>(g&65535)>>>0){x[31725]=0;d=R(275,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break i}w[e+228>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}f=Bb(y[e+478|0]|y[e+479|0]<<8);if((Bb(y[e+280|0]|y[e+281|0]<<8)|0)==2){x[31725]=0;d=R(283,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break j}f=d-2|0}x[31725]=0;d=e+8|0;S(187,d|0,b|0,f|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}h=ic(e+116|0,d);ub(d);B=z[qe(n,e+228|0)>>1];w[a+480190>>1]=B;x[31725]=0;f=D(z[e+228>>1],104)+a|0;i=f+484380|0;O(281,i|0,1);d=x[31725];x[31725]=0;m:{n:{o:{if((d|0)==1){break o}if(Bb(y[e+280|0]|y[e+281|0]<<8)>>>0>1){break n}x[31725]=0;O(705,h|0,f+484423|0);d=x[31725];x[31725]=0;if((d|0)==1){break o}x[31725]=0;P(185,h|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break o}x[31725]=0;S(333,h|0,((z[e+228>>1]<<5)+a|0)+946304|0,30);d=x[31725];x[31725]=0;if((d|0)!=1){break m}}i=N()|0;break f}d=Fb(e+8|0);x[31725]=0;S(360,h|0,d|0,257);l=x[31725];x[31725]=0;p:{q:{if((l|0)==1){break q}ze(f+484423|0,d);x[31725]=0;P(185,h|0,1)|0;l=x[31725];x[31725]=0;if((l|0)==1){break q}x[31725]=0;S(360,h|0,d|0,31);l=x[31725];x[31725]=0;if((l|0)==1){break q}zc(((z[e+228>>1]<<5)+a|0)+946304|0,d);if(!(v[e+124|0]&1)){break p}x[31725]=0;P(185,h|0,1)|0;l=x[31725];x[31725]=0;if((l|0)!=1){break p}}i=N()|0;tb(d);break f}tb(d)}x[31725]=0;O(706,h|0,e+8|0);d=x[31725];x[31725]=0;r:{if((d|0)==1){break r}k=fb-16|0;fb=k;l=$b(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));x[i>>2]=l;v[k+15|0]=y[e+12|0];v[k+14|0]=64;T=i,V=y[Rb(k+15|0,k+14|0)|0]<<2,w[T+30>>1]=V;j=$b(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24));x[i+4>>2]=j;d=$b(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24))+$b(y[e+18|0]|y[e+19|0]<<8|(y[e+20|0]<<16|y[e+21|0]<<24))|0;x[i+8>>2]=d;if(j>>>0>=l>>>0){j=l-1|0;x[i+4>>2]=j}if(d>>>0>l>>>0){x[i+8>>2]=l;d=l}s:{if(d>>>0<j>>>0){x[i+4>>2]=0;x[i+8>>2]=0;break s}if(d>>>0<=j>>>0){break s}w[i+34>>1]=z[i+34>>1]|2;T=yb(i+68|0,0),V=j,x[T>>2]=V}fb=k+16|0;t:{switch(Bb(y[e+280|0]|y[e+281|0]<<8)|0){case 2:v[f+484417|0]=y[e+26|0]<<3;break;case 0:break g;default:break t}}x[31725]=0;O(212,t|0,B|0);d=x[31725];x[31725]=0;if((d|0)==1){break r}x[31725]=0;O(707,o|0,B|0);d=x[31725];x[31725]=0;if((d|0)==1){break r}l=Hd(x[o>>2],z[e+228>>1]-1|0);NW(l);x[31725]=0;d=R(275,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break l}i=x[b+8>>2];k=x[b>>2];x[31725]=0;i=U(152,k|0,i|0,d<<3)|0;k=x[31725];x[31725]=0;if((k|0)==1){break l}if(i){x[31725]=0;O(708,l|0,d|0);i=x[31725];x[31725]=0;if((i|0)==1){break l}x[e+248>>2]=0;if(!(y[f+484414|0]&2)|d){break h}d=x[f+484384>>2];x[e+240>>2]=d;i=x[f+484388>>2];x[31725]=0;x[e+244>>2]=i-d;O(709,l|0,e+240|0);d=x[31725];x[31725]=0;if((d|0)!=1){break g}i=N()|0;break f}ub(h);break c}i=N()|0;break f}u:{v:{w:{x:{if(Bb(y[e+280|0]|y[e+281|0]<<8)){u=y[e+283|0];w[e+238>>1]=4;C=128;break x}x[31725]=0;C=R(275,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){i=N()|0;break e}d=y[e+280|0]|y[e+281|0]<<8;u=y[e+283|0];w[e+238>>1]=4;if(!Bb(d)){break w}}l=x[b+8>>2];i=0;while(1){y:{if((i&65535)>>>0>=C>>>0){break y}x[31725]=0;d=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}if((d|0)==65535){break y}x[31725]=0;u=R(275,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break v}x[31725]=0;d=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}w[e+238>>1]=d;if(d>>>0>127){break c}T=m,V=z[qe(m,e+238|0)>>1],w[T>>1]=V;x[31725]=0;P(185,b|0,D(d,u)<<2)|0;d=x[31725];x[31725]=0;if((d|0)==1){break v}i=i+1|0;continue}break}x[31725]=0;P(151,b|0,l|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break u}}d=z[m>>1];x[31725]=0;E=P(710,e+240|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){J=a+484344|0;M=c&1;F=Bb(y[e+414|0]|y[e+415|0]<<8);d=0;l=0;while(1){z:{A:{B:{C:{if((d&65535)>>>0>=C>>>0){break C}D:{if(!Bb(y[e+280|0]|y[e+281|0]<<8)){f=z[e+238>>1];i=d;break D}x[31725]=0;i=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}if((i|0)==65535){break C}x[31725]=0;u=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}x[31725]=0;f=R(275,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break z}w[e+238>>1]=f}h=x[b+8>>2];g=x[b>>2];x[31725]=0;j=h;G=u&65535;h=G<<2;f=U(152,g|0,j|0,D(h,f&65535)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break z}if(!f){break C}if(!M){break B}x[31725]=0;K=i&65535;i=U(198,J|0,K|0,G|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}if(!i){break B}r=0;E:while(1){if((r|0)==(G|0)){break A}i=Wb(x[J>>2],K);cf(e+228|0,x[i>>2],x[x[i+48>>2]+12>>2],r);i=0;s=0;F:{G:{switch((F&3)-1|0){case 0:s=!(r&3);break F;case 1:s=!(r&1);break F;case 2:break G;default:break F}}s=(r&3)!=3}H=0;while(1){if(z[e+238>>1]<=i>>>0){r=r+1|0;continue E}g=x[E>>2];h=Wc(x[e+228>>2],i);x[31725]=0;f=e+224|0;O(359,f|0,b|0);k=x[31725];x[31725]=0;if((k|0)==1){break z}k=D(i,9)+g|0;g=Jc(f);q=af(f);v[h+1|0]=y[e+224|0];j=y[g|0];v[h|0]=j;g=y[ej(f)|0];v[h+5|0]=g;m=h+5|0;if(j){v[h|0]=j+25;v[k+8|0]=0;v[k|0]=0;v[k+1|0]=0;v[k+2|0]=0;v[k+3|0]=0;v[k+4|0]=0;v[k+5|0]=0;v[k+6|0]=0;v[k+7|0]=0;g=y[h+5|0]}j=g&255;q=y[q|0];H:{I:{if(q>>>0>=240){f=j|(q&15)<<8;if(f){v[h+3|0]=17;T=h,V=fm(+(QW(f)>>>0)/1e4),v[T+5|0]=V;j=0;break H}break I}I=j>>>4|0;L=j<<4;f=I|L;J:{switch(q|0){case 0:if(g&255){v[h+3|0]=1;j=0;break H}break I;case 1:v[h+3|0]=2;j=0;break H;case 2:v[h+3|0]=3;j=0;break H;case 3:v[e+220|0]=15;T=k,V=y[Rb(m,e+220|0)|0]|16,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break I;case 4:v[e+220|0]=15;T=k,V=y[Rb(m,e+220|0)|0]|32,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break I;case 5:v[k+7|0]=0;v[k+2|0]=0;v[k+1|0]=g;v[k|0]=0;break I;case 6:v[k+7|0]=0;v[k+2|0]=g;v[k|0]=0;v[k+1|0]=0;break I;case 7:v[h+3|0]=23;j=0;l=0;break H;case 8:v[h+3|0]=0;j=1;l=f;break H;case 9:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Rb(m,e+220|0)|0]|16,v[T+5|0]=V;j=0;break H;case 10:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Rb(m,e+220|0)|0]|32,v[T+5|0]=V;j=0;break H;case 11:v[k+3|0]=f;break I;case 12:v[h+4|0]=g;j=1;v[h+2|0]=1;v[k+3|0]=0;v[h+3|0]=0;break H;case 13:K:{L:{if((g&255)>>>0>=16){v[h+2|0]=4;g=(g&240)>>>4|0;break L}if(!(j&15)){break K}v[h+2|0]=3}v[h+4|0]=g}v[k+3|0]=0;break I;case 14:v[h+3|0]=19;v[h+5|0]=!(g&255);j=0;break H;case 15:v[h+3|0]=16;v[h+5|0]=(g&240)>>>4;F=g&15;j=0;break H;case 16:v[k+5|0]=0;v[k+4|0]=g;break I;case 17:v[k+6|0]=j&15?g:0;break I;case 18:v[h+3|0]=14;j=0;break H;case 19:v[k+8|0]=0;v[k+7|0]=g;v[k+2|0]=0;v[k|0]=0;v[k+1|0]=0;break I;case 20:v[h+3|0]=12;j=0;break H;case 22:f=y[h+1|0];M:{if(!f){break M}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break M}g=g-1|0;v[m|0]=g;x[31725]=0;R(711,e+116|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break z}x[e+220>>2]=9;f=Hd(j,f-1|0);T=e,V=Ud(x[f>>2],x[f+4>>2]),x[T+112>>2]=V;if(A[Gb(e+220|0,e+112|0)>>2]<=(g&255)>>>0){break M}v[h+2|0]=15;v[h+4|0]=y[h+5|0]}break I;case 23:f=y[h+1|0];N:{if(!f){break N}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break N}g=g-1|0;v[m|0]=g;f=Hd(j,f-1|0);j=x[f>>2];q=Ud(j,x[f+4>>2]);f=g&255;if(q>>>0<=f>>>0){break N}f=Hd(j,f);g=z[f+8>>1];O:{if(g){break O}g=0;j=z[n>>1];if(!ui(j)){break O}g=j+1|0;w[n>>1]=g;w[f+8>>1]=g}v[h+1|0]=g}break I;case 24:f=y[h+1|0];P:{if(!f){break P}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break P}g=g-1|0;v[m|0]=g;x[31725]=0;R(711,e+8|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break z}x[e+220>>2]=9;f=Hd(j,f-1|0);T=e,V=Ud(x[f>>2],x[f+4>>2]),x[T+112>>2]=V;if(A[Gb(e+220|0,e+112|0)>>2]>(g&255)>>>0){v[h+2|0]=15;v[h+4|0]=y[h+5|0]}f=_b(x[t>>2],y[h+1|0]-1|0);g=z[f>>1];Q:{if(g){break Q}g=0;j=z[n>>1];if(!ui(j)){break Q}g=j+1|0;w[n>>1]=g;w[f>>1]=g}v[h+1|0]=g}break I;case 25:f=y[h+1|0];R:{if(!f){break R}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break R}g=g-1|0;v[m|0]=g;f=Hd(j,f-1|0);j=x[f>>2];q=Ud(j,x[f+4>>2]);f=g&255;if(q>>>0<=f>>>0){break R}f=Hd(j,f);g=z[f+10>>1];S:{if(g){break S}g=0;j=z[n>>1];if(!ui(j)){break S}g=j+1|0;w[n>>1]=g;w[f+10>>1]=g}v[h+1|0]=g}break I;case 29:v[h+5|0]=f;v[h+3|0]=11;if(j&15){v[m|0]=L|15;j=0;break H}j=0;if((g&255)>>>0<16){break H}v[m|0]=I|240;break H;case 32:if((g&255)>>>0>=16){v[k+3|0]=I;break I}v[h+3|0]=19;v[h+5|0]=g|192;j=0;break H;case 33:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Rb(m,e+220|0)|0]|208,v[T+5|0]=V;j=0;break H;case 34:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Rb(m,e+220|0)|0]|144,v[T+5|0]=V;j=0;break H;case 73:v[h+3|0]=10;j=0;break H;case 78:if((g&112|128)==224){v[h+3|0]=19;j=0;break H}break I;case 79:if((g&255)>>>0<=31){v[h+3|0]=16;j=0;F=0;break H}v[h+3|0]=17;j=0;break H;default:break J}}}v[h+3|0]=0;j=1}f=0;g=y[k+3|0];if(!(y[h+2|0]|!g)){f=g>>>0<16;v[h+4|0]=f?g:g>>>4|0;v[h+2|0]=f?6:5;f=1}T:{if(!j){break T}g=y[k+1|0];U:{if(g){v[h+3|0]=2;break U}g=y[k+2|0];if(g){v[h+3|0]=3;break U}g=y[k|0];if(g){v[h+3|0]=19;break U}g=y[k+7|0];if(g){v[h+3|0]=4;v[k+8|0]=g;break U}g=y[k+4|0];if(g){v[h+3|0]=5;v[k+5|0]=g;break U}g=f;f=y[k+3|0];if(!(g|!f)){v[h+5|0]=f;v[h+3|0]=11;if(f&15){g=f|-16;break U}if(f>>>0<16){break T}g=f|15;break U}g=y[k+6|0];if(g){v[h+3|0]=8;break U}if(s){v[h+3|0]=20;s=0;g=97;break U}s=0;f=l&255;if(!f|H){break T}v[h+5|0]=l;v[h+3|0]=24;if(l&15){g=l|-16}else{H=1;if(f>>>0<16){break T}g=l|15}H=1}v[m|0]=g}i=i+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];j=1;Xh(a,1);if(Bb(y[e+280|0]|y[e+281|0]<<8)){V:{while(1){d=x[b+8>>2];l=x[b>>2];x[31725]=0;d=U(152,l|0,d|0,2)|0;l=x[31725];x[31725]=0;if((l|0)==1){break z}if(!d){break V}x[31725]=0;d=R(275,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break z}if((d|0)==65535){break V}x[31725]=0;P(185,b|0,2)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}x[31725]=0;d=R(283,b|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){x[31725]=0;P(185,b|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}break z}x[31725]=0;P(185,b|0,34)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}}W:{if(!(c&2)){break W}while(1){c=j&65535;if(c>>>0>B>>>0){break W}X:{i=(D(c,104)+a|0)+484380|0;if(!x[i>>2]){break X}d=Xc(e+228|0,8,1,0,0);x[31725]=0;U(217,d|0,i|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}d=x[o>>2];if(Ud(d,x[o+4>>2])>>>0<c>>>0){break X}k=c-1|0;h=Hd(d,k);c=0;d=0;m=fb-112|0;fb=m;Y:{g=x[i>>2];if(!je(g,x[i+20>>2])){break Y}r=x[h>>2];l=Ud(r,x[h+4>>2]);if(l>>>0<2){break Y}f=ap(m+8|0,i);x[f+20>>2]=0;x[f>>2]=0;Z:{while(1){if((c|0)==(l|0)){break Z}_:{n=Hd(r,c);s=x[n>>2];if(s>>>0>=g>>>0){break _}n=x[n+4>>2];if(n>>>0>g-s>>>0|268435456-n>>>0<d>>>0){break _}d=d+n|0;x[f>>2]=d;c=c+1|0;continue}break}l=c}if(!Fh(f)){break Y}n=f+68|0;d=0;c=0;while(1){if((c|0)==(l|0)){un(i);c=ap(i,f);x[c+4>>2]=0;x[c+8>>2]=x[c>>2];w[c+34>>1]=z[c+34>>1]|2;break Y}r=x[f+20>>2]+d|0;s=x[i+20>>2];g=Hd(x[h>>2],c);yc(r,s+x[g>>2]|0,x[g+4>>2]);x[g>>2]=d;if(c-10>>>0>=4294967287){T=yb(n,c-1|0),V=d,x[T>>2]=V}c=c+1|0;d=x[g+4>>2]+d|0;continue}}fb=m+112|0;c=z[_b(x[t>>2],k)>>1];if(c){wC(i,(D(c,104)+a|0)+484380|0,0,x[i>>2],0)}c=Hd(x[o>>2],k);T=e,V=wb(x[c>>2]),x[T+228>>2]=V;d=wb(x[c+4>>2]);while(1){c=x[e+228>>2];if(!Ib(c,d)){break X}l=z[c+8>>1];if(l){wC(i,(D(l,104)+a|0)+484380|0,x[c>>2],x[c+4>>2],1)}l=z[c+10>>1];if(l){wC(i,(D(l,104)+a|0)+484380|0,x[c>>2],x[c+4>>2],0)}il(e+228|0);continue}}j=j+1|0;continue}}PW(E);f=1;break b}x[31725]=0;P(185,b|0,D(h,z[e+238>>1])|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){break A}break z}d=d+1|0;continue}break}i=N()|0;PW(E);break e}i=N()|0;break e}i=N()|0;break e}i=N()|0;break e}i=N()|0;break f}i=N()|0;break e}i=N()|0;break e}i=N()|0;break e}f=0;while(1){if(d>>>0<=(f&65535)>>>0){break g}x[31725]=0;i=R(283,b|0)|0;k=x[31725];x[31725]=0;$:{if((k|0)==1){break $}x[31725]=0;x[e+240>>2]=i;i=R(283,b|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break $}x[31725]=0;x[e+244>>2]=i;O(709,l|0,e+240|0);i=x[31725];x[31725]=0;if((i|0)==1){break $}f=f+1|0;continue}break}i=N()|0;break f}ub(h);g=g+1|0;continue}break}ub(h)}md(t);OW(o);break d}i=N()|0;Eb(e+8|0)}Q(i|0);p()}f=0}md(t);OW(o)}fb=e+480|0;return f|0}function toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-576|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+496|0;l:{if(!yD(b,g)){break l}if(!MV(g)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(LV(g),hb))){break l}if(!c){e=1;break l}Bd(a,4);gg(a);v[a+1074368|0]=4;l=Fb(d+484|0);k=d+534|0;m:{if(!(kd(k,18410,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){r=41144;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=fu(d+513|0,0,20)?1154:34;break m}r=41144;if(!kd(k,18389,20)){e=1;break m}e=d+104|0;vi(e,3,k);x[31725]=0;g=d+192|0;S(371,g|0,4,e|0);e=x[31725];x[31725]=0;n:{if((e|0)!=1){Ab(l,g);tb(g);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break n}e=1048;break m}b=N()|0;break a}if(!kd(k,18137,12)){e=16;if((y[d+546|0]|y[d+547|0]<<8|(y[d+548|0]<<16|y[d+549|0]<<24))==538976288&(y[d+550|0]|y[d+551|0]<<8|(y[d+552|0]<<16|y[d+553|0]<<24))==538976288){break m}v[a+1074368|0]=5;break m}if(!kd(k,11657,20)){e=48;break m}if(!kd(k,25456,15)){x[31725]=0;g=P(269,a+1074312|0,54)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;P(269,g|0,51)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}r=41136;e=16;break m}o:{if(kd(k,25472,14)){if(kd(k,25487,14)){break o}}x[31725]=0;g=P(269,a+1074312|0,57)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;P(269,g|0,51)|0;g=x[31725];x[31725]=0;e=16;if((g|0)!=1){break m}break b}e=kd(k,18225,11)?16:256}f=d+104|0;u=d+513|0;vi(f,3,u);x[31725]=0;g=d+192|0;O(220,g|0,f|0);m=x[31725];x[31725]=0;p:{q:{r:{s:{t:{if((m|0)!=1){Ab(a+1298308|0,g);tb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;H=a,I=z[Nc(g,f)>>1],w[H+480192>>1]=I;g=y[d+572|0]|y[d+573|0]<<8;if(g){x[a+480196>>2]=g}g=y[d+574|0]|y[d+575|0]<<8;if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=g<<4&16|g<<3&32768;f=x[a+484360>>2];m=y[a+484376|0];x[31725]=0;aa(350,Xb(f,m)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);f=x[31725];x[31725]=0;if((f|0)==1){break b}f=g>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;W(764,Xb(e,g)|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}}x[31725]=0;P(151,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31725]=0;S(765,b|0,d+496|0,a|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}}v[d+483|0]=0;B=c&2;F=d+122|0;o=d+225|0;m=Nb(d+468|0);s=1;g=-1;while(1){e=s&65535;if(e>>>0>z[a+480192>>1]){if(!(!(f&2)|t&255)){f=fu(u,0,20)?f|16:f}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31725]=0;S(765,b|0,d+496|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break q}}if(!B){break r}e=1;while(1){c=e&65535;if(c>>>0>z[a+480190>>1]){break r}o=x[m>>2];x[31725]=0;U(217,yb(o,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31725]=0;i=R(153,b|0)|0;j=x[31725];x[31725]=0;u:{v:{if((j|0)!=1){Gh(b,4);x[31725]=0;S(766,b|0,d+192|0,(i?i:263)|0);i=x[31725];x[31725]=0;if((i|0)==1){break s}w:{if((f|0)==1){i=x[d+192>>2];if((i|0)!=263){f=16;if((i|0)!=245){break w}x[a+1074308>>2]=16777381;x[31725]=0;f=P(1,d+180|0,13445)|0;i=x[31725];x[31725]=0;if((i|0)!=1){Ab(l,f);tb(f);f=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31725]=0;f=P(1,d+168|0,13336)|0;i=x[31725];x[31725]=0;if((i|0)!=1){Ab(l,f);tb(f);f=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}i=x[d+192>>2];if(!(!(f&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(i|0)!=263)){f=f|16;break w}if(!(!(f&256)|(i|0)==29)){f=f&-257;break w}if(!(f&160)){break w}f=(i|0)==33?f:0}x[31725]=0;i=U(253,a|0,e|0,0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}if(!i){break u}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[31725]=0;O(767,d+192|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((g|0)==-1){g=e;break x}if(!(f&32)|(e|0)==(g|0)){break x}f=f&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31725]=0;j=y[d+439|0];h=y[d+435|0]|y[d+436|0]<<8;n=y[d+434|0];q=y[d+433|0];S(768,d+156|0,a|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break t}f=j|(h|(n|q))?f&-4:f;i=x[i>>2]+236|0;e=12;j=x[d+156>>2];h=Zc(j,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Nf(m)}e=0;x[31725]=0;i=P(769,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;j=x[31725];x[31725]=0;if((j|0)!=1){break z}b=N()|0;break y}if(h>>>0>z[_b(i,e)>>1]){n=z[_b(j,z[_b(i,e)>>1])>>1];H=_b(i,e),I=n,w[H>>1]=I}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){j=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=j>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=j>>>0){break v}n=y[yb(x[m>>2],e)+3|0];j=x[yb(x[i>>2],e)>>2];x[31725]=0;h=d+72|0;S(187,h|0,b|0,((n|0)==10?(j+1>>>1|0)+16|0:j)|0);j=x[31725];x[31725]=0;if((j|0)!=1){j=ic(d+104|0,h);ub(h);h=x[d+156>>2];if(!(!B|Zc(h,x[d+160>>2])>>>0<=e>>>0)){n=z[_b(h,e)>>1];h=yb(x[m>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[31725]=0;x[d+68>>2]=h;x[d+8>>2]=h;h=ba(770,(D(n,104)+a|0)+484380|0,d+8|0,j|0,d+483|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break E}C=h^1|C}ub(j);e=e+1|0;j=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(j);break A}x[31725]=0;q=d+104|0;O(771,b|0,q|0);j=x[31725];x[31725]=0;if((j|0)==1){break B}j=d+72|0;h=y[d+118|0];F:{if(!(h&48|y[d+121|0]!=173)){Xc(j,8,1,0,10);break F}Xc(j,h&16?16:8,h&32?3:1,0,2)}x[31725]=0;O(772,m|0,j|0);h=x[31725];x[31725]=0;if((h|0)!=1){H=yb(x[i>>2],e),I=x[d+104>>2],x[H>>2]=I;G=y[d+121|0];h=x[d+156>>2];if(Zc(h,x[d+160>>2])>>>0>e>>>0){n=z[_b(h,e)>>1];x[31725]=0;h=(D(n,104)+a|0)+484380|0;O(773,q|0,h|0);q=x[31725];x[31725]=0;if((q|0)==1){break D}v[h+38|0]=y[o+202|0];v[h+39|0]=y[o+203|0];v[h+40|0]=y[o+204|0];v[h+41|0]=y[o+205|0];h=d+92|0;Yk(h,3,F);x[31725]=0;O(220,j|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break C}zc(((n<<5)+a|0)+946304|0,j);tb(j);f=(y[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}t=t|G;e=e+1|0;E=y[xf(x[m+4>>2])+3|0]==10|E;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}uc(i)}md(d+156|0);break c}b=N()|0;break c}uc(i);md(d+156|0)}s=s+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(C&1)){break G}x[31725]=0;c=P(1,d+104|0,16662)|0;e=x[31725];x[31725]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31725]=0;S(387,e|0,2,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31725]=0;c=P(414,b|0,5558)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}if(c){x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}x[31725]=0;V(338,a+1298332|0,b|0,c|0,0);c=x[31725];x[31725]=0;if((c|0)==1){break q}f=f|16}x[31725]=0;o=P(414,b|0,14118)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(o){x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}x[31725]=0;e=a+901404|0;S(774,b|0,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}zD(e);f=f|16}x[31725]=0;c=P(414,b|0,13890)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(!c){break p}x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;H=d,I=ek(x[a+484344>>2],x[a+484348>>2]),w[H+72>>1]=I;c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break p}x[31725]=0;i=d+192|0;O(581,b|0,i|0);j=x[31725];x[31725]=0;I:{if((j|0)==1){break I}j=x[a+484344>>2];x[31725]=0;O(582,Wb(j,e)|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31725]=0;c=P(414,b|0,13895)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break J}x[31725]=0;S(426,b|0,((e<<5)+a|0)+480289|0,20);i=x[31725];x[31725]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31725]=0;S(427,d+192|0,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}f=(c|0)==x[b+8>>2]?f:f|16}K:{if(!(f&16)){break K}if(f&4){x[a+1074308>>2]=17367040;x[31725]=0;c=P(1,d+192|0,14679)|0;e=x[31725];x[31725]=0;if((e|0)!=1){Ab(l,c);tb(c);break K}b=N()|0;break c}if(!(f&2)){break K}x[a+1074308>>2]=18219008;x[31725]=0;c=P(1,d+192|0,14864)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}Ab(l,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[31725]=0;c=U(394,d+72|0,d+542|0,12)|0;e=x[31725];x[31725]=0;if((e|0)==1){break R}x[31725]=0;e=d+156|0;S(260,e|0,1,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break Q}x[31725]=0;f=R(775,e|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break P}x[a+1074308>>2]=f;tb(e);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;Pv(a+1074312|0)}c=f&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!o){rr(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31725]=0;U(268,a+1074312|0,4,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}}if(!Ad(x[l+4>>2],y[l+11|0])){break L}if(!(f&256)|t&255|g+1>>>0>1){break M}x[31725]=0;c=P(1,d+156|0,8292)|0;g=x[31725];x[31725]=0;if((g|0)==1){break N}Ab(l,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31725]=0;c=P(1,d+156|0,12069)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(l,c);tb(c);break L}b=N()|0;break c}x[31725]=0;c=P(1,d+156|0,9750)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}Ab(l,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31725]=0;c=P(437,a|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}v[d+67|0]=c}x[31725]=0;ba(438,a|0,b|0,1,d+67|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31725]=0;c=P(1,d+52|0,18237)|0;b=x[31725];x[31725]=0;if((b|0)==1){break da}g=x[a+1074308>>2];x[31725]=0;b=d+40|0;O(776,b|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break ca}x[31725]=0;g=d+92|0;S(2,g|0,c|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break ba}Ab(l,g);tb(g);tb(b);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];f=x[a+484348>>2];if(!He(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31725]=0;W(777,Xb(c,b)|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}f=x[a+484348>>2];b=x[a+484344>>2]}if(He(b,f,255)){break ga}RC(Xb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31725]=0;c=d+40|0;O(778,c|0,4102);b=x[31725];x[31725]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31725]=0;x[d+24>>2]=b&255;g=d+28|0;O(446,g|0,d+24|0);b=x[31725];x[31725]=0;if((b|0)==1){break _}x[31725]=0;b=d+92|0;V(432,b|0,c|0,d+12|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break Z}e=Ab(a+1298344|0,b);tb(b);tb(g);Eb(c);f=Ab(a+1298368|0,l);H=a+1298404|0,I=x[Fc(b,x[(x[a+1074308>>2]?41136:r)>>2])>>2],x[H>>2]=I;if(!y[d+483|0]){break U}Ab(a+1298380|0,e);x[31725]=0;b=P(1,b|0,15284)|0;k=x[31725];x[31725]=0;if((k|0)==1){break X}Ab(e,b);tb(b);x[31725]=0;b=P(1,c|0,10101)|0;c=x[31725];x[31725]=0;if((c|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31725]=0;b=P(1,g|0,10102)|0;c=x[31725];x[31725]=0;if((c|0)==1){break V}Ab(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31725]=0;b=P(1,d+92|0,10102)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}Ab(a+1298356|0,b)}tb(b);e=1;if(E&1){x[31725]=0;a=P(1,d+12|0,17141)|0;b=x[31725];x[31725]=0;if((b|0)==1){break k}x[31725]=0;P(76,f|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break j}tb(a)}uc(m);tb(l)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}uc(m);break a}b=N()|0}tb(l);Q(b|0);p()}function zR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if(z[x[x[a+48>>2]+12>>2]+480188>>1]!=z[x[x[b+48>>2]+12>>2]+480188>>1]){break a}if((a|0)!=(b|0)){g=fb-16|0;fb=g;f=x[b>>2];d=x[b+4>>2];c=Ok(f,d);b:{if(bw(a)>>>0>=c>>>0){e=d;h=x[a>>2];i=Ok(h,x[a+4>>2]);k=i>>>0>=c>>>0;if(!k){x[g+12>>2]=f;wR(g+12|0,i);e=x[g+12>>2]}f=uA(f,e,h);if(!k){uu(a,e,d,c-Ok(x[a>>2],x[a+4>>2])|0);break b}sD(a,f);break b}AR(a);NZ(a,oD(a,c));uu(a,f,d,c)}fb=g+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];yR(a+24|0,b+24|0);ow(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=wb(x[a>>2]);x[l+12>>2]=c;m=wb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];f=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((f|0)==(h|0)){break c}e=y[c+3|0];d:{e:{if((f|0)!=16){break e}i=y[c+5|0];if(!((e|0)!=19|(i|0)!=144)){v[c+3|0]=0;f=1;break d}d=5;f=1;if((e|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(e|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((e|0)!=46){d=e;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}n=(f|0)==32|(f|0)==16777216|(f|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){e=9;j=1;i=LD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;e=9;i=LD(h);if((d&255)!=9){break k}if((f|0)!=2){break h}e=y[c+5|0];if((e|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){e=d;break h}d=x[i+84>>2];if($i(d,32)){break i}e=31;if(!$i(d,31)){break i}v[c+3|0]=31;break h}o=c,p=yi(e<<1),v[o+5|0]=p;break g}e=32}l:{if((f|0)==16777216){d=y[c|0];m:{if(!Vg(d)){d=e;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!$i(j,d)){d=$i(j,31)?31:0}w[g+4>>1]=999;o=g,p=Kj(e,y[c+5|0]),w[o+110>>1]=p;o=c,p=(D(z[Nc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[o+5|0]=p;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{e=d&255;switch(e-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((e|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;e=-128-j|0;d=3;break r}e=128;if((j|0)==-128){break q}v[c+3|0]=2;e=j^-128;d=2}v[c+5|0]=e;if((e&255)>>>0>30){break q}v[c+5|0]=e+1>>>1|224;break g}v[g+4|0]=(e&255)+7>>>3;v[g+110|0]=15;o=c,p=y[Rb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break g}d=e;s:{switch(f-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}qw(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}tg(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];e=(d&240)-16>>>4|0;if(e>>>0>9){break f}if(!(1<<e&880)){if(!e){break t}if((e|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;o=c,p=y[Rb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break f}v[g+4|0]=14;v[g+110|0]=d;o=c,p=y[Rb(g+4|0,g+110|0)|0]<<4|15,v[o+5|0]=p;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!n){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((e|0)!=29){break f}d=y[c+5|0];e=d&15;if((e|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch((d&240)-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}e=y[c+5|0];j=e&15;if(!((j|0)==15&e>>>0>=16)&(!j|(e&240)!=240)){break O}e=11;$:{switch((d&255)-6|0){case 1:e=8;case 0:v[c+2|0]=e;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];e=d&15;if(!((e|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!e|(d&240)!=240){break f}v[c+3|0]=19;v[c+5|0]=e|176;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|16;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|16;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|32;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|32;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!e|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(e){v[c+5|0]=240;break f}if(d>>>0>=16){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((f|0)!=16777216&(f|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];e=d&240;if((e|0)!=144){if((e|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;o=c,p=y[Rb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}da:{ea:{fa:{ga:{ha:{ia:{ja:{if(!((f|0)!=16777216&(f|0)!=32)){if((h|0)!=4){break ja}d=y[c+3|0];if((d|0)==23){break ia}if((d|0)!=5){break ga}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break ha}if((f|0)!=4){break ja}ka:{la:{switch(h-1|0){default:if((h|0)==32|(h|0)==16777216){break ka}break;case 1:case 2:break la;case 0:case 3:break ha}}d=y[c+3|0];break ea}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break ja}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;o=c,p=y[Rb(g+4|0,g+110|0)|0]|d&240,v[o+5|0]=p;break ja}v[g+4|0]=64;o=c,p=y[Rb(g+4|0,c+5|0)|0]<<1,v[o+5|0]=p}ma:{switch(h-1|0){case 0:case 3:break ha;default:break ma}}d=y[c+3|0];break fa}v[g+4|0]=128;o=c,p=y[Rb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}d=y[c+3|0]}na:{switch((d&255)-16|0){case 0:v[g+4|0]=31;o=c,p=y[Rb(c+5|0,g+4|0)|0],v[o+5|0]=p;d=16;break fa;case 1:break na;default:break fa}}v[g+4|0]=32;o=c,p=y[ef(c+5|0,g+4|0)|0],v[o+5|0]=p;d=17}oa:{if((f|0)!=1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:break oa;case 0:case 1:case 9:break sa;case 5:break ta;case 4:break ua;default:break va}}switch(e-19|0){case 1:break qa;case 0:break ra;default:break oa}}d=6;if(y[c+5|0]){break oa}e=4;break pa}d=7;if(y[c+5|0]){break oa}e=5;break pa}if(y[c+5|0]){break oa}e=0;break pa}d=19;j=y[c+5|0];e=(j<<4|(j<<24)+1610612736>>>28)&255;if(!(e>>>0>8|!(1<<e&387))){v[c+3|0]=0;d=0}e=0;if(j>>>0>239){break pa}break oa}d=20;e=0;if(y[c+5|0]<240){break oa}}v[c+3|0]=e;d=e}if((h|0)!=1){break ea}wa:{xa:{ya:{za:{Aa:{if(Nl(y[c|0])){v[c|0]=0;Ba:{Ca:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 0:break Aa;case 4:break Ba;default:break Ca}}if(e){break wa}v[c+5|0]=0;d=13;v[c+3|0]=13;break wa}f=y[c+5|0];if((f&240)!=208){break ya}v[c+5|0]=f&15|192;break wa}Da:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 4:break za;case 0:break Aa;default:break Da}}if(!e){break xa}break wa}d=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break wa}f=y[c+5|0]}if((f&255)>>>0<240){break wa}v[c+3|0]=0}d=0;Ea:{switch(y[c+2|0]-1|0){case 0:d=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break wa;case 1:d=9;v[c+3|0]=9;e=y[c+4|0];v[c+5|0]=e>>>0>=64?-1:e<<2;break wa;case 3:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break wa;case 2:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break wa;case 5:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break wa;case 4:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break wa;case 12:d=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break wa;case 11:d=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break wa;case 10:d=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break wa;case 7:d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break wa;case 6:break Ea;default:break wa}}d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0;break da}if(!(d&255|(h|0)!=2)){d=0;Fa:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];d=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;d=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;d=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;d=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;d=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];d=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;d=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;d=29;break da;case 7:break Fa;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];d=29;break da}if((h|0)==4){f=y[c|0];if(!(f|(y[c+5|0]&240)!=208|(d&255)!=19)){f=0;v[c+5|0]=0;v[c+3|0]=0;d=0}Ga:{if(Nl(f)){v[c+1|0]=0;e=d&255;if(!e){break Ga}if((e|0)!=19){break da}d=19;e=y[c+5|0];if((e&240)!=208){break da}d=25;v[c+3|0]=25;v[c|0]=0;v[c+5|0]=e&15;break da}if(d&255){break da}}Ha:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ha;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42208|0];d=4;break da}if((h|0)!=16777216&(h|0)!=32){break da}Ia:{if(d&255|((f|0)==32|(f|0)==16777216)){break Ia}d=0;Ja:{Ka:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;e=y[c+4|0]<<4;d=29;break Ja;case 3:v[c+3|0]=29;e=y[c+4|0];d=29;break Ja;case 0:v[c+3|0]=5;e=y[c+4|0]<<4;d=5;break Ja;case 4:break Ka;default:break Ia}}v[c+3|0]=4;e=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=e}e=y[c+2|0];if(e>>>0>15|!(1<<e&47480)){break da}v[g+4|0]=9;o=c,p=y[Rb(c+4|0,g+4|0)|0],v[o+4|0]=p}La:{if(y[c+2|0]!=15){break La}if(Vv(x[i+88>>2],15)){break La}e=d&255;if(!(!e|(e|0)==10)){if($i(x[i+84>>2],e)){break La}}v[c+2|0]=0;v[c+3|0]=10;Ma:{Na:{f=y[c+1|0];if(!f){break Na}d=y[c+5|0];if(z[k+480192>>1]>=f>>>0){h=y[c|0];Oa:{if(!Tc(h)){break Oa}j=x[(k+(f<<2)|0)+900380>>2];if(!j){break Oa}f=z[_b(j+236|0,h-1|0)>>1]}if(!(f&65535)){break Na}}f=f&65535;if(f>>>0>z[k+480190>>1]){break Na}h=y[c+4|0];Uv(g+4|0);if(h>>>0>9){break Na}d=(e|0)==10?d:0;e=ti(k,f);f=y[c+4|0];if(!f){e=nva(x[e>>2],0,d&255,0);d=hb;e=e+32768|0;d=e>>>0<32768?d+1|0:d;d=yi(Bc((d&65535)<<16|e>>>16,d>>>16|0));break Ma}d=yi((x[yb(e+68|0,f-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break Ma}d=y[c+4|0]<<3}v[c+5|0]=d;d=y[c+3|0]}Pa:{Qa:{e=d&255;switch(e-42|0){case 0:case 2:break Qa;default:break Pa}}if($i(x[i+84>>2],e)){break Pa}d=10;v[c+3|0]=10}f=y[c|0];Ra:{if(f>>>0>=y[i+8|0]){e=1;if(f>>>0<=y[i+9|0]){break Ra}}if(Nl(f)){Sa:{switch(f-253|0){case 1:e=y[i+70|0]!=0;break Ra;case 2:e=y[i+71|0]!=0;break Ra;case 0:e=y[i+72|0]!=0;break Ra;default:break Sa}}e=x[i>>2]==16777216;break Ra}e=!f}if(!e){v[c|0]=0}if(!$i(x[i+84>>2],d&255)){v[c+3|0]=0}if(Vv(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[vg(l+12|0)>>2];continue}}fb=l+16|0;return a}function Lka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=E(0),I=E(0),J=0,K=0;h=fb-32|0;fb=h;c=x[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){dg(a+1074312|0,0)}c=h+12|0;i=a+1074312|0;Kb(c,i,0);b=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);d=x[a+480180>>2];Kb(c,i,0);n=(d&16777248)!=0&b;B=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);C=x[a+480180>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}c=1;while(1){b:{b=c&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[h+12>>2]=D(y[b+20|0],100)>>>6;x[h+24>>2]=100;J=b,K=x[Gb(h+12|0,h+24|0)>>2],v[J+20|0]=K;if(A[a+1074308>>2]>18350079&n){break b}d=v[b+26|0];v[b+26|0]=((d>>31|1)+d|0)/2;if(A[a+1074308>>2]>18285313&n){break b}AD(Zh(b,2),x[a+480180>>2]);d=x[a+1074308>>2];c:{if(d>>>0<18284544){break c}if(d>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Rj(y[b+31|0])){break c}Lb(i,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(i,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&n){break d}c=z[a+480190>>1]+1&65535;d=c>>>0<=1?1:c;b=1;while(1){if((b|0)==(d|0)){break d}c=D(b,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;continue}}c=a+901404|0;d=c+288|0;b=CV(d);while(1){if((b|0)==(d|0)){e:{d=c+800|0;c=sC(d);while(1){if((c|0)==(d|0)){break e}BV(d);d=d+32|0;continue}}}else{BV(d);d=d+32|0;continue}break}c=x[a+1074308>>2];break a}c=c+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break f}b=z[a+480192>>1]+1&65535;g=b>>>0<=1?1:b;d=0;b=1;while(1){if((b|0)==(g|0)){if(!d){break f}Lb(i,3,1);c=x[a+1074308>>2]}else{e=x[((b<<2)+a|0)+900380>>2];if(!(!e|!y[e+31|0])){v[e+33|0]=13;d=1}b=b+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break g}Kb(h+12|0,i,0);if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){Kb(h+24|0,i,1);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break g}}c=z[a+480192>>1]+1&65535;d=c>>>0<=1?1:c;b=1;while(1){if((b|0)==(d|0)){break g}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}f=x[a+480180>>2];h:{i:{if(!(f&16777252)){break i}c=a+906300|0;e=Ck(c);b=c;while(1){if((b|0)==(e|0)){break i}d=b;b=b+160|0;if(!Ti(x[d+16>>2],x[d+20>>2])){continue}break}s=1;d=x[a+1074308>>2];if(d>>>0>19007232){break h}while(1){if((c|0)!=(e|0)){d=h+12|0;b=fb-32|0;fb=b;g=b+8|0;k=c+80|0;kS(g,k);x[31725]=0;f=b+20|0;S(125,f|0,22,g|0);m=x[31725];x[31725]=0;j:{k:{l:{if((m|0)!=1){x[31725]=0;S(246,d|0,0,f|0);m=x[31725];x[31725]=0;if((m|0)==1){break l}Qb(f);tb(g);fb=b+32|0;break j}a=N()|0;break k}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}lw(k,d);c=c+160|0;tb(d);continue}break}f=x[a+480180>>2]}d=x[a+1074308>>2]}m:{n:{o:{p:{q:{if((f|0)!=4){break q}if(d>>>0<19007257){break p}if(y[a+1074368|0]!=4|d>>>0>19071235){break q}SA(a,5);d=x[a+1074308>>2]}if(d>>>0>19202054){break o}c=19202048;if((d|0)==19202048){break n}}c=z[a+480192>>1]+1&65535;g=c>>>0<=1?1:c;c=1;while(1){if((c|0)==(g|0)){break o}e=x[((c<<2)+a|0)+900380>>2];r:{if(!e|!y[e+20|0]|!y[e+31|0]){break r}b=e+236|0;f=zr(b);while(1){if((b|0)!=(f|0)){k=z[b>>1];b=b+2|0;if(!k){continue}break r}break}v[e+20|0]=0}c=c+1|0;continue}}c=d;if(c>>>0>19267583){break m}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break m}d=x[((b<<2)+a|0)+900380>>2];s:{if(!d){break s}c=v[d+26|0];v[d+26|0]=((c>>31|1)+c|0)/2;c=x[a+1074308>>2];if(c>>>0>18350079&n){break s}v[d+19|0]=y[d+19|0]+3>>>2}b=b+1|0;continue}}t:{if(c>>>0>19398673){break t}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break t}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){b=b+1|0;continue}else{Lb(i,94,1);c=x[a+1074308>>2]}break}}u:{if(c>>>0>19399427){break u}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break u}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){b=b+1|0;continue}else{Lb(i,101,1);c=x[a+1074308>>2]}break}}v:{if(c>>>0>19923027){break v}d=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break v}c=D(c,104)+a|0;if(!je(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Lb(i,116,1)}break}}c=fb-16|0;fb=c;w[h+4>>1]=0;x[h>>2]=a;Kb(c+8|0,a+1074312|0,0);J=h,K=Hb(x[x[c+8>>2]>>2],x[c+12>>2]),v[J+6|0]=K;fb=c+16|0;c=x[h>>2];u=x[h+4>>2];e=fb-32|0;fb=e;b=a+484344|0;f=wb(x[b>>2]);x[e+28>>2]=f;F=wb(x[b+4>>2]);while(1){if(Ib(f,F)){b=wb(x[f>>2]);G=wb(x[f+4>>2]);x[e+16>>2]=c;x[e+20>>2]=u;x[e>>2]=c;x[e+4>>2]=u;m=fb-16|0;fb=m;x[m+12>>2]=b;while(1){if(Ib(b,G)){t=z[e+4>>1];d=t+1|0;w[e+4>>1]=d;f=x[e>>2];w[e+4>>1]=z[f+480188>>1]>(d&65535)>>>0?d:0;w:{if(Vg(y[b|0])){break w}g=x[f+1074308>>2];x:{k=x[f+480180>>2];y:{z:{if((k|0)==2){if(g>>>0>18415615){break z}if(y[b+3|0]!=23){break y}Qf(b+5|0,64);break y}A:{if(k&16777248){B:{C:{if(g>>>0>=18285314){if(y[e+6|0]){break C}d=0;f=0;if(g>>>0>18874367){break B}}D:{switch(y[b+3|0]-20|0){case 3:Qf(b+5|0,128);break C;case 0:break D;default:break C}}d=y[b+5|0];if((d|0)!=208){if((d|0)!=192){break C}v[b|0]=254;v[b+3|0]=0;break C}v[b+3|0]=0}E:{F:{G:{if(g>>>0>=18350080){if(y[e+6|0]){break G}d=0;f=0;if(g>>>0>18874367){break B}}f=y[b+3|0];if(f>>>0>29){break F}d=1;if(!(1<<f&536873152)){break F}break E}d=0;f=0;if(g>>>0>18874367){break B}f=y[b+3|0]}d=0}f=(f|0)==24|(f|0)==22}H:{if(!(d|f)){break H}f=y[b+5|0];d=f&15;if(!d|(d|0)==15){break H}f=f&240;if(!f|(f|0)==240){break H}v[b+5|0]=y[b+3|0]==24?f:d}I:{if((g|0)==19005440|g>>>0>19005699){break I}d=z[x[e>>2]+480192>>1];if(y[e+6|0]|(!d|d>>>0>=y[b+1|0])){break I}v[b+4|0]=0;v[b+2|0]=1}if(y[b+3|0]!=18|y[b+5|0]!=17){break z}if(g>>>0>19468801){break x}if(!Ob(x[e>>2]+1074312|0,22)|y[x[e>>2]+480208|0]&4){break z}d=b+5|0;break A}if((k|0)!=4){break z}d=!y[e+6|0];J:{if((d|g>>>0<18285314)&g>>>0<=18874367){break J}if(g>>>0>19137025){break x}if(y[b+3|0]!=23|y[b+5|0]<65){break J}v[b+3|0]=0}K:{L:{M:{if(!(!(d&g>>>0<18874368)&g>>>0>=18415616)){d=y[b+3|0];f=y[b+2|0];if((d|0)!=10|(f|0)!=11){break M}d=0;v[b+3|0]=0;break K}if(g>>>0>18874639){break L}d=y[b+3|0];f=y[b+2|0]}if((f|0)!=11|(d|0)!=4){break K}f=y[b+4|0];if(!(f|y[e+6|0])){d=4;break K}d=4;o=y[b+5|0];if(!o){break K}v[b+2|0]=0;J=b,K=_v(o+(f<<4)|0),v[J+5|0]=K;break K}if(g>>>0>19007240){break x}d=y[b+3|0]}if(y[b+5|0]|(d|0)!=16){break z}d=b+3|0}v[d|0]=0}if(g>>>0>18874367){break x}}d=y[b+3|0];f=y[b+5|0]&240;N:{O:{if((d|0)!=28|(f|0)!=96){o=0}else{if(!y[e+6|0]|(k|0)!=4){break O}o=g>>>0<18350080}if(!(o|(d|0)==20&(f|0)==96)){break N}}d=D(t,-6)+b|0;while(1){if(b>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}d=y[b+3|0]}if((d|0)!=20|(f|0)!=224){break x}d=D(t,-6)+b|0;while(1){if(b>>>0<=d>>>0){break x}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=y[b+2|0];if(!((d|0)!=8|g>>>0>19333174|(g|0)==19333120)){g=y[b+4|0];d=y[b+3|0];if(!(!g|(d|0)!=7)){v[b+3|0]=11;break w}P:{Q:{switch(d-5|0){default:if((d|0)!=26){break w}break;case 1:break w;case 2:break P;case 0:break Q}}f=y[b+5|0];if(!(f&15)){v[b+2|0]=0;v[b+3|0]=5;v[b+5|0]=f|g&15;break w}R:{switch(d-5|0){case 1:break w;case 0:case 2:break P;default:break R}}if((d|0)!=26){break w}}v[b+2|0]=0;break w}S:{if(!((k|0)==16777216|(d|0)!=15)){d=y[b+3|0];if(d){break S}v[b+2|0]=0;v[b+3|0]=10;v[b+5|0]=y[b+4|0]<<3;break w}if((d|0)!=15){break w}d=y[b+3|0]}if((d&255)!=10|g>>>0>19922963){break w}if(y[b+4|0]?y[b+5|0]:1){v[b+2|0]=0;break w}v[b+3|0]=0}b=x[vg(m+12|0)>>2];continue}break}b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=b;fb=m+16|0;f=x[am(e+28|0)>>2];continue}else{fb=e+32|0}break}T:{c=A[a+1074308>>2]<19267584;if(c&n){b=40304;while(1){if((b|0)==40648){break T}c=x[a+1074308>>2];d=x[b+4>>2];Lb(i,x[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(c&((C|0)==4&B))){break T}b=40656;while(1){if((b|0)==40896){break T}Lb(i,x[b>>2],A[a+1074308>>2]>=A[b+4>>2]);b=b+8|0;continue}}U:{d=x[a+480180>>2];if(d&16777248){b=40896;while(1){if((b|0)==40968){break U}c=x[a+1074308>>2];d=x[b+4>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(c>>>0<=e>>>0|c>>>0>=d>>>0))){dg(i,x[b>>2])}b=b+8|0;continue}}b=41040;c=40976;V:{switch(d-2|0){case 2:while(1){if((c|0)==41040){break U}if(A[a+1074308>>2]<A[c+4>>2]){dg(i,x[c>>2])}c=c+8|0;continue};case 0:break V;default:break U}}while(1){if((b|0)==41136){break U}if(A[a+1074308>>2]<A[b+4>>2]){dg(i,x[b>>2])}b=b+8|0;continue}}b=x[a+1074308>>2];if(!(x[a+480180>>2]!=4|b>>>0>18415615)){Lb(i,98,1);b=x[a+1074308>>2]}if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Kb(h+12|0,i,c);dg(Lb(i,b+86|0,Hb(x[x[h+12>>2]>>2],x[h+16>>2])),c);b=b+1|0;continue}break}b=x[a+1074308>>2]}c=8;W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}c=6;if((b|0)==18874368){break W}}Lb(i,c,1)}c=x[a+1074308>>2];X:{if(y[a+480208|0]&16){if(c>>>0<=19136511){dg(i,7);break X}if(!(x[a+480180>>2]&16777248)|c>>>0>19267583){break X}Lb(i,7,1);break X}if((c|0)==19922944|c>>>0>19922997){break X}dg(i,7)}Kb(h+12|0,i,31);Y:{if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){break Y}c=x[a+1074308>>2];if(c>>>0<19071234|c>>>0>19398722){break Y}d=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break Y}Z:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break Z}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break Z}Lb(i,97,1);break Y}b=b+1|0;continue}}c=x[a+480180>>2];_:{if(!(c&16777218)){break _}d=z[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break _}b=b+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}$:{aa:{ba:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[a+1074308>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Lb(i,109,1)}b=x[a+1074308>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}dg(i,111);b=x[a+1074308>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Lb(i,108,1);break _}if((c|0)==2){break _}dg(i,108)}ca:{c=x[a+1074308>>2];if(c-19333186>>>0<=589827){if(!s){break ca}b=a+906300|0;c=Ck(b);while(1){if((b|0)!=(c|0)){da:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break da}if((Sc(x[b+4>>2],x[b+8>>2])|0)!=32){break da}d=Dc(h+12|0,16862);lw(b+80|0,d);tb(d)}b=b+160|0;continue}break}c=x[a+1074308>>2]}e=!s;ea:{if(e|c>>>0>19923027){break ea}g=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>g>>>0){break ea}d=x[((d<<2)+a|0)+900380>>2];if(!d|y[d+30|0]!=1&z[d+28>>1]!=1){b=b+1|0;continue}else{Lb(i,121,1);c=x[a+1074308>>2]}break}}b=!s;if(!(e|c>>>0>19988488)){Lb(i,117,1);c=x[a+1074308>>2]}if(c-19333120>>>0>591359|b){break ca}a=a+906300|0;d=Ck(a);while(1){if((a|0)==(d|0)){break ca}fa:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break fa}c=x[a+4>>2];if((Sc(c,x[a+8>>2])|0)!=24){break fa}H=Pd(E(E(E((l(2,y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));I=Pd(E(E(E((l(2,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));b=(q(H),j(2));v[c+12|0]=b;v[c+13|0]=b>>>8;v[c+14|0]=b>>>16;v[c+15|0]=b>>>24;c=x[a+4>>2];b=(q(I),j(2));v[c+16|0]=b;v[c+17|0]=b>>>8;v[c+18|0]=b>>>16;v[c+19|0]=b>>>24}a=a+160|0;continue}}fb=h+32|0}function IP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-32|0;fb=j;a:{b:{c:{d:{e:{f:{if(Ld(b,22267)){Fb(a);break f}if(Ld(b,9893)){b=fb-96|0;fb=b;g=Fb(a);x[31725]=0;W(130,b- -64|0);a=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31725]=0;x[b+40>>2]=0;a=b+52|0;c=b+40|0;O(1123,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break C}x[31725]=0;d=P(842,g|0,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}tb(a);x[31725]=0;d=P(991,d|0,16781)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}x[31725]=0;x[b+40>>2]=7;O(1123,a|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break z}x[31725]=0;d=P(842,d|0,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}tb(a);x[31725]=0;d=P(991,d|0,16781)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}x[31725]=0;x[b+40>>2]=4;O(1123,a|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break x}x[31725]=0;d=P(842,d|0,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break w}tb(a);x[31725]=0;f=P(991,d|0,15683)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}d=Nb(a);a=x[b+76>>2];if(a){x[31725]=0;x[b+16>>2]=a;a=b+28|0;O(1123,a|0,b+16|0);h=x[31725];x[31725]=0;if((h|0)==1){break v}x[31725]=0;S(1017,c|0,8964,a|0);h=x[31725];x[31725]=0;if((h|0)==1){break u}x[31725]=0;O(180,d|0,c|0);h=x[31725];x[31725]=0;if((h|0)==1){break t}tb(c);tb(a)}if(!Ed(y[b+80|0])){break p}x[31725]=0;c=P(36,b+40|0,12838)|0;a=x[31725];x[31725]=0;if((a|0)==1){break r}x[31725]=0;O(180,d|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}tb(c);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(c);break j}if(!Ed(y[b+81|0])){break o}x[31725]=0;c=P(36,b+40|0,12609)|0;a=x[31725];x[31725]=0;if((a|0)==1){break n}x[31725]=0;O(180,d|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}tb(c)}if(Ed(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(c);break j}x[31725]=0;c=P(36,b+28|0,11128)|0;a=x[31725];x[31725]=0;D:{if((a|0)!=1){x[31725]=0;O(180,d|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break D}tb(c);break k}a=N()|0;break j}a=N()|0;tb(c);break j}if(lc(x[d>>2],x[d+4>>2])){break g}x[31725]=0;f=P(991,f|0,16811)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;c=P(36,b+4|0,16781)|0;a=x[31725];x[31725]=0;E:{F:{G:{if((a|0)!=1){x[31725]=0;a=b+16|0;S(1124,a|0,d|0,c|0);h=x[31725];x[31725]=0;if((h|0)==1){break G}x[31725]=0;P(842,f|0,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break F}tb(a);tb(c);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(c);break j}a=N()|0}Td(d)}zg(b- -64|0)}tb(g);break a}Td(d);zg(b- -64|0);fb=b+96|0;break f}if(Ld(b,8132)){x[j>>2]=0;ir(a,j);break f}if(Ld(b,8110)){x[j>>2]=7;ir(a,j);break f}if(Ld(b,10853)){x[j>>2]=4;ir(a,j);break f}if(Ld(b,10625)){Dc(a,15683);break f}if(Ld(b,11403)){Dc(a,15844);break f}if(Ld(b,7412)){b=fb-48|0;fb=b;d=b+24|0;SG(d);x[31725]=0;c=b+12|0;W(147,c|0);g=x[31725];x[31725]=0;H:{I:{J:{K:{if((g|0)!=1){x[31725]=0;g=b+36|0;S(148,g|0,d|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break K}x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)==1){break J}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(Ld(b,9909)){b=fb-16|0;fb=b;f=fb-16|0;fb=f;x[f+12>>2]=101;h=b+4|0;d=fb-96|0;fb=d;g=Nb(d+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{c=x[f+12>>2];if(c&1){x[31725]=0;c=d+52|0;O(136,c|0,19989505);e=x[31725];x[31725]=0;if((e|0)==1){break _}x[31725]=0;O(103,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break Z}tb(c);c=x[f+12>>2]}if(!(c&4)){break X}x[31725]=0;c=ca(137)|0;e=x[31725];x[31725]=0;if((e|0)==1){break W}if(!c){break Y}break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}x[31725]=0;c=d+52|0;W(138,c|0);e=x[31725];x[31725]=0;$:{if((e|0)!=1){x[31725]=0;O(103,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break $}tb(c);break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}aa:{c=x[f+12>>2];if(!(c&32)){break aa}x[31725]=0;e=d+52|0;W(130,e|0);c=x[31725];x[31725]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((c|0)!=1){x[31725]=0;c=d+40|0;O(139,c|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break ca}i=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!i){x[31725]=0;i=d+28|0;W(140,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break ta}x[31725]=0;k=d+16|0;O(139,k|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break sa}x[31725]=0;S(141,c|0,i|0,k|0);e=x[31725];x[31725]=0;if((e|0)==1){break ra}x[31725]=0;O(103,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break qa}tb(c);tb(k);Eb(i)}c=Up(d+52|0);if(!Ad(x[c+4>>2],y[c+11|0])){x[31725]=0;e=d+28|0;W(142,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break na}x[31725]=0;i=d+40|0;S(143,i|0,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break ma}x[31725]=0;O(103,g|0,i|0);c=x[31725];x[31725]=0;if((c|0)==1){break la}tb(i);Eb(e)}x[31725]=0;c=d+40|0;k=d+52|0;O(144,c|0,k|0);e=x[31725];x[31725]=0;if((e|0)==1){break ja}e=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!e){x[31725]=0;e=d+28|0;W(140,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break ia}x[31725]=0;i=d+16|0;O(144,i|0,k|0);k=x[31725];x[31725]=0;if((k|0)==1){break ha}x[31725]=0;S(141,c|0,e|0,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break ga}x[31725]=0;O(103,g|0,c|0);k=x[31725];x[31725]=0;if((k|0)==1){break fa}tb(c);tb(i);Eb(e)}zg(d+52|0);c=x[f+12>>2];break aa}c=N()|0;break M}c=N()|0;break ba}c=N()|0;break oa}c=N()|0;break pa}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ka}c=N()|0;tb(d+40|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ba}c=N()|0;break da}c=N()|0;break ea}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0}zg(d+52|0);break M}ua:{if(!(c&64)){break ua}x[31725]=0;c=ca(137)|0;e=x[31725];x[31725]=0;if((e|0)==1){break W}if(c){break ua}c=d+52|0;Fb(c);x[31725]=0;O(103,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break N}tb(c)}if(y[f+12|0]&128){x[31725]=0;c=d+52|0;W(145,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break V}x[31725]=0;O(103,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break U}tb(c)}x[31725]=0;e=P(1,d+52|0,22267)|0;c=x[31725];x[31725]=0;if((c|0)==1){break T}x[31725]=0;c=d+4|0;S(146,c|0,g|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break S}x[31725]=0;i=d+40|0;W(147,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break R}x[31725]=0;S(148,h|0,c|0,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break Q}tb(i);tb(c);tb(e);Td(g);fb=d+96|0;break L}c=N()|0;break M}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}c=N()|0;break M}c=N()|0;break O}c=N()|0;break P}c=N()|0;tb(d+40|0)}tb(d+4|0)}tb(e);break M}c=N()|0;tb(d+52|0)}Td(g);Q(c|0);p()}fb=f+16|0;x[31725]=0;O(1065,a|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(h);fb=b+16|0;break f}break c}if(Ld(b,10525)){b=fb-48|0;fb=b;d=b+4|0;ws(d);x[31725]=0;c=b+36|0;O(139,c|0,d|0);g=x[31725];x[31725]=0;va:{wa:{if((g|0)!=1){x[31725]=0;O(1065,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break wa}tb(c);zg(d);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}zg(b+4|0);break a}if(Ld(b,11366)){b=fb-32|0;fb=b;ws(b);x[31725]=0;O(1125,a|0,Up(b)|0);a=x[31725];x[31725]=0;if((a|0)!=1){zg(b);fb=b+32|0;break f}a=N()|0;zg(b);break a}if(Ld(b,9922)){b=fb-48|0;fb=b;d=b+16|0;ws(d);c=x[b+28>>2];xa:{if(c){x[31725]=0;x[b+12>>2]=c;O(1123,a|0,b+12|0);a=x[31725];x[31725]=0;if((a|0)!=1){break xa}a=N()|0;zg(d);break a}Fb(a)}zg(b+16|0);fb=b+48|0;break f}if(Ld(b,12828)){ws(j);b=y[j+16|0];x[31725]=0;P(36,a|0,(Ed(b)?15534:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}zg(j);break f}if(Ld(b,9938)){ws(j);b=y[j+17|0];x[31725]=0;P(36,a|0,(Ed(b)?15534:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){zg(j);break f}break e}if(Ld(b,12281)){ws(j);b=y[j+18|0];x[31725]=0;P(36,a|0,(Ed(b)?15534:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){zg(j);break f}break e}if(Ld(b,12583)){b=fb-16|0;fb=b;d=fb-32|0;fb=d;g=b+4|0;c=Fb(g);x[31725]=0;W(130,d|0);f=x[31725];x[31725]=0;ya:{za:{if((f|0)!=1){x[31725]=0;O(131,c|0,Up(d)|0);f=x[31725];x[31725]=0;if((f|0)==1){break za}zg(d);fb=d+32|0;break ya}a=N()|0;break b}a=N()|0;zg(d);break b}x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Ld(b,8253)){b=fb-16|0;fb=b;d=fb-48|0;fb=d;g=b+4|0;c=Fb(g);x[31725]=0;f=d+24|0;O(133,f|0,4135);h=x[31725];x[31725]=0;Aa:{Ba:{Ca:{Da:{if((h|0)!=1){x[d+20>>2]=18;x[d+16>>2]=0;x[31725]=0;x[d+12>>2]=0;h=d+36|0;aa(134,h|0,f|0,d+20|0,d+16|0,d+12|0);e=x[31725];x[31725]=0;if((e|0)==1){break Da}x[31725]=0;P(76,c|0,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ca}tb(h);Eb(f);fb=d+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(d+36|0)}Eb(d+24|0);break b}x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Ld(b,6857)){b=fb-16|0;fb=b;c=b+4|0;d=fb-32|0;fb=d;g=d+8|0;Dc(g,20190);x[31725]=0;f=d+20|0;S(125,f|0,0,g|0);h=x[31725];x[31725]=0;Ea:{Fa:{Ga:{if((h|0)!=1){x[31725]=0;O(12,c|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break Ga}Qb(f);tb(g);fb=d+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Qb(d+20|0)}tb(d+8|0);break a}x[31725]=0;O(1065,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c);fb=b+16|0;break f}break c}if(Ld(b,6455)){b=fb-48|0;fb=b;d=tc(b+24|0,18274);x[31725]=0;c=b+12|0;O(1126,c|0,2);g=x[31725];x[31725]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)!=1){x[31725]=0;g=b+36|0;S(2,g|0,d|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break Ka}x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)==1){break Ja}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(d);break a}if(Ld(b,11389)){b=fb-16|0;fb=b;d=fb-16|0;fb=d;Dc(d+4|0,18590);f=b+4|0;g=Fb(f);h=y[d+15|0];e=x[d+8>>2];x[31725]=0;O(95,g|0,yh(e,h)|0);h=x[31725];x[31725]=0;La:{if((h|0)!=1){Ma:{while(1){if(yh(x[d+8>>2],y[d+15|0])>>>0>c>>>0){h=y[cc(d+4|0,c)|0];x[31725]=0;O(97,g|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break Ma}c=c+1|0;continue}break}tb(d+4|0);fb=d+16|0;break La}}a=N()|0;tb(g);tb(d+4|0);break a}x[31725]=0;O(1065,a|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f);fb=b+16|0;break f}break c}if(Ld(b,10532)){b=fb-16|0;fb=b;d=b+4|0;ss(d,0);x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Ld(b,10507)){b=fb-16|0;fb=b;d=b+4|0;ss(d,2);x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Ld(b,10492)){b=fb-16|0;fb=b;d=b+4|0;ss(d,3);x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}Fb(a)}fb=j+32|0;break d}a=N()|0;zg(j);break a}return}a=N()|0;tb(b+4|0);break a}tb(c)}Q(a|0);p()}function dua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-416|0;fb=e;xc(b);f=e+399|0;g=R0(b,f);if(!g){FE(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!m$(f)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}if(!c){d=1;break f}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;k=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=k;g:{h:{i:{while(1){if((k&65535)>>>0<=d>>>0){j:{Sb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){KE(b,a+1298308|0);n$(e+312|0,b);o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31725]=0;f=U(328,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}if(!f){break j}oe(e+272|0,x[d>>2],x[d+4>>2]);f=Nd(e+264|0);x[31725]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=jg(329,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[31725];x[31725]=0;if((g|0)==1){break o}g=x[d+4>>2];k=x[d>>2];x[31725]=0;U(215,f|0,o|0,Sc(k,g)>>>1|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}ub(f);dc(d)}m=Nb(e+252|0);x[31725]=0;O(330,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31725];x[31725]=0;if((d|0)==1){break i}d=0;while(1){g=y[e+411|0]|y[e+412|0]<<8;f=d&65535;if(g>>>0<=f>>>0){break l}x[e+212>>2]=g-f;x[e+160>>2]=2e3;d=e+212|0;g=x[ud(d,e+160|0)>>2];d=Nb(d);x[31725]=0;g=U(328,b|0,d|0,g<<8)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}if(!g){break m}g=vb(e+248|0,wb(x[m+4>>2]));k=wb(x[d>>2]);h=wb(x[e+216>>2]);g=x[g>>2];x[31725]=0;V(331,m|0,g|0,k|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}dc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;ld(g,1);i=f+(e+320|0)|0;f=Zd(b);v[i|0]=f;if(f<<24>>24>=0){B=g,C=i$(b)<<1,x[B>>2]=C}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}dc(d);d=0;break h}oe(e+232|0,x[m>>2],x[m+4>>2]);mf(e+240|0,x[e+232>>2],x[e+236>>2]);d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;O(332,Xb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break e}q=a+484344|0;s=c&1;h=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=h>>>0){g=c&2;k=1;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{while(1){c=k&65535;if(c>>>0>z[a+480190>>1]){break w}x[31725]=0;d=y[c+(e+320|0)|0];S(333,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[31725];x[31725]=0;if((f|0)==1){break u}B:{C:{if(d<<24>>24<0){break C}x[31725]=0;d=R(334,b|0)|0;f=x[31725];x[31725]=0;D:{E:{F:{G:{H:{I:{J:{K:{if((f|0)==1){break K}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[31725]=0;d=R(334,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break J}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break t}v[e+80|0]=d;v[e+180|0]=64;B=c+484410|0,C=y[Rb(e+80|0,e+180|0)|0]<<2,w[B>>1]=C;x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break K}v[c+484417|0]=d<<4;c=c+484380|0;mp(c);if(!x[c>>2]){break C}x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break E}d=0;switch(f|0){case 4:case 5:break D;case 2:case 3:break G;case 1:break H;case 0:break I;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+80|0);h=x[b+8>>2];i=x[b>>2];j=x[c>>2];x[31725]=0;h=U(152,i|0,h|0,j|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break s}if(!h){break x}d=x[c>>2];x[31725]=0;S(335,b|0,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break s}B=e,C=wb(x[f>>2]),x[B+180>>2]=C;h=wb(x[e+84>>2]);while(1){d=x[e+180>>2];if(Ib(d,h)){i=d;d=y[d|0];v[i|0]=d<<7|(d^-1)>>>1&127;me(e+180|0);continue}break}oe(e+200|0,x[f>>2],x[e+84>>2]);d=Nd(e+192|0);x[31725]=0;h=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=h;d=jg(329,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);h=x[31725];x[31725]=0;L:{if((h|0)!=1){h=Xc(e+180|0,16,1,0,16);x[31725]=0;U(217,h|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break L}ub(d);dc(f);break C}a=N()|0;break p}a=N()|0;ub(d);break p}c=x[c>>2];break F}f=Nb(e+80|0);h=x[c>>2];x[31725]=0;d=e+180|0;S(336,d|0,b|0,h|0);h=x[31725];x[31725]=0;M:{N:{O:{if((h|0)!=1){i=En(f,d);dc(d);if(g){oe(e+152|0,x[i>>2],x[e+84>>2]);h=Nd(e+144|0);x[31725]=0;j=x[h+4>>2];x[e+24>>2]=x[h>>2];x[e+28>>2]=j;h=jg(329,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);j=x[31725];x[31725]=0;if((j|0)==1){break O}d=Xc(d,8,1,0,2);x[31725]=0;U(217,d|0,c|0,h|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break N}ub(h)}dc(i);break C}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break M}Y(a|0)|0;d=0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break v}a=N()|0;break M}a=N()|0;break M}a=N()|0;ub(h)}dc(f);break c}if(g){d=Xc(e+80|0,(f|0)==2?8:16,1,0,0);x[31725]=0;U(217,d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break C}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[31725]=0;P(185,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break C}}a=N()|0;break c}h=Nb(e+80|0);d=x[c>>2];x[31725]=0;i=e+180|0;S(337,i|0,b|0,d|0);d=x[31725];x[31725]=0;P:{Q:{if((d|0)!=1){d=En(h,i);dc(i);if(!g){break P}if((f|0)!=5){break Q}B=e,C=wb(x[d>>2]),x[B+180>>2]=C;j=wb(x[e+84>>2]);while(1){i=x[e+180>>2];if(!Ib(i,j)){break Q}l=i;i=y[i|0];v[l|0]=y[(i>>>7|0)+24721|0]^i;me(e+180|0);continue}}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break y}Y(a|0)|0;d=0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break B}a=N()|0;break y}oe(e+112|0,x[d>>2],x[e+84>>2]);i=Nd(e+104|0);x[31725]=0;j=x[i+4>>2];x[e+32>>2]=x[i>>2];x[e+36>>2]=j;i=jg(329,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);j=x[31725];x[31725]=0;if((j|0)==1){break A}f=(f|0)==5;f=Xc(e+180|0,f?16:8,1,0,f?16:1);x[31725]=0;U(217,f|0,c|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}ub(i)}dc(d)}k=k+1|0;continue}break}dc(h);break h}a=N()|0;break y}a=N()|0;ub(i)}dc(h);break c}dc(f);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=y[xb(e+80|0,d)|0];B=xb(e+180|0,d),C=c,v[B|0]=C;d=d+1|0;continue}break}R:{S:{T:{U:{c=e+180|0;d=eg(c);if(d){c=Nb(c);x[31725]=0;b=U(328,b|0,c|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}if(!b){break S}oe(e+72|0,x[c>>2],x[c+4>>2]);b=Nd(e- -64|0);x[31725]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=jg(329,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break U}x[31725]=0;V(338,a+1298332|0,b|0,d|0,1);d=x[31725];x[31725]=0;if((d|0)==1){break T}ub(b);dc(c)}x[31725]=0;W(339,e+52|0);b=x[31725];x[31725]=0;if((b|0)!=1){break R}a=N()|0;break c}a=N()|0;break q}a=N()|0;ub(b);break q}dc(c);d=0;break h}x[31725]=0;b=e+180|0;c=e+52|0;S(340,b|0,c|0,y[e+407|0]);d=x[31725];x[31725]=0;V:{W:{if((d|0)!=1){Ab(a+1298344|0,b);tb(b);Eb(c);x[31725]=0;b=P(1,b|0,10096)|0;d=x[31725];x[31725]=0;if((d|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31725]=0;b=P(1,c|0,5101)|0;c=x[31725];x[31725]=0;if((c|0)==1){break V}Ab(a+1298368|0,b);tb(b);B=a+1298404|0,C=x[Fc(e+48|0,24)>>2],x[B>>2]=C;d=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}dc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break p}a=N()|0}dc(c);break c}dc(f);break c}B=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],h),C=h,w[B>>1]=C;X:{Y:{if(!s){break Y}x[31725]=0;r=h&65535;d=U(198,q|0,r|0,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break X}if(!d){break Y}f=z[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=_b(x[o>>2],D(d,h)+i|0);d=y[d|0]|y[d+1|0]<<8;Z:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break Z}k=0;t=0-i|0;u=d<<8;d=Wb(x[q>>2],h);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1){if((k|0)==64){break Z}Dr(e+212|0,x[e+240>>2],x[e+244>>2],(k<<2)+u|0,4);f=x[e+212>>2];g=xb(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;j=xb(f,1);v[d+1|0]=y[j|0]<<2&60|y[g|0]>>>6;l=y[j|0];g=xb(f,2);j=y[xb(f,3)|0];f=y[g|0];g=j<<4|f>>>4;w[e+80>>1]=g;A=l>>>6|0;l=f<<2&60;f=A|l;_:{if(!(y[xb(e+312|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|g)){break _}v[d+5|0]=g;l=j>>>4|0;v[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Bf(d,f&15,g&255);if(!y[d+4|0]){break _}v[d+2|0]=f>>>0<32?3:4;break _;case 9:v[d+3|0]=10;v[d+5|0]=g>>>1;if(g>>>0<512){break _}v[d+2|0]=15;v[d+4|0]=j>>>5;break _;case 10:case 42:if(g>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Bf(d,f,g&255);break _}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(j&15){v[d+2|0]=3;v[d+4|0]=(g&240)>>>4;break _}v[d+2|0]=4;v[d+4|0]=g&15;break _}v[d+3|0]=(f|0)==11?12:16;B=d,C=_v(g),v[B+5|0]=C;break _}v[d+3|0]=14;if((g&255)>>>0<64){break _}v[d+5|0]=0;break _}v[d+3|0]=19;v[d+5|0]=g&15|f<<4;break _}v[d+3|0]=19;w[e+160>>1]=15;B=d,C=y[Nc(e+80|0,e+160|0)|0]|f<<4,v[B+5|0]=C;break _}v[d+3|0]=19;if(g&255){v[d+5|0]=g&15|((f|0)==17?16:(f|0)==26?16:32);if(j>>>0<16){break _}v[d+2|0]=f>>>0>25?6:5;break _}v[d+5|0]=l|(f>>>0>25?-80:-96);break _}if(!g){break $}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=g+4;B=d,C=Dh(x[Ze(e+160|0,e+124|0)>>2]/8|0),v[B+5|0]=C;break _}v[d+3|0]=14;j=D(t,6)+d|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break _}g=j+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;B=g,C=_v(r),v[B+5|0]=C}f=f+1|0;continue}}v[d+3|0]=9;f=g&7;if(f){v[d+5|0]=y[f+24713|0];break _}f=g>>>4|0;if((f|0)==128){break $}v[d+5|0]=f;if(g>>>0<=2047){v[d+5|0]=f^128;break _}v[d+5|0]=f^-1;break _}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break _}v[d+3|0]=25;break _}v[d+3|0]=0}k=k+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}i=i+1|0;continue}}h=h+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{ZD(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;k=z[a+480188>>1];continue}break}dc(d);d=0;break g}a=N()|0;break c}dc(m)}md(o)}fb=e+416|0;return d|0}a=N()|0;break c}a=N()|0;dc(d)}dc(m);break a}dc(d)}md(o);Q(a|0);p()}function E1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{n=ik(b,13869);if(!n){break a}b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}f=Pg(b);if(!(!((f|0)==(Kn(13719)|0)|!(f&1616928864)|f&-2139062144)&(f|0)!=70791730)){Gh(b,4);break a}l=1;c=hh(b);while(1){e=l&65535;if(e>>>0>z[a+480192>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{g=0;if((Kn(16765)|0)==(f|0)){Vb(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(f-1349079874|0){default:if((f|0)==1095062094){break t}if((f|0)==1095126087){break q}if((f|0)==1129524782){break z}if((f|0)==1145263150){break W}if((f|0)==1145979182){break V}if((f|0)==1179463214){break x}if((f|0)==1851469358){break D}if((f|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((f|0)!=1196830254){if((f|0)==1229341486){break S}if((f|0)==1229345326){break R}if((f|0)==1264266798){break E}if((f|0)==1296182830){break Q}if((f|0)==1296248366){break O}if((f|0)==1297100334){break P}if((f|0)==1297110852){break o}if((f|0)==1298747438){break B}if((f|0)==1313692462){break F}if((f|0)==1313751342){break X}if((f|0)==1345203758){break ha}if((f|0)==1346711086){break j}if((f|0)==1346720334){break u}if((f|0)==1346722606){break H}if((f|0)==1346784327){break r}if((f|0)==1347175726){break ba}if((f|0)==1347179310){break ca}if((f|0)==1347437358){break M}if((f|0)==1347441454){break N}if((f|0)==1347443502){break K}if((f|0)==1347628590){break U}if((f|0)==1347633710){break aa}if((f|0)==1347634478){break $}if((f|0)==1347703884){break m}if((f|0)==1347831112){break w}if((f|0)==1347833672){break v}if((f|0)==1349076270){break i}if((f|0)==1349076315){break G}if((f|0)==1349078085){break Z}if((f|0)==1349078099){break _}if((f|0)==1349079131){break J}if((f|0)==1378758190){break n}if((f|0)==1381183022){break y}if((f|0)==1447374382){break k}if((f|0)==1447383630){break s}if((f|0)==1447385902){break I}if((f|0)==1447447623){break p}if((f|0)==1447839022){break fa}if((f|0)==1447842606){break ga}if((f|0)==1448106798){break L}if((f|0)==1448226350){break A}if((f|0)==1448291886){break T}if((f|0)==1448297006){break ea}if((f|0)==1448297774){break da}if((f|0)!=1682320942){if((f|0)==1718508334){break C}if((f|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Lw(b,c),x[o>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+15|0]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Lw(b,c),x[o+4>>2]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Lw(b,c),x[o+8>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+61|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+62|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+63|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e- -64|0,q=Jd(b,c),v[o|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+81|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+82|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+83|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+84|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+101|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+102|0]=q;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+103|0]=q;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+104|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+16|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+17|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+18|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+19|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+20|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+21|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+22|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),w[o+28>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+30|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+31|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=EF(b,c),v[o+26|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+27|0]=q;break e}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break h}g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>128){break d}g=e+108|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31725]=0;i=R(195,j|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){o=xb(g,d),q=i,v[o|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>256){break d}g=e+236|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31725]=0;i=R(194,j|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){o=_b(g,d),q=i,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>32){break d}i=e+492|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;while(1){if((c|0)==(d|0)){break f}x[31725]=0;k=R(196,j|0)|0;m=x[31725];x[31725]=0;ia:{if((m|0)==1){break ia}x[31725]=0;P(197,g|0,k|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ia}d=d+1|0;continue}break}d=N()|0;tb(g);break g}if(c>>>0>32){break d}i=e+524|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;ja:{while(1){if((c|0)!=(d|0)){x[31725]=0;k=R(196,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break ja}x[31725]=0;P(197,g|0,k|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ja}d=d+1|0;continue}break}zc(i,g);tb(g);ub(j);break e}d=N()|0;tb(g);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+34|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),w[o+12>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+23|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+24|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+25|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+35|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+36|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+105|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+85|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+65|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+100|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+80|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+60|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=EF(b,c),v[o+33|0]=q;break e}g=1;d=Bp(b,c);if(!Ap(d)){break d}v[e+14|0]=d;break d}o=e,q=D(Jw(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[o+40>>2]=q;break e}g=(Jw(b,c)>>>0)%1e4|0;d=x[e+40>>2];x[e+40>>2]=g+d-(d>>>0)%1e4;break e}x[h+28>>2]=240;o=h,q=Bp(b,c),x[o+8>>2]=q;gh(e+48|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Bp(b,c),x[o+8>>2]=q;gh(e+68|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Bp(b,c),x[o+8>>2]=q;gh(e+88|0,x[Gb(h+28|0,h+8|0)>>2]);break e}d=N()|0}ub(j);Q(d|0);p()}zc(i,g);tb(g);ub(j)}g=1}fb=h+48|0;if(!g){Vb(b,c);break c}if((Kn(16770)|0)==(f|0)){d=y[e+15|0];v[e+15|0]=0;v[e+100|0]=y[e+100|0]&224|(d>>>5&4|d>>>6&1);v[e+60|0]=d>>>1&2|(d<<1&4|(y[e+60|0]&240|d&1));v[e+80|0]=y[e+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Fd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[31601];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+126444|0;d=x[a+126452>>2];a=x[d+8>>2];o:{if((b|0)==(a|0)){m=126404,n=qva(-2,c)&g,x[m>>2]=n;break o}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[31603];if(k>>>0>=h>>>0){break n}if(b){a=2<<c;d=mva((0-a|a)&b<<c);a=d<<3;b=a+126444|0;e=x[a+126452>>2];a=x[e+8>>2];p:{if((b|0)==(a|0)){g=qva(-2,d)&g;x[31601]=g;break p}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+126444|0;f=x[31606];a=1<<(k>>>3);q:{if(!(a&g)){x[31601]=a|g;a=b;break q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[31606]=c;x[31603]=d;break a}j=x[31602];if(!j){break n}c=x[(mva(j)<<2)+126708>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){r:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break r}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break m}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[31602];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+126708>>2];t:{u:{v:{if(!b){a=0;break v}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=b;f=e;if(e){break w}f=0;a=b;break u}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(mva(a)<<2)+126708>>2]}if(!a){break t}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31603]-h>>>0<=f>>>0){break n}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break l}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[31603];if(a>>>0>=h>>>0){d=x[31606];b=a-h|0;x:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break x}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[31603]=b;x[31606]=c;a=d+8|0;break a}i=x[31604];if(i>>>0>h>>>0){b=i-h|0;x[31604]=b;c=x[31607];a=c+h|0;x[31607]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[31719]){c=x[31721]}else{x[31722]=-1;x[31723]=-1;x[31720]=4096;x[31721]=4096;x[31719]=l+12&-16^1431655768;x[31724]=0;x[31712]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[31711];if(d){c=x[31709];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}y:{if(!(y[126848]&4)){z:{A:{B:{C:{d=x[31607];if(d){a=126852;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}c=jp(0);if((c|0)==-1){break z}g=b;d=x[31720];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[31711];if(d){a=x[31709];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=jp(g);if((c|0)!=(a|0)){break B}break y}g=f&e-i;c=jp(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=c}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){c=a;break y}c=x[31721];c=c+(j-g|0)&0-c;if((jp(c)|0)==-1){break z}g=c+g|0;c=a;break y}if((c|0)!=-1){break y}}x[31712]=x[31712]|4}c=jp(b);a=jp(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break i}g=a-c|0;if(g>>>0<=h+40>>>0){break i}}a=x[31709]+g|0;x[31709]=a;if(a>>>0>A[31710]){x[31710]=a}D:{e=x[31607];if(e){a=126852;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[31605];if(!(a>>>0<=c>>>0?a:0)){x[31605]=c}a=0;x[31714]=g;x[31713]=c;x[31609]=-1;x[31610]=x[31719];x[31716]=0;while(1){d=a<<3;b=d+126444|0;x[d+126452>>2]=b;x[d+126456>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=-8-c&7;b=d-a|0;x[31604]=b;a=a+c|0;x[31607]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31608]=x[31723];break j}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break k}x[a+4>>2]=b+g;a=-8-e&7;c=a+e|0;x[31607]=c;b=x[31604]+g|0;a=b-a|0;x[31604]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[31608]=x[31723];break j}d=0;break b}c=0;break c}if(A[31605]>c>>>0){x[31605]=c}b=c+g|0;a=126852;E:{F:{G:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=126852;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(-8-c&7)+c|0;x[j+4>>2]=h|3;g=b+(-8-b&7)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[31607]=i;a=x[31604]+a|0;x[31604]=a;x[i+4>>2]=a|1;break d}if(x[31606]==(g|0)){x[31606]=i;a=x[31603]+a|0;x[31603]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=126404,n=x[31601]&qva(-2,f>>>3|0),x[m>>2]=n;break f}x[b+12>>2]=c;x[c+8>>2]=b;break f}h=x[g+24>>2];c=x[g+12>>2];if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break g}b=g+20|0;f=x[b>>2];if(!f){f=x[g+16>>2];if(!f){break h}b=g+16|0}while(1){d=b;c=f;b=c+20|0;f=x[b>>2];if(f){continue}b=c+16|0;f=x[c+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=-8-c&7;b=d-a|0;x[31604]=b;a=a+c|0;x[31607]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31608]=x[31723];a=(f+(39-f&7)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[31716];x[d+16>>2]=x[31715];x[d+20>>2]=a;a=x[31714];x[d+8>>2]=x[31713];x[d+12>>2]=a;x[31715]=d+8;x[31714]=g;x[31713]=c;x[31716]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+126444|0;c=x[31601];a=1<<(f>>>3);H:{if(!(c&a)){x[31601]=a|c;a=b;break H}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126708|0;I:{d=x[31602];c=1<<a;J:{if(!(d&c)){x[31602]=c|d;x[b>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break I}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[31604];if(a>>>0<=h>>>0){break i}b=a-h|0;x[31604]=b;c=x[31607];a=c+h|0;x[31607]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[31600]=48;a=0;break a}c=0}if(!h){break f}d=x[g+28>>2];b=(d<<2)+126708|0;K:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break K}m=126408,n=x[31602]&qva(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break f}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break f}x[c+20>>2]=b;x[b+24>>2]=c}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+126444|0;c=x[31601];a=1<<(a>>>3);L:{if(!(c&a)){x[31601]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+126708|0;M:{d=x[31602];c=1<<f;N:{if(!(d&c)){x[31602]=c|d;x[b>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break M}d=f>>>29|0;f=f<<1;d=(d&4)+c|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}b=x[d+28>>2];a=(b<<2)+126708|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=qva(-2,b)&j;x[31602]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+126444|0;c=x[31601];a=1<<(f>>>3);R:{if(!(c&a)){x[31601]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126708|0;S:{c=1<<a;T:{if(!(c&j)){x[31602]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+126708|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=126408,n=qva(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+126444|0;e=x[31606];a=1<<(k>>>3);X:{if(!(a&g)){x[31601]=a|g;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[31606]=d;x[31603]=f}a=c+8|0}fb=l+16|0;return a|0}function jva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=fb-272|0;fb=e;xc(b);if(Sr(b,18431)){n=Fb(e+260|0);x[31725]=0;g=P(232,b|0,n|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[31725]=0;h=e+253|0;g=P(247,b|0,h|0)|0;d=x[31725];x[31725]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!O0(y[e+253|0],y[e+254|0])){break a}h=Bc(N0(h),hb);g=x[b+8>>2];d=x[b>>2];x[31725]=0;g=U(152,d|0,g|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[31725]=0;O(248,a|0,4096);d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;O(249,a+1298308|0,n|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Xh(a,1);x[31725]=0;f=P(1,e+240|0,9476)|0;d=x[31725];x[31725]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){Ab(a+1298344|0,f);tb(f);x[31725]=0;f=P(1,e+228|0,7105)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}Ab(a+1298356|0,f);tb(f);x[31725]=0;g=e+32|0;W(250,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break o}v[e+204|0]=y[e+254|0];x[31725]=0;v[e|0]=y[e+253|0];f=e+216|0;O(251,f|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break n}x[31725]=0;h=e+80|0;V(252,h|0,g|0,e+204|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break m}Ab(a+1298368|0,h);tb(h);tb(f);Eb(g);r=a+1298404|0,s=x[Fc(h,4)>>2],x[r>>2]=s;if(y[e+253|0]<2){break i}w[e+80>>1]=8192;x[31725]=0;f=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}w[e+32>>1]=f;r=a,s=D(z[qe(h,g)>>1],1e4)>>>8|0,x[r+480204>>2]=s;x[31725]=0;v[e+80|0]=1;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}v[e+32|0]=f;r=a,s=y[ef(h,g)|0],x[r+480196>>2]=s;x[31725]=0;P(185,b|0,3)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;f=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break h}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break l}b=N()|0;tb(e+216|0)}Eb(e+32|0);break c}b=N()|0;break c}b=N()|0;break c}v[e+80|0]=32;x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;q:{if((d|0)!=1){v[e+32|0]=f;r=a,s=D(y[ef(e+80|0,e+32|0)|0],1e4),x[r+480204>>2]=s;x[31725]=0;v[e+80|0]=1;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}v[e+32|0]=f;r=a,s=y[ef(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break h}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[a+480208>>2]=f>>>2&16|12;l=Nb(e+216|0);j=e+80|12;m=Nb(e+204|0);o=1;while(1){r:{s:{d=o&65535;if(d>>>0>z[a+480192>>1]){break s}x[31725]=0;i=U(253,a|0,d|0,0)|0;d=x[31725];x[31725]=0;t:{if((d|0)==1){break t}if(!i){break s}x[31725]=0;f=P(242,b|0,i+492|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break t}if(!f){break s}x[31725]=0;q=R(199,b|0)|0;d=x[31725];x[31725]=0;u:{v:{w:{if((d|0)!=1){d=e+80|0;Sb(d,0,120);if(!q){break r}x:{if(y[e+253|0]){x[31725]=0;f=P(254,b|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+253|0]){break x}}d=gc(e+72|0,j,96);f=x[d>>2];d=x[d+4>>2];x[31725]=0;bo(161,e+32|0,b,f,d);d=x[31725];x[31725]=0;if((d|0)==1){break v}if(!x[e+36>>2]){break r}}h=i+236|0;f=0;break u}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}while(1){if((f|0)!=120){g=z[a+480190>>1];d=y[(e+80|0)+f|0];r=_b(h,f),s=(d+g|0)+1|0,w[r>>1]=s;f=f+1|0;continue}break}x[31725]=0;f=i+48|0;S(255,e|0,f|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;k=i+68|0;S(255,e+16|0,k|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;h=i+88|0;S(255,e- -64|0,h|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(256,b|0,e+56|0);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[i>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;AE(y[e+59|0]|y[e+60|0]<<8,f,0);AE(y[e+59|0]|y[e+60|0]<<8,k,1);AE(y[e+59|0]|y[e+60|0]<<8,h,2);r=e,s=wb(x[f>>2]),x[r+32>>2]=s;f=d>>>12|0;d=wb(x[i+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;r=g,s=y[Rb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}else{r=e,s=wb(x[k>>2]),x[r+32>>2]=s;d=wb(x[i+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;r=g,s=y[Rb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}break}r=e,s=wb(x[h>>2]),x[r+32>>2]=s;k=f&3;h=wb(x[i+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,h)){g=v[f+2|0];d=g>>31^-1;g=g^-128;i=k&31;if((k&63)>>>0>=32){d=g<<i;i=0}else{d=(1<<i)-1&g>>>32-i|d<<i;i=g<<i}y:{if((d|0)>=-1&i>>>0>=4294967292|(d|0)>=0){g=i+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break y}g=0-((i>>>0>3)+d|0)|0;d=3-i|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}r=f,s=Gc(d,g)^128,v[r+2|0]=s;Je(e+32|0);continue}else{d=z[a+480190>>1]+1|0;w[e+54>>1]=d;f=0;i=d&65535;d=4e3-i|0;k=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(q|0)){break A}if((f|0)==(k|0)){x[31725]=0;P(185,b|0,20)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break A}b=N()|0;break d}x[31725]=0;h=f+i|0;P(242,b|0,((h<<5)+a|0)+946304|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}x[31725]=0;g=e+32|0;O(257,b|0,g|0);d=x[31725];x[31725]=0;C:{if((d|0)==1){break C}x[31725]=0;O(258,g|0,(D(h,104)+a|0)+484380|0);d=x[31725];x[31725]=0;if((d|0)==1){break C}x[31725]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(259,m|0,e+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31725]=0;O(259,l|0,e+54|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=q+z[a+480190>>1];r=a,s=x[ud(e+32|0,e+28|0)>>2],w[r+480190>>1]=s;break r}b=N()|0;break d}b=N()|0;break d}}}b=N()|0;break d}g=Fb(e+80|0);x[31725]=0;f=P(232,b|0,g|0)|0;d=x[31725];x[31725]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[31725]=0;f=e+32|0;S(260,f|0,21,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break I}Ab(a+1298320|0,f);tb(f)}tb(g);f=0;J:{while(1){if((f|0)==32){x[31725]=0;f=P(261,b|0,e+16|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[31725]=0;f=U(152,d|0,f|0,g-11|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Xe(d+480280|0);x[31725]=0;O(233,b|0,d+480289|0);d=x[31725];x[31725]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break d}d=x[e+16>>2]-11|0;x[e+64>>2]=d;i=Nb(e+80|0);x[31725]=0;S(236,b|0,i|0,d|0);d=x[31725];x[31725]=0;K:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;r=e,s=D(x[Gb(e- -64|0,d)>>2],85),x[r+56>>2]=s;j=Fb(d);x[e>>2]=x[e+20>>2];d=x[Gb(e+56|0,e)>>2];x[31725]=0;O(116,j|0,d|0);d=x[31725];x[31725]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break M}k=x[i>>2];g=y[xb(k,f)|0];h=d;d=f+1|0;if(!((g|0)!=255|h-d>>>0<2)){h=v[xb(k,d)|0];g=y[xb(k,f+2|0)|0];d=x[vb(e+12|0,Df(j))>>2];x[31725]=0;V(239,j|0,d|0,g|0,h|0);d=x[31725];x[31725]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[31725]=0;O(117,j|0,g<<24>>24);g=x[31725];x[31725]=0;f=d;if((g|0)!=1){continue}break}break L}x[31725]=0;S(237,e|0,21,j|0);d=x[31725];x[31725]=0;if((d|0)!=1){N:{h=Ab(j,e);tb(e);g=Jb(h);f=y[h+11|0];d=x[h+4>>2];x[31725]=0;aa(238,a+1298332|0,g|0,Yc(d,f)|0,74,0);d=x[31725];x[31725]=0;if((d|0)==1){break N}tb(h);dc(i);break H}}}b=N()|0;tb(j);break K}b=N()|0}dc(i);break d}}b=N()|0;tb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[31725]=0;S(240,Xb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break G}h=c&1;if(h){x[31725]=0;O(225,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break G}}k=a+484344|0;f=0;while(1){O:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[b+8>>2];d=x[b>>2];x[31725]=0;g=U(152,d|0,g|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;while(1){c=z[a+480190>>1];if(f>>>0>=c>>>0){f=0;while(1){if(c>>>0<=f>>>0){break F}g=z[_b(x[m>>2],f)>>1];b=g&255;P:{if(!b){break P}d=x[l>>2];b=b-1&65535;if(Zc(d,x[l+4>>2])>>>0<=b>>>0){break P}b=z[_b(d,b)>>1]+(g>>>8&127)&65535;if(b>>>0>c>>>0){break P}c=D(b,104);b=c+a|0;h=b+484380|0;g=x[h>>2];if(!je(g,x[b+484400>>2])){break P}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!Fh(d)){break P}yc(x[d+20>>2],x[c+20>>2],Wk(x[h>>2],z[h+34>>1]))}f=f+1|0;c=z[a+480190>>1];continue}}c=z[_b(x[m>>2],f)>>1];if(c&255){f=f+1|0;continue}f=f+1|0;d=D(f,104)+a|0;c=Xc(e+80|0,w[d+484414>>1]&1?16:8,1,0,c<<16>>16<0?6:0);x[31725]=0;U(217,c|0,d+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}break}b=N()|0;break d}x[31725]=0;g=R(153,b|0)|0;d=x[31725];x[31725]=0;Q:{R:{S:{T:{if((d|0)!=1){x[31725]=0;i=e+32|0;S(187,i|0,b|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break T}j=ic(e+80|0,i);ub(i);if(!h){break R}x[31725]=0;g=R(199,j|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}x[31725]=0;P(185,j|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}x[31725]=0;g=U(198,k|0,f&65535,g+1|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}if(!g){break R}x[31725]=0;g=P(234,j|0,i|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break E}if(!g){break S}d=x[k>>2];x[31725]=0;O(235,Wb(d,f)|0,i|0);d=x[31725];x[31725]=0;if((d|0)!=1){break S}break E}b=N()|0;break d}b=N()|0;break d}d=x[k>>2];x[31725]=0;S(241,Wb(d,f)|0,1,j|0);d=x[31725];x[31725]=0;if((d|0)==1){break E}}ub(j);f=f+1|0;continue}break}break E}b=N()|0;break d}md(m);md(l);break b}b=N()|0;ub(j);break d}b=N()|0;break d}o=o+1|0;continue}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break d}b=N()|0}md(m);md(l)}tb(n);Q(b|0);p()}f=1}tb(n)}fb=e+272|0;return f|0}function MK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=fb-144|0;fb=e;d=Sb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1199;x[d+84>>2]=a;s=c;a=0;j=fb-304|0;fb=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Vy(d);if(x[d+4>>2]){break d}break c}h=y[b|0];if(!h){break a}e:{f:{g:{h:{while(1){i:{c=h&255;j:{if(yl(c)){while(1){h=b;b=b+1|0;if(yl(y[h+1|0])){continue}break}Ii(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=sd(d)}if(yl(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;i=o+x[d+124>>2]|0;c=b>>31;b=m+x[d+120>>2]|0;i=c+(b>>>0<m>>>0?i+1|0:i)|0;m=b+e|0;o=m>>>0<b>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){e=y[b+1|0];if((e|0)==42){break n}if((e|0)!=37){break m}}Ii(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break p}h=sd(d)}if(yl(h)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break o}h=sd(d)}if(y[b|0]!=(h|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((h|0)>=0){break a}g=0;if(t){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;h=c;f=o+x[d+124>>2]|0;e=c>>31;c=m+x[d+120>>2]|0;g=e+(c>>>0<m>>>0?f+1|0:f)|0;m=c+h|0;o=m>>>0<c>>>0?g+1|0:g;h=b;break j}l=0;b=b+2|0;break l}if(!(!Nh(e)|y[b+2|0]!=36)){c=fb-16|0;x[c+12>>2]=s;f=c;c=e-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+s|0;x[f+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[s>>2];s=s+4|0;b=b+1|0}c=0;while(1){f=y[b|0];if(Nh(f)){b=b+1|0;c=(D(c,10)+f|0)-48|0;continue}break}r=0;if((f|0)==109){p=0;r=(l|0)!=0;f=y[b+1|0];b=b+1|0;a=0}h=b+1|0;k=3;g=r;q:{r:{switch((f&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;h=b?e:h;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;h=b?e:h;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;h=b}e=y[h|0];b=(e&47)==3;u=b?1:k;q=b?e|32:e;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}NK(l,u,m,o);break j}Ii(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=sd(d)}if(yl(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;f=b;i=o+x[d+124>>2]|0;e=b>>31;b=m+x[d+120>>2]|0;o=e+(b>>>0<m>>>0?i+1|0:i)|0;m=b+f|0;o=m>>>0<b>>>0?o+1|0:o}i=c;n=c>>31;Ii(d,c,n);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((sd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:PK(j+8|0,d,u,0);c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-c|0)|x[d+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Sb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}f=y[h+1|0];e=(f|0)==94;Sb(j+32|0,e,257);v[j+32|0]=0;b=e?h+2|0:h+1|0;B:{C:{D:{e=y[(e?2:1)+h|0];if((e|0)!=45){if((e|0)==93){break D}k=(f|0)!=94;break B}k=(f|0)!=94;v[j+78|0]=k;break C}k=(f|0)!=94;v[j+126|0]=k}b=b+1|0}h=b;while(1){f=y[h|0];E:{if((f|0)!=45){if(!f){break f}if((f|0)==93){break x}break E}f=45;g=y[h+1|0];if(!g|(g|0)==93){break E}e=h+1|0;b=y[h-1|0];F:{if(g>>>0<=b>>>0){f=g;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;f=y[e|0];if(f>>>0>b>>>0){continue}break}}h=e}v[(f+j|0)+33|0]=k;h=h+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}e=0;i=0;f=0;g=0;A=0;z=fb-16|0;fb=z;G:{if((b|0)==1){x[31600]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=sd(d)}if(yl(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}A=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=sd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=sd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=sd(d)}if(y[c+95393|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Ii(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+95393|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Ii(d,0,0);x[31600]=28;break G}if((b|0)!=10){break M}f=c-48|0;if(f>>>0<=9){c=0;while(1){c=D(c,10)+f|0;g=c>>>0<429496729;e=x[d+4>>2];Q:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;b=y[e|0];break Q}b=sd(d)}f=b-48|0;if(g&f>>>0<=9){continue}break}e=c}if(f>>>0>9){break K}b=nva(e,0,10,0);g=hb;while(1){e=b+f|0;i=e>>>0<f>>>0?g+1|0:g;b=(i|0)==429496729&e>>>0<2576980378|i>>>0<429496729;c=x[d+4>>2];R:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break R}c=sd(d)}k=c-48|0;if(!(b&k>>>0<=9)){b=10;if(k>>>0<=9){break L}break K}b=nva(e,i,10,0);g=hb;f=k;if((g|0)==-1&(f^-1)>>>0>=b>>>0|(g|0)!=-1){continue}break}b=10;break L}if(b-1&b){g=y[c+95393|0];if(g>>>0<b>>>0){while(1){f=D(b,f)+g|0;e=f>>>0<119304647;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=sd(d)}g=y[c+95393|0];if(e&g>>>0<b>>>0){continue}break}e=f}if(b>>>0<=g>>>0){break L}n=b;while(1){f=nva(e,i,n,0);k=hb;g=g&255;if((k|0)==-1&(g^-1)>>>0<f>>>0){break L}i=k;e=f+g|0;i=e>>>0<g>>>0?i+1|0:i;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=sd(d)}g=y[c+95393|0];if(b>>>0<=g>>>0){break L}Of(z,n,0,0,0,e,i,0,0);if(!(x[z+8>>2]|x[z+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+95649|0];f=y[c+95393|0];if(f>>>0<b>>>0){while(1){g=g<<k|f;e=g>>>0<134217728;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=sd(d)}f=y[c+95393|0];if(e&f>>>0<b>>>0){continue}break}e=g}if(b>>>0<=f>>>0){break L}n=k&31;if((k&63)>>>0>=32){g=0;n=-1>>>n|0}else{g=-1>>>n|0;n=g|(1<<n)-1<<32-n}if(!g&e>>>0>n>>>0){break L}while(1){F=f&255;c=e;f=k&31;if((k&63)>>>0>=32){i=c<<f;c=0}else{i=(1<<f)-1&c>>>32-f|i<<f;c=c<<f}e=F|c;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=sd(d)}f=y[c+95393|0];if(b>>>0<=f>>>0){break L}if((g|0)==(i|0)&e>>>0<=n>>>0|g>>>0>i>>>0){continue}break}}if(y[c+95393|0]>=b>>>0){break K}while(1){c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=sd(d)}if(y[c+95393|0]<b>>>0){continue}break}x[31600]=68;e=-1;i=-1;A=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=A;f=b^e;e=f-b|0;c=b>>31;i=(c^i)-((b>>>0>f>>>0)+c|0)|0}fb=z+16|0;c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-c|0)&x[d+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=e;break w}NK(l,u,e,i);break w}if(!l){break w}c=x[j+16>>2];f=x[j+20>>2];b=x[j+8>>2];e=x[j+12>>2];X:{switch(u|0){case 0:G=l,H=TG(b,e,c,f),B[G>>2]=H;break w;case 1:G=l,I=vx(b,e,c,f),C[G>>3]=I;break w;case 2:break X;default:break w}}x[l>>2]=b;x[l+4>>2]=e;x[l+8>>2]=c;x[l+12>>2]=f;break w}k=(q|0)!=99;c=k?31:c+1|0;Y:{if((u|0)==1){f=l;if(r){f=Fd(c<<2);if(!f){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=f;Z:{while(1){e=x[d+4>>2];_:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break _}e=sd(d)}if(!y[(e+j|0)+33|0]){break Z}v[j+27|0]=e;e=xt(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}p=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}g=1;b=c;c=b<<1|1;f=Ev(a,c<<2);if(f){continue}break e}break}p=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Y}if(r){b=0;f=Fd(c);if(!f){break h}while(1){a=f;while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=sd(d)}if(!y[(e+j|0)+33|0]){c=0;p=a;break Y}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}g=1;b=c;c=b<<1|1;f=Ev(a,c);if(f){continue}break}p=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];aa:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break aa}a=sd(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;p=a;break Y}}}while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=sd(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;p=0;c=0}f=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){f=f-1|0;x[d+4>>2]=f}e=f-x[d+44>>2]|0;f=e+x[d+120>>2]|0;g=x[d+124>>2]+(e>>31)|0;g=f>>>0<e>>>0?g+1|0:g;if(!(g|f)|!(k|(f|0)==(i|0)&(g|0)==(n|0))){break i}if(r){x[l>>2]=a}ca:{if((q|0)==99){break ca}if(c){x[(b<<2)+c>>2]=0}if(!p){p=0;break ca}v[b+p|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;f=o+x[d+124>>2]|0;c=b>>31;b=m+x[d+120>>2]|0;i=c+(b>>>0<m>>>0?f+1|0:f)|0;m=b+e|0;o=m>>>0<b>>>0?i+1|0:i;t=((l|0)!=0)+t|0}b=h+1|0;h=y[h+1|0];if(h){continue}break a}break}a=c;break g}g=1;p=0;a=0;break e}g=r;break b}g=r}if(t){break b}}t=-1}if(!g){break a}Db(p);Db(a)}fb=j+304|0;fb=d+144|0;return t}function Woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=fb-192|0;fb=j;if(!nv(a)){e=j+40|0;tW(e,a);f=j+168|0;df(f,e,128,2);e=j+180|0;Cc(e,f);zc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;p=j+180|0;g=fb-32|0;fb=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;wn(p,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;l=g+24|0;e=y[Rb(g+28|0,l)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;k=g+20|0;m=y[Rb(l,k)|0];x[g+28>>2]=m;c:{if(y[a+140|0]&16){i=Bb(y[a+150|0]|y[a+151|0]<<8);h=Bb(y[a+152|0]|y[a+153|0]<<8);f=x[c>>2];s=+(f>>>0)/6553600;e=Ar(s*+((i|e<<16)>>>0));x[g+24>>2]=f-e;t=g,u=Ar(s*+((h|m<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Gb(l,k)>>2],x[t+28>>2]=u;break c}i=x[c>>2];k=x[c+20>>2];if(!je(i,k)){break c}f=i>>>7|0;e=D(f,(e<<7>>>0)/100|0);x[g+24>>2]=i-e;x[g+20>>2]=D(f,(m<<7>>>0)/100|0);f=x[Gb(g+24|0,g+20|0)>>2];h=z[c+34>>1];i=D(_d(h),i);d:{if(h&1){bc(g+12|0,k,i);k=x[g+12>>2];i=_d(z[c+34>>1]);h=k+(D(i,e+f|0)<<1)|0;m=w[k+(D(e,i)<<1)>>1];k=0-i<<1;while(1){e:{f:{if(f){i=w[h>>1]-m|0;l=i>>31;if((i^l)-l>>>0>=1536){break f}}else{f=0}break e}f=f-1|0;h=h+k|0;continue}break}break d}bc(g+4|0,k,i);k=x[g+4>>2];i=_d(z[c+34>>1]);m=0-i|0;h=k+D(i,e+f|0)|0;k=v[k+D(e,i)|0];while(1){g:{h:{if(f){i=v[h|0]-k|0;l=i>>31;if((i^l)-l>>>0>=6){break h}}else{f=0}break g}f=f-1|0;h=h+m|0;continue}break}}x[g+28>>2]=f}wn(p,e,g+28|0)}fb=g+32|0;r=ec(p);if(!(!x[r>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;f=x[j+180>>2];x[c+4>>2]=f;x[c+8>>2]=f+x[r>>2]}f=j;e=y[a+134|0];if((e-1&255)>>>0<=198){v[f+40|0]=e;v[f+168|0]=100;e=(y[Rb(f+40|0,f+168|0)|0]<<7>>>0)/100|0}else{e=128}v[f+39|0]=e;v[j+40|0]=64;e=j+39|0;f=j+40|0;t=c,u=y[ef(e,f)|0]>>>1|0,w[t+32>>1]=u;v[j+40|0]=64;t=b,u=y[Rb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;gm(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){kk(b,127,1);jk(b,0,1)}i:{if(!je(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){g=x[c>>2];f=x[c+20>>2];j:{if(!je(g,f)|g>>>0<2){break j}k:{l:{switch(dl(z[c+34>>1])-1|0){case 3:e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){Ub(f+(e<<2)|0,f+(g+(e^-1)<<2)|0);e=e+1|0;continue}break};break k;case 1:e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){UR(f+(e<<1)|0,f+(g+(e^-1)<<1)|0);e=e+1|0;continue}break};break k;case 0:break l;default:break j}}e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){tg(e+f|0,f+(g+(e^-1)|0)|0);e=e+1|0;continue}break}}Qj(c,d)}b=y[a+140|0]}if(b&4){m:{f=x[c>>2];g=x[c+20>>2];if(!je(f,g)){break m}b=z[c+34>>1];f=D(_d(b),f);n:{o:{switch(Pn(b)-1|0){case 1:e=0;while(1){if((e|0)!=(f|0)){b=g+(e<<1)|0;w[b>>1]=z[b>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}e=0;while(1){if((e|0)!=(f|0)){b=e+g|0;v[b|0]=y[b|0]^-1;e=e+1|0;continue}break}}Qj(c,d)}}o=y[a+170|0]!=2|y[a+171|0]>100?o:y[a+172|0]<101;b=z[c+34>>1];if(!(!(o|y[a+160|0]!=0|y[a+141|0])|b&1)){f=mv(x[c>>2],_d(b)<<1&254);if(!f){break i}b=f;h=x[c>>2];e=z[c+34>>1];g=D(_d(e),h);l=x[c+20>>2];e=Wk(h,e);i=fb-16|0;fb=i;x[i+12>>2]=g;wc(i+12|0,e);h=x[i+12>>2];while(1){if(h){w[b>>1]=v[l|0]<<8;l=l+1|0;b=b+2|0;h=h-1|0;continue}break}fb=i+16|0;w[c+34>>1]=z[c+34>>1]|1;rW(c,f,x[c>>2],d);b=z[c+34>>1]}f=x[c>>2];e=x[c+20>>2];p:{if(v[a+141|0]>=0){break p}bc(j+40|0,e,D(_d(b),f));q:while(1){if((0-v[a+141|0]|0)<=(n|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break p}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=nn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=qd(w[e>>1]-qd(f,1)|0,1);w[e>>1]=f;Md(j+168|0);continue}else{n=n+1|0;continue q}}}}if(o){bc(j+40|0,e,D(_d(b),f));h=x[j+44>>2];b=(h|0)/2|0;e=b;f=e>>31;b=y[a+172|0];i=y[a+171|0];g=b-i|0;l=0-(b>>>0<i>>>0)<<24|g>>>8;b=g<<24;e=b+e|0;f=f+l|0;b=Gc(ova(e,b>>>0>e>>>0?f+1|0:f,h,h>>31),hb);t=j,u=wb(x[j+40>>2]),x[t+168>>2]=u;g=b;k=g>>31;b=i<<24;f=b>>31;i=nn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,i)){h=w[e>>1];h=nva(b,f,h,h>>31);l=hb;h=h+838860800|0;l=h>>>0<838860800?l+1|0:l;t=e,u=Gc(ova(h,l,1677721600,0),hb),w[t>>1]=u;f=f+k|0;b=b+g|0;f=b>>>0<g>>>0?f+1|0:f;Md(j+168|0);continue}break}f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}if(y[a+160|0]){bc(j+168|0,e,D(_d(b),f));m=y[a+163|0];k=y[a+162|0];b=0;o=0;l=0;if(y[a+161|0]>=2){i=x[j+172>>2];f=(i|0)/2|0;h=f;g=f>>31;f=y[a+164|0];e=0-(f>>>0<k>>>0)|0;f=f-k|0;l=e<<23|f>>>9;f=f<<23;e=f+h|0;l=g+l|0;o=Gc(ova(e,e>>>0<f>>>0?l+1|0:l,i,i>>31),hb);i=x[j+172>>2];f=(i|0)/2|0;h=f;g=f>>31;f=y[a+165|0];e=0-(f>>>0<m>>>0)|0;f=f-m|0;l=e<<23|f>>>9;f=f<<23;e=f+h|0;g=g+l|0;l=Gc(ova(e,e>>>0<f>>>0?g+1|0:g,i,i>>31),hb)}f=m<<23;e=k<<23;g=y[a+160|0];t=j,u=wb(x[j+168>>2]),x[t+32>>2]=u;i=(j+40|0)+((g&2)<<2)|0;h=nn(x[j+168>>2],x[j+172>>2]);n=0;while(1){k=x[j+32>>2];if(Ib(k,h)){g=(w[k>>1]>>1)-n|0;x[j+48>>2]=g;m=g;g=(e|0)/8388608|0;b=qd(D(m,g),8)+b|0;x[j+44>>2]=b;g=qd(D(b,g),6)+n|0;n=qd(qd(D(g,(f|0)/8388608|0),6)+g|0,2);x[j+40>>2]=n;t=k,u=ed(x[i>>2]),w[t>>1]=u;f=f+l|0;e=e+o|0;Md(j+32|0);continue}else{f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}break}}r:{if(v[a+141|0]<=0){break r}bc(j+40|0,e,D(_d(b),f));n=0;s:while(1){if(v[a+141|0]<=(n|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break r}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=nn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=((w[e>>1]<<1)+f|0)/3|0;w[e>>1]=f;Md(j+168|0);continue}else{n=n+1|0;continue s}}}}f=D(_d(b),f);t:{if(b&1){bc(j+24|0,e,f);l=x[j+28>>2];b=fb-16|0;fb=b;p=x[j+24>>2];e=wb(p);q=nn(p,l);n=fb-16|0;fb=n;v[n+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;gc(o+4|0,n+15|0,n+14|0);m=b+8|0;f=o+12|0;h=wn(m,e,f);u:{if(lc(e,q)){break u}k=Md(f);g=x[k>>2];if(lc(g,q)){break u}e=x[h>>2];f=Yl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=Md(k);e=x[g>>2];if(!Ib(e,q)){break u}g=x[Md(g)>>2];if(lc(g,q)){if(!Yl(e,f)){h=i;if(Yl(e,x[i>>2])){break u}}x[h>>2]=e;break u}v:{if(Yl(g,e)){if(Yl(g,f)){x[h>>2]=g;f=g}if(Yl(e,x[i>>2])){continue}break v}if(Yl(e,f)){x[h>>2]=e;f=e}e=g;if(Yl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=n+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[ec(m)>>2]>>1],x[t>>2]=u;w:{g=x[Ze(b+4|0,b)>>2];if((g|0)>32766|!g){break w}e=wb(p);x[b+4>>2]=e;f=nn(p,l);while(1){if(!Ib(e,f)){break w}w[e>>1]=(D(w[e>>1],32767)|0)/(g|0);e=x[Md(b+4|0)>>2];continue}}break t}bc(j+16|0,e,f);l=x[j+20>>2];b=fb-16|0;fb=b;p=x[j+16>>2];e=wb(p);q=Xk(p,l);n=fb-16|0;fb=n;v[n+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;gc(o+4|0,n+15|0,n+14|0);m=b+8|0;f=o+12|0;h=wn(m,e,f);x:{if(lc(e,q)){break x}k=me(f);g=x[k>>2];if(lc(g,q)){break x}e=x[h>>2];f=Zl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=me(k);e=x[g>>2];if(!Ib(e,q)){break x}g=x[me(g)>>2];if(lc(g,q)){if(!Zl(e,f)){h=i;if(Zl(e,x[i>>2])){break x}}x[h>>2]=e;break x}y:{if(Zl(g,e)){if(Zl(g,f)){x[h>>2]=g;f=g}if(Zl(e,x[i>>2])){continue}break y}if(Zl(e,f)){x[h>>2]=e;f=e}e=g;if(Zl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=n+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[ec(m)>>2]],x[t>>2]=u;z:{g=x[Ze(b+4|0,b)>>2];if((g|0)>126|!g){break z}e=wb(p);x[b+4>>2]=e;f=Xk(p,l);while(1){if(!Ib(e,f)){break z}v[e|0]=(D(v[e|0],127)|0)/(g|0);e=x[me(b+4|0)>>2];continue}}}fb=b+16|0;A:{if((y[a+134|0]-101&255)>>>0>98){break A}b=z[c+34>>1];f=D(x[c>>2],_d(b));e=x[c+20>>2];if(b&1){x[j+8>>2]=e;x[j+12>>2]=(e+(f<<1)|0)-e>>1;g=x[j+12>>2];f=y[a+134|0];h=fb-16|0;fb=h;b=x[j+8>>2];e=wb(b);x[h+12>>2]=e;k=(3276800-(f<<14)|0)/100|0;f=0-k|0;i=32768-k|0;b=nn(b,g);while(1){if(Ib(e,b)){g=w[e>>1];B:{if((g|0)>(k|0)){m=i+((D(k,g-k|0)|0)/(i|0)|0)|0;break B}m=((D(k,g+k|0)|0)/(i|0)|0)-i|0;if((f|0)>(g|0)){break B}m=(D(g,i)|0)/(k|0)|0}t=e,u=ed(m),w[t>>1]=u;e=x[Md(h+12|0)>>2];continue}break}fb=h+16|0;break A}b=xo(j,e,e+f|0);h=x[b>>2];g=x[b+4>>2];b=y[a+134|0];i=fb-16|0;fb=i;e=wb(h);x[i+12>>2]=e;m=(3276800-(b<<14)|0)/100|0;f=0-m|0;k=32768-m|0;b=Xk(h,g);while(1){if(Ib(e,b)){g=v[e|0]<<8;C:{if((g|0)>(m|0)){h=k+((D(m,g-m|0)|0)/(k|0)|0)|0;break C}h=((D(m,g+m|0)|0)/(k|0)|0)-k|0;if((f|0)>(g|0)){break C}h=(D(g,k)|0)/(m|0)|0}t=e,u=vY((h|0)/256|0),v[t|0]=u;e=x[me(i+12|0)>>2];continue}break}fb=i+16|0}qW(c);if(y[a+128|0]!=8){break i}e=y[a+131|0];if(!e){break i}f=x[r>>2];if(!f){break i}b=x[j+180>>2];t=yb(c+68|0,0),u=b+D(f,e+1|0)|0,x[t>>2]=u;h=x[j+180>>2];x[c+12>>2]=h;x[c+16>>2]=h+x[r>>2];e=x[r>>2];g=y[a+131|0];if(e>>>0>268435456/(g>>>0)>>>0){break i}b=x[c>>2];f=D(e,g);if(b>>>0>268435456-f>>>0){break i}m=b+f|0;l=dl(z[c+34>>1]);b=mv(m,l);if(!b){break i}h=h+D(e,g+1|0)|0;x[c>>2]=m;g=x[c+20>>2];k=x[j+180>>2];i=yc(b,g,D(l,k+x[r>>2]|0));e=g+D(k,l)|0;f=y[a+131|0];b=0;while(1){if((b|0)==(f|0)){yc(i+D(h,l)|0,g+D(l,k+x[r>>2]|0)|0,D(l,m-h|0));rW(c,i,m,d)}else{b=b+1|0;a=x[r>>2];yc(i+D(l,k+D(b,a)|0)|0,e,D(a,l));continue}break}}fb=j+192|0}function jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-720|0;fb=d;xc(b);a:{b:{c:{d:{if(!Bi(b,d+712|0)){break d}if(!IR(x[d+712>>2],x[d+716>>2])){break d}if(!Tr(b,d+708|0)){break d}f=x[d+708>>2];if(!HR(f)){break d}if((f|0)==1179012417){f=0}else{if((f|0)!=538987841){break d}f=1}e=f?2:1;g=f?1414090313:1313423693;n=Ge(d+688|0,b);k=Nb(d+676|0);e:{f:{g:{h:{i:{j:{k:{if(!c){x[31725]=0;b=d+112|0;V(898,b|0,n|0,e|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){break k}a=N()|0;break a}x[31725]=0;b=d+112|0;S(899,b|0,n|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}}yv(k,b);ie(b);x[31725]=0;b=d+656|0;S(900,b|0,k|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;g=R(174,x[d+656>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}e=0;if(!g){break e}x[31725]=0;j=d+583|0;b=P(901,b|0,j|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}if(!b){break e}b=y[d+648|0];if(!b){break e}x[31725]=0;e=U(152,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}if(!((c|0)!=0&e)){break e}x[31725]=0;O(248,a|0,8388608);b=x[31725];x[31725]=0;if((b|0)==1){break i}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;b=d+112|0;e=d+464|0;o=a,q=z[Nc(b,e)>>1],w[o+480188>>1]=q;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31725]=0;O(132,a+1298344|0,(f?16946:16980)|0);g=x[31725];x[31725]=0;if((g|0)==1){break i}x[31725]=0;g=P(1,d+568|0,13318)|0;m=x[31725];x[31725]=0;if((m|0)==1){break g}Ab(a+1298356|0,g);tb(g);o=a+1298404|0,q=x[Fc(b,4)>>2],x[o>>2]=q;HC(e,2,j);x[31725]=0;O(220,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}Ab(a+1298308|0,b);tb(b);b=0;while(1){l:{m:{n:{if(z[a+480188>>1]<=b>>>0){b=wb(x[k>>2]);g=wb(x[k+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){o:{if(!Ib(b,g)){break o}if(H$(1380209231,x[b>>2],x[b+4>>2])){break o}b=x[mm(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,wb(x[k+4>>2]))){break n}break f}g=(b<<5)+a|0;j=g+480280|0;Xe(j);x[31725]=0;e=R(199,d+656|0)|0;m=x[31725];x[31725]=0;p:{q:{if((m|0)!=1){if(!f){break p}if(e>>>0<129){break q}break m}a=N()|0;break b}w[g+480284>>1]=e<<1;break l}if(e<<24>>24<0){break m}x[d+112>>2]=e<<2;x[d+464>>2]=256;o=g+480284|0,q=x[ud(d+112|0,d+464|0)>>2],w[o>>1]=q;break l}x[31725]=0;b=d+112|0;S(900,b|0,k|0,1380209231);e=x[31725];x[31725]=0;r:{if((e|0)!=1){x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break r}g=y[a+484376|0];j=x[a+484360>>2];x[31725]=0;aa(350,Xb(j,g)|0,b|0,e+1&255,255,254);e=x[31725];x[31725]=0;if((e|0)==1){break r}ub(b);break f}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[j>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}s:{if(!(c&1)){break s}w[d+48>>1]=0;x[31725]=0;S(902,d+528|0,k|0,1414807888);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31725]=0;j=a+484344|0;O(225,j|0,Uf(e,b)&65535);b=x[31725];x[31725]=0;t:{if((b|0)!=1){o=d,q=wb(x[d+528>>2]),x[o+76>>2]=q;m=wb(x[d+532>>2]);u:{v:{w:{x:{y:{while(1){b=x[d+76>>2];if(!Ib(b,m)){b=0;break u}b=Ge(d+112|0,b);x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;w[d+452>>1]=e;e=R(153,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break y}x[31725]=0;g=d+464|0;S(187,g|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break x}e=ic(d+548|0,g);x[31725]=0;i=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=i;x[d+16>>2]=x[e+16>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;V(903,d|0,z[d+452>>1],f|0,a|0);e=x[31725];x[31725]=0;if((e|0)==1){break w}ub(g);o=d,q=z[qe(d+48|0,d+452|0)>>1],w[o+48>>1]=q;ub(b);Sf(d+76|0);continue}break}a=N()|0;break v}a=N()|0;break v}a=N()|0;break v}a=N()|0;ub(d+464|0)}ub(b);break t}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Qc(d+528|0);break s}z:{if(!He(x[a+484344>>2],x[a+484348>>2],e)){x[31725]=0;U(198,j|0,e|0,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}}b=b+1|0;continue}break}a=N()|0;break t}a=N()|0}Qc(d+528|0);break b}A:{B:{C:{if(!f){x[31725]=0;S(902,d+76|0,k|0,1414745673);b=x[31725];x[31725]=0;if((b|0)==1){break B}o=d,q=wb(x[d+76>>2]),x[o+100>>2]=q;g=c&2;j=d+472|0;m=wb(x[d+80>>2]);while(1){b=x[d+100>>2];if(!Ib(b,m)){Qc(d+76|0);break A}c=Ge(d+528|0,b);x[31725]=0;e=d+112|0;b=P(904,c|0,e|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){D:{if(!b){break D}b=y[d+113|0];if((b|0)==255){break D}x[31725]=0;f=U(253,a|0,b+1|0,0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break C}if(!f){break D}i=z[a+480190>>1];b=0;x[31725]=0;S(905,e|0,f|0,i|0);f=x[31725];x[31725]=0;if((f|0)==1){break C}while(1){if(y[d+142|0]<=b>>>0){break D}E:{if(!ui(z[a+480190>>1])){break E}x[31725]=0;e=d+464|0;f=P(906,c|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break C}if(!f){break E}i=z[a+480190>>1]+1|0;w[a+480190>>1]=i;if(x[d+464>>2]!=1347240275){break E}h=d+452|0;aj(h,2,j);x[31725]=0;f=d+48|0;O(220,f|0,h|0);h=x[31725];x[31725]=0;F:{if((h|0)!=1){i=i&65535;zc(((i<<5)+a|0)+946304|0,f);tb(f);x[31725]=0;h=e;e=(D(i,104)+a|0)+484380|0;S(907,h|0,d+112|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break C}if(!g){break F}GR(f,z[d+502>>1]);x[31725]=0;U(217,f|0,e|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break E}break C}break C}f=z[e+34>>1];e=x[e>>2];x[31725]=0;P(185,c|0,Wk(e,f)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}}b=b+1|0;continue}}ub(c);Sf(d+100|0);continue}break}break C}x[31725]=0;S(902,d+452|0,k|0,1179011410);b=x[31725];x[31725]=0;if((b|0)!=1){o=d,q=wb(x[d+452>>2]),x[o+448>>2]=q;g=c&2;j=d+468|0;m=wb(x[d+456>>2]);G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=x[d+448>>2];if(!Ib(b,m)){Qc(d+452|0);break A}c=Ge(d+528|0,b);x[31725]=0;b=R(153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}x[31725]=0;b=P(908,c|0,d+440|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break O}if(!(x[d+440>>2]==1414745673&b)){break R}x[31725]=0;f=d+112|0;b=P(909,c|0,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break N}if(!b){break R}b=y[d+117|0];if((b|0)==255){break R}x[31725]=0;b=U(253,a|0,b+1|0,0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break M}if(!b){break R}e=z[a+480190>>1];x[31725]=0;S(910,f|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break M}x[31725]=0;b=d+464|0;S(899,b|0,c|0,2);f=x[31725];x[31725]=0;if((f|0)==1){break Q}x[31725]=0;S(902,d+100|0,b|0,1179011410);f=x[31725];x[31725]=0;if((f|0)==1){break L}ie(b);o=d,q=wb(x[d+100>>2]),x[o+96>>2]=q;i=wb(x[d+104>>2]);S:{T:{while(1){b=x[d+96>>2];if(!Ib(b,i)){break S}b=Ge(d+76|0,b);x[31725]=0;f=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break K}U:{V:{if((f|0)!=538989377){break V}f=z[a+480190>>1];if(!ui(f)){break V}e=y[d+436|0]|y[d+437|0]<<8;h=e-1|0;v[d+436|0]=h;v[d+437|0]=h>>>8;if(!e){ub(b);break S}h=f+1|0;w[a+480190>>1]=h;x[31725]=0;f=P(908,b|0,d+68|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break J}if(!(x[d+68>>2]==1347240275&f)){break T}x[31725]=0;e=d+464|0;S(187,e|0,b|0,x[d+72>>2]);f=x[31725];x[31725]=0;W:{if((f|0)!=1){f=ic(d+48|0,e);ub(e);x[31725]=0;e=P(911,f|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break U}if(e){break W}ub(f);ub(b);break S}a=N()|0;break H}l=d+24|0;We(l,2,j);x[31725]=0;e=d+36|0;O(220,e|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break I}h=h&65535;zc(((h<<5)+a|0)+946304|0,e);tb(e);x[31725]=0;h=(D(h,104)+a|0)+484380|0;S(912,d+464|0,d+112|0,h|0);l=x[31725];x[31725]=0;if((l|0)==1){break U}X:{if(!g){break X}x[31725]=0;P(151,f|0,x[d+464>>2]+4|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break U}GR(e,z[d+504>>1]);x[31725]=0;U(217,e|0,h|0,f|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break X}break I}ub(f)}ub(b);Sf(d+96|0);continue}break}break I}ub(b)}Qc(d+100|0)}ub(c);Sf(d+448|0);continue}break}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;ie(d+464|0);break G}a=N()|0;break H}a=N()|0;break H}a=N()|0;ub(f)}ub(b);Qc(d+100|0)}ub(c);Qc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Qc(d+76|0);break b}a=N()|0;break b}e=1}ub(d+656|0);ie(k);ub(n)}fb=d+720|0;return e|0}a=N()|0}ub(d+656|0)}ie(k);ub(n);Q(a|0);p()}function v1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-208|0;fb=e;xc(b);d=e+204|0;a:{if(!Tr(b,d)){break a}x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;x[e+168>>2]=0;x[e+172>>2]=0;x[e+160>>2]=0;x[e+164>>2]=0;b:{c:{if(!dF(d)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}Bw(b,e+160|0);break b}m=1;if(!cF(e+204|0)){break a}}j=e+155|0;f=bF(y[e+207|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=lf(b)}l=d+8|0;gk(l,j);k=gc(d+16|0,x[d+8>>2],f);h=x[k>>2];kc(d,x[b>>2],x[b+8>>2],h,x[k+4>>2]);gk(l,j);Sb(x[d+8>>2]+f|0,0,5-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!aF(j,y[e+207|0])){break a}if(!c){n=1;break a}j=e+207|0;Bd(a,2048);gg(a);d:{e:{f:{g:{h:{i:{j:{k:{if(m){d=fb-16|0;fb=d;f=e+4|0;l=tc(d+4|0,3893);_c(f,l);tb(l);fb=d+16|0;x[31725]=0;d=e+72|0;S(211,d|0,f|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break j}Ab(a+1298344|0,d);tb(d);Eb(f);f=tc(d,11144);Ab(a+1298356|0,f);break k}f=e+4|0;We(f,2,e+160|0);d=e+72|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);l=fb-16|0;fb=l;k=tc(l+4|0,3944);_c(f,k);tb(k);fb=l+16|0;x[31725]=0;S(211,d|0,f|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break i}Ab(a+1298344|0,d);tb(d);Eb(f);f=tc(d,11148);Ab(a+1298356|0,f)}tb(f);A=a+1298404|0,B=x[Fc(e+72|0,4)>>2],x[A>>2]=B;w[a+480188>>1]=y[e+159|0];w[a+480190>>1]=y[e+155|0];l:{f=y[e+207|0];if(f>>>0>8){break l}w[a+480188>>1]=4;d=0;while(1){if((d|0)==4){break l}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}m:{if(f>>>0>=11){f=(f|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break m}j=Kw(b);n:{if((j|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break n}x[e+72>>2]=(j<<1)+128;x[e+4>>2]=0;x[e+140>>2]=256;A=((d<<5)+a|0)+480284|0,B=x[fk(e+72|0,e+4|0,e+140|0)>>2],w[A>>1]=B}d=d+1|0;continue}}if(f>>>0<9){break m}Vb(b,16);d=0;while(1){if((d|0)==16){break m}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}o:{if(y[e+207|0]>=13){d=e+72|0;Hw(d,b);f=Jc(d);d=y[e+72|0];if(d>>>0<=31){v[e+72|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}xg(Xb(x[a+484360>>2],y[a+484376|0]),y[e+156|0]);l=Nb(e+140|0);d=x[b+8>>2];f=y[e+207|0]>13;if(!f){break h}x[31725]=0;O(212,l|0,y[e+156|0]);j=x[31725];x[31725]=0;if((j|0)!=1){break h}d=N()|0;break g}d=N()|0;Eb(e+4|0);break f}d=N()|0;Eb(e+4|0);break f}s=d+(f<<1)|0;d=0;p:{q:{while(1){if(y[e+156|0]<=d>>>0){j=0;if(y[e+207|0]!=10){break p}h=x[b+8>>2];d=1;while(1){j=z[a+480190>>1]>=(d&65535)>>>0;if(!j){break q}x[31725]=0;f=P(213,b|0,e+72|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){if(f){f=0;r:{if(y[e+155|0]<(y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24))>>>0|y[e+72|0]>1){break r}k=y[e+122|0]|y[e+123|0]<<8|(y[e+124|0]<<16|y[e+125|0]<<24);if(k>>>0>1048576|y[e+128|0]>64|k>>>0<(y[e+129|0]|y[e+130|0]<<8|(y[e+131|0]<<16|y[e+132|0]<<24))>>>0){break r}f=k>>>0>=(y[e+133|0]|y[e+134|0]<<8|(y[e+135|0]<<16|y[e+136|0]<<24))>>>0}if(!f){break q}}d=d+1|0;continue}break}d=N()|0;break g}A=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],d),B=d,w[A>>1]=B;s:{if(y[e+207|0]>=14){x[31725]=0;f=R(191,b|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}A=_b(x[l>>2],d),B=f,w[A>>1]=B}f=z[a+480188>>1];x[31725]=0;P(185,b|0,f<<1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}d=d+1|0;continue}break}d=N()|0;break g}x[31725]=0;P(151,b|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break p}d=N()|0;break g}d=z[a+480190>>1];x[31725]=0;x[e+72>>2]=0;k=U(214,e+60|0,d|0,e+72|0)|0;d=x[31725];x[31725]=0;t:{u:{v:{w:{if((d|0)!=1){n=j?59:65;h=e+73|0;d=1;x:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){j=Nb(e+48|0);x[31725]=0;n=U(215,b|0,j|0,y[e+157|0]|y[e+158|0]<<8)|0;d=x[31725];x[31725]=0;y:{if((d|0)!=1){if(!n){break d}d=0;f=0;h=x[j>>2];if(!lc(h,x[j+4>>2])){f=wb(h);g=wb(x[j+4>>2]);h=fb-16|0;fb=h;z:{if(!Ib(f,g)){break z}x[h+12>>2]=f;while(1){i=x[Md(h+12|0)>>2];if(!Ib(i,g)){break z}f=cl(y[f|0]|y[f+1|0]<<8,y[i|0]|y[i+1|0]<<8)?i:f;continue}}fb=h+16|0;f=y[f|0]|y[f+1|0]<<8}x[31725]=0;i=P(216,e+24|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break y}A:{while(1){if((d|0)==(f|0)){if(!(c&2)){break w}r=Xc(e+4|0,8,1,0,m?2:1);d=z[a+480190>>1];g=1;B:{C:{D:while(1){o=g&65535;if(o>>>0>(d&65535)>>>0){break w}d=x[b+8>>2];h=x[b>>2];x[31725]=0;d=U(152,h|0,d|0,1)|0;h=x[31725];x[31725]=0;if((h|0)==1){break B}if(!d){break w}t=x[b+8>>2];h=0;E:while(1){d=z[a+480190>>1];if(h>>>0>=d>>>0){g=g+1|0;continue D}if((o|0)!=x[yb(x[k>>2],h)>>2]){h=h+1|0;continue}x[31725]=0;P(151,b|0,t|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;h=h+1|0;d=D(h,104)+a|0;q=d+484380|0;U(217,r|0,q|0,b|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break C}if(!m){continue}bc(e+72|0,x[d+484400>>2],x[q>>2]);A=e,B=wb(x[e+72>>2]),x[A>>2]=B;q=Xk(x[e+72>>2],x[e+76>>2]);while(1){d=x[e>>2];if(!Ib(d,q)){continue E}v[d|0]=y[d|0]^128;me(e);continue}}break}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break v}x[31725]=0;h=R(191,b|0)|0;g=x[31725];x[31725]=0;F:{if((g|0)==1){break F}x[31725]=0;P(185,b|0,1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break F}if(h){x[31725]=0;g=e+4|0;S(187,g|0,b|0,D(h,3)+(y[e+207|0]==1?3:0)|0);h=x[31725];x[31725]=0;if((h|0)==1){break A}h=ic(e+72|0,g);hd(dh(x[i>>2],d),h);ub(h);ub(g)}d=d+1|0;continue}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break u}d=N()|0;break u}G:{H:{if(y[e+207|0]<=9){x[31725]=0;i=e+72|0;O(218,b|0,i|0);g=x[31725];x[31725]=0;I:{J:{if((g|0)==1){break J}x[31725]=0;O(219,i|0,(D(f,104)+a|0)+484380|0);i=x[31725];x[31725]=0;if((i|0)==1){break J}g=e+48|0;We(g,2,h);x[31725]=0;i=e+4|0;O(220,i|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break I}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}if(m){x[31725]=0;i=e+72|0;O(221,b|0,i|0);g=x[31725];x[31725]=0;K:{L:{if((g|0)==1){break L}x[31725]=0;O(222,i|0,(D(f,104)+a|0)+484380|0);i=x[31725];x[31725]=0;if((i|0)==1){break L}x[31725]=0;i=P(36,e+36|0,22267)|0;g=x[31725];x[31725]=0;if((g|0)==1){break K}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+74|0]|y[e+75|0]<<8|(y[e+76|0]<<16|y[e+77|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}x[31725]=0;i=e+72|0;S(223,b|0,i|0,n|0);g=x[31725];x[31725]=0;if((g|0)==1){break G}x[31725]=0;S(224,i|0,(D(f,104)+a|0)+484380|0,j|0);i=x[31725];x[31725]=0;if((i|0)==1){break G}g=e+48|0;We(g,2,h);x[31725]=0;i=e+4|0;O(220,i|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break x}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B}d=d+1|0;continue}break}d=N()|0;break t}d=N()|0;break t}d=N()|0;break g}if(!(c&1)){break e}x[31725]=0;m=a+484344|0;O(225,m|0,y[e+156|0]);c=x[31725];x[31725]=0;M:{if((c|0)!=1){c=0;while(1){N:{if(y[e+156|0]<=c>>>0){break e}d=64;h=x[l>>2];if(Zc(h,x[l+4>>2])>>>0>c>>>0){d=z[_b(h,c)>>1]}x[31725]=0;d=U(198,m|0,c&65535,d&65535)|0;h=x[31725];x[31725]=0;if((h|0)==1){break M}O:{if(d){d=z[a+480188>>1];x[31725]=0;P(151,b|0,D(((y[e+207|0]>13)<<1)+(d<<1)|0,c)+s|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break M}h=Nb(e+72|0);d=z[a+480188>>1];x[31725]=0;g=U(215,b|0,h|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break O}d=0;P:{if(!g){break P}while(1){if(z[a+480188>>1]<=d>>>0){break P}Q:{g=_b(x[h>>2],d);g=(y[g|0]|y[g+1|0]<<8)-1|0;if((g&65535)>>>0>=(y[e+157|0]|y[e+158|0]<<8)>>>0){break Q}g=_b(x[j>>2],g);g=(y[g|0]|y[g+1|0]<<8)-1&65535;if(g>>>0>=f>>>0){break Q}r=x[m>>2];o=x[i>>2];x[31725]=0;S(226,Wb(r,c)|0,d&65535,dh(o,g)|0);g=x[31725];x[31725]=0;if((g|0)!=1){break Q}break N}d=d+1|0;continue}}md(h)}c=c+1|0;continue}}break}d=N()|0;md(h);break v}d=N()|0;break v}d=N()|0}Qc(i)}md(j)}uc(k)}md(l)}Q(d|0);p()}Qc(i)}md(j);uc(k);md(l)}fb=e+208|0;return n|0}function F2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;xc(b);Sp(a);a:{b:{c:{d=e+1432|0;if(!rs(b,d)){break c}if(!OG(d)){break c}if(!c){i=1;break c}if(!Cm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!Cm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}ox(a);w=e,B=nx(),x[w+68>>2]=B;c=e+68|0;mx(lj(x[a+4>>2])+32|0,c);qs(c);m=x[lj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=kh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Gb(d,e+1136|0)>>2],20),x[w+68>>2]=B;wo(m,x[Gb(e+1428|0,c)>>2]);Sb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{i=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!i){x[31725]=0;c=P(151,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}if(!c){break h}x[31725]=0;c=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;d=P(151,b|0,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break q}if(!d){break h}x[31725]=0;d=P(154,b|0,e+1136|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break p}if(!d){break h}x[31725]=0;d=U(155,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break p}if(!d){break h}g=x[s>>2];f=x[b>>2];x[31725]=0;d=y[e+1148|0]|y[e+1149|0]<<8;f=R(156,f|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break o}n=f;f=c+20|0;if(n>>>0<=f+(d<<3)>>>0){break h}c=d?g:0;g=y[e+1148|0]|y[e+1149|0]<<8;f=f+(g<<3)|0;d=0;j=y[e+1150|0]|y[e+1151|0]<<8;if(!(j&1)){while(1){if(d>>>0>=g>>>0){break d}if(!c){break h}g=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);j=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;g=ba(157,j|0,g|0,m|0,x[e+1428>>2])|0;j=x[31725];x[31725]=0;s:{if((j|0)==1){break s}if(!g){break h}x[31725]=0;g=P(151,b|0,f|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}if(!g){break h}g=gc(e+1128|0,xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));j=x[g>>2];g=x[g+4>>2];x[31725]=0;bo(158,e+68|0,b,j,g);g=x[31725];x[31725]=0;if((g|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;g=y[e+1148|0]|y[e+1149|0]<<8;continue}break}i=N()|0;break a}t:{if(j&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;d=ba(157,g|0,d|0,m|0,x[e+1428>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break m}if(!d){break h}o=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[31725]=0;g=y[e+1154|0]|y[e+1155|0]<<8;d=P(151,b|0,f+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break l}if(!d){break h}d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break l}if(!d){break h}x[31725]=0;d=e+48|0;S(159,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31725];x[31725]=0;if((f|0)==1){break b}k=ps(e+68|0,d);ub(d);r=0;j=0;while(1){f=0;u:{while(1){if((j&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31725]=0;d=P(160,k|0,g+1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break u}h=g&15;q=z[(h<<1)+24352>>1];v:{w:{if(q>>>0<=d>>>0){x[31725]=0;h=y[h+24400|0];n=P(160,k|0,h|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break u}d=n+(d-q<<h)|0;if((d|0)!=(g|0)){g=d&15;break v}x[31725]=0;d=P(160,k|0,4)|0;h=x[31725];x[31725]=0;if((h|0)==1){break u}if((d|0)==15){x[31725]=0;h=P(160,k|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;n=f+o|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}q=d>>>8|0;h=h&1024;v[n+1|0]=h?d:q;v[n|0]=h?q:d;f=f+2|0}if(f>>>0<l>>>0){continue}break}j=j+1|0;if(j>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(j<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31725]=0;f=ba(157,f|0,l|0,m|0,x[e+1428>>2])|0;l=x[31725];x[31725]=0;if((l|0)==1){break u}if(!f){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}o=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28848)|0;if((gb|0)==($(28848)|0)){Y(i|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break e}i=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;d=ba(157,g|0,d|0,m|0,x[e+1428>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}if(!d){break h}r=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}o=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[e+1154|0]|y[e+1155|0]<<8;x[31725]=0;d=P(151,b|0,f|0)|0;f=x[31725];x[31725]=0;y:{z:{if((f|0)!=1){if(!d){break h}d=gc(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);f=x[d>>2];d=x[d+4>>2];x[31725]=0;bo(161,e+68|0,b,f,d);d=x[31725];x[31725]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}f=x[b+8>>2];j=x[b>>2];x[31725]=0;d=U(152,j|0,f|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break y}}i=N()|0;break a}i=N()|0;break a}if(!d){break h}x[31725]=0;d=e+48|0;S(159,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31725];x[31725]=0;if((f|0)==1){break f}k=ps(e+68|0,d);ub(d);l=0;j=0;while(1){f=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31725]=0;d=P(160,k|0,g+1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}h=g&7;q=y[h+24384|0];B:{C:{if(q>>>0<=d>>>0){x[31725]=0;h=y[h+24392|0];n=P(160,k|0,h|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break A}d=n+(d-q<<h)|0;if((d|0)!=(g|0)){g=d&7;break B}x[31725]=0;d=P(160,k|0,3)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if((d|0)==7){x[31725]=0;h=P(160,k|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+j|0;n=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[f+r|0]=d?h:n;j=d?h:j;f=f+1|0}if(f>>>0<o>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);o=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31725]=0;f=ba(157,f|0,o|0,m|0,x[e+1428>>2])|0;o=x[31725];x[31725]=0;if((o|0)==1){break A}if(!f){break j}o=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28848)|0;if((gb|0)==($(28848)|0)){Y(i|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break g}i=N()|0}ub(k);break a}ub(k);break h}oe(e+24|0,x[m>>2],x[m+4>>2]);mf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31725]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=jg(162,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}hd(lj(x[a+4>>2])+12|0,b);ub(b);break h}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}ub(k);break h}i=N()|0;break a}Ae(s);break c}ub(k);break d}i=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return i|0}i=N()|0}Ae(s);Q(i|0);p()}function Hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=fb-368|0;fb=e;a:{if(!cd(b,1080)){break a}d=e+364|0;if(!qr(b,d)){break a}l=sY(e+344|0);if(!rY(d,l)){break a}d=z[l+10>>1];if(!d|d>>>0>127){break a}if(!c){R=1;break a}T=1;Bd(a,1);g=z[l+10>>1];w[a+480188>>1]=g;I=y[l+14|0];V=y[l+13|0];m=y[l+12|0];d=e+364|0;if(!ne(d,25242)){T=ne(d,25247)}if(y[l+15|0]){Lb(a+1074312|0,5,1);g=z[a+480188>>1]}d=e+364|0;q=ne(d,16755);n=1;if(!ne(d,17517)){n=ne(d,13686)}u=a+480188|0;B=(g&65535)==8&(V|0)!=0;cd(b,0);k=y[l+16|0];g=fb-16|0;fb=g;b:{f=e+324|0;d=f;if(!fx(b,d)|!k){break b}dx(g+8|0,d);while(1){if(i>>>0>=20){break b}d=x[g+8>>2];tg(xb(d,i),xb(d,i|1));i=i+2|0;continue}}fb=g+16|0;d=e+312|0;df(d,f,20,3);f=e+180|0;Cc(f,d);Ab(a+1298308|0,f);tb(f);w[a+480190>>1]=31;m=(m|0)!=0;g=1;f=0;i=q;while(1){if((g|0)==32){R=A[l+4>>2]>=o>>>0;if(!R){break a}}else{d=y[l+16|0];r=fb-16|0;fb=r;c:{j=e+180|0;if(!hY(b,j)|!d){break c}Dv(r+8|0,j);d=0;while(1){if(d>>>0>=30){break c}k=x[r+8>>2];tg(xb(k,d),xb(k,d|1));d=d+2|0;continue}}fb=r+16|0;k=j;j=D(g,104)+a|0;d=j+484380|0;k=UC(k,d,((g<<5)+a|0)+946304|0,z[a+480188>>1]==4);r=x[d>>2];d:{if(n){v[j+484417|0]=0-(y[e+204|0]<<3);break d}m=r>>>0<65536&m}j=Bb(y[e+202|0]|y[e+203|0]<<8);e:{if(j){Y=!Bb(y[e+208|0]|y[e+209|0]<<8)|Y;break e}Z=y[e+205|0]==64|Z}d=i&1;i=0;f:{if(!d){break f}h=(j<<1)+h|0;d=y[e+204|0];i=!d;if(d|!j){break f}i=y[e+205|0]==64}o=k+o|0;f=f+r|0;g=g+1|0;continue}break}k=y[l+16|0];j=fb-16|0;fb=j;g:{d=e+180|0;if(!OC(b,d)|!k){break g}TC(j+8|0,d);g=0;while(1){if(g>>>0>=130){break g}d=x[j+8>>2];tg(xb(d,g),xb(d,g|1));g=g+2|0;continue}}fb=j+16|0;cd(b,z[l+8>>1]);k=y[e+181|0];d=128;iw(Xb(x[a+484360>>2],y[a+484376|0]),e+182|0,128);j=!k&i;i=j?h:0;k=y[e+180|0];h:{if(k>>>0>=129){o=y[a+484376|0];h=x[a+484360>>2];break h}o=y[a+484376|0];h=x[a+484360>>2];if(k){d=k;break h}k=x[Xb(h,o)>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break h}g=d-1|0;if(!z[_b(k,g)>>1]){continue}break}}r=pY(b,Xb(h,o),d&65535,f,u,i,0);J=1;i:{if(!(j&z[u>>1]==8)){J=(I|0)!=0;break i}x[l>>2]=11263}j:{if(!B){break j}f=Xb(x[a+484360>>2],y[a+484376|0]);aa=e,ba=wb(x[f>>2]),x[aa+312>>2]=ba;f=wb(x[f+4>>2]);while(1){h=x[e+312>>2];if(!Ib(h,f)){break j}w[h>>1]=z[h>>1]>>>1;Md(e+312|0);continue}}bf(Xb(x[a+484360>>2],y[a+484376|0]),y[e+181|0]);I=d-1|0;d=y[e+181|0];k:{if((I&65535)>>>0>=d>>>0){g=z[u>>1];if((d|0)!=120|(g|0)!=4){break k}}bf(Xb(x[a+484360>>2],y[a+484376|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;aa=a,ba=Yb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;Xh(a,0);v[e+179|0]=0;l:{if(m&1){E=1;k=1;break l}E=1;n=0;m=0;h=q;m:while(1){k=m&65535;if(k>>>0<r>>>0){d=0;g=0;while(1)if((g|0)==256){m=m+1|0;continue m}else{i=bh(e+312|0);oY(e+160|0,b,!k&y[l+16|0]!=0);f=x[e+160>>2];x[e+172>>2]=f;x[e+64>>2]=f;f=e+92|0;kp(f,e- -64|0,i);j=Jc(f);i=KD(y[i|0]);n:{o:{p:{q:{t=y[e+92|0];if((t-7&255)>>>0<3){h=0;break q}f=y[j|0];if(!((t|0)!=14|f>>>0<=1)){h=0;break p}if(!((t|0)==15&(f&255)>>>0>31)){h=i?h:0;if((t|0)!=13){break q}d=d+1|0;if((d&65535)>>>0<2){break n}}h=0;break n}if((t|0)==8){break o}if((t|0)!=14){break n}f=y[j|0]}if((f&240)!=128){break n}v[e+80|0]=f<<4;aa=e,ba=y[ef(e+179|0,e+80|0)|0],v[aa+179|0]=ba;break n}aa=e,ba=y[ef(e+179|0,j)|0],v[aa+179|0]=ba;f=v[j|0];if((f|0)>=0){F=1;break n}n=(f|0)!=-92&f>>>0>4294967183|n}E=i&E;g=g+1|0;continue}}break}d=F^-1;F=0;F=(d|n)&1?F:y[e+179|0]>47;k=h&1}cd(b,z[l+8>>1]);d=z[a+480188>>1];G=a+484344|0;W=r+B&65535;Vf(G,W);t=B?4:d;H=a+1074312|0;j=c&1;n=0;m=0;r:{s:{t:{u:{while(1){if((n|0)==(W|0)){break t}v:{if(B){f=(n&65534)>>>1|0;d=n&1;if(!d){if(!Ng(G,f,64)){break t}}i=d<<2;d=Wb(x[G>>2],f);break v}if(!Ng(G,n&65535,64)){break t}i=0;d=Wb(x[G>>2],n)}h=0;i=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i);if(!j){K=0;L=0;break s}d=z[u>>1];v[e+92|0]=0;f=e+92|0;M=dw(e+312|0,d,f);d=z[u>>1];x[31725]=0;v[e+92|0]=0;O=U(601,e+160|0,d|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){X=0;w:{x:while(1){y:{if((X|0)==64){break w}g=0;f=0;r=0;while(1){if((g|0)==(t|0)){X=X+1|0;K=f&r|K;i=D(z[u>>1],6)+i|0;continue x}d=y[l+16|0];x[31725]=0;S(602,e+92|0,b|0,!n&(d|0)!=0);d=x[31725];x[31725]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;h=e+80|0;s=D(g,6)+i|0;kp(h,e+60|0,s);d=y[e+80|0];h=Jc(h);o=y[h|0];if(d|o){z:{if(!(!V|(d&255)!=14)){d=0;v[h|0]=0;v[e+80|0]=0;o=y[h|0];break z}if(!V|(d&255)!=15|(o&255)>>>0<32){break z}o=31;v[h|0]=31;d=y[e+80|0]}Bf(s,d&255,o&255)}d=1;A:{B:{C:{D:{E:{h=y[s+3|0];switch(h-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}m=y[s+5|0]<100|m;r=1;break B}if(!k){break B}v[s+5|0]=0;break B}if((h|0)==9&F){d=y[s+5|0];if((d|0)==164){v[s+3|0]=20;v[s+5|0]=145;break B}aa=s,ba=Dh(d<<1),v[aa+5|0]=ba;break B}if((h|0)!=19){break B}d=y[s+5|0];if(d>>>0>15){break B}d=!(d&1);h=(d^_)&1;_=h?d:_;L=h+L|0}d=f}F:{if(!y[s|0]){h=y[s+1|0];if(!h|B){break F}f=y[xb(x[M>>2],g)|0];if(!f|(f|0)==(h|0)){break F}f=xb(x[O>>2],g);h=y[f|0]+1|0;v[f|0]=h;if((h&255)>>>0<4){break F}x[31725]=0;U(268,H|0,85,1)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break F}break y}aa=xb(x[O>>2],g),ba=0,v[aa|0]=ba}f=y[s+1|0];if(f){aa=xb(x[M>>2],g),ba=f,v[aa|0]=ba}g=g+1|0;f=d;continue}break}}break}i=N()|0;dc(O);break u}dc(O);dc(M);n=n+1|0;continue}break}i=N()|0}dc(M);break r}h=m}G:{H:{I:{f=E^1;if((f|Y)&1){break I}d=e+364|0;J:{if(ne(d,16755)){break J}if(ne(d,17522)){break J}if(!ne(d,13681)){break I}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=Lb(Lb(Lb(H,85,1),91,1),92,1);K:{if(y[e+179|0]>47){break K}d=Lb(d,84,1);if(y[e+181|0]==127){break K}Lb(d,83,1)}if(!((L|0)>6|J)){break H}break G}if(!(E&1)){if(!(y[e+181|0]==127&(I&65535)>>>0<129&q)){break G}x[l>>2]=8494;break G}if((L|0)>6|J){break G}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((q|J)==1){Lb(H,89,1)}if(T){Lb(H,84,1)}i=0;L:{if(!(c&2)){break L}cd(b,z[l+8>>1]+(D(t,W)<<8)|0);m=(f|q^1|Z)&1;g=1;while(1){if((g|0)==32){break L}k=D(g,104)+a|0;j=k+484380|0;d=x[j>>2];if(d){o=2;if(!T){c=nY(b,13884);o=c?10:0;i=c|i;d=x[j>>2]}f=Xc(e+312|0,8,1,0,o);c=wD(f,d)+x[b+8>>2]|0;if(!m){aa=j,ba=x[ad(j,k+484388|0)>>2],x[aa>>2]=ba}fg(f,j,b);cd(b,c)}g=g+1|0;continue}}M:{N:{if(!q){if(!((ne(e+364|0,17522)&h^-1|K)&1)){break N}break M}if((h^-1|K)&1){break M}}c=mY(e+128|0,0);b=x[c+20>>2];x[e+48>>2]=x[c+16>>2];x[e+52>>2]=b;b=x[c+12>>2];x[e+40>>2]=x[c+8>>2];x[e+44>>2]=b;b=x[c+4>>2];x[e+32>>2]=x[c>>2];x[e+36>>2]=b;d=e+312|0;Cv(d,a,0,e+32|0);$=C[x[e+312>>2]>>3];Xi(d);if(!($>=480)){break M}c=Lb(H,5,1);f=lY(e+104|0,$);b=x[f+20>>2];x[e+24>>2]=x[f+16>>2];x[e+28>>2]=b;b=x[f+12>>2];x[e+16>>2]=x[f+8>>2];x[e+20>>2]=b;b=x[f+4>>2];x[e+8>>2]=x[f>>2];x[e+12>>2]=b;Cv(d,a,0,e+8|0);b=y[x[e+312>>2]+26|0];Xi(d);if(b){dg(c,5);break M}x[l>>2]=17089}d=e+364|0;f=d;q=ec(d);b=d;while(1){if((f|0)!=(q|0)){c=y[f|0];v[b|0]=c>>>0<=32?32:c;b=b+1|0;f=f+1|0;continue}break}f=e+92|0;ig(f,16842);x[31725]=0;q=U(44,e+68|0,d|0,q|0)|0;b=x[31725];x[31725]=0;O:{P:{Q:{R:{S:{if((b|0)!=1){x[31725]=0;c=e+80|0;S(603,c|0,1,q|0);b=x[31725];x[31725]=0;if((b|0)==1){break S}x[31725]=0;d=e+312|0;S(141,d|0,f|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break R}Ab(a+1298344|0,d);tb(d);tb(c);tb(q);Eb(f);b=tc(d,12386);Ab(a+1298356|0,b);tb(b);b=x[l>>2];if(b){bi(a+1298368|0,b)}b=e+312|0;aa=a+1298404|0,ba=x[Fc(b,28)>>2],x[aa>>2]=ba;if(!(i&1)){break a}b=tc(b,17141);x[31725]=0;P(76,a+1298368|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break O}tb(b);break a}i=N()|0;break P}i=N()|0;break Q}i=N()|0;tb(e+80|0)}tb(q)}Eb(e+92|0);break r}i=N()|0;tb(b)}Q(i|0);p()}fb=e+368|0;return R|0}function oua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;xc(a);a:{b:{if(b>>>0<=2){H=e,I=Zd(a),v[H+56|0]=I;Vb(a,2);b=hh(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Pg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}pp(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{t=d+484344|0;F=Kd(y[e+58|0]|y[e+59|0]<<8,1,1024);q=eE(t,F);if((q|0)==65535){break c}b=Wb(x[d+484344>>2],q);h=jd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];G=z[Nc(e+12|0,e+44|0)>>1];g=G+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;B=dw(e+44|0,g,e+12|0);d:while(1){if((l|0)==(F|0)){dc(B);break c}e:{f:{g=xb(x[B>>2],0);f=y[g|0];g:{if(!f){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}H=xb(x[B>>2],0),I=g,v[H|0]=I}v[e+12|0]=0;h:{i:{g=h&63;if(!g){break i}x[31725]=0;k=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}v[e+12|0]=k;j:{k:{switch(g-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[ef(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!k){break i}v[c+15|0]=k;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,k),15);break j;case 2:v[c+13|0]=k>>>4;if(k>>>0>=16){b=y[c+12|0];k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b){break g}break f}k=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f;case 3:u=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0>=256-k>>>0?-1:f+k|0;break j;case 6:break k;default:break i}}if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0<=k+1>>>0?1:f-k|0}k=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f}break e}v[g|0]=f-1;k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(!(b&1)){break f}}f=y[c+13|0];b=y[c+12|0];if(b){u=0;if(!f){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(f,y[c+15|0])<<1;f=x[Ze(e+12|0,e+32|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;g=0;s=0;while(1){m:{if(b){h=D(b,f);s=(h|0)/48|0;if(h-1536>>>0>=10752){break m}g=b}x[e+36>>2]=s;x[e+40>>2]=g;Fe(e+36|0,32,255);u=1;x[e+12>>2]=1;H=c,I=x[Ze(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}C=l-1|0;E=1;b=Wb(x[t>>2],q);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],l,1);while(1){i=E&65535;if(i>>>0>G>>>0){if(u){b=e+12|0;ye(Wb(x[t>>2],q),Yh(op(Ye(Ne(b,17,y[e+36|0]),l),0)));ye(Wb(x[t>>2],q),Yh(Ye(Ne(b,16,y[e+40|0]),l)))}if(k>>>0>=16){ye(Wb(x[t>>2],q),R$(Ye(Ne(e+12|0,20,k>>>4|224),l)))}b=k&15;if(b){ye(Wb(x[t>>2],q),R$(Ye(Ne(e+12|0,20,Kd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{r:{g=xb(x[B>>2],i);f=y[g|0];if(!f){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}H=xb(x[B>>2],i),I=g,v[H|0]=I}s=1;m=h&255;if(m&64){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b+1|0]=g;s=!g}if(!(m&32)){g=y[b|0];break r}x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b|0]=g;if((g-1&255)>>>0<=107){f=jm(g+24|0);v[b|0]=f;H=Wc(x[c>>2],i),I=f,v[H+1|0]=I;g=y[b|0];break o}if((g+127&255)>>>0<=107){f=jm((g&127)+24|0);H=Wc(x[c>>2],i),I=f,v[H|0]=I;v[b|0]=0;break q}if((g|0)!=255){break r}g=254;break p}v[g|0]=f-1;break n}if(g&255){break o}}if(!y[b+1|0]){g=0;break o}g=y[Wc(x[c>>2],i)+1|0];v[b+1|0]=0}v[b|0]=g}if(Tc(g)){H=Wc(x[c>>2],i),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(m&16){v[b+2|0]=1;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b+4|0]=g+2>>>2}g=0;r=0;A=0;s:{if(!(m&8)){break s}x[31725]=0;h=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;A=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}t:{switch(h-1|0){case 0:v[b|0]=254;break s;case 1:v[b|0]=255;break s;case 2:f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break s;case 3:f=cw(A,y[c+16|0]);A=f?f|-48:0;r=f?20:0;if(y[b|0]){break s}f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break s;case 4:v[e+12|0]=1;H=e,I=cw(A,y[c+16|0]),v[H+32|0]=I;A=y[ef(e+12|0,e+32|0)|0];H=Wc(x[c>>2],i),I=0,v[H+5|0]=I;r=15;break s;case 5:case 6:case 7:case 8:r=x[c>>2];u:{if(!l){break u}if((h|0)==y[Wc(r,i)+4|0]){break u}f=ye(Wb(x[t>>2],q),Fn(op(Ye(Ne(e+12|0,20,(h+122|160)&255),C),i)));r=x[c>>2];if(!f){break u}H=Wc(r,i),I=h,v[H+4|0]=I}f=Wc(r,i);if(!y[b|0]){v[b|0]=y[f+1|0]}v[f+5|0]=0;r=10;break s;case 9:break t;default:break s}}f=Wc(x[c>>2],i);h=y[f+5|0];v[f+5|0]=h^1;A=h?-98:-97;r=20}v:{w:{x:{if(!(m&4)){break x}x[31725]=0;n=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;j=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[e+31|0]=j;h=1;g=1;y:{switch(n-1|0){case 0:dE(e+12|0,j<<24>>24<<3,128);f=y[b|0];if(Tc(f)){H=b,I=jm(f+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;g=35;break x;case 1:f=cw(j,y[c+16|0]);v[e+31|0]=f;if(!f){break w}v[e+31|0]=f|208;g=20;break v;case 3:case 4:H=e,I=Q$(j,y[c+16|0],1),v[H+31|0]=I;g=(n|0)==4?2:3;break v;case 5:if(!y[b|0]){H=b,I=y[Wc(x[c>>2],i)|0],v[H|0]=I}H=e,I=Q$(j,y[c+16|0],0),v[H+31|0]=I;g=4;break v;case 6:H=b,I=jm(j+25|0),v[H|0]=I;v[e+31|0]=255;g=4;break v;case 7:case 8:case 9:z:{if(!l){break z}if((n|0)==y[Wc(x[c>>2],i)+2|0]){break z}if(!ye(Wb(x[t>>2],q),Fn(op(Ye(Ne(e+12|0,20,(n-8|48)&255),C),i)))){break z}H=Wc(x[c>>2],i),I=n,v[H+2|0]=I}H=e,I=cE(j,y[c+16|0]),v[H+31|0]=I;g=5;break v;case 10:H=e,I=P$(j,y[c+16|0]),v[H+31|0]=I;g=18;break v;case 11:f=cw(j,y[c+16|0]);v[e+31|0]=f;if(f){v[e+31|0]=f|192;g=20;break v}v[b|0]=254;break w;case 2:break v;default:break y}}g=0}h=0;break v}g=0}o=0;f=1;A:{if(m&2){x[31725]=0;m=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;n=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[e+30|0]=n;o=9;f=0;j=0;B:{switch(m-1|0){case 0:case 1:j=1;H=e,I=O$(n,y[c+16|0],(m|0)==1),v[H+30|0]=I;o=11;break A;case 2:H=e,I=P$(n,y[c+16|0]),v[H+30|0]=I;j=1;o=18;break A;case 3:case 4:case 5:C:{if(!l){break C}if((m|0)==y[Wc(x[c>>2],i)+3|0]){break C}if(!ye(Wb(x[t>>2],q),Fn(op(Ye(Ne(e+12|0,20,(m-4|64)&255),C),i)))){break C}H=Wc(x[c>>2],i),I=m,v[H+3|0]=I}H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=8;break A;case 7:case 8:H=e,I=O$(n,y[c+16|0],(m|0)==8),v[H+30|0]=I;j=1;o=29;break A;case 9:H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=27;break A;case 6:break A;default:break B}}o=0;f=1}j=0}if(h){N$(b,l,z[d+480188>>1],g,e+31|0)}if(j){N$(b,l,z[d+480188>>1],o,e+30|0)}D:{E:{F:{G:{H:{if(!s){break H}if(!Tc(y[b|0])){break H}if(!g){break G}if(!f|(g|0)==4){break H}v[e+30|0]=255;o=4}j=b+2|0;if(y[b+2|0]!=1){break D}if(g){break F}v[e+31|0]=y[b+4|0];g=13;break E}v[e+31|0]=255;j=b+2|0;g=4;if(y[b+2|0]!=1){break D}}if(o){break D}v[e+30|0]=y[b+4|0];o=13}v[j|0]=0}h=bh(e+12|0);Gn(e+32|0,h,g,y[e+31|0],o,y[e+30|0]);I:{if(y[j|0]){break I}f=y[e+14|0];if(!f){break I}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];J:{if(r){Gn(e+32|0,h,s&255,y[e+17|0],r,A&255);K:{if(y[j|0]){break K}f=y[e+14|0];if(!f){break K}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];break J}if(!(s&255)){break n}}v[b+3|0]=s;v[b+5|0]=y[e+17|0]}b=b+6|0;E=E+1|0;continue}}break}a=N()|0;dc(B);Q(a|0);p()}else{v[h+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return q|0}function sR(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=fb-336|0;fb=k;m=h;n=i&65535;o=d;p=e&65535;t=(e^i)&-2147483648;r=i>>>16&32767;s=e>>>16&32767;a:{b:{if(r-32767>>>0>4294934529&s-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){q=d;t=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){q=h;t=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;t=2147450880;break a}t=t|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));q=b?0:q;t=b?2147450880:t;b=0;c=0;break a}if(!(f|h|(e|g))){t=t|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(o|p);i=d;j=d?b:o;d=d<<6;i=G(i?c:p);d=d+((i|0)==32?G(j)+32|0:i)|0;bg(k+320|0,b,c,o,p,d-15|0);u=16-d|0;o=x[k+328>>2];p=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|m);h=d;i=d?f:m;d=d<<6;h=G(h?g:n);d=d+((h|0)==32?G(i)+32|0:h)|0;bg(k+304|0,f,g,m,n,d-15|0);u=(d+u|0)-16|0;m=x[k+312>>2];n=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=n|65536;B=e;C=m;d=m;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Of(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Of(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Of(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Of(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Of(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Of(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Of(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Of(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;m=e<<1|x[k+180>>2]>>>31;h=m-1|0;e=(x[k+188>>2]<<1|e>>>31)-!m|0;Of(k+160|0,i,d,0,0,h,e,0,0);d=h;Of(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);w=k+112|0;y=x[k+168>>2];h=x[k+172>>2];m=x[k+160>>2];i=x[k+152>>2];l=m+i|0;n=x[k+164>>2];j=n+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(n|0)==(j|0)&l>>>0<m>>>0|j>>>0<n>>>0;n=j+y|0;j=j>>>0>n>>>0?h+1|0:h;m=!i&l>>>0>1|(i|0)!=0;h=n+m|0;j=m>>>0>h>>>0?j+1|0:j;Of(w,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Of(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);L=(s-r|0)+u|0;e=x[k+116>>2];w=e;d=x[k+112>>2];j=e<<1|d>>>31;i=d<<1;n=j;d=j;h=x[k+140>>2];z=h;e=x[k+136>>2];j=h<<1|e>>>31;l=e<<1|x[k+132>>2]>>>31;h=l+i|0;d=d+j|0;d=h>>>0<l>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;v=d;y=d;l=0;j=p|65536;M=j;N=o;d=o;j=j<<1|d>>>31;P=d<<1;Q=j;H=j;d=nva(v,l,j,0);j=hb;D=d;E=j;u=b<<1;d=c<<1|b>>>31;r=d;j=0;s=j;m=h-13927|0;v=(e|0)==(v|0)&m>>>0<h>>>0|e>>>0>v>>>0;e=(e|0)==(n|0)&h>>>0<i>>>0|e>>>0<n>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|w>>>31;l=z>>>31|0;d=l+d|0;j=h;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;j=h>>>0>d>>>0?j+1|0:j;e=d;d=d+v|0;l=e>>>0>d>>>0?j+1|0:j;e=d-1|0;F=l-!d|0;z=0;i=nva(r,s,F,z);d=i+D|0;h=hb+E|0;h=d>>>0<i>>>0?h+1|0:h;n=(E|0)==(h|0)&d>>>0<D>>>0|h>>>0<E>>>0;D=e;O=c>>>31|0;J=O|o<<1;v=0;e=nva(e,0,J,v);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;p=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+n|0;l=e>>>0>d>>>0?1:l;e=nva(H,s,F,z);d=e+d|0;j=hb+l|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=nva(H,s,D,v);l=hb;h=e;e=nva(J,v,F,z);i=h+e|0;j=hb+l|0;j=e>>>0>i>>>0?j+1|0:j;e=j;j=(l|0)==(j|0)&h>>>0>i>>>0|j>>>0<l>>>0;l=n+e|0;d=d+j|0;d=l>>>0<e>>>0?d+1|0:d;n=l;l=d;e=0;d=e+o|0;j=i+p|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(p|0)&d>>>0<o>>>0|j>>>0<p>>>0;j=l;i=h;h=h+n|0;j=i>>>0>h>>>0?j+1|0:j;I=h;l=j;w=d;o=d;E=m;d=nva(m,0,J,v);i=hb;h=d;m=nva(y,q,r,q);d=d+m|0;j=hb+i|0;j=d>>>0<m>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<h>>>0|i>>>0>j>>>0;h=j;K=u&-2;i=nva(D,v,K,0);p=i+d|0;j=hb+j|0;j=i>>>0>p>>>0?j+1|0:j;i=j;d=(j|0)==(h|0)&d>>>0>p>>>0|h>>>0>j>>>0;h=0;j=d+m|0;d=(j>>>0<d>>>0?1:h)+e|0;n=j+o|0;d=n>>>0<j>>>0?d+1|0:d;j=l;o=d;d=(d|0)==(e|0)&n>>>0<w>>>0|d>>>0<e>>>0;e=d;d=d+I|0;j=e>>>0>d>>>0?j+1|0:j;R=d;w=j;d=nva(H,s,E,q);I=hb;H=d;e=nva(F,z,K,q);d=d+e|0;j=hb+I|0;j=d>>>0<e>>>0?j+1|0:j;m=d;l=nva(y,q,J,v);e=d+l|0;h=j;d=j+hb|0;d=e>>>0<l>>>0?d+1|0:d;s=e;j=nva(r,q,D,v);e=e+j|0;l=hb+d|0;l=e>>>0<j>>>0?l+1|0:l;F=(d|0)==(l|0)&e>>>0<s>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&m>>>0<H>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&m>>>0>s>>>0|d>>>0<h>>>0;d=d+j|0;d=d+F|0;h=l;s=h+n|0;j=(d|z)+o|0;j=h>>>0>s>>>0?j+1|0:j;m=j;d=(o|0)==(j|0)&n>>>0>s>>>0|j>>>0<o>>>0;j=w;h=d;d=d+R|0;j=h>>>0>d>>>0?j+1|0:j;z=d;o=j;d=nva(y,q,K,q);y=hb;n=d;h=nva(r,q,E,q);d=d+h|0;j=hb+y|0;j=d>>>0<h>>>0?j+1|0:j;w=0;h=(j|0)==(y|0)&d>>>0<n>>>0|j>>>0<y>>>0;n=j;d=j+p|0;j=(h|w)+i|0;j=d>>>0<n>>>0?j+1|0:j;i=(i|0)==(j|0)&d>>>0<p>>>0|i>>>0>j>>>0;h=j;j=e;p=0;e=p+d|0;l=h+j|0;j=0;l=e>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>e>>>0|h>>>0>l>>>0;e=d;d=d+i|0;j=(e>>>0>d>>>0?1:j)+m|0;l=o;e=d;d=d+s|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(m|0)==(j|0)&d>>>0<s>>>0|j>>>0<m>>>0;i=h;h=h+z|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){N=P|O;M=v|Q;Of(k+80|0,d,j,h,l,f,g,C,B);l=x[k+84>>2];n=l;j=b<<17;m=0;p=x[k+88>>2];c=m-p|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;p=(j-(x[k+92>>2]+(m>>>0<p>>>0)|0)|0)-(c>>>0<l>>>0)|0;m=0-b|0;n=0-(((b|0)!=0)+n|0)|0;b=L+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Of(k+96|0,d,e,h,i,f,g,C,B);o=x[k+100>>2];r=o;n=0;u=x[k+104>>2];m=n-u|0;l=x[k+96>>2];p=(o|l)!=0;o=m-p|0;p=((b<<16)-(x[k+108>>2]+(n>>>0<u>>>0)|0)|0)-(m>>>0<p>>>0)|0;m=0-l|0;n=0-(((l|0)!=0)+r|0)|0;u=b;r=c;b=L+16383|0}if((b|0)>=32767){t=t|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=p<<1|o>>>31;o=o<<1|n>>>31;p=l;u=h;r=i&65535|b<<16;l=n<<1|m>>>31;i=m<<1;break d}if((b|0)<=-113){b=0;c=0;break a}fn(k- -64|0,d,e,h,i,1-b|0);bg(k+48|0,u,r,N,M,b+112|0);d=x[k+64>>2];e=x[k+68>>2];u=x[k+72>>2];r=x[k+76>>2];Of(k+32|0,f,g,C,B,d,e,u,r);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;m=c-o|0;p=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=m-b|0;p=p-(b>>>0>m>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;Of(k+16|0,f,g,C,B,3,0,0,0);Of(k,f,g,C,B,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(h|0)==(g|0)&f>>>0<i>>>0|g>>>0<h>>>0;l=p;b=(c|0)==(h|0)&i>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(B|0);b=b&(f|0)==(C|0)?g:b&f>>>0>C>>>0|l>>>0>B>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=r;e=d;d=d+u|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];n=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?n:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;n=e;e=b+e|0;d=n>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;q=e|q;t=d|t}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=q;x[a+12>>2]=t;fb=k+336|0}function $O(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-32|0;fb=f;d=Dc(f+20|0,11600);e=rh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){vo(a,x[b+24>>2]+1298356|0);break e}d=Dc(f+20|0,11005);e=rh(c,d);tb(d);if(e){vo(a,x[b+24>>2]+1298344|0);break e}d=Dc(f+20|0,11430);e=rh(c,d);tb(d);if(e){vo(a,x[b+24>>2]+1298392|0);break e}d=Dc(f+20|0,10997);e=rh(c,d);tb(d);if(e){vo(a,x[b+24>>2]+1298380|0);break e}d=f+20|0;e=Dc(d,8243);g=rh(c,e);tb(e);if(g){c=x[x[b+24>>2]+480184>>2];b=31056;f:{g:{while(1){if((b|0)==31104){break g}if((c|0)!=x[b>>2]){b=b+12|0;continue}break}c=fb-32|0;fb=c;e=c+8|0;Qw(e,x[b+8>>2]);x[31725]=0;b=c+20|0;S(125,b|0,0,e|0);g=x[31725];x[31725]=0;h:{i:{j:{if((g|0)!=1){x[31725]=0;O(12,d|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break j}Qb(b);tb(e);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}tb(d);break e}g=f+20|0;d=Dc(g,10982);e=rh(c,d);tb(d);if(e){l=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;b=31056;h=qg(c+36|0);d=Fb(g);while(1){if((b|0)!=31104){if(x[b>>2]==(l|0)){x[31725]=0;e=P(1,c+24|0,x[b+4>>2])|0;i=x[31725];x[31725]=0;k:{l:{m:{n:{o:{p:{if((i|0)!=1){x[31725]=0;S(892,c+16|0,h|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break n}if(!y[c+20|0]){break k}if(!Ad(x[d+4>>2],y[d+11|0])){x[31725]=0;i=P(1,c+4|0,18385)|0;k=x[31725];x[31725]=0;if((k|0)==1){break p}x[31725]=0;P(76,d|0,i|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break o}tb(i)}x[31725]=0;P(76,d|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(i);break m}b=N()|0}tb(e)}tb(d);QR(h);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}QR(h);fb=c+48|0;x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,8309);e=rh(c,d);tb(d);if(e){vo(a,x[b+24>>2]+1298368|0);break e}d=Dc(f+20|0,5620);e=rh(c,d);tb(d);if(e){vo(a,x[b+24>>2]+1298320|0);break e}d=f+20|0;e=Dc(d,12004);g=rh(c,e);tb(e);if(g){lg(d,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31725]=0;S(1059,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,11373);e=rh(c,d);tb(d);if(e){d=oM(x[b+24>>2]);c=x[d+4>>2];q:{if(!lc(x[d>>2],c)){e=aw(c);d=fb-32|0;fb=d;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;c=fb-48|0;fb=c;HF(c+24|0,e,e+4|0,e+8|0,e+12|0,e+16|0,e+24|0);HF(c,d,d+4|0,d+8|0,d+12|0,d+16|0,d+24|0);e=x[c+28>>2];g=x[c+4>>2];fb=c+48|0;fb=d+32|0;if(x[e>>2]==x[g>>2]&x[x[c+24>>2]>>2]==x[x[c>>2]>>2]&x[x[c+32>>2]>>2]==x[x[c+8>>2]>>2]&x[x[c+36>>2]>>2]==x[x[c+12>>2]>>2]&x[x[c+40>>2]>>2]==x[x[c+16>>2]>>2]){e=x[c+44>>2];g=x[c+20>>2];c=x[e>>2]==x[g>>2]&x[e+4>>2]==x[g+4>>2]}else{c=0}if(!c){break q}}Fb(a);break e}g=f+20|0;b=x[b+24>>2];e=aw(x[oM(b)+4>>2]);h=x[b+1298408>>2];d=fb-512|0;fb=d;i=x[e+32>>2];r:{if(i){c=2147483647;j=Ee(+(i>>>0)/18.2);i=-1;s:{if(j>=0x8000000000000000){break s}c=-2147483648;i=0;if(j<=-0x8000000000000000){break s}if(F(j)<0x8000000000000000){c=F(j)>=1?~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0:0;i=~~j>>>0;break s}i=0}b=i;if((h|0)==1){h=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=h;h=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=h;h=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=h;h=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=h;Fu(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;h=_A(OS(d+128|0),hb);c=c+hb|0;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;MS(e,NS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;rN(g,d+96|0);break r}h=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=h;h=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=h;h=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=h;h=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=h;Fu(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;h=_A(OS(d+256|0),hb);c=c+hb|0;i=b;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;MS(e,NS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;Fu(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;BO(g,d+192|0);break r}if((h|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;Fu(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;rN(g,d);break r}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;BO(g,d- -64|0)}fb=d+512|0;x[31725]=0;O(1065,a|0,g|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=f+20|0;e=Dc(d,12273);g=rh(c,e);tb(e);if(g){zV(d,x[b+24>>2]+1298332|0);t:{if(!Ad(x[f+24>>2],y[f+31|0])){break t}c=x[x[b+24>>2]+480180>>2];u:{v:{if((c|0)==33554432){break v}d=1;if((c|0)==32){break u}if((c|0)==16384){break v}if((c|0)==16777216){break u}}d=2}w:{switch(d-1|0){case 0:x[31725]=0;c=f+8|0;O(1066,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){Ab(f+20|0,c);tb(c);break t}break b;case 1:break w;default:break t}}x[31725]=0;c=f+8|0;O(1067,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}d=Ab(f+20|0,c);tb(c);if(!Ad(x[f+24>>2],y[f+31|0])){break t}x[31725]=0;O(1066,c|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}Ab(d,c);tb(c)}b=x[b+24>>2];x[31725]=0;c=a;a=f+20|0;S(1059,c|0,b|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){tb(a);break e}break b}d=f+20|0;e=Dc(d,5472);g=rh(c,e);tb(e);if(g){zV(d,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31725]=0;S(1059,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}i=c;c=Dc(f+20|0,7335);d=rh(i,c);tb(c);if(d){a=Fb(a);m=f,n=wb(x[b+68>>2]),x[m+20>>2]=n;b=wb(x[b+72>>2]);c=1;while(1){d=x[f+20>>2];if(!Ib(d,b)){break e}if(!(c&1)){x[31725]=0;P(991,a|0,22242)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}}x[31725]=0;P(842,a|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}il(f+20|0);c=0;continue}}Dc(a,22267)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=fb-1328|0;fb=d;xc(b);e=fb-16|0;fb=e;i=d+220|0;QX(e+8|0,i);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);k=x[e+4>>2];if((k|0)==(h|0)){Vb(b,x[e+12>>2])}fb=e+16|0;a:{if((h|0)!=(k|0)){break a}if(!SX(i)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(RX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}if(!c){m=1;break a}xc(b);b=Ge(d+220|0,b);x[31725]=0;e=d+208|0;O(643,e|0,b|0);h=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)!=1){ub(b);x[31725]=0;S(644,d+196|0,e|0,1196314451);b=x[31725];x[31725]=0;if((b|0)==1){break i}x[31725]=0;S(644,d+184|0,e|0,1280331091);b=x[31725];x[31725]=0;if((b|0)==1){break h}if(lc(x[d+196>>2],x[d+200>>2])){break b}if(!lc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31725]=0;O(248,a|0,1);b=x[31725];x[31725]=0;j:{if((b|0)!=1){gg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;C=d,E=wb(x[d+184>>2]),x[C+52>>2]=E;k=c&2;g=wb(x[d+188>>2]);k:{l:{while(1){e=x[d+52>>2];if(!Ib(e,g)){break l}b=z[a+480190>>1];if(!ui(b)){break l}b=b+1|0;w[a+480190>>1]=b;x[31725]=0;b=D(b&65535,104)+a|0;h=b+484380|0;O(281,h|0,1);i=x[31725];x[31725]=0;m:{n:{if((i|0)!=1){x[31725]=0;i=d+220|0;l=P(645,e|0,i|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break n}if(!l){break c}if(Av(i)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31725]=0;i=P(36,d+172|0,d+220|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break k}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,i);tb(i);i=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[h>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;o:{if(k){b=Xc(d+24|0,8,1,0,0);x[31725]=0;U(217,b|0,h|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break o}}Sf(d+52|0);continue}break}c=N()|0;break j}C=d,E=wb(x[d+196>>2]),x[C+168>>2]=E;n=a+484344|0;o=c&1;q=a+484360|0;A=wb(x[d+200>>2]);r=a+484380|0;s=a+946304|0;c=1;m=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,A)){break v}if(!(c&1)){x[31725]=0;c=R(276,q|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}if(!c){break v}}kj(Xb(x[a+484360>>2],y[a+484376|0]));x[31725]=0;e=d+220|0;c=P(646,b|0,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break t}if(!(!(y[d+1306|0]|y[d+1307|0]<<8)&c)|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}h=y[a+484376|0];i=x[a+484360>>2];x[31725]=0;c=d+156|0;O(647,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break t}vp(Xb(i,h),c);tb(c);w:{if(o){x[31725]=0;S(187,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31725];x[31725]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31725]=0;b=R(170,d+116|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break s}zG(d+52|0,b)}b=d+52|0;l=ic(d+136|0,b);ub(b);if(!o){ub(d+116|0)}Sb(d+52|0,0,64);c=1;x:{y:{z:{while(1){if((c|0)==32){break z}b=(D(c,34)+d|0)+186|0;e=b+32|0;Ln(d+8|0,e);A:{B:{if(Tj(y[x[d+8>>2]])){break B}h=y[b- -64|0];if(h>>>0>15){break y}b=y[b+65|0];if(b>>>0>64){break y}if(!Av(e)){break y}i=b<<2;k=h<<4;h=0;b=1;while(1){g=b&65535;e=z[a+480190>>1];if(g>>>0<=e>>>0){x[31725]=0;f=d+24|0;S(648,f|0,x[d+8>>2],x[d+12>>2]);e=x[31725];x[31725]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;ee(e+24|0,f);NX(e+16|0,((g<<5)+a|0)+946304|0);j=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=j;j=Ic(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(f);C:{if(j^1){break C}C=_b(d+52|0,c),E=b,w[C>>1]=E;e=D(g,104)+a|0;g=e+484410|0;f=z[g>>1];if((f|0)!=255){h=b;if(y[e+484417|0]!=(k&255)|(f|0)!=(i|0)){break C}}v[e+484417|0]=k;w[g>>1]=i;break B}b=b+1|0;continue}break}h=h&65535;if(!h){break B}if(!ui(e)){break B}b=e+1|0;w[a+480190>>1]=b;C=_b(d+52|0,c),E=b,w[C>>1]=E;b=D(z[a+480190>>1],104)+r|0;un(b);e=D(h,104)+r|0;g=ap(b,e);w[b+30>>1]=i;v[b+37|0]=k;GY(g,e);e=(h<<5)+s|0;h=x[e+4>>2];b=(z[a+480190>>1]<<5)+s|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break r}k=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;i=65535;B=y[d+1308|0]|y[d+1309|0]<<8;h=0;D:while(1){E:{if(h){break E}b=x[l>>2];x[31725]=0;b=U(152,b|0,x[d+144>>2],1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}if(b){break E}c=i;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31725]=0;i=P(369,n|0,64)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}c=65535;if((i|0)==65535){break q}b=y[a+484376|0];c=x[a+484360>>2];e=0;x[31725]=0;O(538,Xb(c,b)|0,i|0);b=x[31725];x[31725]=0;if((b|0)==1){break x}}b=0;c=Wb(x[n>>2],i&65535);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(B|0)){continue D}g=(d+24|0)+D(b,7)|0;f=y[g+6|0];G:{if(f){v[g+6|0]=f-1;f=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=h-1|0;break G}f=x[l>>2];x[31725]=0;f=U(152,f|0,x[d+144>>2],1)|0;j=x[31725];x[31725]=0;if((j|0)==1){break r}if(!f){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){k=Xb(x[a+484360>>2],y[a+484376|0]);bf(k,hE(x[k>>2],x[k+4>>2]));k=e}x[31725]=0;f=R(199,l|0)|0;j=x[31725];x[31725]=0;H:{if((j|0)!=1){f=f<<24>>24;if((f|0)>=0){break H}f=f&127;v[g+6|0]=f;j=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=j;v[c+5|0]=j>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=f+h|0;break G}break r}if((f-1&255)>>>0<=35){v[c|0]=f+48}x[31725]=0;f=R(199,l|0)|0;j=x[31725];x[31725]=0;I:{J:{if((j|0)!=1){f=f<<24>>24;C=c,E=y[_b(d+52|0,f&31)|0],v[C+1|0]=E;if((f|0)>=0){break J}v[c+3|0]=y[g+3|0];v[c+5|0]=y[g+5|0];break I}break r}x[31725]=0;j=d+8|0;O(200,j|0,l|0);f=x[31725];x[31725]=0;K:{if((f|0)!=1){f=y[d+8|0];if(f>>>0>19){break I}t=f<<1;u=y[t+25312|0];v[c+3|0]=u;j=y[Jc(j)|0];v[c+5|0]=j;if((u|0)!=16|j>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>f&1){break I}v[c+5|0]=y[t+25313|0]|j&15}f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[g|0]=f;v[g+1|0]=f>>>8;v[g+2|0]=f>>>16;v[g+3|0]=f>>>24;f=y[c+4|0]|y[c+5|0]<<8;v[g+4|0]=f;v[g+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;b=c>>>0>31;break p}break r}ck(q,0);x[31725]=0;b=P(1,d+220|0,6467)|0;c=x[31725];x[31725]=0;L:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+52|0,6804)|0;c=x[31725];x[31725]=0;if((c|0)==1){break L}Ab(a+1298356|0,b);tb(b);C=a+1298404|0,E=x[Fc(d+24|0,4)>>2],x[C>>2]=E;m=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(l);break j}c=c&65535;if(!(!((k|0)!=0|b>>>0<63)|(c|0)==65535)){ye(Wb(x[n>>2],c),Yh(Ye(Ne(d+8|0,14,k&255),b)))}b=1}ub(l);if(!b){break b}Sf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Qc(d+184|0)}Qc(d+196|0)}ie(d+208|0)}Q(c|0);p()}m=0}Qc(d+184|0);Qc(d+196|0);ie(d+208|0)}fb=d+1328|0;return m|0}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=E(0),D=0,F=0,G=E(0),H=0,I=0,J=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];cQ(a);if(B[a+4268>>2]==g){break a}Sz(a)}b:{if(!y[a+5045|0]){break b}if(!zi(a+44|0)){break b}i=x[a+44>>2];p=Hc(i,0);q=Hc(i,1);i=x[a+56>>2];l=Hc(i,0);m=Hc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;D=a+4504|0;F=a+4960|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;I=Oc(x[a+4864>>2],x[a+4868>>2],x[a+4880>>2]),J=g,B[I>>2]=J;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;I=Oc(x[a+4888>>2],x[a+4892>>2],x[a+4904>>2]),J=g,B[I>>2]=J;g=E(E(E(E(E(oi(t,x[a+4356>>2])*E(.6800000071525574))+E(oi(t,x[a+4360>>2])*E(-.5)))-E(oi(t,x[a+4364>>2])*E(.6200000047683716)))+E(oi(t,x[a+4368>>2])*E(-.5)))-E(oi(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Oc(x[a+4816>>2],x[a+4820>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4816>>2],x[a+4820>>2],x[a+4832>>2]),J=E(e-E(g*E(.6180340051651001))),B[I>>2]=J}u=B[a+4280>>2];I=a,J=E(oi(t,x[a+4352>>2])+B[a+5020>>2]),B[I+5020>>2]=J;e=E(oi(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;C=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(C+E(f*h));I=Oc(x[a+4624>>2],x[a+4628>>2],x[a+4640>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4976>>2]-B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));I=Oc(x[a+4600>>2],x[a+4604>>2],x[a+4616>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));I=Oc(x[a+4576>>2],x[a+4580>>2],x[a+4592>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4968>>2]-B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));I=Oc(x[a+4552>>2],x[a+4556>>2],x[a+4568>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}I=Oc(x[a+4912>>2],x[a+4916>>2],x[a+4928>>2]),J=f,B[I>>2]=J;e=E(B[Oc(x[a+4912>>2],x[a+4916>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));I=Oc(x[a+4528>>2],x[a+4532>>2],x[a+4544>>2]),J=E(f-E(o*h)),B[I>>2]=J;e=E(E(E(B[a+4960>>2]-B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));I=Oc(x[a+4504>>2],x[a+4508>>2],x[a+4520>>2]),J=E(h-E(e*o)),B[I>>2]=J;B[a+5020>>2]=o;e=E(E(E(E(E(oi(s,x[a+4380>>2])*E(.7070000171661377))+E(oi(s,x[a+4384>>2])*E(-.6000000238418579)))-E(oi(s,x[a+4388>>2])*E(.5)))+E(oi(s,x[a+4392>>2])*E(-.6000000238418579)))-E(oi(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Oc(x[a+4840>>2],x[a+4844>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4840>>2],x[a+4844>>2],x[a+4856>>2]),J=E(f-E(e*E(.6180340051651001))),B[I>>2]=J}G=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;C=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(C+E(f*j));I=Oc(x[a+4768>>2],x[a+4772>>2],x[a+4784>>2]),J=E(f-E(j*k)),B[I>>2]=J;f=E(E(E(B[a+5e3>>2]-B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));I=Oc(x[a+4744>>2],x[a+4748>>2],x[a+4760>>2]),J=E(k-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));I=Oc(x[a+4720>>2],x[a+4724>>2],x[a+4736>>2]),J=E(f-E(j*h)),B[I>>2]=J;f=E(E(E(B[a+4992>>2]-B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));I=Oc(x[a+4696>>2],x[a+4700>>2],x[a+4712>>2]),J=E(h-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}H=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*G);I=Oc(x[a+4936>>2],x[a+4940>>2],x[a+4952>>2]),J=f,B[I>>2]=J;g=E(B[Oc(x[a+4936>>2],x[a+4940>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));I=Oc(x[a+4672>>2],x[a+4676>>2],x[a+4688>>2]),J=E(e-E(f*g)),B[I>>2]=J;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));I=Oc(x[a+4648>>2],x[a+4652>>2],x[a+4664>>2]),J=E(g-E(u*e)),B[I>>2]=J;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=D;e:{f:{while(1){if((i|0)==(F|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=H;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];Pi(n,b,c,Hc(a,0),Hc(a,1),d)}}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;h=fb-256|0;fb=h;e=fb-112|0;fb=e;f=Ge(h+76|0,c);x[31725]=0;o=R(170,f+20|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31725]=0;r=R(170,f+40|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break B}x[31725]=0;s=R(170,f+60|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;i=R(170,f+80|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}x[31725]=0;q=R(170,f+100|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}x[31725]=0;m=R(170,f+120|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}j=Nb(f+140|0);xc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31725]=0;d=P(810,f|0,e+100|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break w}if(!d){break n}d=x[e+100>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=x[e+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(d|0)==1414744396;x[31725]=0;g=e+88|0;S(811,g|0,f|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break v}k=x[e+88>>2];C:{if(Or(k,x[e+92>>2])>>>0<4){break C}l=e+36|0;c=xA(k,1);d=x[c>>2];c=x[c+4>>2];wi(l,d,c);if(x[e+36>>2]!=1635017060){break C}wi(e+60|0,d,c);if(!(v[e+64|0]&1)){break C}c=xA(k,2);wi(e+16|0,x[c>>2],x[c+4>>2]);if(y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24)){break C}c=xA(k,3);wi(e+80|0,x[c>>2],x[c+4>>2]);if(x[e+80>>2]){break C}x[31725]=0;P(151,f|0,12)|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}x[31725]=0;S(811,l|0,f|0,1);c=x[31725];x[31725]=0;if((c|0)==1){break t}yv(g,l);ie(l)}x[31725]=0;g=e+60|0;S(812,g|0,e+88|0,544501094);c=x[31725];x[31725]=0;if((c|0)==1){break s}x[31725]=0;d=P(813,g|0,f+156|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}if(!d){break o}d=z[f+156>>1];if((d|0)!=1){break q}x[31725]=0;d=R(204,g|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break r}break k}d=N()|0;break b}d=N()|0;break c}d=N()|0;break d}d=N()|0;break e}d=N()|0;break f}d=N()|0;break g}d=N()|0;break h}d=N()|0;break h}d=N()|0;break i}d=N()|0;break i}d=N()|0;break i}if((d|0)==4){x[31725]=0;g=R(194,e+60|0)|0;c=x[31725];x[31725]=0;D:{if((c|0)!=1){x[31725]=0;d=R(194,e+60|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}if((g|0)!=2|(d|0)!=1){break p}v[f+177|0]=1;break p}d=N()|0;break j}d=N()|0;break j}d=z[f+156>>1]}if((d&65535)!=65534){break p}x[31725]=0;d=P(814,e+60|0,e+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}if(!d){break o}c=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);x[e+8>>2]=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);x[e+12>>2]=c;c=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[e>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[e+4>>2]=c;c=e+16|0;x[c>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);w[c+4>>1]=y[e+4|0]|y[e+5|0]<<8;w[c+6>>1]=y[e+6|0]|y[e+7|0]<<8;t=c,u=sA(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24)),x[t+8>>2]=u;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31725]=0;k=e+36|0;g=e+88|0;S(812,k|0,g|0,1635017060);c=x[31725];x[31725]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){l=hd(o,k);ub(k);c=x[l>>2];x[31725]=0;d=R(174,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}if(!d){x[31725]=0;S(812,k|0,g|0,544039792);c=x[31725];x[31725]=0;if((c|0)==1){break J}hd(l,k);ub(k)}x[31725]=0;g=e+36|0;S(812,g|0,e+88|0,1952670054);c=x[31725];x[31725]=0;if((c|0)==1){break I}x[31725]=0;d=R(153,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break H}x[f+152>>2]=d;ub(g);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}g=z[f+158>>1];d=LR(g,z[f+170>>1]);if(!d){break E}c=z[f+168>>1];if((c>>>0)/(g>>>0)>>>0<d<<1>>>0?c:0){break G}c=x[l>>2];x[31725]=0;d=R(156,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=LR(z[f+158>>1],z[f+170>>1]);break F}d=N()|0;break j}d=N()|0;break j}d=N()|0;break j}d=N()|0;ub(e+36|0);break j}c=x[l>>2];x[31725]=0;d=R(156,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(d>>>0)/((c&65535)>>>0)}x[31725]=0;g=e+88|0;d=P(815,f|0,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}w[f+174>>1]=d;x[31725]=0;O(816,f|0,g|0);c=x[31725];x[31725]=0;if((c|0)==1){break k}x[31725]=0;d=e+36|0;S(812,d|0,g|0,1886221175);c=x[31725];x[31725]=0;if((c|0)==1){break m}hd(q,d);ub(d)}ub(e+60|0);ie(e+88|0)}fb=e+112|0;break a}d=N()|0;break j}d=N()|0;break j}d=N()|0}ub(e+60|0)}ie(e+88|0)}ie(j);ub(m)}ub(q)}ub(i)}ub(s)}ub(r)}ub(o)}ub(f);Q(d|0);p()}c=x[f+20>>2];x[31725]=0;d=R(746,c|0)|0;c=x[31725];x[31725]=0;K:{L:{if((c|0)!=1){M:{if(!d|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Jk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Jk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Jk(f);c=28608;while(1){Q:{R:{if((c|0)!=28632){if((d|0)!=x[c>>2]){break R}}else{c=28632}break Q}c=c+4|0;continue}break}if((c|0)==28632){break M}Uu(a,b);x[31725]=0;g=P(36,h- -64|0,22267)|0;c=x[31725];x[31725]=0;S:{T:{U:{V:{W:{if((c|0)!=1){d=zc(((b<<5)+a|0)+946304|0,g);tb(g);x[31725]=0;g=D(b,104)+a|0;i=g+484380|0;O(281,i|0,0);c=x[31725];x[31725]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[g+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31725]=0;V(747,f|0,i|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break W}Ge(h+44|0,f+20|0);d=z[f+158>>1];j=Xc(h+40|0,8,d>>>0>1?2:1,0,0);c=Jk(f);if((c|0)!=17|d>>>0>2){break U}wc(i,268435456);b=g+484414|0;w[b>>1]=z[b>>1]&65470|((d|0)==2)<<6|1;if(Fh(i)){break V}break S}n=N()|0;break K}n=N()|0;break K}j=x[g+484400>>2];g=x[i>>2];m=Ge(h+20|0,h+44|0);d=z[f+158>>1];c=z[f+168>>1];x[31725]=0;b=x[m+12>>2];x[h+8>>2]=x[m+8>>2];x[h+12>>2]=b;x[h+16>>2]=x[m+16>>2];b=x[m+4>>2];x[h>>2]=x[m>>2];x[h+4>>2]=b;aa(748,j|0,g|0,h|0,c|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}Qj(i,a);break T}if((c|0)==85){x[31725]=0;c=U(575,a|0,b|0,h+44|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(PV(z[f+156>>1])){break Z}_:{if(!Ed(y[f+177|0])){break _}if((Jk(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=d<<2){break _}fd(j,32);b=12;break Y}if((Jk(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=d<<2){break Z}fd(j,32);b=13;break Y}if((Jk(f)&65534)!=6){break X}fd(j,16);b=(Jk(f)|0)==6?17:16}yg(j,b);x[31725]=0;U(217,j|0,i|0,h+44|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break T}break L}d=z[f+170>>1];c=d-1|0;b=c&-8;g=b&31;fd(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>g|0:((1<<g)-1&1074268168)<<32-g|538447880>>>g)&120);if(d>>>0<9){yg(j,1)}if((Jk(f)|0)==3){yg(j,3)}x[31725]=0;U(217,j|0,i|0,h+44|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}}bC(i,x[a+480180>>2]);Qj(i,a);n=1}ub(h+44|0)}OV(f);fb=h+256|0;return n|0}n=N()|0;break K}n=N()|0;ub(h+44|0)}OV(f);Q(n|0);p()}function Wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=fb-288|0;fb=d;xc(b);a:{b:{c:{f=d+192|0;d:{if(!zv(b,f)){break d}if(!JX(f)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(IX(f),hb))){break d}if(!c){j=1;break d}if(!cd(b,y[d+196|0])){break d}Bd(a,268435456);gg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+84|0;i=tc(f,15318);Ab(a+1298344|0,i);tb(i);i=tc(f,10282);Ab(a+1298356|0,i);tb(i);E=a+1298404|0,F=x[Fc(f,4)>>2],x[E>>2]=F;i=d+16|0;df(i,d+198|0,48,3);Cc(f,i);Ab(a+1298308|0,f);tb(f);f=y[d+246|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;f=d+180|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(i+8|0,x[vb(i+4|0,f)>>2]);f:{g:{if(e){x[31725]=0;O(663,f|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break g}jD(f,e)}e=i+8|0;Qd(e);ch(e);fb=i+16|0;break f}a=N()|0;ch(i+8|0);Q(a|0);p()}x[31725]=0;i=f;S(658,b|0,f|0,y[d+286|0]|y[d+287|0]<<8);f=x[31725];x[31725]=0;if((f|0)==1){break b}u=Nb(d+168|0);r=Nb(d+156|0);x[31725]=0;U(422,b|0,u|0,y[d+285|0])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;U(422,b|0,r|0,y[d+284|0])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}s=c&2;t=d+122|0;q=d+90|0;f=0;h:{while(1){e=f;if(e>>>0>=y[d+284|0]){j=1;if(!(c&1)){break e}x[d+68>>2]=0;kj(Xb(x[a+484360>>2],y[a+484376|0]));E=d,F=wb(x[i>>2]),x[E+64>>2]=F;s=a+484344|0;A=wb(x[i+4>>2]);break h}x[31725]=0;f=e+1|0;g=D(f,104)+a|0;k=g+484380|0;O(281,k|0,0);h=x[31725];x[31725]=0;i:{if((h|0)!=1){h=yb(x[r>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);if(!h){continue}x[31725]=0;h=P(151,b|0,h|0)|0;j=x[31725];x[31725]=0;j:{if((j|0)==1){break j}if(!h){continue}x[31725]=0;h=P(659,b|0,d+84|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break j}if(!h){continue}j=d+72|0;We(j,2,q);x[31725]=0;h=d+16|0;O(220,h|0,j|0);n=x[31725];x[31725]=0;if((n|0)==1){break c}zc(((f<<5)+a|0)+946304|0,h);tb(h);Qk(j,2,t);x[31725]=0;O(220,h|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break c}ze(g+484423|0,h);tb(h);h=y[d+134|0];if(h>>>0<=15){w[g+484408>>1]=D(h,17);h=g+484414|0;w[h>>1]=z[h>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;E=g+484412|0,F=y[Rb(d+16|0,d+72|0)|0],w[E>>1]=F;x[g+484404>>2]=y[d+137|0]|y[d+138|0]<<8;n=g+484384|0;h=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[n>>2]=h;o=g+484388|0;j=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[o>>2]=j;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[k>>2]=l;m=y[d+136|0];if(m&1){h=h>>>1|0;x[n>>2]=h;j=j>>>1|0;x[o>>2]=j;x[k>>2]=l>>>1}k:{if(h>>>0>=j>>>0){break k}g=g+484414|0;h=z[g>>1];w[g>>1]=h|2;if(!(m&2)){break k}w[g>>1]=h|6}$k(k);if(!s){continue}e=yb(x[r>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[31725]=0;P(151,b|0,e+y[d+88|0]|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break i}}break c}break c}e=Xc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31725]=0;U(217,e|0,k|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){continue}break}break c}while(1){k=x[d+64>>2];if(!Ib(k,A)){e=y[a+484376|0];f=x[a+484360>>2];l:{b=x[d+68>>2];c=b&63;m:{if(!c){break m}g=Xb(f,e);b=b>>>6&65535;if(!bj(g,b)){break m}b=z[_b(x[g>>2],b)>>1];f=x[s>>2];x[31725]=0;O(660,Wb(f,b)|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break l}e=y[a+484376|0];f=x[a+484360>>2]}a=Xb(f,e);E=d,F=wb(x[a>>2]),x[E+84>>2]=F;b=wb(x[a+4>>2]);g=65535;while(1){a=x[d+84>>2];if(!Ib(a,b)){break e}if(z[a>>1]==65535){n:{if((g&65535)!=65535){break n}x[31725]=0;g=P(369,s|0,64)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break n}break c}w[a>>1]=g}Md(d+84|0);continue}}break c}o:{c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break o}c=yb(x[u>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;p:{if((f|0)!=1){if(!c){break o}x[31725]=0;O(661,b|0,d+84|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break o}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];t=y[Rb(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;E=d,F=x[ad(d+68|0,d+60|0)>>2],x[E+68>>2]=F;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;g=c&63;q=c>>>6|0;n=0;while(1){if((e&255)>>>0<=n>>>0){break o}e=Xb(x[a+484360>>2],y[a+484376|0]);h=g>>>0>63;q=h+q|0;c=q&65535;if(Zc(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[31725]=0;O(332,e|0,q+1&65535);f=x[31725];x[31725]=0;if((f|0)==1){break p}x[31725]=0;f=P(369,s|0,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}e=Xb(x[a+484360>>2],y[a+484376|0]);E=_b(x[e>>2],c),F=f,w[E>>1]=F}l=x[a+484344>>2];f=x[a+484348>>2];o=z[_b(x[e>>2],c)>>1];if(!He(l,f,o)){break o}f=0;c=Wb(l,o);l=h?0:g;e=jd(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);q:{while(1){if((f|0)==(t|0)){c=y[d+89|0];if(c>>>0<=t>>>0){break q}x[31725]=0;P(185,b|0,D(c-t|0,5)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break q}break c}x[31725]=0;c=d+72|0;O(662,c|0,b|0);g=x[31725];x[31725]=0;if((g|0)!=1){h=Jc(c);B=af(c);m=ej(c);C=ec(c);g=0;c=y[d+72|0];if((c-1&255)>>>0<=142){g=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+f|0]=g}v[e|0]=g;c=y[h|0];v[e+2|0]=1;v[e+1|0]=c;c=y[B|0];r:{if((c|0)!=255){v[e+4|0]=c;break r}v[e+2|0]=0}c=y[m|0];s:{if(c>>>0>22){break s}v[e+3|0]=y[c+25360|0];h=y[C|0];v[e+5|0]=h;c=e+5|0;t:{switch(y[m|0]-4|0){case 3:v[c|0]=h&3|64;break s;case 4:v[c|0]=h&3|48;break s;case 7:g=x[i>>2];if(oc(g,x[i+4>>2])>>>0<=h>>>0){break s}m=c;c=yb(g,h);c=y[c|0]|y[c+1|0]<<8;v[m|0]=c>>>6;g=Wb(x[a+484344>>2],o);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 8:m=c;c=x[d+60>>2];v[m|0]=c>>>6;g=Wb(x[a+484344>>2],o);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 10:v[c|0]=h&15|128;break s;case 12:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|208,v[E|0]=F;break s;case 13:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|192,v[E|0]=F;break s;case 14:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|224,v[E|0]=F;break s;case 0:case 16:case 17:if(!(h&15)){break s}g=h&240;if(!g|(g|0)==240){break s}v[c|0]=h|15;break s;case 9:case 18:break t;default:break s}}if(g&255){break s}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}g=l+1|0;n=n+1|0;e=y[d+88|0];continue}}break c}break c}Je(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}uc(r);uc(u);uc(i)}fb=d+288|0;return j|0}a=N()|0;uc(r);uc(u);break a}a=N()|0}uc(i);Q(a|0);p()}function sua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{h=e+206|0;m:{if(!T$(b,h)){break m}if(!U$(h)){break m}if(!c){d=1;break m}Bd(a,131072);d=fb-16|0;fb=d;h=e+120|0;f=tc(d+4|0,3910);_c(h,f);tb(f);fb=d+16|0;x[31725]=0;d=e+160|0;S(211,d|0,h|0,e+210|0);f=x[31725];x[31725]=0;n:{o:{p:{if((f|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(h);f=tc(d,11144);Ab(a+1298356|0,f);tb(f);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;vE(h,3,e+219|0);Cc(d,h);Ab(a+1298308|0,d);tb(d);vi(h,3,e+249|0);Lr(d,4,h);Ab(a+1298320|0,d);tb(d);d=qp(d);o=d,q=Kd(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Kd(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;h=a+1298412|0;ew(h);iE(h,d);g=e+128|0;h=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,8)|0;f=x[31725];x[31725]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31725]=0;O(312,b|0,e- -64|0);d=x[31725];x[31725]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{k=y[e+210|0];switch(k-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(k>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}k=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=k;x[31725]=0;k=e+100|0;S(187,k|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break s}ic(g,k);x[31725]=0;d=e+120|0;O(313,h|0,d|0);i=x[31725];x[31725]=0;if((i|0)==1){break r}Gd(d);ub(k);x[31725]=0;P(185,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Gd(e+120|0);ub(e+100|0);break b}x[31725]=0;k=R(170,e+120|0)|0;b=x[31725];x[31725]=0;z:{A:{B:{if((b|0)!=1){x[31725]=0;d=e+100|0;S(314,d|0,h|0,1431389523);b=x[31725];x[31725]=0;if((b|0)==1){break B}b=hd(k,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31725]=0;d=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31725]=0;d=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;g=R(204,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}x[31725]=0;S(240,Xb(f,d)|0,b|0,g>>>1|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}d=Xb(x[a+484360>>2],y[a+484376|0]);d=hE(x[d>>2],x[d+4>>2]);Gf(e+98|0,d);Gf(e+96|0,d);x[31725]=0;d=e+100|0;S(314,d|0,h|0,1414807888);f=x[31725];x[31725]=0;if((f|0)==1){break e}b=hd(b,d);ub(d);d=x[b>>2];x[31725]=0;d=R(174,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31725]=0;O(315,b|0,e+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break f}o=a,q=Kd(y[e+10|0],1,32)+1|0,w[o+480188>>1]=q;x[31725]=0;d=P(216,e+84|0,z[e+8>>1])|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}o=e,q=wb(x[d>>2]),x[o+44>>2]=q;i=wb(x[d+4>>2]);C:{D:{E:{while(1){j=x[e+44>>2];if(!Ib(j,i)){f=z[a+480188>>1];x[31725]=0;f=P(316,e+100|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31725]=0;f=y[e+210|0]<3?9:8;P(185,b|0,f-4|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;l=R(153,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break E}Gh(b,f);x[31725]=0;g=e- -64|0;S(187,g|0,b|0,f+l|0);f=x[31725];x[31725]=0;if((f|0)==1){break D}f=ic(e+100|0,g);hd(j,f);ub(f);ub(g);Sf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=Xb(x[a+484360>>2],y[a+484376|0]);g=lm(x[g>>2],x[g+4>>2]);x[31725]=0;l=a+484344|0;O(225,l|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){g=Xb(x[a+484360>>2],y[a+484376|0]);o=e,q=wb(x[g>>2]),x[o+64>>2]=q;i=wb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,i)){g=Xb(x[a+484360>>2],y[a+484376|0]);i=z[e+96>>1];F:{if(!bj(g,i)){break F}j=x[g>>2];m=z[e+98>>1];if(!m){if(hE(j,x[g+4>>2])>>>0<=i>>>0){break F}}g=Wb(x[l>>2],z[_b(j,i)>>1]);ye(g,Fn(Ye(Ne(e- -64|0,12,m&255),x[g+12>>2]-1|0)))}Rk(f);Qc(d);break n}j=x[d>>2];n=Uf(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[31725]=0;j=ba(317,dh(j,m)|0,y[e+210|0],f|0,a|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break p}w[g>>1]=j}Md(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Rk(f)}Qc(d);break c}x[31725]=0;d=e- -64|0;S(314,d|0,h|0,1196641603);f=x[31725];x[31725]=0;if((f|0)==1){break k}b=hd(b,d);ub(d);d=x[b>>2];x[31725]=0;d=R(174,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(d){x[31725]=0;P(185,b|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;d=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;aa(318,a+1298332|0,b|0,d|0,40,0);d=x[31725];x[31725]=0;if((d|0)==1){break d}}x[31725]=0;S(314,e- -64|0,h|0,1146113363);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;d=e+44|0;S(314,d|0,h|0,1229999443);f=x[31725];x[31725]=0;if((f|0)==1){break l}b=hd(b,d);ub(d);x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}w[a+480190>>1]=d;i=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31725]=0;d=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break K}}x[31725]=0;S(319,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break K}x[31725]=0;d=e+28|0;O(320,b|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break J}x[31725]=0;g=D(c,104)+a|0;j=g+484380|0;O(321,d|0,j|0);c=x[31725];x[31725]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31725]=0;O(322,b|0,g+484423|0);c=x[31725];x[31725]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31725]=0;P(185,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break J}x[31725]=0;c=e- -64|0;d=R(153,c|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){x[31725]=0;S(187,e+8|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=ic(e+44|0,d);ub(d);l=x[c>>2];x[31725]=0;l=R(174,l|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){L:{if(i|l^1){break L}d=Xc(d,w[g+484414>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31725]=0;U(217,d|0,j|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[a+480190>>1];continue}}break}b=N()|0;ub(c);break i}gg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31725]=0;d=1;U(268,a+1074312|0,114,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);ie(h)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(k)}ie(h)}Q(b|0);p()}function mM(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){rf(i+196|0,f,32);x[31725]=0;U(543,i+184|0,f|0,32)|0;h=x[31725];x[31725]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Rt(c)){h=x[b+24>>2];j=x[h+484344>>2];if(He(j,x[h+484348>>2],c&65535)){break j}}x[31725]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31725];x[31725]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Wb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31725]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31725];x[31725]=0;if((a|0)!=1){break i}f=N()|0;break c}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);tf(i+196|0);tf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Tc(d)){if(!Nl(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31725]=0;j=i+160|0;V(1170,j|0,h|0,d|0,e|0);d=x[31725];x[31725]=0;e=1;if((d|0)==1){break y}x[31725]=0;O(1065,i+172|0,j|0);d=x[31725];x[31725]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31725]=0;P(36,i+172|0,16775)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}}x[31725]=0;h=i+172|0;d=P(842,i+196|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break w}tb(h);if(e){tb(i+160|0)}e=9968;h=y[c|0];if(!Tc(h)){e=Nl(h)?10278:16775}x[31725]=0;h=P(36,i+172|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}x[31725]=0;e=P(842,i+184|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31725]=0;h=P(36,i+148|0,18429)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}x[31725]=0;j=P(842,d|0,h|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break r}tb(h);x[31725]=0;h=P(36,i+136|0,18429)|0;m=x[31725];x[31725]=0;if((m|0)==1){break q}x[31725]=0;m=P(842,e|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31725]=0;O(560,i+124|0,h|0);k=x[31725];x[31725]=0;if((k|0)!=1){break B}break d}x[31725]=0;P(36,i+124|0,16780)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}}x[31725]=0;k=j;j=i+124|0;k=P(842,k|0,j|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break o}tb(j);h=y[h|0];x[31725]=0;h=P(36,j|0,(h?10801:16780)|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break n}x[31725]=0;m=P(842,m|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Vg(y[c|0]);O:{if(j){x[31725]=0;l=P(36,i+100|0,18429)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31725]=0;o=i,q=Kj(n,h)&255,x[o+76>>2]=q;n=i+88|0;O(559,n|0,i+76|0);h=x[31725];x[31725]=0;if((h|0)==1){break M}h=0;x[31725]=0;S(1021,i+112|0,l|0,n|0);l=x[31725];x[31725]=0;if((l|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=DR(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31725]=0;h=U(543,i+100|0,1,h|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break E}x[31725]=0;l=i+88|0;O(560,l|0,c+4|0);n=x[31725];x[31725]=0;if((n|0)==1){break L}x[31725]=0;S(1021,i+112|0,h|0,l|0);l=x[31725];x[31725]=0;h=1;if((l|0)!=1){break O}f=N()|0;break J}h=0;x[31725]=0;P(36,i+112|0,16779)|0;l=x[31725];x[31725]=0;if((l|0)==1){break e}}x[31725]=0;l=k;k=i+112|0;l=P(842,l|0,k|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break K}tb(k);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5488;if(!Vg(y[c|0])){h=y[c+2|0]?5484:16779}x[31725]=0;h=P(36,i+112|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break D}x[31725]=0;j=P(842,m|0,h|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31725]=0;h=P(36,i+76|0,18429)|0;m=x[31725];x[31725]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((m|0)!=1){x[31725]=0;m=P(842,l|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break Z}tb(h);x[31725]=0;h=P(36,i- -64|0,18429)|0;k=x[31725];x[31725]=0;if((k|0)==1){break Y}x[31725]=0;j=P(842,j|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break X}tb(h);_:{if(Vg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[31725]=0;o=i,q=Kj(k,h)&4095,x[o+16>>2]=q;O(1171,i+52|0,i+16|0);h=x[31725];x[31725]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=CR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31725]=0;b=U(543,i+40|0,1,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break W}x[31725]=0;h=i+28|0;O(560,h|0,c+5|0);k=x[31725];x[31725]=0;if((k|0)==1){break V}x[31725]=0;S(1021,i+52|0,b|0,h|0);h=x[31725];x[31725]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31725]=0;P(36,i+52|0,16775)|0;h=x[31725];x[31725]=0;if((h|0)==1){break U}}x[31725]=0;h=i+52|0;P(842,m|0,h|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break T}tb(h);if(b){tb(i+28|0);tb(i+40|0)}b=11161;if(!Vg(y[c|0])){b=y[c+3|0]?11161:16775}x[31725]=0;b=P(36,i+52|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Q}x[31725]=0;P(842,j|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Yc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31725]=0;b=i+16|0;V(123,b|0,d|0,0,f|0);c=x[31725];x[31725]=0;if((c|0)!=1){Ab(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31725]=0;b=U(543,i+16|0,f-b|0,32)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ca}x[31725]=0;P(842,d|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ba}tb(b)}b=Yc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31725]=0;b=i+4|0;V(123,b|0,e|0,0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break aa}Ab(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31725]=0;b=U(543,i+4|0,f-b|0,32)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}x[31725]=0;P(842,e|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break g}tb(b)}x[31725]=0;S(1169,a|0,d|0,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function Ata(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-256|0;fb=d;xc(b);f=fb-16|0;fb=f;i=d+99|0;H_(f+8|0,i);h=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(j|0);if(!f){G_(i)}a:{if(!f){break a}if(!I_(i)){break a}if(!c){e=1;break a}Bd(a,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24752>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+36|0;f=tc(e,13171);Ab(a+1298344|0,f);tb(f);f=tc(e,10313);Ab(a+1298356|0,f);tb(f);i=fb-16|0;fb=i;f=d+4|0;h=tc(i+4|0,4389);_c(f,h);tb(h);fb=i+16|0;x[31725]=0;V(231,e|0,f|0,y[d+178|0],d+175|0);i=x[31725];x[31725]=0;b:{if((i|0)!=1){Ab(a+1298368|0,e);tb(e);Eb(f);bi(a+1298392|0,((y[d+215|0]|y[d+216|0]<<8)<<2)+24800|0);bi(a+1298380|0,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24848>>2]);t=a+1298404|0,u=x[Fc(e,4)>>2],x[t>>2]=u;We(f,2,d+103|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);We(f,2,d+135|0);Cc(e,f);c:{if(!Ld(e,9750)){x[31725]=0;S(260,f|0,4,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}Ab(a+1298320|0,f);tb(f)}tb(d+36|0);w[a+480188>>1]=32;d:{while(1){if((g|0)!=32){f=(g<<5)+a|0;i=f+480280|0;Xe(i);e=y[(d+g|0)+180|0];e:{if(e>>>0<=15){x[d+36>>2]=e<<4|8;x[d+4>>2]=256;t=f+480284|0,u=x[ud(d+36|0,d+4|0)>>2],w[t>>1]=u;break e}if((e|0)!=16){if((e|0)!=255){break e}w[a+480188>>1]=g;break d}w[f+480284>>1]=128;x[i>>2]=256}g=g+1|0;continue}break}g=z[a+480188>>1]}e=0;if(!(g&65535)){break a}x[d+36>>2]=y[d+212|0]<<2;x[d+4>>2]=256;t=a,u=x[Gb(d+36|0,d+4|0)>>2],x[t+480200>>2]=u;x[a+480196>>2]=y[d+213|0];x[a+480204>>2]=D(y[d+214|0],1e4);if(cd(b,y[d+217|0]|y[d+218|0]<<8|(y[d+219|0]<<16|y[d+220|0]<<24))){hk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[d+221|0]+1|0,255,254)}if(!cd(b,y[d+227|0]|y[d+228|0]<<8|(y[d+229|0]<<16|y[d+230|0]<<24))){break a}g=y[d+235|0]+1|0;w[a+480190>>1]=g;l=d+68|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(g&65535)>>>0){break g}e=fb-16|0;fb=e;f=d+36|0;bc(e+8|0,f,62);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){Sb(f,0,62)}if(!e){break g}g=0;e=D(j,104)+a|0;k=e+484380|0;ld(k,0);h=d+24|0;We(h,2,f);f=d+4|0;Cc(f,h);zc(((j<<5)+a|0)+946304|0,f);tb(f);Qk(h,2,l);Cc(f,h);ze(e+484423|0,f);tb(f);f=y[d+94|0]|y[d+95|0]<<8;x[e+484404>>2]=f;if(!Dn(x[a+480180>>2])){break f}while(1){if((g|0)==16){break f}if((f|0)==z[(g<<1)+24896>>1]){v[e+484417|0]=g<<4;break f}else{g=g+1|0;continue}}}h:{if(!(c&2)){break h}if(!cd(b,y[d+231|0]|y[d+232|0]<<8|(y[d+233|0]<<16|y[d+234|0]<<24))){break h}g=1;while(1){e=g&65535;if(e>>>0>z[a+480190>>1]){break h}e=D(e,104)+a|0;fg(Xc(d+36|0,w[e+484414>>1]&1?16:8,1,0,1),e+484380|0,b);g=g+1|0;continue}}n=a+484344|0;Vf(n,y[d+226|0]+1|0);j=LD(yr(a));cd(b,y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24));s=c&1;h=0;l=1;i:{j:{k:{while(1){if(y[d+226|0]<h>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{e=hh(b);if(e>>>0>=3){c=d+4|0;fe(c,b,e-2|0);i=ic(d+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31725]=0;c=R(174,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}if(!c){break m}x[31725]=0;c=U(198,n|0,h&65535,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}c=Wb(x[n>>2],h);cf(d+4|0,x[c>>2],x[x[c+48>>2]+12>>2],k);n:{o:while(1){x[31725]=0;c=R(199,i|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(!c){break n}e=c&31;if(e>>>0>=z[a+480188>>1]){break n}g=Wc(x[d+4>>2],e);if(c&32){x[31725]=0;e=d+24|0;O(200,e|0,i|0);f=x[31725];x[31725]=0;if((f|0)==1){break i}f=Jc(e);e=y[d+24|0];if(e){e=(e&127)-1|0;v[d+24|0]=e;e=(D((e&240)>>>4|0,12)+(e&15)|0)+13|0;v[g|0]=e;l=KD(e)&l}v[g+1|0]=y[f|0]}if(!(c&64)){continue}v[g+2|0]=0;v[g+3|0]=0;o=g+5|0;while(1){c=x[i>>2];x[31725]=0;c=U(152,c|0,x[d+44>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(!c){continue o}q=y[g+5|0];c=y[g+3|0];x[31725]=0;e=d+24|0;O(200,e|0,i|0);f=x[31725];x[31725]=0;if((f|0)!=1){f=y[Jc(e)|0];v[g+5|0]=f;r=y[d+24|0];e=y[(r&31)+24928|0];v[g+3|0]=e;p:{q:{r:{s:{t:{switch(e-2|0){case 0:case 1:if(f>>>0<224){break p}m=223;if(x[a+480180>>2]!=1){break s}break p;case 11:v[d+3|0]=64;e=y[Rb(o,d+3|0)|0];v[o|0]=e;if(!Vv(x[j+88>>2],1)){break p}v[g+4|0]=e;v[g+2|0]=1;v[g+5|0]=q;v[g+3|0]=c;e=c;break r;case 17:u:{switch(((f&240)>>>4|0)-8|0){case 0:v[g+3|0]=2;v[g+5|0]=f&15|224;break p;case 1:v[g+3|0]=3;v[g+5|0]=f&15|224;break p;default:break u}}if($i(x[j+84>>2],19)){break p}qw(g);e=y[g+3|0];break r;case 13:c=x[j+84>>2];if($i(c,15)){break p}if(!$i(c,19)){break p}v[g+3|0]=19;v[g+5|0]=f&15|144;break p;case 18:m=145;if((f|0)==1){break s}if((f&240)==128){if($i(x[j+84>>2],20)){break q}v[g+3|0]=19;break p}v[g+3|0]=0;break p;case 4:case 5:break t;default:break r}}m=f&240;if(!m){break p}}v[o|0]=m}if((e&255)!=20){break p}}e=y[g+5|0];if(y[g+2|0]|(e&240)!=128){break p}v[g+2|0]=2;v[g+5|0]=q;v[g+3|0]=c;v[g+4|0]=(((e&15)<<6|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?l&1?8454144:0:0)}x[a+480208>>2]=c;e=1;if(!(y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break a}if(!cd(b,y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24))){break a}_D(a+1298332|0,b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24),4);break a}g=N()|0;ub(i);break b}w[e+484412>>1]=64;f=y[d+81|0]|y[d+82|0]<<8|(y[d+83|0]<<16|y[d+84|0]<<24);x[k>>2]=f;g=y[d+93|0];if(g&2){h=e+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=f>>>1}x[e+484384>>2]=y[d+85|0]|y[d+86|0]<<8|(y[d+87|0]<<16|y[d+88|0]<<24);x[e+484388>>2]=(y[d+89|0]|y[d+90|0]<<8|(y[d+91|0]<<16|y[d+92|0]<<24))-1;if(g&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}v:{w:{if(!(g&4)){break w}f=y[d+96|0];if((f|0)==255){break w}v[d+4|0]=f;v[d+24|0]=64;t=e+484410|0,u=y[Rb(d+4|0,d+24|0)|0]<<2,w[t>>1]=u;break v}f=e+484414|0;w[f>>1]=z[f>>1]|32768}x:{if(g&8){g=e+484414|0;f=z[g>>1]|32;w[g>>1]=f;j=e+484408|0;e=y[d+97|0];if(e>>>0<=15){x[d+24>>2]=256;x[d+4>>2]=e<<4|8;h=x[ud(d+4|0,d+24|0)>>2]}else{h=128}w[j>>1]=h;w[g>>1]=f&65279|((e|0)==16)<<8;break x}w[e+484408>>1]=128}i=i+1|0;g=z[a+480190>>1];continue}}g=N()|0;tb(d+36|0);break b}g=N()|0;Eb(d+4|0)}Q(g|0);p()}fb=d+256|0;return e|0}function Q7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(li(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1238;b=l+72|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);n=Fb(l+48|0);o=Fb(l+36|0);s=Fb(l+24|0);b=x[d>>2];x[31725]=0;ka(1248,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,n|0,o|0,l+20|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=U(1249,h|0,1,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){x[31725]=0;O(1250,l+12|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(35,s|0,x[l+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=U(1249,h|0,1,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(!b){break c}x[31725]=0;O(1250,l+12|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(35,s|0,x[l+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Cb(x[n+4>>2],y[n+11|0])){break m}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(x[Wd(n,0)>>2]!=(b|0)){break m}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}n:{o:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(x[Wd(o,0)>>2]==(b|0)){break o}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break n}if(!Cb(k,b)){break n}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|r|A))){r=0;break c}c=vb(l+12|0,zd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=tl(q);d=x[c>>2];if(!Ib(d,b)){break q}b=x[d>>2];x[31725]=0;b=U(1249,h|0,1,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){if(!b){break q}Je(c);continue}break}break a}b=zd(q);b=Hv(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){d=Lk(tl(s),0-b|0);k=tl(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Ib(d,k);if(!z){break r}if(!lc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Je(b+12|0);Je(b+8|0);d=x[d>>2];continue}break}fb=b+16|0;if(z^1){break p}}C=c,D=x[vb(l+8|0,zd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=tl(q);if(!Ib(x[l+8>>2],b)){break s}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break t}if(x[x[l+8>>2]>>2]!=(b|0)){break s}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}Je(l+8|0);continue}break}break a}if(!A){break c}b=tl(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[31725]=0;d=P(1222,a|0,l+524|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break v}if(d){break u}d=x[a>>2];x[31725]=0;k=R(1223,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;d=U(1249,h|0,64,k|0)|0;B=x[31725];x[31725]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31725]=0;S(1251,i|0,j|0,l+520|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break w}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31725]=0;R(1225,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[t>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!r){break x}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break x}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}if(x[Wd(r,k)>>2]==(b|0)){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Xf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(x[l+88>>2]==(b|0)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;b=R(1225,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[31725]=0;c=P(1222,b|0,l+524|0)|0;d=x[31725];x[31725]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[31725]=0;c=R(1223,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}x[31725]=0;c=U(1249,h|0,64,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31725]=0;S(1251,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break C}}c=x[b>>2];x[31725]=0;c=R(1223,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31725]=0;R(1225,b|0)|0;c=x[31725];x[31725]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Qb(s);Qb(o);Qb(n);Qb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Qb(s);Qb(o);Qb(n);Qb(q);tb(u);Lc(t);Q(a|0);p()}function vT(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=E(0),V=0;j=fb-48|0;fb=j;Yj(b+223848|0,Wj(e,Li(e,Xo(e),0))+1|0);oe(j+40|0,x[b+223848>>2],x[b+223852>>2]);gc(j+32|0,e,Wj(e,Li(e,Xo(e),0)));F=x[j+32>>2];G=x[j+36>>2];g=fb-16|0;fb=g;H=a+906300|0;p=a+1074312|0;o=D(c,872)+b|0;I=o+1415|0;J=o+1304|0;K=o+1392|0;u=o+1368|0;s=o+1364|0;L=o+1336|0;M=o+1308|0;N=o+1300|0;O=o+1280|0;P=o+1402|0;m=o+1466|0;Q=E(y[m|0]);R=E(f>>>0);C=o+616|0;l=x[o+1272>>2];q=1;k=255;while(1){if((n|0)!=(G|0)&A[j+44>>2]>i>>>0){h=y[xb(F,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=vm(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[vd(H,e)>>2];if(!e){break f}e=gB(e,45960,43016);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!l){break b}break c}if(l){break c}e=0;break b;case 21:g:{if(!Ob(p,28)){e=0;if(!Ob(p,1)){break g}}e=w[K>>1]}h=D(x[u>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Yb((Gc(ova(nva(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[u>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Yb((Gc(ova(nva(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[g>>2]=x[M>>2]/2;x[g+12>>2]=127;e=x[ud(g,g+12|0)>>2];break d;case 24:x[g>>2]=x[N>>2]/2;x[g+12>>2]=127;e=x[ud(g,g+12|0)>>2];break d;case 0:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[a+480188>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[o+704|0]>>>7|0;break d;case 15:e=0;if(!l){break d}h=y[l+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[m|0]<0){break h}i:{if(i>>>0<3){break i}e=x[j+40>>2];if(y[xb(e,i-3|0)|0]!=240){break i}if(y[xb(e,i-2|0)|0]>239){break h}}r=Kq(b,Q,R);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[m|0]=e;k=128;break d}k=(k&255)==255?f:k;e=f;break d;case 18:k:{if(!i){e=0;break k}h=x[j+40>>2];e=i;while(1){e=e-1|0;t=xb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(i-e>>>0<5){break a}t=x[j+40>>2];if(y[xb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(i|0)){h=y[xb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=Tc(e)?e-1|0:0}h=q^-1;q=1;i=(h&1)+i|0;S=xb(x[j+40>>2],i),T=e,v[S|0]=T;i=i+1|0;break a}e=z[C+786>>1];h=y[l+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=Rj(h)?h-1&15:0}}h=xb(x[j+40>>2],i);v[h|0]=(q&1?0:y[h|0]<<4)|e;q=q^1;i=(q&1)+i|0}n=n+1|0;continue}else{if(k<<24>>24>=0){v[m|0]=k}bc(g,x[j+40>>2],((q^-1)&1)+i|0);e=x[g+4>>2];x[j+40>>2]=x[g>>2];x[j+44>>2]=e;fb=g+16|0}break}o=x[j+44>>2];i=0;m:while(1){q=0;while(1){e=i;n:{o:{p:{q:{while(1){if(A[j+44>>2]<=e>>>0){break n}f=x[j+40>>2];m=xb(f,e);g=v[m|0];if((g|0)==-16){if(o-e>>>0>=4){i=4;if((y[xb(f,e+1|0)|0]&254)==240){break o}}i=e;r:{while(1){i=i+1|0;if(o>>>0<=i>>>0){break r}if(y[xb(f,i)|0]!=247){continue}break}i=(i-e|0)+1|0;if(i){break o}}S=xb(f,o),T=247,v[S|0]=T;o=o+1|0;i=o-e|0;break p}if((g|0)<0){break q}if(q&255){e=e-1|0;S=xb(f,e),T=q,v[S|0]=T;continue}break}i=i+1|0;continue m}S=j,T=EV(g&255),x[S+20>>2]=T;x[j+28>>2]=o-e;i=x[Gb(j+20|0,j+28|0)>>2]}if(!i){break n}f=x[j+40>>2];m=xb(f,e)}u=y[m|0];Dr(j+20|0,f,x[j+44>>2],e,i);f=gc(j+12|0,x[j+20>>2],x[j+24>>2]);m=x[f+4>>2];x[j>>2]=x[f>>2];x[j+4>>2]=m;m=fb-32|0;fb=m;n=x[j+4>>2];s:{if(!n){break s}l=Ed(y[b+223884|0]);t:{g=x[j>>2];h=xb(g,0);f=y[h|0]-250|0;if(f>>>0>5|!(1<<f&37)){break t}k=z[a+480188>>1];f=0;while(1){if((f|0)==(k|0)){break t}p=(D(f,872)+b|0)+1453|0;v[p|0]=127;v[p+1|0]=0;f=f+1|0;continue}}u:{if((n|0)!=4|y[h|0]!=240){break u}k=y[xb(g,1)|0];if((k&254)!=240){break u}n=D(c,872)+b|0;h=n+616|0;p=xb(g,2);s=y[xb(g,3)|0];f=s<<24>>24;C=(k|0)!=241&(f|0)>=0;p=y[p|0];if(!(!C|p)){g=n+1453|0;if(d){f=Ah(Kq(b,E(y[g|0]),E((f&255)>>>0)))}v[g|0]=f;v[n+1412|0]=0;f=Oq(a,h,!(x[n+704>>2]&32768),256);if((f|0)<0|!(y[n+705|0]&2)){break s}g=x[a+1298300>>2];if(l|Dd(g)^1){break s}Uq(g,c,f>>>2&255,1);break s}g=p<<24>>24;if(C&(g|0)==1){g=D(c,872)+b|0;l=g+1454|0;if(d){f=Ah(Kq(b,E(y[l|0]),E((f&255)>>>0)))}v[l|0]=f;v[g+1411|0]=0;Oq(a,h,!(x[g+704>>2]&32768),256);break s}if(!((k|0)==241|(g|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;Oq(a,h,!(x[g+704>>2]&32768),256);break s}if(!((k|0)==241|(g|0)!=3)){h=(f|0)<0;f=vm(a,b,c,3,0)-1|0;if(h|(f&255)>>>0>249){break s}v[m+24|0]=f;g=a+906300|0;k=f&255;f=x[vd(g,k)>>2];if(!f){break s}r=E(E(127-s|0)/E(127));if(l){k=0;g=fb-16|0;fb=g;S=g,T=Zj(m+24|0),x[S+4>>2]=T;f=fb-16|0;fb=f;l=b+223860|0;h=fB(l,f+12|0,y[m+24|0]);n=x[h>>2];if(!n){k=fb-16|0;fb=k;n=ec(l);p=Ch(f,Ec(24),Mg(k+8|0,n));n=x[p>>2];s=y[x[g+4>>2]];x[n+20>>2]=0;v[n+16|0]=s;S=ec(p),T=1,v[S+4|0]=T;fb=k+16|0;$g(l,x[f+12>>2],h,x[f>>2]);n=le(f);dm(f);k=1}_g(g+8|0,x[vb(f,n)>>2],k);fb=f+16|0;f=td(x[g+8>>2]);fb=g+16|0;B[f+4>>2]=r;break s}if(!d){Hu(x[f+20>>2],r);break s}g=vd(g,k);Hu(x[f+20>>2],Kq(b,B[g+144>>2],r));break s}k=(k|0)!=241;if(k&(g|0)>=0){break s}n=vm(a,b,c,3,0)-1|0;if((f|0)<0|(n&255)>>>0>249){break s}g=x[vd(a+906300|0,n&255)>>2];if(!g){break s}k=k?p&127:p+128|0;r=E(E((f&255)>>>0)/E(127));if(l){S=LT(b+223872|0,aT(m+24|0,n,k)),U=r,B[S>>2]=U;break s}f=x[g>>2];if(!d){ib[x[f+44>>2]](g,k,r);break s}T=g,V=k,U=Kq(b,E(ib[x[f+48>>2]](g,k)),r),S=x[x[g>>2]+44>>2],ib[S](T|0,V|0,E(U));break s}if(l){break s}l=z[a+480188>>1];v:{if(l>>>0>c>>>0){f=c+1|0;break v}f=z[(D(c,872)+b|0)+1402>>1];if(!f){break s}}if(y[(D(c,872)+b|0)+707|0]&4|l>>>0<(f&65535)>>>0){break s}f=vm(a,b,c,3,0)-1|0;if(f>>>0>249){break s}f=x[vd(a+906300|0,f)>>2];if(!f){break s}l=y[h|0];if((l|0)==240){mf(m+16|0,x[j>>2],x[j+4>>2]);g=x[x[f>>2]+72>>2];l=x[m+20>>2];x[m>>2]=x[m+16>>2];x[m+4>>2]=l;ib[g|0](f,m)|0;break s}S=m,V=EV(l),x[S+24>>2]=V;x[m+12>>2]=n;l=m+24|0;k=x[Gb(l,m+12|0)>>2];x[m+24>>2]=0;yc(l,g,k);ib[x[x[f>>2]+68>>2]](f,x[m+24>>2])|0}fb=m+32|0;q=u>>>0<240?u:q;i=e+i|0;continue}break}break}fb=j+48|0}function X7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(th(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1238;b=l+76|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l- -64|0);n=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31725]=0;ka(1241,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,q|0,n|0,o|0,l+24|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];d=m;e=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(Kf(x[h+8>>2],1,b)){x[31725]=0;O(1242,l+16|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(117,s|0,v[l+16|0]);b=x[31725];x[31725]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(!Kf(x[h+8>>2],1,b)){break c}x[31725]=0;O(1242,l+16|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(117,s|0,v[l+16|0]);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(x[n+4>>2],y[n+11|0])){break l}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(y[cc(n,0)|0]!=(b&255)){break l}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}m:{n:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(y[cc(o,0)|0]==(b&255)){break n}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break m}if(!Cb(k,b)){break m}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|r|((e|0)==2&(B|0)!=0|A))){r=0;break c}c=vb(l+16|0,zd(q));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=Df(q);k=x[c>>2];if(!Ib(k,b)){break p}if(!Kf(x[h+8>>2],1,v[k|0])){break p}me(c);continue}break}b=zd(q);b=Gk(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){k=YC(Df(s),b);E=Df(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=k;while(1){q:{z=Ib(k,E);if(!z){break q}if(!E0(y[k|0],y[x[b+8>>2]])){break q}k=me(b+12|0);me(b+8|0);k=x[k>>2];continue}break}fb=b+16|0;if(z^1){break o}}F=c,G=x[vb(l+12|0,zd(q))>>2],x[F>>2]=G}x[l+12>>2]=x[c>>2];r:{while(1){b=Df(q);if(!Ib(x[l+12>>2],b)){break r}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;s:{if((c|0)==1){break s}if(b){break r}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break s}if(y[x[l+12>>2]]!=(b&255)){break r}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}me(l+12|0);continue}break}break a}if(!A){break c}b=Df(q);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}t:{while(1){u:{x[31725]=0;c=P(1207,a|0,l+524|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break u}if(c){break t}c=x[a>>2];x[31725]=0;k=R(1208,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}v:{if(Kf(x[h+8>>2],64,k)){c=x[j>>2];if((c|0)==x[l+520>>2]){x[31725]=0;S(1243,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}c=x[j>>2]}x[j>>2]=c+1;v[c|0]=k;b=b+1|0;break v}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k&255)!=(D|0)){break t}if(x[l+96>>2]==(d|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}d=x[l+100>>2]}m=d+4|0;x[l+100>>2]=m;x[d>>2]=b;d=m;b=0}x[31725]=0;R(1210,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}w:{if(!b){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break w}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;b=R(1210,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31725]=0;c=P(1207,b|0,l+524|0)|0;d=x[31725];x[31725]=0;x:{if((d|0)==1){break x}y:{if(!c){c=x[b>>2];x[31725]=0;c=R(1208,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}if(Kf(x[h+8>>2],64,c)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31725]=0;S(1243,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break x}}c=x[b>>2];x[31725]=0;c=R(1208,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+1;v[d|0]=c;x[31725]=0;R(1210,b|0)|0;c=x[31725];x[31725]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;z:{if(!r){break z}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break z}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;A:{if((c|0)==1){break A}B:{if(!b){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}if(y[cc(r,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Xf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}d=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);Q(a|0);p()}function Epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-272|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+126|0;rX(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){qX(f)}a:{b:{c:{d:{if(!d){break d}if(!sX(f)){break d}if(!c){k=1;break d}Bd(a,4194304);d=e+40|0;f=tc(d,17048);Ab(a+1298344|0,f);tb(f);f=tc(d,10137);Ab(a+1298356|0,f);tb(f);n=a+1298404|0,o=x[Fc(d,4)>>2],x[n>>2]=o;n=a,o=Kd(y[e+204|0]|y[e+205|0]<<8,y[e+206|0]|y[e+207|0]<<8,127),w[n+480188>>1]=o;f=y[e+195|0];x[a+480228>>2]=(f|0)==255?48:f;x[a+480196>>2]=y[e+193|0];x[a+480204>>2]=D(y[e+194|0],1e4);f=e+104|0;df(f,e+130|0,59,3);Cc(d,f);Ab(a+1298308|0,d);tb(d);d=y[e+208|0]|y[e+209|0]<<8|(y[e+210|0]<<16|y[e+211|0]<<24);e:{if(d>>>0<5){break e}if(!cd(b,d-4|0)){break e}if(!ik(b,14233)){break e}hk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[e+198|0]|y[e+199|0]<<8,65535,65535)}f:{d=y[e+212|0]|y[e+213|0]<<8|(y[e+214|0]<<16|y[e+215|0]<<24);if(d>>>0<5){break f}if(!cd(b,d-4|0)){break f}if(!ik(b,13843)){break f}d=0;while(1){if((d|0)==32){break f}f=(d<<5)+a|0;Xe(f+480280|0);n=f+480284|0,o=((((Zd(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;d=d+1|0;continue}}d=y[e+220|0]|y[e+221|0]<<8|(y[e+222|0]<<16|y[e+223|0]<<24);g:{if(d>>>0<5){break g}if(!cd(b,d-4|0)){break g}if(!ik(b,14128)){break g}d=e+40|0;fe(d,b,(y[e+202|0]|y[e+203|0]<<8)<<6);i=c&2;k=a+480190|0;f=ic(e+104|0,d);ub(d);l=e+53|0;d=0;h:{while(1){if((d&65535)>>>0>=(y[e+202|0]|y[e+203|0]<<8)>>>0){break h}x[31725]=0;h=e+40|0;g=P(691,f|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break b}if(!g){break h}g=y[e+85|0]|y[e+86|0]<<8;w[e+38>>1]=g;i:{j:{if((g-1&65535)>>>0>3998){break j}g=D(g,104)+a|0;j=g+484380|0;if(je(x[j>>2],x[g+484400>>2])){break j}n=k,o=z[qe(k,e+38|0)>>1],w[n>>1]=o;x[31725]=0;O(692,h|0,j|0);g=x[31725];x[31725]=0;if((g|0)==1){break i}h=e+12|0;s_(h,1,l);x[31725]=0;g=e+24|0;O(220,g|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break b}zc(((z[e+38>>1]<<5)+a|0)+946304|0,g);tb(g);if(!i){break j}x[31725]=0;P(151,b|0,y[e+77|0]|y[e+78|0]<<8|(y[e+79|0]<<16|y[e+80|0]<<24))|0;h=x[31725];x[31725]=0;if((h|0)==1){break i}j=1;h=y[e+87|0];m=Xc(g,h&4?16:8,1,0,0);k:{l:{if(h&8){break l}j=2;if(h&16){break l}if(h&127){break k}}yg(m,j)}x[31725]=0;U(217,g|0,(D(z[e+38>>1],104)+a|0)+484380|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break j}break b}d=d+1|0;continue}break}break b}ub(f)}k=1;if(!(c&1)){break d}m:{c=y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24);if(c>>>0<5){break m}if(!cd(b,c-4|0)){break m}if(!ik(b,13714)){break m}j=a+484344|0;Vf(j,y[e+200|0]|y[e+201|0]<<8);g=0;while(1){if((y[e+200|0]|y[e+201|0]<<8)>>>0<=g>>>0){break m}if(!Tr(b,e+24|0)){break m}n:{d=z[e+24>>1];if(d>>>0>3){c=e+104|0;fe(c,b,(d+15&131056)-4|0);f=ic(e+40|0,c);ub(c);x[31725]=0;c=U(198,j|0,g&65535,y[e+26|0])|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[f>>2];x[31725]=0;d=U(152,c|0,x[e+48>>2],1)|0;c=x[31725];x[31725]=0;q:{if((c|0)!=1){c=y[e+26|0];if(!(d&c>>>0>(h&255)>>>0)){break p}x[31725]=0;c=R(199,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[e+104>>1]=d&31;w[e+12>>1]=z[a+480188>>1]-1;c=Wb(c,g);i=e+104|0;c=jd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Nc(i,e+12|0)>>1]);if((d|0)<0){x[31725]=0;O(200,i|0,f|0);l=x[31725];x[31725]=0;if((l|0)==1){break c}v[c|0]=y[e+104|0]+36;n=c,o=y[Jc(i)|0],v[n+1|0]=o}d=d&255;if(d&64){v[c+2|0]=1;x[31725]=0;i=R(199,f|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break c}v[e+104|0]=i;v[e+12|0]=64;n=c,o=y[Rb(e+104|0,e+12|0)|0],v[n+4|0]=o}if(!(d&32)){continue}x[31725]=0;d=e+104|0;O(200,d|0,f|0);i=x[31725];x[31725]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((i|0)!=1){d=y[Jc(d)|0];v[c+5|0]=d;switch(y[e+104|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[31725]=0;d=R(199,f|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){v[c+5|0]=d;x[31725]=0;P(185,f|0,1)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}ye(Wb(x[j>>2],g),Yh(Ye(Ne(e+104|0,14,0),c-1|0)))}ub(f)}g=g+1|0;continue}break}break c}c=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);if(!c){break d}cd(b,c);_D(a+1298332|0,b,hh(b),4)}fb=e+272|0;return k|0}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function Oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=fb-48|0;fb=j;d=x[b>>2];x[31725]=0;f=R(174,d|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){h=Nb(j+36|0);x[31725]=0;e=(c|0)!=0;g=U(866,h|0,b|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}f=2;g:{h:{i:{j:{if(g){break j}x[31725]=0;g=U(867,h|0,b|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}f=3;if(g){break j}x[31725]=0;g=U(868,h|0,b|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}f=4;if(g){break j}g=0;x[31725]=0;e=U(869,h|0,b|0,e|0)|0;d=x[31725];x[31725]=0;f=1;if((d|0)==1){break e}if(!e){break i}}if(!c){f=1;d=0;break h}d=x[h>>2];if(!lc(d,x[h+4>>2])){Ww(b,d+12|0)}g=f}d=29920;k:{while(1){f=d;if((d|0)!=30496){e=x[d+8>>2];i=(e>>1)+a|0;d=x[d+4>>2];d=e&1?x[x[i>>2]+d>>2]:d;x[31725]=0;e=U(d|0,i|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}d=f+12|0;if(!e){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){f=(f|0)!=30496;d=0;break h}if(!(x[a+480184>>2]|!g)){x[a+480184>>2]=g}x[31725]=0;d=1;O(805,a+1298264|0,1);g=x[31725];x[31725]=0;f=1;if((g|0)==1){break g}}pS(h);if(d){break f}break a}break c}x[31725]=0;O(248,a|0,0);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;O(805,a+1298264|0,1);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[a+1074304>>2]=19989505;x[a+1298408>>2]=0}f=0;while(1){if((f|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){d=0;f=0;l:{while(1){g=f&65535;if(g>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=d;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{e=x[((g<<2)+a|0)+900380>>2];if(e){g=x[a+480180>>2];wc(e,65536);wc(e+4|0,64);wc(e+8|0,256);Gf(e+28|0,16384);Qf(e+30|0,128);Qf(e+31|0,17);if(y[e+16|0]>=4){v[e+16|0]=0}if(y[e+17|0]>=5){v[e+17|0]=0}if(y[e+18|0]>=3){v[e+18|0]=0}Qf(e+19|0,64);Qf(e+20|0,100);h=224;d=v[e+26|0];n:{if((d|0)>=-32){h=32;if((d|0)<33){break n}}v[e+26|0]=h}Qf(e+23|0,64);Qf(e+24|0,64);dC(e+48|0,64);dC(e+68|0,64);dC(e+88|0,(g|0)==4096?255:64);d=e+108|0;g=0;while(1){if((g|0)==128){if(!Ap(y[e+14|0])){v[e+14|0]=5}if(y[e+34|0]>=251){v[e+34|0]=0}}else{o:{if(y[xb(d,g)|0]){if(y[xb(d,g)|0]<121){break o}}l=xb(d,g),m=g+1|0,v[l|0]=m}g=g+1|0;continue}break}d=f}f=f+1|0;continue}break}wc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}g=a+480216|0;f=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[g>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[f>>2]=d}wc(g,65536);wc(f,65536);wc(a+480200|0,256);p:{if(!lc(x[a+480248>>2],x[a+480252>>2])){d=x[g>>2];x[31725]=0;O(870,a+480248|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];sB(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(Dn(x[a+480180>>2])){x[31725]=0;P(269,a+1074312|0,7)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Hq(a);l=j,m=wb(x[a+484360>>2]),x[l+36>>2]=m;f=wb(x[a+484364>>2]);q:{while(1){r:{g=x[j+36>>2];if(!Ib(g,f)){if(x[a+480180>>2]){break r}f=0;break a}x[31725]=0;W(871,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break q}if(Zc(x[g>>2],x[g+4>>2])>>>0<=z[g+28>>1]){bf(g,0)}dr(j+36|0);continue}break}Au(a+8|0,yr(a));if(x[a+1074308>>2]){x[31725]=0;W(872,a|0);d=x[31725];x[31725]=0;if((d|0)==1){break p}}i=Nb(j+36|0);s:{t:{if((c&12)!=12){break t}g=a+906300|0;f=0;u:{v:{w:{x:{y:{z:{while(1){if((f|0)==250){break t}A:{k=vd(g,f);B:{if(!Ti(x[k+16>>2],x[k+20>>2])){break B}x[31725]=0;O(873,k|0,a|0);c=x[31725];x[31725]=0;C:{if((c|0)!=1){e=x[k>>2];if(!e){break C}d=x[k+148>>2];c=x[x[e>>2]+56>>2];x[31725]=0;O(c|0,e|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){break B}}a=N()|0;break s}h=wb(x[i>>2]);c=wb(x[i+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=h;while(1){D:{if(!Ib(h,c)){break D}d=x[h>>2];if((y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){d=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{d=0}if(d){break D}h=x[Je(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(h,wb(x[i+4>>2]))){break B}x[31725]=0;x[j+24>>2]=k+16;e=j+24|0;O(874,i|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;d=P(1,j+12|0,18314)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}x[31725]=0;O(875,j|0,k|0);c=x[31725];x[31725]=0;if((c|0)==1){break y}x[31725]=0;S(2,e|0,d|0,j|0);c=x[31725];x[31725]=0;if((c|0)==1){break x}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break w}tb(e);tb(j);tb(d)}f=f+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(j+24|0)}tb(j)}tb(d);break s}c=y[a+1074368|0];x[31725]=0;O(876,a|0,c|0);a=x[31725];x[31725]=0;f=1;if((a|0)!=1){uc(i);break a}a=N()|0}uc(i);break b}a=N()|0;break b}a=N()|0;break b}e=D(f,104)+a|0;i=e+484380|0;E:{if(je(x[i>>2],x[e+484400>>2])){Qj(i,a);break E}g=e+484414|0;f=z[g>>1];if(f&16384){break E}x[i>>2]=0;x[i+4>>2]=0;x[i+16>>2]=0;x[i+8>>2]=0;x[i+12>>2]=0;w[g>>1]=f&65505}f=e+484412|0;if(z[f>>1]>=65){w[f>>1]=64}F:{G:{if(!(y[e+484415|0]&2)){break G}if(!Nj(x[a+1298300>>2])){break G}x[31725]=0;W(877,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}g=(f<<5)+a|0;Gf(g+480286|0,64);d=g+480284|0;if(z[d>>1]>=257){w[d>>1]=128}d=g+480288|0;if(y[d|0]>=251){v[d|0]=0}Vo((D(f,872)+a|0)+1074992|0,a,f&65535,134217728);f=f+1|0;continue}}break c}a=N()|0;break b}a=N()|0;pS(h)}ub(b);Q(a|0);p()}ub(b);fb=j+48|0;return f|0}function Ru(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}i=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{j=x[b+656>>2];k:{if(!(!j|x[a+480180>>2]!=16777216)){l=x[j+44>>2]!=0;break k}if(!j){break j}}if((c|0)>128){break i}m=c-1|0;h=z[_b(j+236|0,m)>>1];l:{if((h-1&65535)>>>0<=3998){i=(D(h,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Jj(x[b+656>>2])){break a}}m=y[xb(j+108|0,m)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;h=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Ko(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];if(!(!(c&512)|x[a+480180>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}h=0;if(!l){break g}if(d){h=y[b+797|0];if(h){break f}}x[b+708>>2]=0;h=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!i)){w[b+770>>1]=v[i+36|0];w[b+772>>1]=v[i+37|0];break d}if(i){break d}i=0;p=1;break c}h=D((x[x[j+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(h<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=h;x[b+852>>2]=0-h;h=1}p=!i;l=1;if(Ti(x[b+8>>2],x[b+12>>2])){break b}p:{l=a+1074312|0;if(!Ob(l,54)){break p}if(Jj(x[b+656>>2])){if(!Ob(l,117)){break p}}x[b+700>>2]=0;break a}l=(Ob(l,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[i+24>>2]}l=0}q:{if(Dn(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Fe(n+12|0,12,131);break q}VX(n+12|0)}k=a+1074312|0;r:{if(Ob(k,34)){d=jm(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:l)){v[b+803|0]=0}o=xh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(k,48)){qT(a,b,j,i)}s:{if(!Ob(k,115)|!j){break s}d=y[j+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}pT(b+692|0,c,d,y[j+27|0])}t:{if(l|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!j){break t}if(Ob(k,29)){v[b+798|0]=y[j+16|0]}if(!(y[j+60|0]&8)){Ij(b+724|0)}if(!(y[j+80|0]&8)){Ij(b+732|0)}if(!(y[j+100|0]&8)){Ij(b+740|0)}if(y[j+20|0]){c=((D(Ou(Jo(a)),y[j+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Ob(k,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[j+19|0]){break v}r=b,s=(D(Ou(Jo(a)),y[j+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(k,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[j+23|0];if(m){d=Ou(Jo(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[j+24|0];if(!m){break t}d=Ou(Jo(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(p){break a}w:{x:{if(!o){d=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=o}y:{z:{if(!h){if(!l){if(Ob(k,69)){break z}if(Ob(k,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=o;v[b+851|0]=y[b+851|0]&239}if(!l){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=i;c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Ob(k,96)|y[b+789|0]){break B}q=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Gb(b+660|0,n+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[i+34>>1];h=c&1023;d=h|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[i+12>>2];c=x[i+16>>2];x[b+88>>2]=(h&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(h&2)){break D}x[b+80>>2]=x[i+4>>2];c=x[i+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Ob(k,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Ob(k,21);h=x[a+480180>>2];H:{I:{if(!(c|!(h&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((h|0)==16){break H}}if(h&67633152){break G}d=0}v[b+819|0]=d}if(Ob(k,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!l){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){dn(b);if(!Ob(k,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){i=y[b+789|0];break J}i=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(i&255)){break w}}if(!(i&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}K:{if(!(!c|!Ob(k,40)|(y[b+789|0]?y[a+480208|0]&8:0))){d=x[b+88>>2]&-4194305;break K}d=x[b+88>>2]&-4196353}x[b+88>>2]=d;L:{if(c){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=d&-6324225|2097152;M:{if(Ob(k,23)){break M}if(Ob(k,22)){break M}if(Ob(k,52)){break M}if(Ob(k,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!Dd(x[a+1298300>>2])|(g|0)==65535){break L}if(Ob(k,111)){Fk(x[a+1298300>>2],g);break L}if(!Ob(k,110)){break L}SB(x[a+1298300>>2],g,0,1,0)}d=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=d&-1025;break P}if(!(d&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(c){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function O5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=xd(a,c);x[a>>2]=111976;f=DJ(a+8|0);x[31725]=0;e=P(72,a+152|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31725]=0;b=ca(106)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=x[b>>2];c=0;x[31725]=0;b=P(1307,f|0,b+8|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}while(1){f:{d=x[b>>2];if(oc(d,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break f}break e}d=x[yb(d,c)>>2];if(d){gl(d)}c=c+1|0;continue}break}x[31725]=0;b=U(1308,c|0,e|0,0)|0;d=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31725]=0;O(1309,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1310,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break t}x[31725]=0;O(1311,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,20)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1312,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break s}x[31725]=0;O(1313,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1314,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}x[31725]=0;O(1315,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=113924;x[b>>2]=119536;x[31725]=0;O(1316,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1317,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;O(1318,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114072;x[b>>2]=119744;x[31725]=0;O(1319,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114304;x[b>>2]=119848;x[31725]=0;O(1320,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114188;x[b>>2]=119952;x[31725]=0;O(1321,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114420;x[b>>2]=120056;x[31725]=0;O(1322,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,24)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1323,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}x[31725]=0;O(1324,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,28)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1325,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break o}x[31725]=0;O(1326,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,72)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1327,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}x[31725]=0;O(1328,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,72)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1329,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[31725]=0;O(1330,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,76)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1331,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break l}x[31725]=0;O(1332,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,76)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1333,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}x[31725]=0;O(1334,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,544)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1335,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}x[31725]=0;O(1336,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,544)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1337,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break i}x[31725]=0;O(1338,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1339,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;O(1340,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1341,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;O(1342,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=mJ(b,0);x[b>>2]=119384;x[31725]=0;O(1343,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=lJ(b,0);x[b>>2]=119460;x[31725]=0;O(1344,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}return a|0}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}a=N()|0;break c}b=T(0)|0}Y(b|0)|0;c=0;while(1){b=x[f>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}tb(e);break c}b=x[yb(b,c)>>2];if(b){Am(b)}c=c+1|0;continue}}cy(f);Q(a|0);p()}T(0)|0;Tb()}p()}function faa(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=fb-560|0;fb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;B=5296;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;B=5299;break a}u=e&1;B=u?5302:5297;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;Yf(a,32,c,g,e&-65537);Lf(a,B,u);d=f&32;Lf(a,b!=b?d?9978:13848:d?11132:14166,3);Yf(a,32,c,g,e^8192);q=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=HL(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}k=x[n+44>>2];m=(d|0)<0?6:d;break d}k=g-29|0;x[n+44>>2]=k;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((k|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((k|0)<=0){d=k;g=h;i=s;break f}i=s;d=k;while(1){l=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}p=0;while(1){d=x[g>>2];q=l&31;C=p;if((l&63)>>>0>=32){p=d<<q;d=0}else{p=(1<<q)-1&d>>>32-q;d=d<<q}q=C+d|0;p=p+r|0;p=pva(q,d>>>0>q>>>0?p+1|0:p,1e9,0);d=nva(p,hb,-1e9,0)+q|0;x[g>>2]=d;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!p){break g}i=i-4|0;x[i>>2]=p}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-l|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;q=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}p=1e9>>>q|0;l=-1<<q^-1;d=0;h=i;while(1){C=d;d=x[h>>2];x[h>>2]=C+(d>>>q|0);d=D(p,d&l);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=q+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){p=h+9216|0;l=(p|0)/9|0;k=((((k|0)<0?4:292)+n|0)+(l<<2)|0)-4048|0;h=10;q=p+D(l,-9)|0;if((q|0)<=7){while(1){h=D(h,10);q=q+1|0;if((q|0)!=8){continue}break}}p=x[k>>2];w=(p>>>0)/(h>>>0)|0;r=D(w,h);l=k+4|0;j:{if((p|0)==(r|0)&(l|0)==(g|0)){break j}p=p-r|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[k-4|0]&1)|((h|0)!=1e9|i>>>0>=k>>>0)){break k}}b=9007199254740994}t=(g|0)==(l|0)?1:1.5;l=h>>>1|0;t=l>>>0>p>>>0?.5:(l|0)==(p|0)?t:1.5;if(!(y[B|0]!=45|E)){t=-t;b=-b}x[k>>2]=r;if(b+t==b){break j}d=h+r|0;x[k>>2]=d;if(d>>>0>=1e9){while(1){x[k>>2]=0;k=k-4|0;if(k>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[k>>2]+1|0;x[k>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=k+4|0;g=g>>>0>h>>>0?h:g}while(1){l=g;p=g>>>0<=i>>>0;if(!p){g=g-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){k=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;k=e&8;if(k){break l}g=-9;m:{if(p){break m}k=x[l-4>>2];if(!k){break m}q=10;g=0;if((k>>>0)%10|0){break m}while(1){h=g;g=g+1|0;q=D(q,10);if(!((k>>>0)%(q>>>0)|0)){continue}break}g=h^-1}h=D(l-s>>2,9);if((f&-33)==70){k=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}k=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}q=-1;p=k|m;if(((p?2147483645:2147483646)|0)<(m|0)){break b}r=(((p|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=po((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;Yf(a,32,c,r,e);Lf(a,B,u);Yf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;k=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=po(x[i>>2],0,k);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(k|0)){break r}v[n+24|0]=48;g=d}Lf(a,g,k-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(p){Lf(a,16781,1)}if((m|0)<=0|i>>>0>=l>>>0){break q}while(1){g=po(x[i>>2],0,k);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}Lf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(l>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<l>>>0?l:i+4|0;f=n+16|0;d=f|8;l=f|9;h=i;while(1){g=po(x[h>>2],0,l);if((l|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}Lf(a,g,1);g=g+1|0;if(!(k|m)){break t}Lf(a,16781,1)}f=l-g|0;Lf(a,g,(f|0)<(m|0)?f:m);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Yf(a,48,m+18|0,18,0);Lf(a,w,z-w|0);break o}g=m}Yf(a,48,g+9|0,9,0)}Yf(a,32,c,r,e^8192);q=(c|0)<(r|0)?r:c;break b}k=(f<<26>>31&9)+B|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[k|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=po((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){l=~~b}else{l=-2147483648}v[h|0]=i|y[l+93488|0];b=(b-+(l|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}q=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}l=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=l+d|0;Yf(a,32,c,h,e);Lf(a,k,s);Yf(a,48,c,h,e^65536);Lf(a,f,i);Yf(a,48,d-i|0,0,0);Lf(a,m,g);Yf(a,32,c,h,e^8192);q=(c|0)<(h|0)?h:c}fb=n+560|0;return q|0}function tta(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Rb(l,k)|0];v[j+8|0]=14;l=y[Rb(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[ud(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=ud(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=ID(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=Dh(ID(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Gc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=wr(a,f,g);if(!c){break c}a=ti(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;wc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;Uv(j+8|0);x[j+112>>2]=9;s=b,t=x[Gb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Bf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Tc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);if(z[a+480192>>1]){break a}w[j+8>>1]=255;c=z[Nc(a+480190|0,j+8|0)>>1];w[a+480192>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=BE(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;e=d+946304|0;f=x[e+4>>2];x[c+492>>2]=x[e>>2];x[c+496>>2]=f;e=d+946312|0;f=x[e+4>>2];x[c+500>>2]=x[e>>2];x[c+504>>2]=f;e=d+946320|0;f=x[e+4>>2];x[c+508>>2]=x[e>>2];x[c+512>>2]=f;d=d+946328|0;e=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=e;kk(c,127,1);jk(c,0,1)}b=b+1|0;c=z[a+480192>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=fm(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=wr(a,f,g);if(!i){break a}k=ti(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[xb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=Ci(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=fm(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Tv(qL(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Tc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Dh(ID(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function Ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-176|0;fb=d;xc(c);a:{if(!np(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break a}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break a}e=fb-32|0;fb=e;i=d+152|0;f=Nb(i);b:{c:{d:{e:{f:{while(1){g=x[c+8>>2];h=x[c>>2];x[31725]=0;g=U(152,h|0,g|0,8)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(!g){break e}x[31725]=0;g=e+4|0;O(829,g|0,c|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;O(830,f|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}Gd(g);continue}break}a=N()|0;break c}a=N()|0;Gd(e+4|0);break c}fb=e+32|0;break b}a=N()|0}ie(f);Q(a|0);p()}x[31725]=0;e=d+132|0;S(749,e|0,i|0,1129270605);c=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[31725]=0;c=P(750,e|0,d+114|0)|0;f=x[31725];x[31725]=0;n:{o:{if((f|0)!=1){if(!c){break g}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Bb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Bb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[31725]=0;c=P(629,e|0,d+108|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[31725]=0;e=d+88|0;S(749,e|0,d+152|0,1397968452);f=x[31725];x[31725]=0;p:{q:{if((f|0)!=1){x[31725]=0;l=P(751,e|0,d+80|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}if(l){break q}break h}c=N()|0;break j}f=(Bb(z[d+120>>1])-1|0)/8|0;g=f<<3;e=g&31;g=Xc(d+76|0,(f>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>e|0:((1<<e)-1&1074268168)<<32-e|538447880>>>e)&120,(Bb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}yg(g,3);break r}yg(g,17);fd(g,16);break r}yg(g,16);fd(g,16);break r}yg(g,1)}c=x[d+80>>2];x[31725]=0;c=U(152,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[31725]=0;P(185,d+88|0,$b(c)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}}Uu(a,b);x[31725]=0;c=D(b,104)+a|0;i=c+484380|0;O(281,i|0,0);e=x[31725];x[31725]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=i,t=$b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);h=30-y[d+123|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[31725]=0;U(217,g|0,i|0,d+88|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}x[31725]=0;e=d+56|0;f=d+152|0;S(749,e|0,f|0,1296126539);c=x[31725];x[31725]=0;if((c|0)==1){break C}x[31725]=0;c=R(174,x[d+56>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break B}if(!c){break u}x[31725]=0;c=d+16|0;S(749,c|0,f|0,1229869908);f=x[31725];x[31725]=0;if((f|0)==1){break A}x[31725]=0;f=P(752,c|0,d+36|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break z}ub(c);if(!f){break u}x[31725]=0;f=R(275,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}e=Nb(c);x[31725]=0;O(753,e|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[31725]=0;g=d+56|0;h=d+4|0;j=P(754,g|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break w}if(!j){break x}x[31725]=0;O(755,e|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break w}x[31725]=0;h=g;g=y[d+10|0];P(185,h|0,!(g&1)+g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Bb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Bb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=wb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;k=c+484392|0;m=wb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,m)){break v}f=Bb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Bb(n)|0)){s=k,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(o)|0)==(f|0)){s=j,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(q)|0)==(f|0)){s=h,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Bb(r)|0)){s=g,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;ZT(e);break m}$k(i);ZT(e)}x[31725]=0;c=d+16|0;S(749,c|0,d+152|0,1312902469);e=x[31725];x[31725]=0;if((e|0)==1){break n}x[31725]=0;e=R(174,x[d+16>>2])|0;f=x[31725];x[31725]=0;E:{if((f|0)==1){break E}F:{if(e){x[31725]=0;e=R(156,x[d+16>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break E}x[31725]=0;S(319,c|0,((b<<5)+a|0)+946304|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break F}break E}x[31725]=0;c=P(36,d+4|0,22267)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}zc(((b<<5)+a|0)+946304|0,c);tb(c)}bC(i,x[a+480180>>2]);Qj(i,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}ie(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);ie(d+152|0)}fb=d+176|0;return l|0}function Qo(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Tc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[_b(g,j)>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(Rj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[xb(h+108|0,j)|0]>120){break b}j=z[_b(g,j)>>1];k=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){k=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(Rj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(k|0);i=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;n=d^1;g=(h|0)!=(i|0);if((n|g|m)==1){w[b+774>>1]=0}l=!m;if(!(l|(!(d&p)|g))){break b}f:{if(l|n){break f}q=a+1074312|0;if(!(!Ob(q,32)|!(y[a+480208|0]&8))){k=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:k}j=x[a+480180>>2];g:{h:{i:{j:{if(!g){if((h|0)!=0&(j&1048580)!=0|(j|0)==268435456){break h}if((j|0)!=1){break i}break j}if((j|0)==1){break j}if((j|0)==268435456){break h}break i}if(Ti(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(q,79)){break g}if(!Ti(x[b+8>>2],x[b+12>>2])){break g}}o=1}if(!Ob(q,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}k:{if(!x[b+16>>2]|(l|(!z[a+480192>>1]|g))){break k}if(!Ob(a+1074312|0,87)){break k}o=Tc(y[b+788|0])^1|o}l=(h|0)!=(i|0);l:{if(Ti(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break l}if(h){if(Rj(y[h+31|0])){break l}}l=1}m:{n:{if(!(m|l)|!d){break n}if(!Ob(a+1074312|0,61)){break n}g=x[b+104>>2];i=x[b+656>>2];j=0;if(g|i){break m}}x[b+656>>2]=h;g=k;i=h;j=l}o:{p:{q:{if(!e){break q}r:{if(y[a+480180|0]&3){if(g){if(je(x[g>>2],x[g+20>>2])){break r}}if(!Jj(i)){break q}}if(!g){break p}}if(w[g+34>>1]<0){break q}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(m&o)|!g){break o}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break o}if(!je(x[g>>2],x[g+20>>2])){break o}x[b+704>>2]=x[g+24>>2];break o}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break o}h=0;x[b+688>>2]=0}if(o){break b}v[b+803|0]=0;s:{if(!i){break s}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break s}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}t:{if(!(x[a+480180>>2]&1048580?e:1)){break t}if(Ob(a+1074312|0,48)){break t}qT(a,b,i,g)}u:{v:{w:{if(!f){break w}x:{y:{z:{A:{B:{C:{D:{E:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break D}if(!(!c|n)){e=(y[a+480208|0]&8)>>>3|0;if(e){break D}break E}e=0;if(c){break E}break D}F:{c=x[a+480180>>2]&17301536;e=1;G:{if(!d|!c){break G}c=1;e=1;if(y[a+480208|0]&8){break G}e=1;if(!x[b+76>>2]){break G}if(!(y[b+89|0]&16)){break F}e=!x[b+696>>2]}if(j|(!i|!c)){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break A}break C}if((j|!i)!=1){break x}break y}if(d){break D}if(!(y[b+89|0]&24)){e=0;break D}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break z}if(c&2048){break A}}if(!(y[i+60|0]&8)){Ij(b+724|0)}if(!(y[i+80|0]&8)){Ij(b+732|0)}if(y[i+100|0]&8){break z}Ij(b+740|0);break z}if(!e){break y}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break z}}dn(b)}if(Ob(f,21)){break w}v[b+818|0]=0;x[b+756>>2]=0;break w}if(!i){break v}}if(v[i+60|0]&1){break w}if(Ob(f,32)){Ij(b+724|0);break w}dn(b)}c=0;if(g){break u}if(!i){break a}c=1;if(Rj(y[i+31|0])){break u}break a}c=0;if(!g){break a}}H:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}I:{J:{if((e|0)!=4){break J}if(!Ob(a+1074312|0,40)|y[b+789|0]){break J}e=x[b+88>>2];break I}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break H}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;K:{L:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break L}break K}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break K}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break H}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];M:{if((y[i+100|0]&17)!=17){break M}if(Ob(e,36)|y[b+837|0]){break M}v[b+837|0]=127}e=y[i+21|0];if(Cd(e)){s=b,t=Vh(e),v[s+837|0]=t}e=y[i+22|0];if(!Cd(e)){break H}s=b,t=Vh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}N:{if(x[b+76>>2]|!d){break N}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break N}}x[b+8>>2]=0;x[b+12>>2]=0}O:{if(y[b+788|0]!=255){break O}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break O}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Xq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}P:{Q:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break Q}if(!(m|n)){d=x[a+480180>>2];if(d&5){break P}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(Dn(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];R:{if(!(h&2)){break R}d=x[b+84>>2];if(d>>>0>=c>>>0){break R}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-224|0;fb=d;xc(b);f=d+160|0;a:{if(!Fr(b,f)){break a}if(!VW(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(UW(f),hb))){break a}if(!c){e=1;break a}Bd(a,256);f=d+148|0;vi(f,2,d+160|0);e=d+56|0;Cc(e,f);Ab(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;j=xC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=j;v[d+56|0]=64;q=a,r=y[Rb(d+202|0,e)|0]<<2,x[q+480200>>2]=r;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{j=Nb(d+148|0);m=Nb(d+136|0);x[31725]=0;P(151,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31725];x[31725]=0;i:{if((e|0)==1){break i}x[31725]=0;U(215,b|0,j|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;P(151,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;U(215,b|0,m|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;P(151,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}e=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;O(332,Xb(f,e)|0,y[d+212|0]|y[d+213|0]<<8);e=x[31725];x[31725]=0;if((e|0)==1){break i}e=Xb(x[a+484360>>2],y[a+484376|0]);q=d,r=wb(x[e>>2]),x[q+56>>2]=r;e=wb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!YW(Xb(x[a+484360>>2],y[a+484376|0]))){break b}k=c&2;n=d+57|0;e=1;break j}x[31725]=0;g=R(199,b|0)|0;h=x[31725];x[31725]=0;k:{if((h|0)==1){break k}w[f>>1]=g;x[31725]=0;P(185,b|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}Md(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){g=e&65535;if(g>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}f=_b(x[m>>2],g-1|0);f=y[f|0]|y[f+1|0]<<8;x[31725]=0;f=P(151,b|0,f<<4)|0;h=x[31725];x[31725]=0;p:{if((h|0)!=1){if(f){break p}e=0;break b}b=N()|0;break c}x[31725]=0;h=d+56|0;P(700,b|0,h|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;l=(D(g,104)+a|0)+484380|0;S(701,h|0,l|0,0);f=x[31725];x[31725]=0;if((f|0)==1){break o}i=d+28|0;Qk(i,2,n);x[31725]=0;f=d+40|0;O(220,f|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break n}zc(((g<<5)+a|0)+946304|0,f);tb(f);q:{r:{if(!k|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}g=iX(h);x[31725]=0;g=P(151,b|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}if(!g){break r}hX(f,y[d+86|0],y[d+87|0],1);x[31725]=0;U(217,f|0,l|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;n=0;e=x[j>>2];s:{if(lc(e,x[j+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31725]=0;f=P(151,b|0,f<<4)|0;g=x[31725];x[31725]=0;if((g|0)==1){break h}if(!f){break b}x[31725]=0;e=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}if((y[d+188|0]|y[d+189|0]<<8)!=(e|0)){break s}v[d+27|0]=0;n=1}l=c&1;if(l){x[31725]=0;O(225,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31725];x[31725]=0;if((c|0)==1){break h}}h=a+484344|0;f=0;while(1){t:{if(!l|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31725]=0;c=U(198,h|0,f&65535,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}if(!c){break t}c=_b(x[j>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31725]=0;c=P(151,b|0,c<<4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(n){x[31725]=0;c=R(191,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Wb(x[h>>2],f);cf(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}k=e<<24>>24;if(!k){e=64;if(c>>>0>62){continue u}e=Wb(x[h>>2],f);g=x[e>>2];i=x[x[e+48>>2]+12>>2];e=c+1|0;cf(d+56|0,g,i,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=bh(d+56|0);g=k&31;if(g>>>0<z[a+480188>>1]){e=Wc(x[d+40>>2],g)}i=k&255;if(i&32){x[31725]=0;g=d+25|0;O(200,g|0,b|0);o=x[31725];x[31725]=0;v:{w:{x:{if((o|0)!=1){o=Jc(g);g=y[d+25|0];if(g>>>0>239){break x}g=gX((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[o|0]}if(i&64){x[31725]=0;g=R(199,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;q=e,r=y[Rb(d+25|0,d+24|0)|0],v[q+4|0]=r}if((k|0)>=0){continue}x[31725]=0;g=d+25|0;O(200,g|0,b|0);k=x[31725];x[31725]=0;if((k|0)==1){break d}q=e,r=y[Jc(g)|0],v[q+5|0]=r;XW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){ye(Wb(x[h>>2],f),Fn(Ye(Ne(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31725]=0;b=P(1,d+56|0,6088)|0;c=x[31725];x[31725]=0;z:{A:{B:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+40|0,5274)|0;c=x[31725];x[31725]=0;if((c|0)==1){break B}Ab(a+1298356|0,b);tb(b);b=d+28|0;q=a+1298404|0,r=x[Fc(b,4)>>2],x[q>>2]=r;x[31725]=0;c=d+12|0;O(703,c|0,4405);e=x[31725];x[31725]=0;if((e|0)==1){break A}x[31725]=0;S(211,b|0,c|0,d+27|0);e=x[31725];x[31725]=0;if((e|0)==1){break z}Ab(a+1298368|0,b);tb(b);Eb(c);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}md(m);md(j);Q(b|0);p()}md(m);md(j)}fb=d+224|0;return e|0}function Vsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-1344|0;fb=f;xc(b);d=fb-16|0;fb=d;i=f+768|0;$Z(d+8|0,i);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(j|0);if(!d){_Z(i)}a:{if(!d){break a}if(!b_(i)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(a_(y[f+802|0]|y[f+803|0]<<8,y[f+804|0]|y[f+805|0]<<8),hb))){break a}b:{if(!c){break b}r=sc(f+764|0);d=0;c:{d:{e:{while(1){if((e|0)!=32){i=(e<<5)+a|0;h=i+480280|0;Xe(h);j=(f+768|0)+(e<<4)|0;w[i+480284>>1]=((y[j+78|0]<<8&65280)>>>0)/255;m=f+496|0;Qk(m,1,j- -64|0);k=f+108|0;Cc(k,m);om(i+480289|0,k);tb(k);f:{g:{switch(y[j+79|0]){case 0:g=d+1|0;break f;case 1:x[h>>2]=1024;g=e+1|0;break f;case 2:break g;default:break e}}x[h>>2]=1024;i=f+108|0;Pc(i,r,e);gp(i)}d=d+1|0;e=e+1|0;continue}break}Bd(a,33554432);w[a+480188>>1]=g&255;e=f+108|0;d=tc(e,6808);Ab(a+1298344|0,d);tb(d);d=tc(e,11140);Ab(a+1298356|0,d);tb(d);t=a+1298404|0,u=x[Fc(e,4)>>2],x[t>>2]=u;h:{if(y[f+847|0]){break h}e=1;d=1;while(1){if((e|0)==16){while(1){if((d|0)==16){break h}e=((d<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025;d=d+1|0;continue}}g=e<<4;e=e+1|0;if(y[(f+g|0)+847|0]==1){continue}break}}e=f+496|0;We(e,1,f+768|0);d=f+108|0;Cc(d,e);Ab(a+1298308|0,d);tb(d);x[a+480208>>2]=x[a+480208>>2]&-17|(y[f+806|0]|y[f+807|0]<<8)<<4&16;x[a+480196>>2]=y[f+816|0];x[a+480204>>2]=D(y[f+817|0],1e4);x[a+480200>>2]=y[f+818|0]<<2;x[a+480228>>2]=y[f+819|0];d=y[f+804|0]|y[f+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=d;Cw(b,e);Ur(Xb(x[a+484360>>2],y[a+484376|0]),e,y[f+800|0]|y[f+801|0]<<8,65535,255);s=c&1;if(s){Vf(a+484344|0,y[f+802|0]|y[f+803|0]<<8)}m=a+484344|0;i:{while(1){if((y[f+802|0]|y[f+803|0]<<8)>>>0<=l>>>0){r=c&2;i=1;c=0;j:while(1){if(z[a+480192>>1]<=(c&65535)>>>0){break b}c=c+1|0;e=BE(a,c&65535,0);j=!e;g=fb-16|0;fb=g;d=f+108|0;bc(g+8|0,d,384);h=x[g+12>>2];kc(g,x[b>>2],x[b+8>>2],x[g+8>>2],x[g+12>>2]);l=x[g+4>>2];if((l|0)==(h|0)){Vb(b,x[g+12>>2])}fb=g+16|0;g=(h|0)==(l|0);if(!g){Sb(d,0,384)}if(!g|j){continue}j=i&65535;h=fb-32|0;fb=h;l=h+8|0;We(l,1,d);g=h+20|0;Cc(g,l);zc(e+492|0,g);tb(g);k:{if(!(y[d+378|0]|y[d+379|0]<<8)){break k}l=e+236|0;g=0;while(1){x[h+20>>2]=120;x[h+8>>2]=116;if(A[Gb(h+20|0,h+8|0)>>2]<=g>>>0){break k}k=y[(d+g|0)+32|0];t=_b(l,g+12|0),u=j+k|0,w[t>>1]=u;g=g+1|0;continue}}g=y[d+376|0]|y[d+377|0]<<8;v[e+33|0]=1;x[e>>2]=g;BD(d,e+48|0,0);BD(d,e+68|0,1);BD(d,e+88|0,2);d=y[e+100|0];if(d&1){v[e+100|0]=d|16}if(!(x[e>>2]|v[e+60|0]&1)){x[e>>2]=32767}fb=h+32|0;e=0;while(1){d=y[f+486|0]|y[f+487|0]<<8;if(d>>>0<=e>>>0){i=d+i|0;continue j}d=f+44|0;t$(b,d);l:{m:{if((y[f+104|0]|y[f+105|0]<<8|(y[f+106|0]<<16|y[f+107|0]<<24))!=808538953){break m}g=e+i|0;l=g&65535;if(l>>>0>3999){break m}w[a+480190>>1]=g;j=fb-32|0;fb=j;k=D(l,104)+a|0;h=k+484380|0;ld(h,0);m=j+8|0;lk(m,1,d);g=j+20|0;Cc(g,m);ze(h+43|0,g);tb(g);m=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);x[h>>2]=m;o=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);x[h+4>>2]=o;n=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);x[h+8>>2]=n;x[h+24>>2]=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);w[h+30>>1]=y[d+32|0]<<2;w[h+28>>1]=y[d+33|0];g=y[d+48|0];if(g&1){w[h+34>>1]=z[h+34>>1]|2;g=y[d+48|0]}if(g&2){w[h+34>>1]=z[h+34>>1]|4;g=y[d+48|0]}if(g&4){x[h+8>>2]=n>>>1;x[h+4>>2]=o>>>1;x[h>>2]=m>>>1;w[h+34>>1]=z[h+34>>1]|1;g=y[d+48|0]}if(g&8){w[h+34>>1]=z[h+34>>1]|32}fb=j+32|0;d=fb-16|0;fb=d;Ow(d+8|0,k+484423|0);g=f+24|0;Fp(g,x[d+8>>2],x[d+12>>2]);fb=d+16|0;zc(((l<<5)+a|0)+946304|0,g);tb(g);j=y[f+60|0]|y[f+61|0]<<8|(y[f+62|0]<<16|y[f+63|0]<<24);if(!j){break m}d=f+4|0;fe(d,b,j);g=ic(g,d);ub(d);if(r){d=Xc(d,w[k+484414>>1]&1?16:8,1,0,0);x[31725]=0;U(217,d|0,h|0,g|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break l}}ub(g)}e=e+1|0;continue}break}break}a=N()|0;ub(g);break c}d=hh(b);o=hh(b);e=f+44|0;fe(e,b,d-4|0);j=ic(f+108|0,e);ub(e);n:{o:{if(!s){break o}x[31725]=0;e=U(198,m|0,l&65535,o|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}if(!e){break o}g=0;h=bh(f+24|0);while(1){if(g>>>0>=o>>>0){break o}x[31725]=0;k=R(199,j|0)|0;e=x[31725];x[31725]=0;p:{if((e|0)!=1){if(k){break p}g=g+1|0;continue}break d}d=h;n=k&31;if(n>>>0<z[a+480188>>1]){e=Wb(x[m>>2],l);d=jd(x[e>>2],x[x[e+48>>2]+12>>2],g,n)}if(k&32){x[31725]=0;e=f+44|0;O(200,e|0,j|0);i=x[31725];x[31725]=0;if((i|0)==1){break i}i=y[f+44|0];v[d|0]=i;t=d,u=y[Jc(e)|0],v[t+1|0]=u;q:{r:{if((i|0)==160){e=255;break r}if((i|0)==255){e=0;break r}e=0;i=(D(i>>>4|0,12)+(i&15)|0)+13|0;if(ZZ(i)){break q}}i=e}v[d|0]=i}e=k&192;s:{if(!e){break s}if((e|0)==192){x[31725]=0;e=f+44|0;O(359,e|0,j|0);i=x[31725];x[31725]=0;if((i|0)!=1){i=Jc(e);k=af(e);e=ej(e);q=f+4|0;CD(q,y[f+44|0],y[i|0]);i=Jc(q);q=f+494|0;CD(q,y[k|0],y[e|0]);Gn(f+492|0,d,y[f+4|0],y[i|0],y[f+494|0],y[Jc(q)|0]);break s}break d}x[31725]=0;e=f+44|0;O(200,e|0,j|0);i=x[31725];x[31725]=0;t:{u:{if((i|0)!=1){i=f+4|0;CD(i,y[f+44|0],y[Jc(e)|0]);i=y[Jc(i)|0];e=y[f+4|0];if((e|0)!=13){break u}v[d+2|0]=1;e=d+4|0;break t}break d}v[d+3|0]=e;e=d+5|0}v[e|0]=i}Pc(f+44|0,r,n);if(!Hb(x[x[f+44>>2]>>2],x[f+48>>2])){continue}if(!u0(y[d+3|0],y[d+5|0])){continue}v[d+3|0]=0;continue}}ub(j);l=l+1|0;continue}break}break d}break d}e=e>>>0>31;break a}a=N()|0;ub(j)}Q(a|0);p()}e=1}fb=f+1344|0;return e|0}function Eqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-1824|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+1224|0;fY(d+8|0,f);i=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);m=x[d+4>>2];if((m|0)==(i|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(i|0)==(m|0);if(!d){eY(f)}a:{if(!d){break a}if(!gY(f)){break a}if(!SC(b,16,0)){break a}d=e+1240|0;x[e+1216>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[e+1228|0]|y[e+1229|0]<<8|(y[e+1230|0]<<16|y[e+1231|0]<<24);x[e+1200>>2]=y[e+1224|0]|y[e+1225|0]<<8|(y[e+1226|0]<<16|y[e+1227|0]<<24);x[e+1204>>2]=d;d=e+1232|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+1208>>2]=f;x[e+1212>>2]=d;Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;cd(b,20);l=a+480188|0;g=1;i=1;b:{while(1){c:{if((g|0)==16){d=e+1064|0;if(!OC(b,d)){KC(d)}d=a+484376|0;iw(Xb(x[a+484360>>2],y[d|0]),e+1066|0,128);m=pY(b,Xb(x[a+484360>>2],y[d|0]),y[e+1064|0],h,l,0,1);if(!(y[e+1065|0]|m>>>0>1)){g=0;if(!y[e+1064|0]){break a}}d=(m<<10)+h|0;x[e+1060>>2]=d;x[e+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],d-x[Gb(e+1060|0,e+24|0)>>2]|0)){break a}if(c){break c}break b}d=e+24|0;MC(b,d);n=d;f=D(g,104)+a|0;m=f+484380|0;d=((g<<5)+a|0)+946304|0;UC(n,m,d,1);k=x[m>>2];d:{if(!y[xb(d,0)|0]){break d}e:{if(kd(d,16783,3)){if(kd(d,16787,3)){break e}}if(y[xb(d,5)|0]==58){break d}}i=0}d=Bb(y[e+52|0]|y[e+53|0]<<8);if(d>>>0>=2){n=d<<1;d=Bb(y[e+50|0]|y[e+51|0]<<8);x[f+484388>>2]=n+d;x[f+484384>>2]=d;$k(m)}f:{if(Bb(y[e+46|0]|y[e+47|0]<<8)>>>0<=4999){if(Bb(y[e+50|0]|y[e+51|0]<<8)>>>0<1e4){break f}}x[e+1064>>2]=5;s=e,t=x[Ze(e+1196|0,e+1064|0)>>2],x[s+1196>>2]=t}h=h+k|0;g=g+1|0;continue}break}g=y[e+1065|0];if(!g){v[e+1065|0]=120;g=120}g:{if(!kd(e+1200|0,14939,6)){v[e+1065|0]=120;x[a+480204>>2]=125e4;break g}x[a+480204>>2]=125e4;if((g|0)==120){break g}s=a,t=_e(1773447.5/(+(240-g|0)*122)*1e4),x[s+480204>>2]=t;if(x[e+1196>>2]>=2){x[e+24>>2]=i&1?4:5;s=e,t=x[Ze(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t;break g}x[e+24>>2]=i&1?1:2;s=e,t=x[Ze(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=e+1048|0;vi(f,3,e+1200|0);d=e+24|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);Xh(a,0);f=i&1;n=x[b+8>>2];while(1){h:{if(m>>>0>(j&65535)>>>0){d=Xb(x[a+484360>>2],y[a+484376|0]);d=Ib(LC(wb(x[d>>2]),wb(x[d+4>>2]),j),wb(x[d+4>>2]));g=e+24|0;dY(b,g);i:{if(d){q=QC(g,0)+q|0;if(q>>>0>512){break i}}o=0;d=x[e+1196>>2];h=0;i=0;j:while(1){if((i|0)==64){break h}g=0;while(1)if((g|0)==4){i=i+1|0;continue j}else{k=yb(Xd(e+24|0,i),g);p=y[xb(k,2)|0]&15;l=y[xb(k,3)|0];k:{if(!(!(h&255)|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24)))){h=h+1|0;if((h&255)>>>0<33){break k}d=6;x[e+1196>>2]=6;break k}h=0}l:{m:{n:{o:{switch(p-1|0){case 0:case 1:if((d|0)==1&l>>>0>=32){break m}k=(p|0)!=1;if(!(k|!l|l>>>0>2)){x[e+1048>>2]=2;d=x[Ze(e+1196|0,e+1048|0)>>2];break n}if(k|(l|0)!=55&(l|0)!=71){break l}if((d|0)<=2){break m}break l;case 10:d=6;break n;case 11:case 12:case 13:x[e+1048>>2]=2;d=x[Ze(e+1196|0,e+1048|0)>>2];x[e+1196>>2]=d;if((p|0)!=13){break l}o=((i|l)!=0)+o|0;h=1;break l;case 14:break o;default:break l}}x[e+1048>>2]=3;d=x[Ze(e+1196|0,e+1048|0)>>2]}x[e+1196>>2]=d;break l}x[e+1196>>2]=f;d=f}g=g+1|0;continue}}}g=0;break a}if(!(x[e+1196>>2]!=6|m+32>>>0>=r>>>0)){x[e+1196>>2]=5}cd(b,n);p=c&1;if(p){Vf(a+484344|0,m)}o=a+484344|0;l=0;while(1)if((l|0)==(m|0)){g=22267;d=x[e+1196>>2];if(d>>>0<7){g=x[(d<<2)+25260>>2]}d=e+24|0;f=tc(d,8304);Ab(a+1298344|0,f);tb(f);f=tc(d,10785);Ab(a+1298356|0,f);tb(f);bi(a+1298368|0,g);s=a+1298404|0,t=x[Fc(d,28)>>2],x[s>>2]=t;g=1;if(!(c&2)){break a}while(1){if((g|0)==16){break b}c=D(g,104)+a|0;d=c+484384|0;Vb(b,x[d>>2]);f=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-f;c=c+484388|0;x[c>>2]=x[c>>2]-f;c=e+24|0;Xc(c,8,1,1,0);fg(c,d,b);g=g+1|0;continue}}else{dY(b,e+24|0);p:{if(!p){break p}if(!Ng(o,l&65535,64)){break p}i=0;x[e+20>>2]=0;q:while(1){if((i|0)==64){break p}d=Wb(x[o>>2],l);cf(e+1048|0,x[d>>2],x[x[d+48>>2]+12>>2],i);g=0;while(1)if((g|0)==4){i=i+1|0;continue q}else{d=Wc(x[e+1048>>2],g);f=yb(Xd(e+24|0,i),g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[e+8>>2]=f;x[e+12>>2]=f;f=e+18|0;kp(f,e+8|0,d);k=(e+20|0)+g|0;h=y[e+18|0];f=Jc(f);j=y[f|0];r:{s:{if(!((h|0)!=14?j:0)){v[k|0]=0;if(h|j){break s}break r}j=y[k|0];if(!j){break s}n=j;q=j>>>4|0;j=j>>>0<16;v[d+4|0]=j?n:q;v[d+2|0]=j?4:3}t:{u:{v:{w:{x:{switch(h-12|0){case 1:h=x[e+1196>>2];if((h|0)!=6){v[e+18|0]=10;break v}v[f|0]=0;break w;case 0:v[f|0]=y[f|0]&127;break w;case 2:h=y[f|0];if(h>>>0<=1){j=14;if(x[e+1196>>2]>3){break u}}v[e+18|0]=10;v[k|0]=y[f|0];break w;case 3:break x;default:break w}}v[f|0]=y[f|0]&15}h=x[e+1196>>2]}if((h|0)<2){break t}h=y[f|0];j=y[e+18|0]}Bf(d,j,h&255);break r}h=y[f|0];v[d+5|0]=h;y:{z:{A:{switch(y[e+18|0]){case 0:if(y[f|0]>2){break z}break;case 2:break y;case 1:break z;default:break A}}v[d+3|0]=0;break r}v[d+3|0]=1;break r}f=h&15;if(f){v[d+5|0]=f;v[d+3|0]=2;break r}if(h>>>0<16){break r}v[d+3|0]=3;v[d+5|0]=(h&240)>>>4}g=g+1|0;continue}}}l=l+1|0;continue}}if((o-1&255)>>>0<2){x[e+1196>>2]=6}j=j+1|0;r=(o&255)+r|0;continue}}g=1}fb=e+1824|0;return g|0}function FL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=fb-80|0;fb=j;x[j+76>>2]=b;F=j+55|0;s=j+56|0;a:{b:{c:{d:while(1){h=0;e:while(1){k=b;if((r^2147483647)<(h|0)){break c}r=h+r|0;f:{g:{h:{h=b;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;n=y[i+2|0];b=i+2|0;i=b;if((n|0)==37){continue}break}}h=h-k|0;E=r^2147483647;if((h|0)>(E|0)){break c}if(a){Lf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Nh(i)|y[b+2|0]!=36)){q=i-48|0;t=1;h=b+3|0}x[j+76>>2]=h;o=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){n=h;break k}n=h;b=1<<b;if(!(b&75913)){break k}while(1){n=h+1|0;x[j+76>>2]=n;o=b|o;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=n;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[n+1|0];m:{if(!(!Nh(b)|y[n+2|0]!=36)){b=b-48|0;n:{if(!a){x[(b<<2)+e>>2]=10;p=0;break n}p=x[(b<<3)+d>>2]}b=n+3|0;t=1;break m}if(t){break h}b=n+1|0;if(!a){x[j+76>>2]=b;t=0;p=0;break l}h=x[c>>2];x[c>>2]=h+4;p=x[h>>2];t=0}x[j+76>>2]=b;if((p|0)>=0){break l}p=0-p|0;o=o|8192;break l}p=EL(j+76|0);if((p|0)<0){break c}b=x[j+76>>2]}h=0;l=-1;i=0;o:{if(y[b|0]!=46){break o}if(y[b+1|0]==42){i=v[b+2|0];p:{if(!(!Nh(i)|y[b+3|0]!=36)){i=i-48|0;b=b+4|0;q:{if(!a){x[(i<<2)+e>>2]=10;l=0;break q}l=x[(i<<3)+d>>2]}break p}if(t){break h}b=b+2|0;l=0;if(!a){break p}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;i=(l|0)>=0;break o}x[j+76>>2]=b+1;l=EL(j+76|0);b=x[j+76>>2];i=1}z=i;while(1){u=h;m=28;A=b;i=v[b|0];if(i-123>>>0<4294967238){break b}b=b+1|0;h=y[(i+D(h,58)|0)+92959|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;r:{if((h|0)!=27){if(!h){break b}if((q|0)>=0){if(!a){x[(q<<2)+e>>2]=h;continue d}h=(q<<3)+d|0;i=x[h+4>>2];x[j+64>>2]=x[h>>2];x[j+68>>2]=i;break r}if(!a){break f}DL(j- -64|0,h,c,g);break r}if((q|0)>=0){break b}h=0;if(!a){continue e}}m=-1;if(y[a|0]&32){break a}i=o&-65537;o=o&8192?i:o;q=0;B=5286;n=s;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{h=v[A|0];h=u?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break s;case 9:case 13:case 14:case 15:break t;case 27:break y;case 12:case 17:break B;case 23:break C;case 0:case 32:break D;case 24:break E;case 22:break F;case 29:break G;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break H}}I:{switch(h-65|0){case 0:case 4:case 5:case 6:break t;case 2:break w;case 1:case 3:break g;default:break I}}if((h|0)==83){break x}break g}i=x[j+64>>2];m=x[j+68>>2];h=5286;break A}h=0;J:{switch(u&255){case 0:x[x[j+64>>2]>>2]=r;continue e;case 1:x[x[j+64>>2]>>2]=r;continue e;case 2:i=x[j+64>>2];x[i>>2]=r;x[i+4>>2]=r>>31;continue e;case 3:w[x[j+64>>2]>>1]=r;continue e;case 4:v[x[j+64>>2]]=r;continue e;case 6:x[x[j+64>>2]>>2]=r;continue e;case 7:break J;default:continue e}}i=x[j+64>>2];x[i>>2]=r;x[i+4>>2]=r>>31;continue e}l=l>>>0<=8?8:l;o=o|8;h=120}k=s;A=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=A|y[(i&15)+93488|0];G=!m&i>>>0>15|(m|0)!=0;u=m;m=m>>>4|0;i=(u&15)<<28|i>>>4;if(G){continue}break}}if(!(o&8)|!(x[j+64>>2]|x[j+68>>2])){break z}B=(h>>>4|0)+5286|0;q=2;break z}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;u=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(u){continue}break}}k=h;if(!(o&8)){break z}h=s-h|0;l=(h|0)<(l|0)?l:h+1|0;break z}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(h+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;h=5286;break A}if(o&2048){q=1;h=5287;break A}q=o&1;h=q?5288:5286}B=h;k=po(i,m,s)}if((l|0)<0&z){break c}o=z?o&-65537:o;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:17082;h=k;n=l>>>0>=2147483647?2147483647:l;m=Kz(h,0,n);h=m?m-h|0:n;n=h+k|0;if((l|0)>=0){o=i;l=h;break g}o=i;l=h;if(y[n|0]){break c}break g}if(l){i=x[j+64>>2];break v}h=0;Yf(a,32,p,0,o);break u}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;K:{while(1){k=x[i>>2];if(!k){break K}k=CL(j+4|0,k);n=(k|0)<0;if(!(n|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break K}break}if(n){break a}}m=61;if((h|0)<0){break b}Yf(a,32,p,h,o);if(!h){h=0;break u}n=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break u}m=j+4|0;k=CL(m,k);n=k+n|0;if(n>>>0>h>>>0){break u}Lf(a,m,k);i=i+4|0;if(h>>>0>n>>>0){continue}break}}Yf(a,32,p,h,o^8192);h=(h|0)<(p|0)?p:h;continue e}if((l|0)<0&z){break c}m=61;h=ib[f|0](a,C[j+64>>3],p,l,o,h)|0;if((h|0)>=0){continue e}break b}v[j+55|0]=x[j+64>>2];l=1;k=F;o=i;break g}i=y[h+1|0];h=h+1|0;continue}}m=r;if(a){break a}if(!t){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){DL((h<<3)+d|0,a,c,g);m=1;h=h+1|0;if((h|0)!=10){continue}break a}break}m=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break b}n=n-k|0;l=(l|0)>(n|0)?l:n;if((l|0)>(q^2147483647)){break c}m=61;i=l+q|0;h=(i|0)<(p|0)?p:i;if((E|0)<(h|0)){break b}Yf(a,32,h,i,o);Lf(a,B,q);Yf(a,48,h,i,o^65536);Yf(a,48,l,n,0);Lf(a,k,n);Yf(a,32,h,i,o^8192);continue}break}break}m=0;break a}m=61}x[31600]=m;m=-1}fb=j+80|0;return m}function xsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;g=fb-192|0;fb=g;n=ik(b,13874);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;u=a+480228|0;B=a+480232|0;s=a+480200|0;m=a+480268|0;C=a+1298320|0;E=a+480248|0;F=Pv(a+1074312|0);a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Pg(b);f=hh(b);if((e|0)==70791730){Gh(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],f)){break a}i=g+152|0;fe(i,b,f);h=ic(g+172|0,i);ub(i);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=B;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=u;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31725]=0;S(453,h|0,f|0,i|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}x[k>>2]=D(x[g+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31725]=0;S(453,h|0,f|0,g+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[g+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31725]=0;w[g+152>>1]=0;S(454,h|0,f|0,g+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){G=a,H=Kd(z[g+152>>1],z[a+480188>>1],127),w[G+480188>>1]=H;break j}e=N()|0;break b}x[31725]=0;S(455,h|0,f|0,l|0);d=x[31725];x[31725]=0;if((d|0)!=1){break j}break c}x[31725]=0;x[g+152>>2]=0;S(453,h|0,f|0,g+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+1074304>>2]=x[g+152>>2];break j}e=N()|0;break b}x[31725]=0;x[g+152>>2]=0;S(453,h|0,f|0,g+152|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}d=x[g+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31725]=0;S(453,h|0,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}break j}if(x[a+480180>>2]==4){break j}x[31725]=0;S(454,h|0,f|0,g+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){bf(Xb(x[a+484360>>2],y[a+484376|0]),z[g+152>>1]);break j}e=N()|0;break b}x[31725]=0;S(456,h|0,f|0,m|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}if(Ap(y[m|0])){break j}v[m|0]=5;break j}d=Fb(g+152|0);e=x[h>>2];x[31725]=0;e=R(156,e|0)|0;f=x[31725];x[31725]=0;x:{if((f|0)==1){break x}x[31725]=0;S(457,h|0,d|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break x}x[31725]=0;e=g+140|0;S(260,e|0,0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break x}Ab(C,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(f&1|f>>>0>126){break j}d=64;w[g+152>>1]=(f>>>1|0)- -64;w[g+140>>1]=127;e=z[Nc(g+152|0,g+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31725]=0;f=g+152|0;O(200,f|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}e=y[g+152|0];y:{if((e|0)==255){break y}j=y[Jc(f)|0];f=(d<<5)+a|0;t=f+480284|0;w[t>>1]=128;w[f+480286>>1]=j;f=f+480280|0;j=(e&128)<<3;x[f>>2]=j;e=e&127;if(e>>>0<65){w[t>>1]=e<<2;break y}if((e|0)!=100){break y}x[f>>2]=j|256}d=d+1|0;continue}}if(f>>>0<3){break j}x[31725]=0;d=R(191,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}if(z[a+480190>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;f=RZ(d);while(1){if((d|0)==(f|0)){break j}e=x[h>>2];x[31725]=0;i=U(152,e|0,x[g+180>>2],4)|0;e=x[31725];x[31725]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31725]=0;e=R(153,h|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(f>>>0<3){break j}x[31725]=0;f=g+140|0;O(458,f|0,h|0);d=x[31725];x[31725]=0;A:{B:{C:{D:{if((d|0)!=1){x[31725]=0;e=g+152|0;S(459,e|0,x[g+140>>2],x[g+144>>2]);d=x[31725];x[31725]=0;if((d|0)==1){break D}x[31725]=0;d=P(105,g|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break C}tb(e);dc(f);e=x[h>>2];x[31725]=0;R(156,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break A}x[31725]=0;S(460,d|0,E|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break A}Ff(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(g+152|0)}dc(g+140|0);break b}e=N()|0;Ff(d);break b}e=0;f=Pv(F);E:while(1){d=x[h>>2];x[31725]=0;d=U(152,d|0,x[g+180>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}if(!(e>>>0<122&d)){break j}x[31725]=0;i=R(199,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>121){break F}x[31725]=0;U(268,f|0,e|0,1)|0;j=x[31725];x[31725]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31725]=0;S(461,h|0,f|0,r|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];Lp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}wc(s,256);wc(o,65536);wc(q,65536)}fb=g+192|0;return n|0}function iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;e=fb-272|0;fb=e;xc(b);f=e+206|0;a:{if(!T$(b,f)){break a}if(!UX(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(TX(f),hb))){break a}b:{if(!c){break b}Bd(a,16);f=e+44|0;vi(f,2,e+210|0);d=e- -64|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);w[a+480190>>1]=y[e+236|0];w[a+480188>>1]=y[e+239|0];g=tc(d,8365);Ab(a+1298344|0,g);tb(g);g=tc(d,10129);Ab(a+1298356|0,g);tb(g);ig(f,4211);g=y[e+209|0];x[e+24>>2]=g>>>4;x[31725]=0;x[e+12>>2]=g&15;V(309,d|0,f|0,e+24|0,e+12|0);g=x[31725];x[31725]=0;c:{d:{if((g|0)!=1){Ab(a+1298368|0,d);tb(d);Eb(f);u=a+1298404|0,B=x[Fc(d,4)>>2],x[u>>2]=B;d=1;while(1){k=d&65535;if(k>>>0>z[a+480190>>1]){d=0;while(1)if(z[a+480188>>1]<=d>>>0){f=e- -64|0;d=fb-16|0;fb=d;j=b;e:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){eh(b+f|0);b=b+1|0;continue}break}break e}pZ(d+8|0,f);rd(d,j,x[d+8>>2],x[d+12>>2])}fb=d+16|0;Ew(Xb(x[a+484360>>2],y[a+484376|0]),f,y[e+233|0]+1|0,255,254);b=y[e+238|0];d=e+24|0;fe(d,j,D(y[e+230|0]|y[e+231|0]<<8,192));m=ic(e+44|0,d);ub(d);f:{o=c&1;if(!o){break f}x[31725]=0;O(225,a+484344|0,y[e+232|0]+1|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break d}q=b?b:64;r=a+484344|0;b=0;while(1){g:{h:{i:{if(y[e+232|0]<l>>>0){if(!(b&t)){break h}u=e,B=wb(x[a+484344>>2]),x[u+12>>2]=B;i=wb(x[a+484348>>2]);break i}j:{if(o){x[31725]=0;d=U(198,r|0,l&65535,q|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}n=0;if(d){break j}}x[31725]=0;P(185,j|0,64)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break g}break d}while(1){d=n&65535;if(d>>>0>31){break g}x[31725]=0;f=R(191,j|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}k:{if((f-1&65535)>>>0>=(y[e+230|0]|y[e+231|0]<<8)>>>0|d>>>0>=z[a+480188>>1]){break k}x[31725]=0;P(151,m|0,D(f,192)-192|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}f=0;g=Wb(x[r>>2],l);d=jd(x[g>>2],x[x[g+48>>2]+12>>2],0,d);while(1){if((f|0)==(q|0)){break k}i=b;x[31725]=0;b=e+24|0;O(550,b|0,m|0);g=x[31725];x[31725]=0;l:{m:{n:{o:{p:{if((g|0)!=1){k=Jc(b);g=af(b);b=y[e+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[e+24|0]}v[d+1|0]=b<<4&48|y[k|0]>>>4;b=y[g|0];h=0;g=0;q:{r:{k=y[k|0]&15;switch(k-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}k=14;s=(b&240)<<24>>24;if((s|0)<=-17|!(435>>>((s+16&240)>>>4)&1)){break n}break o}b=(b&240?-16:15)&b;k=10;break n}break d}h=k;g=b}k=h;b=g;if(!((h|b)&255)){break m}}Bf(d,k,b&255);b=1;s:{switch(y[d+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}t=1}b=i}f=f+1|0;d=D(z[a+480188>>1],6)+d|0;continue}}n=n+1|0;continue}}while(1){t:{b=x[e+12>>2];if(Ib(b,i)){h=0;u:while(1){if(A[b+12>>2]<=h>>>0){break t}cf(e+24|0,x[b>>2],x[x[b+48>>2]+12>>2],h);u=e,B=wb(x[e+24>>2]),x[u+20>>2]=B;f=0;k=hw(x[e+24>>2],x[e+28>>2]);g=0;while(1){l=x[e+20>>2];if(Ib(l,k)){d=1;v:{switch(y[l+3|0]-16|0){case 1:g=1;default:d=f;break;case 0:break v}}vg(e+20|0);f=d;continue}else{h=h+1|0;if(!(f&g&1)){continue u}break h}}}}u=e,B=wb(x[a+484344>>2]),x[u+20>>2]=B;d=wb(x[a+484348>>2]);w:while(1){b=x[e+20>>2];if(!Ib(b,d)){break h}f=0;x:while(1){if(A[b+12>>2]<=f>>>0){am(e+20|0);continue w}cf(e+12|0,x[b>>2],x[x[b+48>>2]+12>>2],f);u=e,B=wb(x[e+12>>2]),x[u+8>>2]=B;g=hw(x[e+12>>2],x[e+16>>2]);while(1){y:{h=x[e+8>>2];if(Ib(h,g)){h=y[h+3|0];if((h&254)!=16){break y}g=(h|0)==16;ye(b,Ye(Ne(e+24|0,g?17:16,g?125:6),f))}f=f+1|0;continue x}vg(e+8|0);continue}}}}am(e+12|0);continue}}z:{b=y[e+234|0]|y[e+235|0]<<8;if(!b){break z}x[31725]=0;aa(318,a+1298332|0,j|0,b|0,39,1);b=x[31725];x[31725]=0;if((b|0)!=1){break z}break d}A:{if(!(c&2)){break A}d=1;while(1){b=d&65535;if(b>>>0>z[a+480190>>1]){break A}b=D(b,104)+a|0;c=Xc(e+24|0,w[b+484414>>1]&1?16:8,1,0,1);x[31725]=0;U(217,c|0,b+484380|0,j|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){d=d+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(m);break b}l=l+1|0;continue}}else{f=(d<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+240|0]<<4|8)&248;d=d+1|0;continue}}else{i=e- -64|0;fF(b,i);j=fb-16|0;fb=j;h=(D(k,104)+a|0)+484380|0;ld(h,0);w[j+14>>1]=y[i+35|0]<<2;w[j+12>>1]=256;u=h,B=z[Nc(j+14|0,j+12|0)>>1],w[u+30>>1]=B;f=y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24);B:{if(f>>>0<3){break B}x[h>>2]=f;x[h+4>>2]=y[i+26|0]|y[i+27|0]<<8|(y[i+28|0]<<16|y[i+29|0]<<24);x[j+8>>2]=y[i+30|0]|y[i+31|0]<<8|(y[i+32|0]<<16|y[i+33|0]<<24);x[j+4>>2]=1;u=h,B=x[ad(j+8|0,j+4|0)>>2]-1|0,x[u+8>>2]=B;wc(h+8|0,f);g=x[h+8>>2];f=x[h+4>>2];C:{if(g>>>0<=f+4>>>0){x[h+4>>2]=0;x[h+8>>2]=0;g=0;f=0;break C}if(g>>>0<3){break C}w[h+34>>1]=z[h+34>>1]|2}v[h+37|0]=y[i+34|0];u=h,B=IE(0,v[i+34|0]<<4),x[u+24>>2]=B;if(!(v[i+36|0]&1)){break B}x[h+8>>2]=g>>>1;x[h+4>>2]=f>>>1;w[h+34>>1]=z[h+34>>1]|1;x[h>>2]=x[h>>2]>>>1}fb=j+16|0;g=e+24|0;Yk(g,2,i);f=e+44|0;Cc(f,g);zc(((k<<5)+a|0)+946304|0,f);d=d+1|0;tb(f);continue}}}d=N()|0;Eb(e+44|0);break c}d=N()|0;ub(m)}Q(d|0);p()}d=1}fb=e+272|0;return d|0}function spa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-352|0;fb=d;a:{b:{c:{if(!cd(b,60)){break c}e=d+332|0;if(!Tp(b,e)){break c}f=15;if(uv(e,15)){break b}}e=0;if(!cd(b,124)){break a}g=d+332|0;if(!Tp(b,g)){break a}f=31;if(!uv(g,31)){break a}}Bd(a,536870912);w[a+480190>>1]=f;xc(b);e=0;d:{while(1){if(z[a+480190>>1]>e>>>0){g=up(b);x[(d+208|0)+(e<<2)>>2]=g;e=e+1|0;if(g>>>0<=131072){continue}break d}break}Vb(b,20);f=0;w[a+480192>>1]=0;w[a+480188>>1]=4;e=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;o=a,q=_e(1776930/+(Bb(e)>>>0)*1e4),x[o+480204>>2]=q;x[a+480228>>2]=64;Xh(a,1);m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){MC(b,d+52|0);e=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=(D(l,104)+a|0)+484380|0;ld(i,1);x[i>>2]=e;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;o=i,q=y[Rb(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=q;f:{if(!e){break f}g=Bb(y[d+80|0]|y[d+81|0]<<8);k=Bb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(e>>>0<=k>>>0){k=e-1|0;x[i+4>>2]=k}if(e>>>0<g>>>0){x[i+8>>2]=e;g=e}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;e=0;while(1)if((e|0)==22){if(f>>>0>=128){break d}g=d+184|0;Yk(g,3,d+52|0);e=d+196|0;Cc(e,g);zc(((l<<5)+a|0)+946304|0,e);m=m+1|0;tb(e);continue e}else{g=(d+52|0)+e|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;f=f+1|0}e=e+1|0;continue}}break}m=1;g:{h:{i:{f=a+946336|0;e=Dc(d+52|0,14036);if(!cX(f,e)){x[31725]=0;g=P(36,d+196|0,14047)|0;i=x[31725];x[31725]=0;if((i|0)==1){break i}m=cX(f,g);tb(g)}tb(e);e=0;g=d+52|0;f=OC(b,g);if(!f){KC(g)}if(!f){break a}g=y[d+52|0];if(!eX(g)){break a}if(!c){break g}w[d+50>>1]=0;while(1)if((e|0)==(g|0)){e=a+484376|0;h=Xb(x[a+484360>>2],y[e|0]);f=y[d+53|0];bf(h,g>>>0>f>>>0?f:0);Ew(Xb(x[a+484360>>2],y[e|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Vb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){Vf(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){j:{k:{l:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break l}e=1;while(1){f=z[a+480190>>1];c=e&65535;if(f>>>0<c>>>0){break k}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(d+184|0,8,1,0,0),c,b)}e=e+1|0;continue}}m:{if(n){k=0;if(Ng(l,i&65535,64)){break m}}Vb(b,1024);break j}n:while(1){if((k|0)==64){break j}e=Wb(x[l>>2],i);cf(d+184|0,x[e>>2],x[x[e+48>>2]+12>>2],k);e=0;while(1)if((e|0)==4){k=k+1|0;continue n}else{g=Wc(x[d+184>>2],e);f=d+12|0;sm(f,b);o:{p:{q:{r:{if(y[xb(f,0)|0]!=255){break r}v[(d+44|0)+e|0]=0;v[(d+36|0)+e|0]=0;f=xb(f,1);h=y[f|0];if((h|0)==252&m){v[f|0]=254;break p}switch(h-252|0){case 1:break o;case 2:break p;case 0:break q;default:break r}}f=x[d+12>>2];x[d+28>>2]=f;x[d+8>>2]=f;f=d+33|0;kp(f,d+8|0,g);h=Jc(f);f=y[g|0];s:{if(!f){break s}v[(d+36|0)+e|0]=0;v[(d+44|0)+e|0]=f;if(f>>>0>48){break s}v[d+27|0]=8;o=d,q=y[ef(d+35|0,d+27|0)|0],v[o+35|0]=q}j=y[d+33|0];f=y[h|0];t:{if(j|f){v[g+5|0]=f;u:{v:{w:{switch(j-1|0){case 0:v[g+3|0]=1;break o;case 1:if(f>>>0>=16){v[g+3|0]=3;v[g+5|0]=(f&240)>>>4;break o}if(!f){break v}v[g+5|0]=f;v[g+3|0]=2;break o;case 2:if(y[(d+36|0)+e|0]){break v}v[g+5|0]=0;v[g+3|0]=19;break o;case 3:if(y[(d+36|0)+e|0]){break v}v[g+5|0]=1;v[g+3|0]=19;break o;case 4:h=y[g+1|0];if(!h){break v}v[d+27|0]=63;v[d+26|0]=f+(z[(D(h,104)+a|0)+484410>>1]>>>2|0);f=y[Rb(d+27|0,d+26|0)|0];v[g+5|0]=f;v[g+3|0]=13;if(!y[(d+36|0)+e|0]){break o}h=g+3|0;v[g+4|0]=f;v[g+2|0]=1;break u;case 5:h=g+3|0;j=y[g+1|0];if(!j){break u}v[g+3|0]=13;j=z[(D(j,104)+a|0)+484410>>1]>>>2|0;f=f>>>0<=j>>>0?j-f|0:0;v[g+5|0]=f;if(!y[(d+36|0)+e|0]){break o}v[g+4|0]=f;v[g+2|0]=1;break u;case 6:h=f&15;v[(d+36|0)+e|0]=h;j=y[(d+44|0)+e|0];f=j-((f&240)>>>4|0)|0;v[(d+40|0)+e|0]=f;o=g,q=bX(h,f&255,j),v[o+5|0]=q;v[g+3|0]=3;break o;case 7:h=f&15;v[(d+36|0)+e|0]=h;j=(f&240)>>>4|0;f=y[(d+44|0)+e|0];j=j+f|0;v[(d+40|0)+e|0]=j;o=g,q=bX(h,f,j&255),v[o+5|0]=q;v[g+3|0]=2;break o;case 8:break w;default:break v}}v[d+27|0]=8;o=d,q=y[ef(d+35|0,d+27|0)|0],v[o+35|0]=q}h=g+3|0}v[h|0]=0;break t}if(y[g+3|0]){break o}}h=y[(d+36|0)+e|0];if(!h){break o}j=(d+40|0)+e|0;f=y[j|0];if(f){v[(d+44|0)+e|0]=f;v[g+5|0]=h;v[g|0]=f;v[j|0]=0}v[g+3|0]=4;break o}v[g+3|0]=14;v[d+35|0]=9;break o}v[g+3|0]=13}e=e+1|0;continue}}}f=z[a+480190>>1]}x:{y:{if((f&65535)==15){b=d+12|0;ig(b,4418);x[31725]=0;S(211,d+184|0,b|0,d+35|0);c=x[31725];x[31725]=0;if((c|0)!=1){break y}f=N()|0;Eb(b);break h}x[31725]=0;P(1,d+184|0,12390)|0;b=x[31725];x[31725]=0;if((b|0)==1){break x}}b=d+184|0;Ab(a+1298344|0,b);tb(b);if((f&65535)==15){Eb(d+12|0)}bi(a+1298356|0,z[a+480190>>1]==15?5282:15116);o=a+1298404|0,q=x[Fc(d+184|0,28)>>2],x[o>>2]=q;break g}f=N()|0;break h}i=i+1|0;continue}}else{w[d+184>>1]=y[(d+e|0)+54|0]+1;o=d,q=z[qe(d+50|0,d+184|0)>>1],w[o+50>>1]=q;e=e+1|0;continue}}f=N()|0;tb(e)}Q(f|0);p()}e=1;break a}e=0}fb=d+352|0;return e|0}function hM(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=fb-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+87712>>2]);h=E(E(m-z)*B[g+87716>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+87720>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=yc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;Qt(y,d,o+244|0);f=d<<6;Qt(f+y|0,d,o+500|0);Qt(x,d,o+240|0);Qt(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=87808;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=Bj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=Bj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=Bj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=Bj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=Bj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=Bj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=Bj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=Bj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}yc(a,C+(b<<2)|0,3840)}}function yta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=fb-272|0;fb=f;xc(b);e=fb-16|0;fb=e;g=f+66|0;B_(e+8|0,g);i=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(i|0);if(!e){A_(g)}a:{if(!e){break a}if(!D_(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(C_(g),hb))){break a}b:{if(!c){break b}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;xr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);r=a,s=Bb(y[f+266|0]|y[f+267|0]<<8),w[r+480188>>1]=s;Xh(a,1);e=tc(d,8541);Ab(a+1298368|0,e);tb(e);e=f+24|0;ig(e,3924);x[31725]=0;S(372,d|0,e|0,y[f+69|0]);g=x[31725];x[31725]=0;c:{if((g|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(e);g=tc(d,10789);Ab(a+1298356|0,g);tb(g);r=a+1298404|0,s=x[Fc(d,26)>>2],x[r>>2]=s;We(e,3,f+70|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);e=160;while(1){d:{d=e;if(!d){d=0;break d}e=d-1|0;if(y[(f+e|0)+102|0]==32){continue}}break}z_(a+1298332|0,f+102|0,d,4);d=Bb(y[f+262|0]|y[f+263|0]<<8);w[a+480190>>1]=d;n=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=n&65535;if(e>>>0<d>>>0){e=a+484376|0;bf(Xb(x[a+484360>>2],y[e|0]),Bb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;fe(d,b,512);m=ic(f+44|0,d);ub(d);d=y[e|0];e=x[a+484360>>2];g=y[f+268|0]|y[f+269|0]<<8;x[31725]=0;S(278,Xb(e,d)|0,m|0,Bb(g)|0);d=x[31725];x[31725]=0;if((d|0)!=1){break i}d=N()|0;break h}i=D(d,104)+a|0;m=i+484380|0;ld(m,1);mp(m);S$(b,((d<<5)+a|0)+946304|0,y[f+69|0]==1?32:28);h=1;d=y[f+69|0];if(d>>>0>=3){Vb(b,14);d=JD(b);if((d|0)>=0){e=i+484414|0;w[e>>1]=z[e>>1]|32;r=i+484408|0,s=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),w[r>>1]=s}d=y[f+69|0]}if((d&255)>>>0>=2){h=Vk(b);r=i+484404|0,s=Vk(b),x[r>>2]=s}e=f+44|0;g=fb-16|0;fb=g;j:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[g>>2]=0;d=e;k=3;while(1){if(k){l=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;k=k-1|0;d=d+4|0;continue}break}break j}Gr(g+8|0,e);rd(g,b,x[g+8>>2],x[g+12>>2])}fb=g+16|0;g=ec(e);d=zb(e);l=$b(x[f+44>>2]);x[m>>2]=l;j=i+484384|0;k=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24));x[j>>2]=k;o=i+484388|0;q=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+k|0;x[o>>2]=q;g=i+484414|0;if(k){e=z[g>>1];break f}e=z[g>>1];if($b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=wb(x[Xb(x[a+484360>>2],y[a+484376|0])>>2]);g=wb(x[Xb(x[a+484360>>2],y[a+484376|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){i=x[Md(e+12|0)>>2];if(!Ib(i,g)){break k}d=cl(z[d>>1],z[i>>1])?i:d;continue}}fb=e+16|0;d=z[d>>1];x[31725]=0;k=a+484344|0;o=d+1&65535;O(225,k|0,o|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];l=d>>>0<4?4:5;q=c&1;e=0;while(1){if((e|0)==(o|0)){if(!(c&2)){break g}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break g}c=D(c,104)+a|0;e=Xc(f+8|0,w[c+484414>>1]&1?16:8,1,1,0);x[31725]=0;U(217,e|0,c+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){d=d+1|0;continue}break}d=N()|0;break h}l:{if(!q){break l}d=y[f+264|0]|y[f+265|0]<<8;g=x[b+8>>2];i=x[b>>2];h=z[a+480188>>1];x[31725]=0;d=U(152,i|0,g|0,D(h,D(Bb(d),l))|0)|0;g=x[31725];x[31725]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31725]=0;d=U(198,k|0,e&65535,Bb(d)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}if(!d){break l}d=z[a+480188>>1];v[f|0]=0;g=de(f+8|0,0,f);x[31725]=0;n=U(373,f+24|0,d|0,g|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}i=0;o:while(1){if(Bb(y[f+264|0]|y[f+265|0]<<8)>>>0<=i>>>0){md(n);break l}d=Wb(x[k>>2],e);cf(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],i);d=0;while(1){if(z[a+480188>>1]<=d>>>0){i=i+1|0;continue o}g=Wc(x[f+8>>2],d);v[f+4|0]=0;x[31725]=0;x[f>>2]=0;S(374,b|0,f|0,l|0);h=x[31725];x[31725]=0;p:{if((h|0)==1){break p}h=x[n>>2];j=y[f|0];if((j-24&255)>>>0<=59){j=j+13|0;v[g|0]=j;r=_b(h,d),s=j,v[r|0]=s}j=y[f+1|0];q:{if(!j){h=_b(h,d);break q}v[g+1|0]=j;h=_b(h,d);v[h+1|0]=j}j=y[h+1|0];h=y[h|0];x[31725]=0;ya(375,a|0,g|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,j|0,f+20|0,f+16|0);h=x[31725];x[31725]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[g+2|0]=1;v[g+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;md(n);break h}d=N()|0;break h}d=N()|0;break h}e=e+1|0;continue}}d=N()|0}ub(m);break c}ub(m);break b}d=e|2}w[g>>1]=d;if((h|0)==2){w[g>>1]=d|1;x[m>>2]=l>>>1;x[j>>2]=k>>>1;x[o>>2]=q>>>1}r=i+484410|0,s=Vk(b),w[r>>1]=s;d=JD(b);if(d){gm(m,+(d|0)/96)}v[i+484417|0]=d<<4;n=n+1|0;d=z[a+480190>>1];continue}}d=N()|0;Eb(f+24|0)}Q(d|0);p()}d=1}fb=f+272|0;return d|0}function Qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-112|0;fb=d;xc(c);a:{b:{c:{d:{if(!np(c,d+100|0)|(y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24))!=1297239878){break d}e=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);if(!((e|0)==1482052408|(e|0)==1448293937)&(e|0)!=1146437965){break d}e=fb-32|0;fb=e;g=d+88|0;l=Nb(g);e:{f:{g:{h:{i:{while(1){j=x[c+8>>2];k=x[c>>2];x[31725]=0;j=U(152,k|0,j|0,8)|0;k=x[31725];x[31725]=0;if((k|0)==1){break g}if(!j){break h}x[31725]=0;j=e+4|0;O(833,j|0,c|0);k=x[31725];x[31725]=0;if((k|0)!=1){x[31725]=0;O(834,l|0,j|0);k=x[31725];x[31725]=0;if((k|0)==1){break i}Gd(j);continue}break}a=N()|0;break f}a=N()|0;Gd(e+4|0);break f}fb=e+32|0;break e}a=N()|0}ie(l);Q(a|0);p()}x[31725]=0;j=R(170,d+68|0)|0;c=x[31725];x[31725]=0;j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){l=Xc(d- -64|0,8,1,1,0);if((y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break n}x[31725]=0;c=d+44|0;S(743,c|0,g|0,1296581714);e=x[31725];x[31725]=0;if((e|0)==1){break m}x[31725]=0;e=d+24|0;S(743,e|0,g|0,1296318804);f=x[31725];x[31725]=0;if((f|0)==1){break l}f=hd(j,e);ub(e);e=0;x[31725]=0;h=R(744,c|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break l}m=0;if(!h){break o}f=x[f>>2];x[31725]=0;f=R(174,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break l}if(!f){break o}x[31725]=0;m=R(283,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}x[31725]=0;h=R(275,c|0)|0;e=x[31725];x[31725]=0;q:{if((e|0)==1){break q}x[31725]=0;P(185,c|0,2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}x[31725]=0;e=R(283,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break p}}break l}f=N()|0;break a}x[31725]=0;f=d+24|0;O(654,f|0,d+44|0);c=x[31725];x[31725]=0;if((c|0)==1){break l}c=r_(f);g=Bb(z[d+24>>1]);if(!g){break o}e=(e>>>0)/(g>>>0)|0;g=ec(f);f=af(f);g=Bb(y[g|0]|y[g+1|0]<<8);if((g|0)!=(Bb(y[f|0]|y[f+1|0]<<8)+1|0)){break o}if((g|0)==2){Cp(l,2)}r:{if((h|0)!=16){if((h|0)!=8){break o}s:{switch(Bb(y[c|0]|y[c+1|0]<<8)|0){case 0:i=1;yg(l,1);break o;case 2:yg(l,17);break r;case 3:break s;default:break o}}yg(l,16);break r}if(Bb(y[c|0]|y[c+1|0]<<8)){break o}fd(l,16)}i=1}ub(d+44|0);c=0;h=0;f=0;if(!i){break j}break k}x[31725]=0;n=d+44|0;c=d+88|0;S(743,n|0,c|0,1447576658);e=x[31725];x[31725]=0;t:{u:{v:{if((e|0)!=1){x[31725]=0;o=d+24|0;S(743,o|0,c|0,1128808782);e=x[31725];x[31725]=0;if((e|0)==1){break v}x[31725]=0;g=d+4|0;S(743,g|0,c|0,1112491097);c=x[31725];x[31725]=0;if((c|0)==1){break u}k=hd(j,g);ub(g);c=x[k>>2];x[31725]=0;q=R(174,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}e=0;c=0;w:{if(!q){break w}x[31725]=0;q=R(174,x[d+44>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}c=0;if(!q){break w}x[31725]=0;g=P(745,n|0,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}c=0;if(!g){break w}c=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);x[31725]=0;m=R(283,o|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}h=(c|0)!=1482052408;if(h){fd(l,16)}if((m|0)==6){Cp(l,3)}g=$b(x[d+4>>2]);e=x[d+8>>2];c=x[d+12>>2];i=$b(c);x:{y:{if(i>>>0<33){break y}n=$b(e);if(n>>>0<=i>>>0){break y}if(!((n>>>0)%(i>>>0)|0)){break x}}c=e}e=x[k>>2];x[31725]=0;k=x[d+20>>2];n=z[d+16>>1];e=R(156,e|0)|0;o=x[31725];x[31725]=0;i=1;if((o|0)==1){break u}o=g;g=h+((m|0)==6)|0;h=o>>>g|0;m=e>>>g|0;r=$b(k);e=Bb(n);c=$b(c)>>>g|0}ub(d+24|0);ub(d+44|0);if(i){break k}break j}f=N()|0;break b}f=N()|0;break t}f=N()|0;ub(d+24|0)}ub(d+44|0);break b}f=N()|0;break b}f=N()|0;ub(d+44|0);break b}Uu(a,b);x[31725]=0;f=D(b,104)+a|0;i=f+484380|0;O(281,i|0,0);g=x[31725];x[31725]=0;z:{if((g|0)!=1){x[i>>2]=m;c=c+h|0;x[f+484388>>2]=c;x[f+484384>>2]=h;if(!(c>>>0<=h+4>>>0|c>>>0>m>>>0)){c=f+484414|0;w[c>>1]=z[c>>1]|2}c=D(b,104)+a|0;x[c+484404>>2]=e>>>0<2?22050:e;g=c+484410|0;c=r+128|0;e=c>>>8|0;w[g>>1]=(c&16776960)>>>0>65536?256:e&65535?e:256;bC(i,x[a+480180>>2]);x[31725]=0;c=d+44|0;S(743,c|0,d+88|0,1312902469);e=x[31725];x[31725]=0;if((e|0)==1){break z}x[31725]=0;e=R(174,x[d+44>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}A:{B:{if(e){x[31725]=0;e=R(156,x[d+44>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;S(333,c|0,((b<<5)+a|0)+946304|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break B}break c}x[31725]=0;c=P(36,d+24|0,22267)|0;e=x[31725];x[31725]=0;if((e|0)==1){break A}zc(((b<<5)+a|0)+946304|0,c);tb(c)}x[31725]=0;U(217,l|0,i|0,j|0)|0;b=x[31725];x[31725]=0;f=1;if((b|0)==1){break c}Qj(i,a);ub(d+44|0);break j}break c}f=N()|0;break b}f=N()|0;break b}ub(j);ie(d+88|0)}fb=d+112|0;return f|0}f=N()|0;ub(d+44|0)}ub(j)}ie(d+88|0);Q(f|0);p()}function Boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;i=fb-160|0;fb=i;xc(b);d=i+112|0;a:{if(!OD(b,d)){break a}if(!TV(d)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(SV(y[i+159|0]),hb))){break a}Bd(a,128);g=i+100|0;We(g,2,i+127|0);d=i+32|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);e=tc(d,8453);Ab(a+1298344|0,e);tb(e);e=tc(d,6056);Ab(a+1298356|0,e);tb(e);g=tc(g,18163);x[31725]=0;S(758,d|0,g|0,x[(y[i+126|0]<<2)+25228>>2]);e=x[31725];x[31725]=0;c:{if((e|0)!=1){Ab(a+1298368|0,d);tb(d);tb(g);u=a+1298404|0,A=x[Fc(d,4)>>2],x[u>>2]=A;x[a+480208>>2]=12;gE(a+1298332|0,b,y[i+159|0]<<5,32,0);e=Zd(b);w[a+480190>>1]=e;g=1;while(1){k=g&65535;if(k>>>0>(e&65535)>>>0){hk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);g=0;d=Zd(b);if(d>>>0>=127){break a}w[a+480188>>1]=d+1;d=Zd(b);while(1)if(z[a+480188>>1]<=g>>>0){o=a+484344|0;r=d+1|0;Vf(o,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){e:while(1){t=s&65535;g=z[a+480188>>1];if(t>>>0>=g>>>0){d=Yo(i);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[31725]=0;O(760,d|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){a=N()|0;uf(d);Q(a|0);p()}x[31725]=0;O(759,o|0,d|0);e=x[31725];x[31725]=0;g=1;if((e|0)==1){break d}uf(d);if(!(c&2)){break a}while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break b}c=D(c,104)+a|0;fg(Xc(i+32|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);g=g+1|0;continue}}n=0;f=bh(i+32|0);f:while(1){g:{if((n|0)!=(r|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break g}}s=s+1|0;continue e}e=0;d=Wb(x[o>>2],n);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,t);while(1){h:{i:{if(e>>>0>63){break i}j=y[i+126|0];h=fb-16|0;fb=h;q=1;d=Zd(b);if((d|0)==252){q=Zd(b);d=Zd(b)}v[f|0]=(d-1&255)>>>0<60?d+36|0:0;d=h+12|0;sm(d,b);l=Jc(d);k=af(d);d=ej(d);v[f+1|0]=y[h+12|0];m=h+10|0;QV(m,y[l|0]&15,y[k|0],j);k=Jc(m);m=h+8|0;QV(m,y[l|0]>>>4|0,y[d|0],j);j=Jc(m);d=y[h+10|0];m=(d|0)!=10;l=y[h+8|0];j:{if(!(m|(l|0)!=10)){k=y[k|0];d=y[j|0];v[f+3|0]=10;k=k|d<<8;v[f+5|0]=k>>>6;if(k>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=d>>>6;break j}k:{l:{m:{n:{o:{if(!m){l=y[k|0];m=l<<2;u=k,A=yi(m),v[u|0]=A;if(l>>>0<64){break o}d=y[h+8|0];if(xi(d)>>>0>=xi(10)>>>0){break n}v[f+5|0]=m;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=l>>>6;break j}if((l|0)==10){d=y[j|0];l=d<<2;u=j,A=yi(l),v[u|0]=A;if(d>>>0<64){break o}if(xi(y[h+10|0])>>>0>=xi(10)>>>0){break o}v[f+5|0]=l;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=d>>>6;break j}if((d|0)!=(l|0)){break o}v[h+8|0]=0;break m}d=y[h+8|0]}if((d|0)==13){break l}if(d){break k}d=y[h+10|0]}if((d|0)==13){break k}}tg(h+10|0,h+8|0);tg(k,j)}GE(h+8|0,j,h+10|0,k);Gn(h+6|0,f,y[h+10|0],y[k|0],y[h+8|0],y[j|0])}fb=h+16|0;h=e+q|0;e=h>>>0>64?64-e|0:q;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[g+4|0]=d;v[g+5|0]=d>>>8;e=e-1|0;g=D(z[a+480188>>1],6)+g|0;continue}}n=n+1|0;continue f}e=h>>>0>=64?64:h;continue}}}}e=e+1|0;g=0;if(Ng(o,f,64)){continue}break a}break}e=N()|0;uf(d);break c}else{e=(g<<5)+a|0;Xe(e+480280|0);f=e+480284|0;p:{if(y[i+126|0]>=51){e=(Zd(b)<<4|8)&248;break p}e=g&1?192:64}w[f>>1]=e;g=g+1|0;continue}}else{q:{if(y[i+126|0]>=52){d=i+32|0;if(!x$(b,d)){jE(d)}break q}f=i+32|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;h=x[b>>2];j=x[b+8>>2];e=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(h,j,e)){e=lf(b)}h=d+8|0;fw(h,f);j=gc(d+16|0,x[d+8>>2],e);n=x[j>>2];kc(d,x[b>>2],x[b+8>>2],n,x[j+4>>2]);fw(h,f);Sb(x[d+8>>2]+e|0,0,66-e|0);Vb(b,x[d+28>>2]);fb=d+32|0;d=y[i+94|0]|y[i+95|0]<<8;v[i+96|0]=d;v[i+97|0]=d>>>8;v[i+94|0]=171;v[i+95|0]=32}h=fb-32|0;fb=h;f=(D(k,104)+a|0)+484380|0;ld(f,0);mp(f);j=h+8|0;e=i+32|0;Qk(j,2,e+32|0);d=h+20|0;Cc(d,j);ze(f+43|0,d);tb(d);j=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);n=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);r:{if(j>>>0<=n>>>0){break r}x[f>>2]=j-n;x[f+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[h+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);u=f,A=x[Gb(d,f)>>2],x[u+16>>2]=A;w[f+30>>1]=y[e+60|0];x[f+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){gm(f,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[f+34>>1]=z[f+34>>1]|8;d=y[e+61|0]}if(d&16){w[f+34>>1]=z[f+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break r}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}fb=h+32|0;f=i+20|0;We(f,2,e);d=i+100|0;Cc(d,f);zc(((k<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[a+480190>>1];continue}}}e=N()|0;tb(g)}Q(e|0);p()}g=1}fb=i+160|0;return g|0}function Vd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;z=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=e;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;bg(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];z=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;bg(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=nva(v,e,c,0);e=hb;A=e;M=f;q=b;c=nva(f,0,b,0);b=c+s|0;f=hb+e|0;i=b;c=b>>>0<c>>>0?f+1|0:f;f=b;j=0;b=nva(q,l,v,l);p=j+b|0;e=hb+f|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=nva(v,l,d,0);P=hb;b=nva(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=nva(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(A|0)&i>>>0<s>>>0|c>>>0<A>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=z|65536;z=nva(v,l,F,n);Q=hb;d=nva(O,m,M,l);H=d+z|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=nva(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;d=nva(B,m,L,l);b=d+J|0;K=f;f=f+hb|0;A=b;s=b>>>0<d>>>0?f+1|0:f;f=b;b=0;q=b+g|0;e=c+f|0;e=b>>>0>q>>>0?e+1|0:e;v=e;f=e;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=nva(I,m,L,l);h=hb;e=nva(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=nva(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=nva(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;h=f;e=nva(B,m,F,m);l=hb;g=nva(I,m,O,m);d=g+e|0;f=hb+l|0;f=d>>>0<g>>>0?f+1|0:f;g=f;f=(l|0)==(f|0)&d>>>0<e>>>0|f>>>0<l>>>0;y=g+j|0;e=f+h|0;e=g>>>0>y>>>0?e+1|0:e;l=y;h=e;j=d;e=0;d=e+w|0;f=j+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=h;h=g;g=g+l|0;f=h>>>0>g>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&A>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&z>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;bg(k+48|0,p,r,b,c,f);bg(k+32|0,d,e,h,i,f);fn(k+16|0,p,r,b,c,g);fn(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-128|0;fb=g;xc(b);a:{b:{c:{d:{e:{if(!MX(b,14147)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[31725]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(248,a|0,32768);d=x[31725];x[31725]=0;if((d|0)==1){break b}x[31725]=0;d=P(1,g+84|0,8169)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}Ab(a+1298344|0,d);tb(d);x[31725]=0;d=P(1,g+72|0,6060)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}Ab(a+1298356|0,d);tb(d);n=a+1298404|0,o=x[Fc(g+44|0,28)>>2],x[n>>2]=o;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,8)|0;f=x[31725];x[31725]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31725]=0;d=P(653,b|0,g- -64|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}if(!d){break n}f=x[g+68>>2];x[31725]=0;d=g+24|0;S(187,d|0,b|0,$b(f)|0);f=x[31725];x[31725]=0;if((f|0)==1){break l}f=ic(g+44|0,d);ub(d);d=x[f>>2];x[31725]=0;d=R(174,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[31725]=0;O(654,g+24|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{h=_b(g+24|0,d);e=z[a+480188>>1];v:{if(!Bb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;n=xb(h,e),o=1,v[n|0]=o;n=xb(h,z[a+480188>>1]+1|0),o=255,v[n|0]=o;Xe(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Xe(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31725]=0;O(655,f|0,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31725]=0;d=R(275,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}n=a,o=Kd(d,1,255),x[n+480196>>2]=o;break f}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31725]=0;m=R(275,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}d=y[a+484376|0];e=x[a+484360>>2];h=x[f>>2];x[31725]=0;h=R(156,h|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break j}x[31725]=0;aa(350,Xb(e,d)|0,f|0,h|0,255,254);d=x[31725];x[31725]=0;if((d|0)==1){break j}break f}d=k;if(Uf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Uf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[31725]=0;e=R(156,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[31725]=0;O(656,d|0,f|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=x[a+484360>>2];d=y[a+484376|0];x[31725]=0;O(332,Xb(b,d)|0,m&65535);b=x[31725];x[31725]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[31725]=0;O(225,a+484344|0,Uf(i,b)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Uf(e,x[k+4>>2])>>>0<=b>>>0){break w}x[31725]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(657,dh(e,b)|0,b|0,a|0,g+8|0);b=x[31725];x[31725]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Uf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;Dp(c);x:{if(x[c>>2]){e=x[dh(x[j>>2],b)>>2];x[31725]=0;e=R(156,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break h}wc(c,e);e=Xc(g+44|0,8,1,1,0);h=x[j>>2];x[31725]=0;U(217,e|0,c|0,dh(h,b)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Qc(j);Qc(k);break e}ub(f);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Qc(j);Qc(k);Q(a|0);p()}function VS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;a:{if(!Tc(d&255)){break a}m=a+1074376|0;g=D(b,872);j=(m+g|0)+616|0;b:{f=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!f|e)){break b}if(Jj(x[j+656>>2])){break b}c=a+g|0;d=c+1075068|0;if(!x[d>>2]){break a}e=x[c+1075080>>2];if(e&1024){break a}g=c+1075012|0;c=c+1075016|0;if(!(x[g>>2]|x[c>>2])){break a}c:{if(!(e&512)){break c}e=x[a+1298300>>2];if(!Dd(e)){break c}Mj(e,b,0);break a}e=dB(a,b);if((e|0)==65535){break a}i=D(e,872);e=a+1074992|0;a=i+e|0;Lq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;$o(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=e+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[c>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=f>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[_b(g+236|0,k)>>1];f=a+1074312|0;Kb(h+8|0,f,104);e:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){Kb(h,f,34);if(Hb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[xb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Kb(h+8|0,f,43);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!Rj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;c=b;f:{g:{while(1){if((c|0)==(o|0)){h:{c=0;if(Jj(x[j+656>>2])){break h}break g}}else{f=(b|0)==(c|0);i:{if(!f&z[a+480188>>1]>c>>>0){break i}e=D(c,872)+a|0;if(!f&z[e+1075778>>1]!=(p|0)){break i}n=e+1075648|0;f=x[n>>2];if(!f){break i}j:{k:{l:{m:{n:{o:{p:{switch(y[f+17|0]-1|0){case 0:if(!d){break i}i=(f|0)==(g|0)&y[e+1075789|0]==(d|0);if(!g){break o}if(i){break l}break i;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break i}if((f|0)==(g|0)){break j}Kb(h+8|0,k,104);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break j}break i;case 3:break n;case 2:break p;default:break i}}if(g){break m}i=(f|0)==(g|0)}if(i){break j}break i}if(!g){break i}i=y[g+34|0];if(!i){break i}if((i|0)==y[f+34|0]){break k}break i}if((f|0)!=(g|0)){break i}}if(!y[g+34|0]){break j}}if(!y[e+1075789|0]|y[f+18|0]>2){break j}f=e+1075793|0;i=y[f|0];if(!i){break j}cn(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;q:{r:{switch(y[x[n>>2]+18|0]){case 0:Ko(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break q}f=x[a+1298300>>2];if(!Dd(f)){break q}Mj(f,c&65535,1);break q;case 1:Ko(a,f);if(!(y[e+1075081|0]&2)){break q}f=x[a+1298300>>2];if(!Dd(f)){break q}Fk(f,c&65535);break q;case 2:break r;default:break q}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break q}if(!Dd(x[a+1298300>>2])){break q}Kb(h+8|0,k,105);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break q}Fk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break i}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}g=D(b,872)+a|0;if(!Tc(y[g+1075789|0])){break g}d=vm(a,m,b,2,1)-1|0;if((d&255)>>>0>249){break g}d=x[vd(a+906300|0,d)>>2];if(!d){break g}e=1;g=y[g+1075793|0];if(!g){break f}c=ib[x[x[d>>2]+104>>2]](d,g,b)|0;break f}e=0}if(!(Ti(x[j+8>>2],x[j+12>>2])|c)){break a}s:{if(!(c&e)){break s}c=D(b,872)+a|0;d=y[c+1075790|0];if(d>>>0>3|(d|0)==1){break s}cn(a,b,255,0);w[c+1075792>>1]=0}c=dB(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;t:{if(!(y[e+1075081|0]&2)){break t}e=x[a+1298300>>2];if(!Dd(e)){break t}Mj(e,c,1)}l=Lq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;u:{v:{switch(y[(i+D(b,872)|0)+798|0]){case 2:Ko(a,l);if(!(y[d+1|0]&2)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}Fk(e,b);Kb(h+8|0,k,105);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break u}TB(x[a+1298300>>2],b,c);break u;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}Mj(e,b,1);break u;case 3:x[d>>2]=g|4096;if(!(e&512)){break u}if(!Dd(x[a+1298300>>2])){break u}Kb(h+8|0,k,105);e=x[a+1298300>>2];if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){TB(e,b,c);break u}Fk(e,b);break u;case 1:break v;default:break u}}if(!(e&512)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}TB(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}fb=h+16|0}function i1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-80|0;fb=g;xc(b);a:{if(!Sr(b,11774)){break a}i=g+69|0;if(!uw(b,i)){break a}if(!NE(y[g+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(ME(i),hb))){break a}if(!Vb(b,y[g+78|0]|y[g+79|0]<<8)){break a}b:{if(!c){break b}Bd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[g+71|0]&31)+1;w[a+480190>>1]=y[g+72|0];Xh(a,1);d=g+20|0;e=tc(d,8476);Ab(a+1298344|0,e);tb(e);e=tc(d,7105);Ab(a+1298356|0,e);tb(e);e=fb-16|0;fb=e;f=tc(e+4|0,4247);_c(g,f);tb(f);fb=e+16|0;x[31725]=0;V(231,d|0,g|0,y[g+70|0],i|0);i=x[31725];x[31725]=0;c:{if((i|0)!=1){Ab(a+1298368|0,d);tb(d);Eb(g);l=a+1298404|0,m=x[Fc(d,4)>>2],x[l>>2]=m;d=y[g+72|0];i=g+56|0;x[i>>2]=0;x[i+4>>2]=0;Fc(i+8|0,0);if(d){_r(i,d);LF(i,d,0)}d=1;d:{while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){x[31725]=0;P(232,b|0,a+1298308|0)|0;e=x[31725];x[31725]=0;d=1;e:{if((e|0)==1){break e}while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){d=0;f:{while(1){if(z[a+480188>>1]<=d>>>0){d=0;x[31725]=0;e=a+484344|0;O(225,e|0,y[g+73|0]|y[g+74|0]<<8);f=x[31725];x[31725]=0;if((f|0)==1){break e}break f}e=(d<<5)+a|0;Xe(e+480280|0);x[31725]=0;O(233,b|0,e+480289|0);e=x[31725];x[31725]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}g:{h:{i:{j:{while(1){if((y[g+73|0]|y[g+74|0]<<8)>>>0<=d>>>0){x[31725]=0;f=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break h}if(!f){break i}d=x[b+8>>2];e=x[b>>2];x[31725]=0;d=U(152,e|0,d|0,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}if(d){break j}break i}x[31725]=0;f=g+20|0;h=P(234,b|0,f|0)|0;j=x[31725];x[31725]=0;k:{if((j|0)==1){break k}x[31725]=0;j=U(198,e|0,d&65535,64)|0;k=x[31725];x[31725]=0;if((k|0)==1){break k}if((h&j)==1){h=x[e>>2];x[31725]=0;O(235,Wb(h,d)|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break k}}d=d+1|0;continue}break}b=N()|0;break d}e=Nb(g+20|0);x[31725]=0;S(236,b|0,e|0,f|0);d=x[31725];x[31725]=0;l:{if((d|0)!=1){d=Fb(g);x[31725]=0;O(116,d|0,f|0);f=x[31725];x[31725]=0;m:{if((f|0)==1){break m}l=g,m=wb(x[e>>2]),x[l+40>>2]=m;h=wb(x[e+4>>2]);while(1){n:{f=x[g+40>>2];if(!Ib(f,h)){x[31725]=0;h=g+40|0;S(237,h|0,20,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}f=Ab(d,h);tb(h);h=Jb(f);j=y[f+11|0];k=x[f+4>>2];x[31725]=0;aa(238,a+1298332|0,h|0,Yc(k,j)|0,76,0);h=x[31725];x[31725]=0;if((h|0)==1){break m}tb(f);dc(e);break i}o:{f=v[f|0];if((f|0)<0){j=x[vb(g+52|0,Df(d))>>2];x[31725]=0;V(239,d|0,j|0,f&127,32);f=x[31725];x[31725]=0;if((f|0)!=1){break o}break m}x[31725]=0;O(117,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){break o}break m}me(g+40|0);continue}break}}b=N()|0;tb(d);break l}b=N()|0}dc(e);break d}d=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;S(240,Xb(e,d)|0,b|0,y[g+75|0]|y[g+76|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break h}f=c&1;d=0;while(1){p:{q:{if((y[g+73|0]|y[g+74|0]<<8)>>>0>d>>>0){e=x[b+8>>2];h=x[b>>2];x[31725]=0;e=U(152,h|0,e|0,4)|0;h=x[31725];x[31725]=0;if((h|0)==1){break p}if(e){break q}}if(!(c&2)){break g}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break g}e=D(c,104)+a|0;f=z[e+484414>>1];Kb(g+20|0,x[i>>2],c-1|0);c=Xc(g,f&1?16:8,1,0,Hb(x[x[g+20>>2]>>2],x[g+24>>2])?6:0);x[31725]=0;U(217,c|0,e+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}x[31725]=0;e=R(153,b|0)|0;h=x[31725];x[31725]=0;r:{s:{if((h|0)!=1){x[31725]=0;S(187,g|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break s}e=ic(g+20|0,g);ub(g);if(!f){break r}h=x[a+484344>>2];if(!He(h,x[a+484348>>2],d&65535)){break r}x[31725]=0;S(241,Wb(h,d)|0,0,e|0);h=x[31725];x[31725]=0;if((h|0)!=1){break r}b=N()|0;ub(e);break d}b=N()|0;break d}b=N()|0;break d}ub(e);d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}uf(i);break b}x[31725]=0;P(242,b|0,((e<<5)+a|0)+946304|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31725]=0;f=g+20|0;O(243,b|0,f|0);h=x[31725];x[31725]=0;t:{if((h|0)==1){break t}x[31725]=0;O(244,f|0,(D(e,104)+a|0)+484380|0);f=x[31725];x[31725]=0;if((f|0)==1){break t}f=y[g+36|0];Kb(g,x[i>>2],e-1|0);Jf(g,(f&3)!=0);d=d+1|0;continue}break}b=N()|0}uf(i);break c}b=N()|0;Eb(g)}Q(b|0);p()}d=1}fb=g+80|0;return d|0}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0;d=fb-80|0;fb=d;h=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}$d(d- -64|0,b);e=x[d+72>>2];g=x[d+76>>2];f=d+56|0;fl(f);b=Dj(b,f,8);if((y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))!=1414681667|(y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24))!=776101705){Hi(b,e,g,0);break d}w[d+54>>1]=0;pg(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}e=d+46|0;fl(e);e=Dj(b,e,8);if((y[d+46|0]|y[d+47|0]<<8|(y[d+48|0]<<16|y[d+49|0]<<24))!=1933333571|(y[d+50|0]|y[d+51|0]<<8|(y[d+52|0]<<16|y[d+53|0]<<24))!=1111389030){break d}w[d+44>>1]=0;pg(e,d+44|0);g=w[d+44>>1];if((g-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(g>>>0<=3){b=Fb(d- -64|0);x[31725]=0;f=U(497,e|0,b|0,65535)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!f){break i}x[31725]=0;f=d+32|0;S(498,f|0,c|0,b|0);i=x[31725];x[31725]=0;if((i|0)!=1){break j}break b}b=Fb(d- -64|0);x[31725]=0;f=P(500,e|0,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}if(!f){break h}x[31725]=0;f=d+32|0;S(498,f|0,c|0,b|0);i=x[31725];x[31725]=0;if((i|0)==1){break c}}Ab(a+40|0,f);tb(f);tb(b);w[d+30>>1]=0;pg(e,d+30|0);w[d+28>>1]=0;pg(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((g|0)<=3){x[d+64>>2]=0;Nk(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=km(b);w[d+26>>1]=b;break k}pg(e,d+26|0);b=z[d+26>>1]}i=a+52|0;m=b&65535;n=(g|0)>3;b=0;l:{m:{while(1){if((b&65535)>>>0>=m>>>0){break l}g=Fb(d- -64|0);x[31725]=0;w[d+8>>1]=0;O(940,e|0,d+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break g}n:{if(!n){x[31725]=0;f=U(497,e|0,g|0,65535)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}if(f){break n}break e}x[31725]=0;f=P(500,e|0,g|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}if(!f){break e}}x[31725]=0;f=d+32|0;S(498,f|0,c|0,g|0);j=x[31725];x[31725]=0;if((j|0)!=1){x[31725]=0;j=P(937,i|0,d+8|0)|0;o=x[31725];x[31725]=0;if((o|0)==1){break m}Ab(j,f);tb(f);tb(g);b=b+1|0;continue}break}h=N()|0;break f}h=N()|0;tb(d+32|0);break f}b=d+32|0;fl(b);b=Dj(e,b,8);if((y[d+32|0]|y[d+33|0]<<8|(y[d+34|0]<<16|y[d+35|0]<<24))!=1933333571|(y[d+36|0]|y[d+37|0]<<8|(y[d+38|0]<<16|y[d+39|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(bR(b,c)){break o}break d}if(!aR(b,c)){break d}}q=d,r=wb(x[a+4>>2]),x[q+64>>2]=r;c=wb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!$m(B[e>>2])){break d}Je(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(bR(b,c)){break p}break d}if(!aR(b,c)){break d}}q=d,r=wb(x[a+16>>2]),x[q+64>>2]=r;c=wb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!$m(B[e>>2])){break d}Je(d- -64|0);continue}break}q=a,r=oc(x[a+16>>2],x[a+20>>2]),x[q+36>>2]=r;w[d+24>>1]=0;pg(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;pg(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;Cq(b,d+16|0);l=eR(B[d+16>>2]);B[a+32>>2]=l;if(!$m(l)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;el(c+16|0,e);Rm(c+24|0,b,x[c+16>>2],x[c+20>>2]);el(c+8|0,e);fb=c+32|0;if(x[d+8>>2]!=1414681667|x[d+12>>2]!=776298313){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}q=d,r=uh(b),x[q+64>>2]=r;x[d+4>>2]=0;b=d- -64|0;q=a,r=x[fk(b,d+4|0,42288)>>2],x[q+36>>2]=r;Dq(a);h=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(lR(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}h=a+32|0;e=Nb(b);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;q=d,r=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[q+6>>1]=r;x[31725]=0;w[d+2>>1]=0;ha(935,a|0,e|0,h|0,d+4|0,d+2|0)|0;a=x[31725];x[31725]=0;h=1;if((a|0)==1){break r}uc(e);break d}c=w[a+28>>1];g=x[a+4>>2];x[31725]=0;O(941,e|0,yb(g,b-c|0)|0);c=x[31725];x[31725]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}h=N()|0;uc(e);break a}tb(b);break d}tb(b);break d}h=N()|0}tb(g);break a}tb(g)}fb=d+80|0;return h|0}h=N()|0;tb(b);break a}h=N()|0;tb(b)}Q(h|0);p()}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!vk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Pm(d+192|0,b);x[31725]=0;e=P(463,d+180|0,14001)|0;f=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[31725]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;f=d+160|0;S(464,b|0,e|0,f|0);g=x[31725];x[31725]=0;if((g|0)==1){break A}Eb(e);v[d+179|0]=0;x[31725]=0;e=P(463,f|0,14728)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}x[31725]=0;S(465,b|0,d+179|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break y}Eb(e);e=Fc(d+156|0,y[d+179|0]?0:c);x[31725]=0;c=P(463,d+144|0,15844)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}f=x[e>>2];x[31725]=0;V(929,b|0,a+40|0,c|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break w}Eb(c);w[d+142>>1]=65535;x[31725]=0;c=P(463,d+128|0,15534)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}x[31725]=0;U(493,b|0,d+142|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}Eb(c);w[d+126>>1]=0;x[31725]=0;c=P(463,d+112|0,15374)|0;f=x[31725];x[31725]=0;if((f|0)==1){break t}x[31725]=0;U(493,b|0,d+126|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}Eb(c);w[a>>1]=z[d+126>>1];x[31725]=0;c=P(463,d+100|0,15047)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}e=x[e>>2];x[31725]=0;V(930,b|0,a+52|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break q}Eb(c);x[31725]=0;c=P(463,d+88|0,14995)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}x[31725]=0;S(919,b|0,a+36|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break o}Eb(c);x[31725]=0;c=P(463,d+76|0,15536)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}x[31725]=0;h=a+4|0;S(931,b|0,h|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}Eb(c);x[31725]=0;c=P(463,d- -64|0,15376)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}x[31725]=0;f=a+28|0;S(932,b|0,f|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break k}Eb(c);x[31725]=0;c=P(463,d+52|0,15231)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;S(932,b|0,a+30|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break i}Eb(c);x[31725]=0;c=P(463,d+40|0,15019)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}x[31725]=0;S(933,b|0,a+32|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}Eb(c);w[d+38>>1]=0;x[31725]=0;c=P(463,d+24|0,14974)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;U(493,b|0,d+38|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}Eb(c);i=eR(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!$m(i)){break d}k=d,l=wb(x[a+4>>2]),x[k+20>>2]=l;c=wb(x[a+8>>2]);while(1){g=x[d+20>>2];if(!Ib(g,c)){break e}if(!$m(B[g>>2])){break d}Je(d+20|0);continue}}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;Eb(c);break a}if(vl(y[b|0])){break d}c=z[f>>1];if((c-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=uh(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[fk(d+20|0,d+16|0,42288)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[d+38>>1];if((f|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31725]=0;w[d+16>>1]=c;w[d+18>>1]=(c+f|0)-1;a=ba(934,a|0,d+14|0,d+20|0,d+16|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31725]=0;w[d+16>>1]=c;w[d+18>>1]=(c+g|0)-1;a=ha(935,a|0,h|0,d+20|0,d+16|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31725]=0;W(936,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}}e=1}Bh(b)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}Bh(b);Q(a|0);p()}function Vs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;h=e+448|0;fa(h|0,100,e+445|0,e+548|0,x[b>>2])|0;f=e+32|0;x[e+28>>2]=f;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=h;h=Gi(f,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;h=(h<<2)+f|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31725]=0;a=U(1249,d|0,1,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){x[31725]=0;O(35,g|0,32);a=x[31725];x[31725]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31725]=0;a=U(1249,d|0,1,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31725]=0;x[e+4>>2]=0;a=ea(1359,e+8|0,h|0,k|0,j|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31725]=0;O(35,g|0,37);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(35,g|0,((a|0)<84?65:97)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break q}break c}x[31725]=0;x[e+8>>2]=f;a=ea(1359,e+8|0,h|0,j|0,i|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31725]=0;O(35,g|0,37);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;O(35,g|0,((a|0)<144?66:98)|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}if(m){break q}a=x[Wd((D(c,12)+b|0)+172|0,0)>>2];x[31725]=0;a=U(1249,d|0,64,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(!a){break q}n=(Jb(g)+(Cb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31725]=0;x[e+8>>2]=f;a=ea(1359,e+8|0,h|0,i|0,l|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(35,g|0,112);a=x[31725];x[31725]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31725]=0;a=U(1249,d|0,64,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){x[31725]=0;a=ba(1360,e+28|0,h|0,e+4|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31725]=0;O(35,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31725]=0;a=P(1361,d|0,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(35,g|0,37);break u}a=x[f>>2];x[31725]=0;O(35,g|0,a|0)}a=x[31725];x[31725]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=89;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=106;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=121;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=83;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=77;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=100;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=72;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=109;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=73;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=117;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=119}if((a|0)==1){break c}x[31725]=0;O(35,g|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Qb(g);Q(a|0);p()}x[e+28>>2]=f;continue}}jo(12661);p()}function IL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+90176>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+90192>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;h=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;u=(k|0)<25;z=k-25|0;g=n;while(1){f=C[(g<<3)+i>>3];c=0;h=g;o=(g|0)<=0;if(!o){while(1){m=(i+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;b:{if(F(l)<2147483648){j=~~l;break b}j=-2147483648}l=+(j|0);f=l*-16777216+f;c:{if(F(f)<2147483648){j=~~f;break c}j=-2147483648}x[m>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=rk(f,q);f=f+J(f*.125)*-8;d:{if(F(f)<2147483648){m=~~f;break d}m=-2147483648}f=f-+(m|0);e:{f:{g:{h:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>r;s=h;h=j-(c<<r)|0;x[s+476>>2]=h;m=c+m|0;j=h>>y;break h}if(q){break g}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!o){while(1){s=(i+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;i:{j:{if(h){break j}v=16777216;if(o){break j}h=0;break i}x[s>>2]=v-o;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-rk(1,q)}m:{n:{if(f==0){h=0;c=g;if((c|0)<=(n|0)){break m}while(1){c=c-1|0;h=x[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break n}f=rk(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=rk(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+92960>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){l=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=l+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){l=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return m&7}c=1;while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(t+g<<2)+90192>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function $7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31725]=0;i=R(1217,x[h>>2])|0;j=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}gK(a,f+24|0,h+44|0,c,e,i);break b}fK(a,f+16|0,h+44|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=xk(g,i,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[27955];x[h+24>>2]=x[27954];x[h+28>>2]=g;g=x[27953];x[h+16>>2]=x[27952];x[h+20>>2]=g;g=x[27951];x[h+8>>2]=x[27950];x[h+12>>2]=g;g=x[27949];x[h>>2]=x[27948];x[h+4>>2]=g;k=h,l=xk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[27963];x[h+24>>2]=x[27962];x[h+28>>2]=g;g=x[27961];x[h+16>>2]=x[27960];x[h+20>>2]=g;g=x[27959];x[h+8>>2]=x[27958];x[h+12>>2]=g;g=x[27957];x[h>>2]=x[27956];x[h+4>>2]=g;k=h,l=xk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(li(a,b+12|0)){break H}if(!yj(i,1,Al(x[a>>2]))){break H}no(a);continue}break}if(li(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=ht(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=yc(h,111856,44);k=g,l=xk(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[27980];g=x[27979];x[h+8>>2]=x[27978];x[h+12>>2]=g;g=x[27977];x[h>>2]=x[27976];x[h+4>>2]=g;k=h,l=xk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[27991];x[h+24>>2]=x[27990];x[h+28>>2]=g;g=x[27989];x[h+16>>2]=x[27988];x[h+20>>2]=g;g=x[27987];x[h+8>>2]=x[27986];x[h+12>>2]=g;g=x[27985];x[h>>2]=x[27984];x[h+4>>2]=g;k=h,l=xk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=xk(g,i,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}eK(f+20|0,h+44|0,c,e,i);break b}a=pj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;d=a+12|0;L:{M:{if(li(c,d)){break M}b=4;if((wk(i,Al(x[c>>2]))|0)!=37){break M}b=2;if(!li(no(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function C1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-864|0;fb=f;xc(b);e=fb-16|0;fb=e;d=f+92|0;xF(e+8|0,d);i=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(i|0);if(!e){wF(d)}a:{if(!e){break a}if(!zF(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],yF(y[f+607|0]))){break a}if(!c){j=1;break a}Bd(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[f+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;e=a+484376|0;hk(Xb(x[a+484360>>2],y[e|0]),b,y[f+607|0],65535,65535);e=Xb(x[a+484360>>2],y[e|0]);o=f,q=wb(x[e>>2]),x[o+40>>2]=q;e=wb(x[e+4>>2]);while(1){d=x[f+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break a}Md(f+40|0);continue}break}gg(a);j=1;while(1){i=j&65535;if(i>>>0>z[a+480190>>1]){b:{j=1;c:{d:{e:{if(!(c&1)){break e}n=x[b+8>>2];i=a+484344|0;Vf(i,128);c=0;f:{while(1){if((c|0)==128){break f}d=f+16|0;e=(c<<1)+f|0;vF(d,b,(y[e+608|0]|y[e+609|0]<<8)+n|0,4674);e=ic(f+40|0,d);ub(d);g=x[e>>2];x[31725]=0;g=R(174,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break c}g:{if(!g){break g}x[31725]=0;g=U(198,i|0,c&65535,32)|0;h=x[31725];x[31725]=0;if((h|0)==1){break c}if(!g){break g}g=0;k=d;d=Wb(x[i>>2],c);cf(k,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){h:{d=x[e>>2];x[31725]=0;d=U(152,d|0,x[f+48>>2],1)|0;h=x[31725];x[31725]=0;i:{j:{k:{l:{m:{if((h|0)!=1){if(!d){break h}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}n:{switch(d-251|0){case 0:break j;case 1:break k;case 2:break l;case 3:break m;case 4:break n;default:break i}}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}if(!d){break h}g=d+g|0;if(g>>>0>=32){break h}d=Wb(x[i>>2],c);cf(f- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=d;continue}break b}x[31725]=0;d=f- -64|0;O(200,d|0,e|0);h=x[31725];x[31725]=0;if((h|0)==1){break b}k=z[a+480188>>1];h=y[xb(d,0)|0];if(k>>>0<=h>>>0){break d}d=y[xb(d,1)|0];if(d>>>0>63){break d}o=Wc(x[f+16>>2],h),q=d+1|0,v[o+1|0]=q;continue}x[31725]=0;d=f- -64|0;O(200,d|0,e|0);h=x[31725];x[31725]=0;if((h|0)==1){break b}k=z[a+480188>>1];h=y[xb(d,0)|0];if(k>>>0<=h>>>0){break d}d=y[xb(d,1)|0];if(d>>>0>63){break d}h=Wc(x[f+16>>2],h);v[h+4|0]=63-d;v[h+2|0]=1;continue}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){h=Wc(x[f+16>>2],0);v[h+5|0]=d;v[h+3|0]=12;continue}break b}d=Wc(x[f+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break d}x[31725]=0;h=R(199,e|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break b}if(h>>>0>=124){break d}o=Wc(x[f+16>>2],d),q=(D(h>>>4|0,12)+(h&15)|0)+13|0,v[o|0]=q;l=d|l;m=!(d&1)|m;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(l&m&1)){break e}c=z[a+480188>>1];b=0;while(1){if((b|0)==(c|0)){break e}w[((b<<5)+a|0)+480284>>1]=b<<8&256;b=b+1|0;continue}}bi(a+1298344|0,14749);bi(a+1298356|0,14758);bi(a+1298368|0,14749);o=a+1298404|0,q=x[Fc(f+40|0,4)>>2],x[o>>2]=q;break a}ub(e);j=0;break a}}}else{e=f+81|0;d=fb-16|0;fb=d;o:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Uh(e,11,d);break o}Gw(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[f+48>>2]=0;x[f+40>>2]=0;x[f+44>>2]=0;g=xb(e,1);d=f+40|0;o=xb(d,0),q=y[g|0],v[o|0]=q;g=xb(e,6);o=xb(d,1),q=y[g|0],v[o|0]=q;g=xb(e,2);o=xb(d,2),q=y[g|0],v[o|0]=q;g=xb(e,7);o=xb(d,3),q=y[g|0],v[o|0]=q;g=xb(e,3);o=xb(d,4),q=y[g|0],v[o|0]=q;g=xb(e,8);o=xb(d,5),q=y[g|0],v[o|0]=q;g=xb(e,4);o=xb(d,6),q=y[g|0],v[o|0]=q;g=xb(e,9);o=xb(d,7),q=y[g|0],v[o|0]=q;g=xb(e,5);o=xb(d,8),q=y[g|0],v[o|0]=q;g=xb(e,10);o=xb(d,9),q=y[g|0],v[o|0]=q;e=xb(e,0);o=xb(d,10),q=y[e|0],v[o|0]=q;e=(D(i,104)+a|0)+484380|0;ld(e,2);x[f+8>>2]=x[f+48>>2];d=x[f+44>>2];x[f>>2]=x[f+40>>2];x[f+4>>2]=d;Zk(e,1,f);d=f- -64|0;tF(d,((i<<3)+f|0)+86|0);e=f+16|0;Cc(e,d);zc(((i<<5)+a|0)+946304|0,e);j=j+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}fb=f+864|0;return j|0}function Bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-736|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+128|0;nX(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(i|0);if(!d){mX(f)}a:{if(!d){break a}if(!pX(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(oX(y[e+162|0]|y[e+163|0]<<8),hb))){break a}if(!c){q=1;break a}Bd(a,262144);f=e+92|0;aj(f,2,e+128|0);d=e+12|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);g=tc(d,8317);Ab(a+1298344|0,g);tb(g);g=tc(d,10125);Ab(a+1298356|0,g);tb(g);g=fb-16|0;fb=g;i=tc(g+4|0,4193);_c(f,i);tb(i);fb=g+16|0;v[e|0]=y[e+158|0];x[31725]=0;v[e+115|0]=y[e+157|0];g=e+116|0;O(693,g|0,e+115|0);i=x[31725];x[31725]=0;b:{c:{d:{if((i|0)!=1){x[31725]=0;V(252,d|0,f|0,e|0,g|0);i=x[31725];x[31725]=0;if((i|0)!=1){Ab(a+1298368|0,d);tb(d);tb(g);Eb(f);B=a+1298404|0,C=x[Fc(d,4)>>2],x[B>>2]=C;x[a+480208>>2]=12;w[a+480188>>1]=y[e+166|0]|y[e+167|0]<<8;w[e+12>>1]=y[e+162|0]|y[e+163|0]<<8;w[e+92>>1]=3999;B=a,C=z[Nc(d,f)>>1],w[B+480190>>1]=C;P_(Xb(x[a+484360>>2],y[a+484376|0]),e+224|0,y[e+160|0]|y[e+161|0]<<8);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=e+12|0;fe(d,b,D(y[e+162|0]|y[e+163|0]<<8,80));l=c&2;i=ic(e+92|0,d);ub(d);m=e+60|0;d=0;e:{f:{while(1){if(z[a+480190>>1]<=d>>>0){q=1;if(c&1){break f}break b}x[31725]=0;g=e+12|0;O(694,i|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}aj(e,2,m);x[31725]=0;f=e+116|0;O(220,f|0,e|0);j=x[31725];x[31725]=0;if((j|0)==1){break e}d=d+1|0;zc(((d<<5)+a|0)+946304|0,f);tb(f);x[31725]=0;h=g;g=(D(d,104)+a|0)+484380|0;S(695,f|0,h|0,g|0);j=x[31725];x[31725]=0;g:{if((j|0)==1){break g}if(!l|!x[g>>2]){continue}x[31725]=0;j=P(151,b|0,y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24))|0;k=x[31725];x[31725]=0;if((k|0)==1){break g}if(!j){continue}x[31725]=0;U(217,f|0,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){continue}}break}break e}x[31725]=0;o=a+484344|0;O(225,o|0,y[e+164|0]|y[e+165|0]<<8);c=x[31725];x[31725]=0;if((c|0)==1){break e}r=e+16|0;t=e+14|0;s=e+15|0;u=e+17|0;A=e+13|0;c=0;while(1){if((y[e+164|0]|y[e+165|0]<<8)>>>0<=c>>>0){break b}x[31725]=0;d=U(198,o|0,c&65535,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h:{if(!d){break h}d=(c<<1)+e|0;d=y[d+480|0]|y[d+481|0]<<8;if(!d){break h}x[31725]=0;d=P(151,b|0,d<<4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}if(!d){break h}l=0;d=Wb(x[o>>2],c);m=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,0);while(1){if(l>>>0>63){break h}d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,1)|0;f=x[31725];x[31725]=0;i:{if((f|0)!=1){if(!d){break h}x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}j=d<<24>>24;if(j){break i}l=l+1|0;m=D(z[a+480188>>1],6)+m|0;continue}break e}w[r>>1]=0;x[e+12>>2]=0;f=j&31;d=D(f,6)+m|0;g=bh(e+12|0);f=f>>>0<z[a+480188>>1];k=f?d:g;h=j&255;j:{if(!(h&32)){break j}x[31725]=0;n=e+116|0;O(200,n|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break e}g=y[e+116|0];v[k|0]=g;B=f?d+1|0:A,C=y[Jc(n)|0],v[B|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}v[k|0]=g}l:{if(!(h&64)){break l}x[31725]=0;h=e+116|0;O(200,h|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break e}g=f?d+5|0:u;n=Jc(h);v[g|0]=y[n|0];h=y[e+116|0];m:{if(h>>>0<=15){Bf(k,h,y[n|0]);break m}v[(f?d+3|0:s)|0]=h>>>0<=23?y[h+25367|0]:0}k=f?d+3|0:s;h=y[k|0];if((h|0)!=23){if((h|0)!=9){break l}v[k|0]=20;v[e|0]=y[g|0]>>>3;v[e+115|0]=1;B=g,C=y[ef(e,e+115|0)|0]-1&15|128,v[B|0]=C;break l}v[e|0]=64;B=g,C=y[Rb(g,e)|0]<<1,v[B|0]=C}if((j|0)>=0){continue}v[(f?d+2|0:t)|0]=1;x[31725]=0;g=R(199,b|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break e}v[(f?d+4|0:r)|0]=g;continue}}c=c+1|0;continue}}b=N()|0;ub(i);break c}else{f=(d<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+192|0]<<4|4)&244;d=d+1|0;continue}}b=N()|0;tb(e+116|0);break d}b=N()|0}Eb(e+92|0)}Q(b|0);p()}ub(i)}fb=e+736|0;return q|0}function Gz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(d|g|h|i){j=g?l+44|0:0;b:{if(!j){break b}k=x[j>>2];if(!k){break b}Db(k);x[j>>2]=0}x[31725]=0;X(86);k=x[31725];x[31725]=0;c:{d:{if((k|0)==1){m=Va(125e3,47456,47512,48492,125188,125292,125240,125132,125120,125436,125404,125372,125360,125584,0)|0;e:{f:{n=gb;if((n|0)==($(125e3)|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=277;if((j|0)==1){break f}break c}if(($(47456)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=358;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(47512)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=359;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(48492)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=357;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125188)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=300;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125292)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=299;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125240)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=298;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125132)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=297;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125120)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=296;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125436)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=289;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125404)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=288;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125372)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=287;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125360)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=286;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}o=$(125584)|0;k=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31725]=0;O(1104,j|0,m|0);j=x[31725];x[31725]=0;k=267;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break e}break d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}T(0)|0;Tb()}p()}Q(a|0);p()}Z();m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Bg(g?g:22267),x[q+20>>2]=r}if(h){x[h>>2]=k}g=x[l+44>>2];if(i){q=i,r=Bg(g?g:22267),x[q>>2]=r;g=x[l+44>>2]}if(g){Db(g);x[l+44>>2]=0}if(!(j&1)){break a}}x[31725]=0;g=l+32|0;O(1102,g|0,a|0);h=x[31725];x[31725]=0;g:{h:{if((h|0)!=1){i:{if(f){h=x[f+24>>2];x[31725]=0;O(1103,h|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){break i}break h}g=Jb(l+32|0);if(b){x[31725]=0;O(b|0,g|0,c|0);g=x[31725];x[31725]=0;if((g|0)==1){break h}break i}iu(g,l)}tb(l+32|0);break a}g=T(0)|0;break g}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22267;x[l+4>>2]=254;x[l>>2]=9174;FP(18460,l);hu(125936);Z()}fb=l+48|0}function Ro(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=OB(x[a+24>>2],y[a+32|0]);t=Pj(r);c=t;e=x[a>>2];d=Ud(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=fb-32|0;fb=k;c=c-d|0;d=x[zb(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=fb-16|0;fb=e;c=tv(e+4|0,a,c);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){hc(c);fb=e+16|0}else{eU(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=zb(a);d=Dm(k+12|0,Xp(a,Ud(x[a>>2],e)+c|0),Ud(x[a>>2],x[a+4>>2]),d);g=fb-16|0;fb=g;c=FW(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){eU(e);e=x[c>>2]+12|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;g=fb-16|0;fb=g;h=zb(a);c=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);j=vb(g+4|0,x[d+4>>2]);e=x[c>>2];i=x[i>>2];c=fb+-64|0;fb=c;j=x[j>>2];x[c+56>>2]=j;x[c+60>>2]=e;x[c+52>>2]=j;h=Se(c+24|0,h,c+52|0,c+56|0);x[c+16>>2]=x[h+8>>2];j=x[h+4>>2];x[c+8>>2]=x[h>>2];x[c+12>>2]=j;Re(c+36|0,c+8|0);while(1){if(pd(e,i)){AC(Wp(x[c+56>>2]),jl(e));e=sk(c+60|0);sk(c+56|0);e=x[e>>2];continue}break}Qe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){h=fb-16|0;fb=h;e=vb(h+12|0,x[x[c+44>>2]>>2]);n=x[vb(h+8|0,x[x[c+40>>2]>>2])>>2];i=fb-16|0;fb=i;e=x[e>>2];x[i+12>>2]=e;while(1){if(ci(e,n)){uf(tx(e));e=x[il(i+12|0)>>2];continue}break}fb=i+16|0;fb=h+16|0}fb=c- -64|0;x[d+4>>2]=j;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=g+16|0;c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;uf(e);continue}break}c=x[d>>2];if(c){xs(d);Db(c)}}fb=k+32|0;break a}if(c>>>0<d>>>0){kU(a,e+D(c,12)|0)}}if(b){c=a+12|0;Rq(c,ce(c));A=zb(c),B=0,x[A>>2]=B;d=c;c=ec(c);x[d>>2]=c;x[c>>2]=0;x[a+28>>2]=0}h=Nb(f+52|0);c=x[a+24>>2];c=Yu(x[c+484344>>2],x[c+484348>>2]);x[31725]=0;i=U(627,f+40|0,c|0,28588)|0;c=x[31725];x[31725]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((l|0)==(t|0)){md(i);dc(h);fb=f- -64|0;return}c=x[a+24>>2];d=x[c+484344>>2];c=x[c+484348>>2];j=z[_b(x[r>>2],l)>>1];d=qU(d,c,j);x[f+36>>2]=d;c=Hd(x[a>>2],l);d:{e:{f:{if(b){x[31725]=0;v[f+20|0]=0;S(806,c|0,d|0,f+20|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31725]=0;O(760,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!bj(r,l&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];c=f+20|0;s=x[Gb(c,f+36|0)>>2];n=Rf(g);d=z[_b(x[i>>2],j)>>1];if((d|0)!=65535){d=nU(g,z[jn(c,d,s)>>1],x[f+24>>2]);g:{if(Zg(d,Rf(g))){c=nU(g,z[jn(c,z[_b(x[i>>2],j)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Rf(g)}x[f+32>>2]=d;while(1){h:{if(!Zg(d,c)){break d}e=Nb(f+20|0);d=Yn(td(d)+8|0);x[31725]=0;O(807,e|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=Fc(f+12|0,n);k=jn(f+4|0,l,x[td(x[f+32>>2])+4>>2]);d=x[d>>2];x[31725]=0;d=ba(808,g|0,d|0,k|0,e|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break h}x[f+16>>2]=d;n=x[ah(f+16|0)>>2];Ae(e);d=x[ah(f+32|0)>>2];continue}}break}d=N()|0;Ae(e);break e}q=Wb(x[x[a+24>>2]+484344>>2],j);c=z[x[x[q+48>>2]+12>>2]+480188>>1];x[31725]=0;v[f+20|0]=0;S(781,h|0,c|0,f+20|0);c=x[31725];x[31725]=0;if((c|0)!=1){o=x[f+36>>2];i:while(1){j:{if((o|0)==(s|0)){if(s){break d}A=_b(x[i>>2],j),B=l,w[A>>1]=B;break d}c=1;k=0;e=x[x[q+48>>2]+12>>2];o=o-1|0;d=jd(x[q>>2],e,o,0);while(1){if(c>>>0<16&z[e+480188>>1]>k>>>0){u=xb(x[h>>2],k);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:m=y[d+5|0];if((m&240)==176){break l}break k;case 0:break m;default:break k}}m=y[d+5|0];if((m&240)!=96){break k}}v[u|0]=m&15;m=y[xb(x[h>>2],k)|0];e=m?m:e}d=d+6|0;k=k+1|0;c=D((e&255)+1|0,c);e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31725]=0;O(807,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}c=Fc(f,n);d=jn(f+4|0,l,o);c=x[c>>2];x[31725]=0;n=ba(808,g|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break j}Ae(e);continue i}}break}}break}d=N()|0;Ae(e);break e}d=N()|0}md(i);break c}l=l+1|0;continue}}d=N()|0}dc(h);Q(d|0);p()}function Aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-192|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+180|0;l:{if(!np(b,g)){break l}if(!aY(g)){break l}g=ai(d+160|0);h=Fb(d+148|0);$v(d+84|0);x[31725]=0;f=P(618,b|0,d+76|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=$b($b(x[d+80>>2])-4|0),x[m+80>>2]=n;while(1){f=$b($b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(c){break n}if(($b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31725]=0;e=d+56|0;S(187,e|0,b|0,$b(f)|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}f=ic(d,e);ub(e);e=x[f>>2];x[31725]=0;j=R(174,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}o:{if(!j){break o}p:{e=$b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31725]=0;P(185,f|0,4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;e=R(619,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!e){break o}e=$b(x[d+80>>2]);if(e>>>0<7){break o}i=x[Fc(d+52|0,28)>>2];x[31725]=0;V(620,f|0,h|0,i|0,e-6|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}break o}x[31725]=0;l=P(621,f|0,d+84|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break o}break b}Ww(g,f);break o}x[31725]=0;k=U(622,a|0,f|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}}ub(f);if(j){x[31725]=0;f=P(618,b|0,d+76|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(f){continue}}break}if(Ad(x[h+4>>2],y[h+11|0])){x[31725]=0;b=P(1,d+56|0,14892)|0;c=x[31725];x[31725]=0;if((c|0)==1){break g}Ab(h,b);tb(b)}q:{if(!(k&l&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31725]=0;b=Bb(b)&256;U(268,a+1074312|0,5,!b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}c=Bb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;m=a,n=z[Nc(d,d+40|0)>>1],x[m+480228>>2]=n}c=!b;b=Bb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;We(b,2,d+84|0);x[31725]=0;O(220,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}Ab(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!jr(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!jr(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!jr(e,0,23)){break q}j=y[d+136|0]|y[d+137|0]<<8;if(!jr(j,0,59)){break q}i=y[d+138|0]|y[d+139|0]<<8;if(!jr(i,0,59)){break q}x[a+1298408>>2]=0;b=qp(d);m=b,n=Bb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[m>>2]=n;m=b,n=Bb(c),x[m+4>>2]=n;m=b,n=Bb(f),x[m+8>>2]=n;m=b,n=Bb(e),x[m+12>>2]=n;m=b,n=Bb(j),x[m+16>>2]=n;m=b,n=Bb(i),x[m+24>>2]=n;x[b+28>>2]=0;x[31725]=0;O(449,a+1298412|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31725]=0;b=R(174,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31725]=0;S(272,g|0,b|0,32);c=x[31725];x[31725]=0;if((c|0)==1){break c}if(!Ld(b,13798)){x[31725]=0;c=d+40|0;S(260,c|0,28,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}Ab(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31725]=0;c=P(623,f|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(!c){x[31725]=0;c=R(204,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;aa(318,a+1298332|0,g|0,c|0,40,0);c=x[31725];x[31725]=0;if((c|0)==1){break c}}tb(b)}x[31725]=0;b=P(1,d+40|0,18151)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}x[31725]=0;S(491,d|0,b|0,h|0);c=x[31725];x[31725]=0;if((c|0)==1){break j}Ab(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31725]=0;a=U(268,a+1074312|0,84,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;a=U(268,a|0,83,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;P(269,a|0,85)|0;a=x[31725];x[31725]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function Yua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-3056|0;fb=g;xc(b);e=fb-16|0;fb=e;f=g+1102|0;D0(e+8|0,f);i=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(i|0);if(!e){C0(f)}a:{if(!e){break a}if(!F0(f)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(1024,0))){break a}B0(b,g+576|0);B0(b,g- -64|0);e=0;while(1){if((e|0)!=128){f=e<<2;i=x[f+(g+576|0)>>2];if(i>>>0>16777215){break a}f=x[f+(g- -64|0)>>2];if(f-4097>>>0<4294963202){break a}e=e+1|0;if(Cm(x[b>>2],(f+i|0)+2978|0)){continue}break a}break}Bd(a,2);gg(a);d=g+40|0;e=tc(d,13879);Ab(a+1298344|0,e);tb(e);e=tc(d,14745);Ab(a+1298356|0,e);tb(e);e=tc(d,15552);Ab(a+1298368|0,e);tb(e);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;d=y[g+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=d;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[g+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;e=0;while(1){if((e|0)==4){c:{while(1){d:{if((d|0)==32){e=0;break d}e=d+1|0;f=D(e,104)+a|0;h=f+484380|0;ld(h,2);j=g+20|0;A0(j,(D(d,13)+g|0)+1104|0);i=g+40|0;Cc(i,j);zc(((e<<5)+a|0)+946304|0,i);tb(i);d=(g+1102|0)+(d<<4)|0;i=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[h>>2]=i;m=i;i=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(m>>>0>=i>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[f+484414>>1]=2;x[f+484388>>2]=i;x[f+484384>>2]=d}x[f+484404>>2]=8287;d=e;continue}break}while(1){if((e|0)!=32){f=e+33|0;i=(D(f,104)+a|0)+484380|0;ld(i,2);h=g+20|0;A0(h,(D(e,13)+g|0)+2032|0);d=g+40|0;Cc(d,h);zc(((f<<5)+a|0)+946304|0,d);tb(d);x[g+48>>2]=0;x[g+40>>2]=0;x[g+44>>2]=0;f=(D(e,11)+g|0)+2448|0;h=xb(f,1);o=xb(d,0),q=y[h|0],v[o|0]=q;h=xb(f,6);o=xb(d,1),q=y[h|0],v[o|0]=q;h=xb(f,2);o=xb(d,2),q=y[h|0],v[o|0]=q;h=xb(f,7);o=xb(d,3),q=y[h|0],v[o|0]=q;h=xb(f,3);o=xb(d,4),q=y[h|0],v[o|0]=q;h=xb(f,8);o=xb(d,5),q=y[h|0],v[o|0]=q;h=xb(f,4);o=xb(d,6),q=y[h|0],v[o|0]=q;h=xb(f,9);o=xb(d,7),q=y[h|0],v[o|0]=q;h=xb(f,5);o=xb(d,8),q=y[h|0],v[o|0]=q;h=xb(f,10);o=xb(d,9),q=y[h|0],v[o|0]=q;f=xb(f,0);o=xb(d,10),q=y[f|0],v[o|0]=q;x[g+16>>2]=x[g+48>>2];d=x[g+44>>2];x[g+8>>2]=x[g+40>>2];x[g+12>>2]=d;Zk(i,1,g+8|0);e=e+1|0;continue}break}Ur(Xb(x[a+484360>>2],y[a+484376|0]),g+2800|0,256,255,65535);n=a+484344|0;Vf(n,128);m=c&1;i=0;while(1){e:{f:{if((i|0)!=128){d=i<<2;cd(b,x[d+(g+576|0)>>2]+2978|0);e=g+20|0;fe(e,b,x[d+(g- -64|0)>>2]);d=ic(g+40|0,e);ub(e);if(!m){break e}x[31725]=0;e=U(198,n|0,i&65535,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(!e){break e}e=0;h=Wb(x[n>>2],i);while(1){if(e>>>0>63){break e}f=x[d>>2];x[31725]=0;f=U(152,f|0,x[g+48>>2],1)|0;j=x[31725];x[31725]=0;g:{if((j|0)!=1){if(!f){break e}x[31725]=0;f=R(199,d|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break c}if(f>>>0>12){break g}j=jd(x[h>>2],x[x[h+48>>2]+12>>2],e,f);x[31725]=0;k=g+20|0;O(200,k|0,d|0);l=x[31725];x[31725]=0;if((l|0)==1){break c}l=y[g+20|0];f=f>>>0>3;v[j|0]=((l&15)+(f?13:37)|0)+D(l>>>4&7,12);k=Jc(k);v[j+1|0]=((y[k|0]>>>4|0)+(f?33:1)|0)+(y[g+20|0]>>>3&16);z0(j,y[k|0],f);continue}break c}j=f-32|0;if((j&255)>>>0<=12){j=jd(x[h>>2],x[x[h+48>>2]+12>>2],e,j&65535);x[31725]=0;k=R(199,d|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break c}z0(j,k,f>>>0>35);continue}if((f|0)!=64){if((f|0)!=96){break f}if(!e){break e}o=jd(x[h>>2],x[x[h+48>>2]+12>>2],e-1|0,0),q=14,v[o+3|0]=q;break e}x[31725]=0;f=R(199,d|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break c}e=e+f|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}fg(Xc(g+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,b);d=d+1|0;continue}}ub(d);d=0;break a}ub(d);i=i+1|0;continue}}}else{w[((e<<5)+a|0)+480284>>1]=e&1?192:64;e=e+1|0;continue}break}a=N()|0;ub(d);Q(a|0);p()}d=1}fb=g+3056|0;return d|0}function Usa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=fb-720|0;fb=j;a:{b:{if(d>>>0<=511){d=fb-16|0;fb=d;a=j+46|0;bc(d+8|0,a,554);e=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;b=(e|0)==(f|0);if(!b){Sb(a,0,554)}if(!b){break b}d=fb-32|0;fb=d;c:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;$r(e,a+32|0);b=d+20|0;Cc(b,e);zc(c+492|0,b);tb(b);lk(e,1,a+4|0);Cc(b,e);zc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;gh(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=yb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}gh(f,b);e=x[f>>2]}b=ef(k,g);a=Sd(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[ef(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=_b(k,b),q=g,w[o>>1]=q;o=xb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}k=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=lf(b)}g=d+8|0;e=j+46|0;YZ(g,e);h=gc(d+16|0,x[d+8>>2],f);i=x[h>>2];kc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);YZ(g,e);Sb(x[d+8>>2]+f|0,0,674-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;g=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;$r(f,e+32|0);a=d+20|0;Cc(a,f);zc(c+492|0,a);tb(a);lk(f,1,e+4|0);Cc(a,f);zc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;wc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Rb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Rb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];kk(c,a&127,a>>>7|0);a=y[e+59|0];jk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;Sw(e+304|0,c+48|0,0,f);Sw(e+386|0,c+68|0,32,f);Sw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=_b(h,a),q=i,w[o>>1]=q;o=xb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=_b(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}cd(b,d+k|0);if(!ik(b,14031)){break b}d=j+4|0;fe(d,b,Pg(b));a=ic(j+24|0,d);ub(d);b=x[a>>2];x[31725]=0;R(156,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=P(414,a|0,13813)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(b){x[31725]=0;b=R(199,a|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function iua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-320|0;fb=d;xc(b);a:{e=d+308|0;if(!np(b,e)){break a}if(!v$(e)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Vb(b,4)}if(!Bi(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}if(!c){l=1;break a}f=d+108|0;J0(b,f,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Bd(a,8192);e=d+24|0;g=tc(e,6574);Ab(a+1298344|0,g);tb(g);g=tc(e,10141);Ab(a+1298356|0,g);tb(g);r=a+1298404|0,s=x[Fc(e,4)>>2],x[r>>2]=s;g=d+88|0;aj(g,2,f);Cc(e,g);Ab(a+1298308|0,e);tb(e);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;f=z[qe(e,g)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Rb(e,g)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(f>>>0);x[d+88>>2]=128;e=x[Gb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;e=0;while(1){if((e|0)==16){f=Xb(x[a+484360>>2],y[a+484376|0]);l=d+172|0;g=fb-16|0;fb=g;x[g+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=g+12|0;wc(e,128);wc(e,65535);i=z[g+12>>1];xg(f,i);e=0;while(1){if((e|0)==(i|0)){fb=g+16|0}else{h=y[e+l|0];r=Vr(x[f>>2],x[f+4>>2],e),s=(h|0)==255?-1:(h|0)==254?-2:h,w[r>>1]=s;e=e+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){bf(Xb(x[a+484360>>2],y[a+484376|0]),e)}n=c&2;i=a+484344|0;l=1;o=c&1;q=d+60|0;while(1){if(!Bi(b,d+300|0)){break a}e=d+24|0;fe(e,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));c=ic(d+88|0,e);ub(e);c:{d:{if(!(!o|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[31725]=0;j=m&65535;e=U(198,i|0,j|0,64)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!e){break c}x[31725]=0;P(185,c|0,2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}g=0;e:{while(1){e=x[c>>2];x[31725]=0;e=U(152,e|0,x[d+96>>2],1)|0;f=x[31725];x[31725]=0;f:{if((f|0)!=1){if(!(e&g>>>0<64)){break e}x[31725]=0;e=R(199,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}h=e<<24>>24;if(h){break f}g=g+1|0;continue}break d}e=d+24|0;f=h&15;if(f>>>0<z[a+480188>>1]){e=Wb(x[i>>2],j);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],g,f)}g:{if((h|0)>=0){break g}x[31725]=0;f=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}if(!f){break g}v[e|0]=f>>>0<109?f+12|0:f}f=h&255;if(f&64){x[31725]=0;h=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}v[e+1|0]=h}if(f&32){v[e+2|0]=1;x[31725]=0;h=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}v[d+12|0]=h;v[d|0]=64;r=e,s=y[Rb(d+12|0,d)|0],v[r+4|0]=s}if(!(f&16)){continue}x[31725]=0;f=d+12|0;O(200,f|0,c|0);h=x[31725];x[31725]=0;if((h|0)!=1){Bf(e,y[d+12|0],y[Jc(f)|0]);continue}break}break d}m=m+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}e=z[a+480190>>1];if(!ui(e)){break c}e=e+1|0;w[a+480190>>1]=e;x[31725]=0;g=d+24|0;O(326,c|0,g|0);f=x[31725];x[31725]=0;h:{if((f|0)==1){break h}x[31725]=0;j=(D(e&65535,104)+a|0)+484380|0;O(327,g|0,j|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}aj(d,2,q);x[31725]=0;e=d+12|0;O(220,e|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break h}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,e);tb(e);if(!n){break c}g=y[d+37|0]|y[d+38|0]<<8;f=2;h=Xc(e,8,1,0,1);i:{if(!(g&64)){f=0;if(!(g&2)){break i}}yg(h,f)}if(g&4){fd(h,16)}x[31725]=0;U(217,e|0,j|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}g=(e<<5)+a|0;Xe(g+480280|0);f=y[(d+e|0)+156|0];if(f>>>0<=128){w[g+480284>>1]=f<<1}e=e+1|0;continue}}fb=d+320|0;return l|0}function fta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=fb-32|0;fb=g;a:{b:{if(!c){break b}f=Zh(a,b);a=wb(x[d>>2]);x[g+28>>2]=a;d=wb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}xc(a);c:{if((Vk(a)|0)==(c|0)){Vb(a,20);d=Vk(a);l=qg(g+16|0);c=em(g+12|0,0,b?32:64);x[31725]=0;O(404,f|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;m=1;d:{while(1){i=o;while(1){e=x[a+8>>2];h=x[a>>2];x[31725]=0;e=U(152,h|0,e|0,1)|0;h=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(!e){break d}e=x[f+4>>2];h=x[f>>2];j=x[a+8>>2];x[31725]=0;x[g+12>>2]=j;j=P(405,l|0,g+12|0)|0;r=x[31725];x[31725]=0;if((r|0)==1){break a}u=j,A=Sd(h,e),x[u>>2]=A;x[31725]=0;e=R(199,a|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[31725]=0;e=R(275,a|0)|0;h=x[31725];x[31725]=0;t:{if((h|0)==1){break t}x[31725]=0;x[g+12>>2]=e;e=P(405,l|0,g+12|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[31725]=0;e=R(275,a|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}w[g+12>>1]=e;w[g+10>>1]=1;h=g+12|0;j=g+10|0;e=z[qe(h,j)>>1];i=D(e,D(s<<16>>16,m))+i|0;u:{if(e>>>0<2){break u}u=g,A=km((e+z[xf(x[f+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Rv(b,i);x[31725]=0;v[g+10|0]=e;S(406,f|0,h|0,j|0);e=x[31725];x[31725]=0;if((e|0)!=1){break u}break a}u=g,A=km(z[xf(x[f+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Rv(b,i);x[31725]=0;v[g+10|0]=e;S(406,f|0,g+12|0,g+10|0);e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}x[31725]=0;k=R(199,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31725]=0;e=R(275,a|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}e=c+e|0;x[g+12>>2]=e;if(!(!(k&255)|e>>>0<t>>>0)){k=k-1|0;if(!(k&255)){break f}x[31725]=0;P(151,a|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}if(!(k&255)){break f}x[31725]=0;e=P(407,l|0,g+12|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[31725]=0;i=R(275,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}e=Rv(b,i);u=xf(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[31725]=0;s=R(408,a|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}x[31725]=0;e=R(199,a|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){v[g+12|0]=e;v[g+10|0]=1;m=y[ef(g+12|0,g+10|0)|0];break e}break a}x[31725]=0;P(185,a|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}k=0}if(!n|c>>>0>=d>>>0){continue}break}x[31725]=0;c=P(151,a|0,d|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}if(!c){break d}c=x[a+8>>2];i=x[a>>2];x[31725]=0;c=U(152,i|0,c|0,2)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}if(!c){break d}c=x[f+4>>2];i=y[f+12|0];if(!(i&4)&q){e=x[f>>2];v[f+12|0]=i|4;i=Sd(e,c)-1|0;v[f+15|0]=i;v[f+16|0]=i}u=g,A=km(z[xf(c)>>1]+1|0),w[u+12>>1]=A;c=Rv(b,o);x[31725]=0;v[g+10|0]=c;S(406,f|0,g+12|0,g+10|0);c=x[31725];x[31725]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;j_(l);break b}a=x[Sf(g+28|0)>>2];continue}break}break a}fb=g+32|0;return}a=N()|0;j_(l);Q(a|0);p()}function Mz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){i=x[b>>2];break a}i=x[b>>2];h=y[Hl(i,g)|0];if((h|0)==33){e=1}else{if((h|0)!=63){break a}e=0}Tl(f+96|0,i,g,g-1|0);g=x[f+100>>2];i=x[f+96>>2];x[b>>2]=i;x[b+4>>2]=g}j=f+96|0;ge(j);h=x[f+96>>2];k=f+236|0;ge(k);h=Gl(h,x[f+240>>2],b);ge(j);b:{c:{d:{e:{if(x[f+100>>2]==(h|0)){h=qc(f+248|0,22267);a=x[h+4>>2];x[f+8>>2]=x[h>>2];x[f+12>>2]=a;if(Ic(i,g,f+8|0)){e=ac(8);x[31725]=0;c=fi(k,c,d);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,j|0,18246,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(e,j);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(j);break g}g=N()|0;break f}g=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}if(!e){break e}h=ac(8);e=x[b>>2];a=x[b+4>>2];x[31725]=0;i=fi(f+212|0,e,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31725]=0;b=f+224|0;S(1017,b|0,18282,i|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;e=f+236|0;O(1019,e|0,b|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break p}x[31725]=0;d=fi(f+200|0,c,d);a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;c=f+96|0;S(1021,c|0,e|0,d|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break n}pc(h,c);x[31725]=0;S(99,h|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}g=N()|0;tb(c);a=0;break m}g=N()|0;break i}g=N()|0;a=1;break j}g=N()|0;break k}g=N()|0;a=1;break l}g=N()|0}tb(d)}tb(f+236|0)}tb(f+224|0)}tb(i);if(!a){break c}}jc(h);break c}e=qc(f+192|0,22267);b=x[e+4>>2];x[f+88>>2]=x[e>>2];x[f+92>>2]=b;if(Ic(i,g,f+88|0)){e=ac(8);x[31725]=0;d=fi(f+236|0,c,d);a=x[31725];x[31725]=0;r:{s:{t:{if((a|0)!=1){x[31725]=0;c=f+96|0;S(1017,c|0,18246,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}pc(e,c);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break s}g=N()|0;break r}g=N()|0;a=1}tb(d);if(!a){break c}}jc(e);break c}e=qc(f+184|0,12421);b=x[e+4>>2];x[f+80>>2]=x[e>>2];x[f+84>>2]=b;if(Ic(i,g,f+80|0)){e=qc(f+176|0,5601);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(c,d,f+32|0)){x[a+52>>2]=0;break e}e=qc(f+168|0,11285);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(c,d,f+24|0)){x[a+52>>2]=1;break e}e=qc(f+160|0,9206);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(Ic(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ac(8);x[31725]=0;d=fi(f+236|0,c,d);a=x[31725];x[31725]=0;u:{v:{w:{if((a|0)!=1){x[31725]=0;c=f+96|0;S(1017,c|0,14606,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break w}pc(e,c);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break v}g=N()|0;break u}g=N()|0;a=1}tb(d);if(!a){break c}}jc(e);break c}e=qc(f+152|0,11522);b=x[e+4>>2];x[f+72>>2]=x[e>>2];x[f+76>>2]=b;if(!Ic(i,g,f+72|0)){break e}e=qc(f+144|0,15627);b=x[e+4>>2];x[f+64>>2]=x[e>>2];x[f+68>>2]=b;b=0;x:{if(Ic(c,d,f- -64|0)){break x}e=qc(f+136|0,15632);b=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=b;b=1;if(Ic(c,d,f+56|0)){break x}e=qc(f+128|0,12695);b=x[e+4>>2];x[f+48>>2]=x[e>>2];x[f+52>>2]=b;b=2;if(Ic(c,d,f+48|0)){break x}e=qc(f+120|0,9270);b=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=b;b=3;if(Ic(c,d,f+40|0)){break x}c=ac(8);x[31725]=0;b=P(36,f+96|0,11558)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}g=N()|0;tb(b);break c}x[a+56>>2]=b;d=x[a+24>>2];if(!x[d+24668>>2]){break e}c=d+24664|0;a=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=a;c=d+24656|0;a=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=a;a=x[d+24652>>2];x[f+96>>2]=x[d+24648>>2];x[f+100>>2]=a;l=f,m=dN(b),x[l+116>>2]=m;a=f+96|0;if(!yz(a,d+24648|0)){break e}KA(d,a)}fb=f+256|0;return}g=N()|0;jc(c)}Q(g|0)}p()}function loa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Vb(c,4);while(1){if(Nv(x[c>>2],x[c+8>>2])){break b}m=fb-288|0;fb=m;f=KU(m+6|0);i=fb-368|0;fb=i;l=yc(f,KU(i+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;j=gc(g+8|0,g+28|0,4);h=x[j>>2];kc(g+20|0,x[c>>2],x[c+8>>2],h,x[j+4>>2]);j=x[g+24>>2]==4&x[g+28>>2]==1399285583;if(j){Vb(c,4)}fb=g+32|0;c:{d:{e:{f:{g:{if(j){LU(c,4);j=p0(i+60|0,c);x[31725]=0;g=P(792,j|0,l|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break g}h:{if(!g){break h}g=x[j+8>>2];h=x[j>>2];k=y[l+26|0];x[31725]=0;g=U(793,h|0,g|0,k|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break g}if(!g){break h}g=0;i:{while(1){if(y[l+26|0]<=f>>>0){h=x[j+8>>2];k=x[j>>2];f=0;x[31725]=0;n=h;h=g&65535;g=U(793,k|0,n|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break e}if(!g){break h}x[31725]=0;O(794,j|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}LU(j,MU(l));g=sc(i+56|0);f=i+80|0;QB(f);x[31725]=0;O(795,j|0,f|0);k=x[31725];x[31725]=0;if((k|0)!=1){w[i+102>>1]=0;w[i+104>>1]=0;f=JU(g,f,i+107|0);g=y[l+26|0];x[31725]=0;O(794,j|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){break i}}f=N()|0;break d}x[31725]=0;h=R(796,j|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){v[(f+l|0)+27|0]=h;f=f+1|0;g=g+h|0;continue}break}f=N()|0;break d}n=f;f=l+27|0;g=JU(n,f,f+y[l+26|0]|0);x[31725]=0;k=i+36|0;S(797,k|0,j|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break f}f=0;x[31725]=0;O(576,i+16|0,k|0);h=x[31725];x[31725]=0;if((h|0)==1){f=N()|0;ub(k);break d}n=i+16|0;gG(i+8|0,n);h=wb(x[i+8>>2]);o=Xk(x[i+8>>2],x[i+12>>2]);k=fb-16|0;fb=k;x[k+12>>2]=h;while(1){if(Ib(h,o)){HU(g,y[h|0]);h=x[me(k+12|0)>>2];continue}else{fb=k+16|0}break}Kc(n);ub(i+36|0);if(x[g>>2]!=(y[l+22|0]|y[l+23|0]<<8|(y[l+24|0]<<16|y[l+25|0]<<24))){break h}f=MU(l);x[31725]=0;O(794,c|0,f|0);g=x[31725];x[31725]=0;f=1;if((g|0)==1){break e}}ub(j)}fb=i+368|0;break c}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(j);Q(f|0);p()}fb=m+288|0;if(f){continue}break}}xc(c);fg(b,a,c);a=1;break a}v[d|0]=1;xc(c);f=Pg(c);d=e+136|0;fe(d,c,lf(c));g=ic(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31725]=0;O(576,d|0,g|0);b=x[31725];x[31725]=0;j:{k:{l:{m:{if((b|0)!=1){c=$e(d);d=x[e+136>>2];i=ZC(c,uh(d),e+132|0,e+128|0);x[31725]=0;b=x[e+132>>2];P(185,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){if(!i){break j}Fh(a);l=b+c|0;d=d-b|0;b=x[e+128>>2];c=0;while(1){n:{if(b){if(!d|(b|0)!=1){break k}b=x[a>>2];if(c>>>0<b>>>0){break n}break k}b=x[a>>2];if(c>>>0>=b>>>0){break k}}if(!je(b,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;b=e+120|0;j=EY(i,l,uh(d),e+124|0,e+116|0,b);x[31725]=0;P(185,g|0,j|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}Ai(b,uh(x[a>>2]-c|0));b=x[e+120>>2];o:{if((b|0)<=0){break o}f=x[e+124>>2];m=z[a+34>>1];if((_d(m)|0)!=(f|0)){break o}h=D(c,f);k=x[a+20>>2];if(m&1){x[e+112>>2]=b;x[e+100>>2]=b;x[e- -64>>2]=b;x[e+48>>2]=b;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=k+(h<<1);x[31725]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(577,e+56|0,e+40|0);f=x[31725];x[31725]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=b;x[e+76>>2]=b;x[e+32>>2]=b;x[e+16>>2]=b;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=h+k;x[31725]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(578,e+24|0,e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break m}}d=d-j|0;l=j+l|0;c=b+c|0;b=DY(i);continue}}break m}c=N()|0;break l}c=N()|0;Kc(e+136|0)}ub(g);Q(c|0);p()}CY(i)}Kc(e+136|0);ub(g);a=(i|0)!=0}fb=e+176|0;return a|0}function f8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31725]=0;i=R(28,x[h>>2])|0;j=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}jK(a,f+24|0,h+12|0,c,e,i);break b}iK(a,f+16|0,h+12|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=yk(g,i,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=yk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=yk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(th(a,b+12|0)){break H}c=Bl(x[a>>2]);if(!Kf(x[i+8>>2],1,c)){break H}Km(a);continue}break}if(th(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=lt(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[111768]|y[111769]<<8|(y[111770]<<16|y[111771]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[111765]|y[111766]<<8|(y[111767]<<16|y[111768]<<24);x[h>>2]=y[111761]|y[111762]<<8|(y[111763]<<16|y[111764]<<24);x[h+4>>2]=g;k=h,l=yk(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[111776];x[h>>2]=y[111772]|y[111773]<<8|(y[111774]<<16|y[111775]<<24);k=h,l=yk(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=yk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=yk(g,i,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}hK(f+20|0,h+12|0,c,e,i);break b}a=qj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;d=a+12|0;L:{M:{if(th(c,d)){break M}b=4;if((sl(i,Bl(x[c>>2]))|0)!=37){break M}b=2;if(!th(Km(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function uk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);e=j(1)|0;a:{b:{f=j(0)|0;p=e&2147483647;c:{if(!(f|p)){break c}o(+a);c=j(1)|0;g=j(0)|0;if(!g&(c|0)==1072693248){break c}t=g;q=c&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(g|0)!=0|p>>>0>2146435072)&(!f|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}g=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-g|0;g=f>>>m|0;r=0;if((f|0)!=g<<m){break i}r=2-(g&1)|0}m=r;if(f){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(e|0)>0|(e|0)>=0?b:0}if(f){break f}g=1043-g|0;f=p>>>g|0;if((p|0)!=f<<g){break g}m=2-(f&1)|0}if((p|0)==1072693248){if((e|0)>0|(e|0)>=0){return a}return 1/a}if((e|0)==1073741824){return a*a}if((e|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(e|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(e|0)>0|(e|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(e|0)<0?Infinity:0}return(e|0)>0?Infinity:0}if(q>>>0<=1072693246){return(e|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(e|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;f=q>>>0<1048576;d=f?a:d;o(+a);c=j(1)|0;j(0)|0;m=f?c:q;g=m&1048575;c=g|1072693248;m=(m>>20)+(f?-1076:-1023)|0;f=0;n:{if(g>>>0<235663){break n}if(g>>>0<767610){f=1;break n}c=g|1071644672;m=m+1|0}g=((f<<18)+(c>>>1|0)|0)+537395200|0;f=f<<3;w=C[f+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[f+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,g|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[f+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,e|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);e=j(1)|0;c=j(0)|0;o:{if((e|0)>=1083179008){if(c|e-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((e&2147482624)>>>0<1083231232){break o}if(c|e+1064252416){break a}if(!(d<=a-b)){break o}break a}f=0;g=e&2147483647;if(g>>>0>=1071644673){c=e+(1048576>>>(g>>>20|0)-1022|0)|0;g=c>>>20&2047;f=(c&1048575|1048576)>>>1043-g|0;f=(e|0)<0?0-f|0:f;l(0,0);l(1,c&-1048576>>g-1023);b=b-+n();o(+(d+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);e=j(1)|0;c=j(0)|0;e=(f<<20)+e|0;p:{if((e|0)<=1048575){a=rk(a,f);break p}l(0,c|0);l(1,e|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function ny(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-32|0;fb=e;j=a+32|0;Pc(e+8|0,j,11);a:{b:{c:{if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Hi(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);b=x[a+36>>2];if(vk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Ph(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];d=oj(f,x[c+4>>2]);d:{if(b>>>0>d>>>0){n=fb-32|0;fb=n;f=b-d|0;d=x[zb(c)>>2];g=x[c+4>>2];e:{if(f>>>0<=(d-g|0)/24>>>0){d=fb-16|0;fb=d;c=CJ(d+4|0,c,f);b=x[c+4>>2];f=x[c+8>>2];while(1){if((b|0)==(f|0)){hc(c);fb=d+16|0}else{BJ(b);b=b+24|0;x[c+4>>2]=b;continue}break}break e}b=zb(c);d=LJ(n+12|0,OJ(c,oj(x[c>>2],g)+f|0),oj(x[c>>2],x[c+4>>2]),b);g=fb-16|0;fb=g;b=g+4|0;x[b>>2]=x[d+8>>2];h=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=h+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){BJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}he(b);fb=g+16|0;k=fb-16|0;fb=k;b=vb(k+12|0,x[c+4>>2]);g=vb(k+8|0,x[c>>2]);h=x[vb(k+4|0,x[d+4>>2])>>2];m=fb-16|0;fb=m;p=m+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[b>>2],x[g>>2]);q=f+16|0;b=x[f+24>>2];r=x[f+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=h;x[g+12>>2]=b;while(1){if(pd(b,r)){b=pl(b);h=pl(x[g+8>>2]);l=z[b+18>>1]|z[b+20>>1]<<16;o=z[b+14>>1]|z[b+16>>1]<<16;w[h+14>>1]=o;w[h+16>>1]=o>>>16;w[h+18>>1]=l;w[h+20>>1]=l>>>16;l=x[b+12>>2];x[h+8>>2]=x[b+8>>2];x[h+12>>2]=l;l=x[b+4>>2];x[h>>2]=x[b>>2];x[h+4>>2]=l;b=_s(g+12|0);_s(g+8|0);b=x[b>>2];continue}break}Ac(q,b,g+8|0);fb=g+16|0;b=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(p,b,f+12|0);fb=f+32|0;fb=m+16|0;x[d+4>>2]=x[m+12>>2];Ub(c,d+4|0);Ub(c+4|0,d+8|0);Ub(zb(c),nc(d));x[d>>2]=x[d+4>>2];fb=k+16|0;JJ(d)}fb=n+32|0;break d}if(b>>>0<d>>>0){FJ(c,f+D(b,24)|0)}}f=a+40|0;wo(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>i>>>0){c=x[a+36>>2];if(vk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Ph(a,2,1024);break a}b=z[a+24>>1];w[e>>1]=b;if((b|0)==65535){xy(c,e);b=z[e>>1]}c=Sc(x[a+40>>2],x[a+44>>2]);d=b&65535;f:{if(!d){b=0;break f}if(d>>>0>(c^-1)>>>0){break f}Yj(f,c+d|0);Dj(x[a+36>>2],xb(x[a+40>>2],c),d)}d=wf(x[a+52>>2],i);x[d>>2]=c;w[d+20>>1]=b;b=e+8|0;Pc(b,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){ul(x[a+36>>2],b);b=x[e+8>>2];c=x[e+12>>2];if(!ry(b,c)){break c}d=wf(x[a+52>>2],i);x[d+8>>2]=b;x[d+12>>2]=c}c=x[a+8>>2];g:{if(c){b=wf(x[a+52>>2],i);x[b+16>>2]=c;break g}Pc(e+8|0,j,7);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){b=wf(x[a+52>>2],i);break g}ul(x[a+36>>2],e+8|0);c=x[e+8>>2];if(!ry(c,x[e+12>>2])){break b}b=wf(x[a+52>>2],i);x[b+16>>2]=c}h:{if(x[b+16>>2]==-1){break h}Pc(e+8|0,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break h}i:{if(!i){c=0;d=wf(x[a+52>>2],0);b=0;break i}d=x[a+52>>2];b=wf(d,i-1|0);g=x[b+16>>2];c=x[b+8>>2]+g|0;b=x[b+12>>2];d=wf(d,i);b=c>>>0<g>>>0?b+1|0:b}x[d+8>>2]=c;x[d+12>>2]=b}b=e+8|0;Pc(b,j,8);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){w[e+30>>1]=0;xy(x[a+36>>2],e+30|0);Pc(b,j,9);Tm(x[a+36>>2],z[e+30>>1]<<Hb(x[x[e+8>>2]>>2],x[e+12>>2]))}i=i+1|0;continue}break}$d(e+8|0,x[a+36>>2]);b=x[e+20>>2];x[a+80>>2]=x[e+16>>2];x[a+84>>2]=b}d=e+8|0;Pc(d,j,4);Jf(d,1);f=x[a+80>>2];g=x[a+84>>2];b=x[a+96>>2];h=x[a+16>>2];i=b+h|0;k=x[a+100>>2];c=k+x[a+20>>2]|0;c=i>>>0<h>>>0?c+1|0:c;h=i;i=(b|0)==x[a+72>>2]&(k|0)==x[a+76>>2];b=i?f:h;x[a+88>>2]=b;c=i?g:c;x[a+92>>2]=c;Hi(x[a+36>>2],b,c,0);Pc(d,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}Pc(e,j,7);if(!(Hb(x[x[e>>2]>>2],x[e+4>>2])|x[a+8>>2])){break a}c=x[a+88>>2];d=x[a+16>>2];b=c-d|0;f=x[a+92>>2]-(x[a+20>>2]+(c>>>0<d>>>0)|0)|0;j=x[a+52>>2];g=x[a+104>>2];a=0;while(1){if((a|0)==(g|0)){break a}c=wf(j,a);d=c;h=x[c+8>>2];i=h+b|0;c=x[c+12>>2]+f|0;x[d+8>>2]=i;x[d+12>>2]=i>>>0<h>>>0?c+1|0:c;a=a+1|0;continue}}Ph(a,2,2048);break a}Ph(a,2,2048)}fb=e+32|0}function Dta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;xc(b);d=fb-16|0;fb=d;h=f+102|0;K_(d+8|0,h);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(i|0)){break c}if(!M_(h)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(L_(y[f+318|0],y[f+319|0]),hb))){break c}if(!c){e=1;break c}Bd(a,2);gg(a);x[a+480188>>2]=524296;t=a,u=_e(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;We(d,2,f+133|0);e=f+88|0;Cc(e,d);Ab(a+1298308|0,e);tb(e);e=0;d:{e:{while(1){if((e|0)==8){f:{d=Xb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];m=o+1|0;hk(d,b,m,65535,65535);d=Nb(f+88|0);x[31725]=0;S(236,b|0,d|0,m|0);e=x[31725];x[31725]=0;if((e|0)==1){break f}t=f,u=wb(x[d>>2]),x[t+72>>2]=u;e=wb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}me(f+72|0);continue}break}t=a,u=y[xb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];h=y[f+319|0];g=Nb(f+72|0);x[31725]=0;n=h+1|0;S(236,b|0,g|0,n|0);h=x[31725];x[31725]=0;g:{if((h|0)==1){break g}x[31725]=0;h=a+484344|0;O(225,h|0,n|0);i=x[31725];x[31725]=0;if((i|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(n|0)){break e}e=y[xb(x[g>>2],c)|0];x[31725]=0;e=U(198,h|0,e|0,r|0)|0;i=x[31725];x[31725]=0;h:{if((i|0)!=1){if(!e){break e}i=0;l=Wb(x[h>>2],y[xb(x[g>>2],c)|0]);i:while(1){s=i&65535;if(s>>>0>7){break h}i=i+1|0;e=0;while(1){if(A[l+12>>2]<=e>>>0){continue i}x[31725]=0;j=R(199,b|0)|0;k=x[31725];x[31725]=0;j:{k:{if((k|0)!=1){j=j<<24>>24;if((j|0)>=0){break k}e=(j&127)+e|0;break j}break b}k=jd(x[l>>2],x[x[l+48>>2]+12>>2],e,s);if((j|0)==1){v[k|0]=254;break j}if((j-1&255)>>>0>96){break j}v[k+1|0]=i;v[k|0]=j+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{h=f+88|0;d=(f+102|0)+D(e,19)|0;ND(h,d+63|0);g=f+72|0;Cc(g,h);om(((e<<5)+a|0)+480289|0,g);tb(g);e=e+1|0;i=D(e,104)+a|0;j=i+484380|0;ld(j,2);v[f+83|0]=0;g=y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+75|0]|y[d+76|0]<<8|(y[d+77|0]<<16|y[d+78|0]<<24);d=y[d+71|0]|y[d+72|0]<<8|(y[d+73|0]<<16|y[d+74|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;Zk(j,1,f+8|0);x[i+484404>>2]=8215;d=f+60|0;Cc(d,h);zc(((e<<5)+a|0)+946304|0,d);tb(d);continue}break}e=N()|0;break a}i=o+1|0;e=0;while(1){l:{if((e|0)==(i|0)){x[31725]=0;b=P(1,f+60|0,8616)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break l}break b}b=Xb(x[a+484360>>2],y[a+484376|0]);j=e&65535;m:{if(!bj(b,j)){x[31725]=0;c=P(369,h|0,r|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if((c|0)==65535){break m}b=Xb(x[a+484360>>2],y[a+484376|0]);t=_b(x[b>>2],e),u=c,w[t>>1]=u}b=MD(wb(x[Wb(x[h>>2],z[_b(x[b>>2],e)>>1])+4>>2]),1);c=y[b+5|0];l=y[xb(x[d>>2],(e+1>>>0)%(m>>>0)|0)|0];if((c|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}c=y[a+484376|0];k=x[a+484360>>2];x[31725]=0;c=P(370,Xb(k,c)|0,j|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break b}if((c|0)==65535){break n}b=MD(wb(x[Wb(x[h>>2],c)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,f+48|0,6049)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}Ab(a+1298356|0,b);tb(b);c=f+24|0;vi(c,2,f+113|0);x[31725]=0;b=f+36|0;S(371,b|0,4,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}Ab(a+1298368|0,b);tb(b);t=a+1298404|0,u=x[Fc(b,4)>>2],x[t>>2]=u;dc(g)}dc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;dc(g)}dc(d);Q(e|0);p()}function dS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-16|0;fb=j;a:{b:{c:{if(!Tc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[j+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];i=j+14|0;c=w[i>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=iA(c,i);if(!Zg(d,Rf(c))){break f}Bm(a,td(d)+4|0);break d}e=hA(c,e<<16>>16);w[b+62>>1]=e;c=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;f=iA(a,b+62|0);t:{if(Zg(f,Rf(a))){x[31725]=0;O(131,c|0,td(f)+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}a=w[d+30>>1];d=w[i>>1];x[31725]=0;n=b,o=gA(d,a)+5|0,x[n+36>>2]=o;a=b+48|0;O(128,a|0,b+36|0);d=x[31725];x[31725]=0;u:{if((d|0)!=1){x[31725]=0;P(76,c|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break u}tb(a);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31725]=0;e=U(543,b+36|0,1,e+65<<24>>24)|0;a=x[31725];x[31725]=0;if((a|0)==1){break s}x[31725]=0;a=b+48|0;S(603,a|0,0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break r}f=Ab(c,a);tb(a);tb(e);x[31725]=0;P(129,f|0,14629)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(e);break g}x[31725]=0;g=e<<16>>16;a=(g|0)/16|0;x[b+32>>2]=e-(a<<4)<<16>>16;e=b+36|0;O(884,e|0,b+32|0);f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;x[b+16>>2]=(a<<16>>16)%16;a=b+20|0;O(884,a|0,b+16|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}x[31725]=0;f=b+48|0;S(2,f|0,e|0,a|0);h=x[31725];x[31725]=0;if((h|0)==1){break m}k=Ab(c,f);tb(f);tb(a);tb(e);if((g|0)<256){break p}x[31725]=0;g=b+4|0;O(885,g|0,k|0);a=x[31725];x[31725]=0;if((a|0)==1){break k}h=zd(g);l=Df(g);m=zd(g);a=fb-16|0;fb=a;x[a+8>>2]=m;x[a+12>>2]=h;while(1){if(Ib(h,l)){n=x[a+8>>2],o=Qq(v[h|0]),v[n|0]=o;h=me(a+12|0);me(a+8|0);h=x[h>>2];continue}break}fb=a+16|0;_c(e,g);x[31725]=0;S(603,f|0,0,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}Ab(k,f);tb(f);tb(e);tb(g)}a=w[d+30>>1];d=w[i>>1];x[31725]=0;n=b,o=gA(d,a)+5|0,x[n+20>>2]=o;a=b+48|0;O(128,a|0,b+20|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}x[31725]=0;P(76,c|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break h}tb(a);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}tb(c);Q(a|0);p()}f=fb-16|0;fb=f;e=f+4|0;c=fb-32|0;fb=c;d=rf(c+20|0,1,0);v:{while(1){g=Jb(d);vs(c+12|0,g,Cb(x[d+4>>2],y[d+11|0])+g|0,w[i>>1]);if(!x[c+16>>2]){break v}g=qi(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}g=x[c+12>>2];i=Jb(d);x[31725]=0;O(46,d|0,g-i|0);g=x[31725];x[31725]=0;w:{if((g|0)!=1){x[31725]=0;O(47,e|0,d|0);g=x[31725];x[31725]=0;if((g|0)!=1){break w}break a}break a}tb(d);fb=c+32|0;Rh(a,e);tb(e);fb=f+16|0}fb=b- -64|0;break b}e=x[b>>2];b=fb-32|0;fb=b;x:{if(Nl(c)){x[b+16>>2]=x[7628];d=x[7627];x[b+8>>2]=x[7626];x[b+12>>2]=d;d=x[7625];x[b>>2]=x[7624];x[b+4>>2]=d;tc(a,(b+(c<<2)|0)-1004|0);break x}if(Tc(c)){d=Fb(b);x[31725]=0;c=c-1|0;f=(c|0)/12|0;c=P(886,d|0,e+(D(f,-12)+c<<16>>16<<2)|0)|0;e=x[31725];x[31725]=0;y:{if((e|0)==1){break y}x[31725]=0;c=P(887,c|0,f+48&255)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}x[31725]=0;P(3,a|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break y}tb(c);break x}break a}if(!c){tc(a,16775);break x}tc(a,14600)}fb=b+32|0}fb=j+16|0;return}a=N()|0;tb(d);Q(a|0);p()}function PS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=a+1074376|0;h=D(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Sj(x[e+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;e=z[(d<<1)+31712>>1];x[b+1075696>>2]=e;d=b+1075692|0;if(!x[d>>2]){break a}l=d,m=xh(a,y[b+1075789|0],c,e),x[l>>2]=m;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=a+906300|0;j=b+1|0;k=d-1|0;while(1){if((c|0)==(h|0)){break a}e=D(c,872)+a|0;c:{if((j|0)!=z[e+1075778>>1]){break c}d:{e:{switch(k|0){case 0:Ko(a,e+1074992|0);if(!(y[e+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Fk(d,c&65535);break d;case 1:g=e+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Fk(d,c&65535);break d;default:break e}}x[e+1075688>>2]=0;g=e+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Mj(d,c&65535,1)}d=x[e+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[vd(i,g-1|0)>>2];if(!g){break c}ib[x[x[g>>2]+96>>2]](g,d,y[e+1075789|0]|256,0,b)}c=c+1|0;continue}}tV(e,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}en(a,e,d,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d|0){case 0:x[e+88>>2]=x[e+88>>2]&-257;break f;case 1:x[e+692>>2]=128;x[e+88>>2]=x[e+88>>2]|256;break f;case 8:x[e+88>>2]=x[e+88>>2]&-25165825|16777216;break f;case 9:x[e+88>>2]=x[e+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[e+88>>2]=x[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[e>>2]|x[e+4>>2]){break h}a=x[e+76>>2];if(!a){break h}if(!(l=Tc(y[e+788|0]),m=1,n=y[e+88|0]&2,n?l:m)){break h}x[e>>2]=-1;x[e+4>>2]=a-1}x[e+88>>2]=x[e+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}b=D(b,872)+a|0;v[b+1075828|0]=d;Kb(f+8|0,a+1074312|0,35);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!Tc(y[b+1075780|0])){break a}a=d<<16;if(a>>>0>=A[b+1075068>>2]){break a}x[e+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}uB(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Kb(f+8|0,a+1074312|0,30);cB(a,b,d,Hb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}fb=f+16|0}function Fta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-960|0;fb=f;xc(b);d=fb-16|0;fb=d;e=f+862|0;T_(d+8|0,e);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){S_(e)}a:{if(!d){break a}if(!V_(e)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(U_(y[f+909|0]|y[f+910|0]<<8),hb))){break a}if(!c){m=1;break a}Bd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[f+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=f+88|0;e=tc(d,8224);Ab(a+1298344|0,e);tb(e);e=tc(d,8912);Ab(a+1298356|0,e);tb(e);t=a+1298404|0,u=x[Fc(d,4)>>2],x[t>>2]=u;e=f+12|0;Q_(e,f+866|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[f+958|0]|y[f+959|0]<<8;if(d){gE(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;e=f+88|0;bc(d+8|0,e,771);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;m=(g|0)==(h|0);if(!m){Sb(e,0,771)}if(!m){break a}d=a+484376|0;P_(Xb(x[a+484360>>2],y[d|0]),e,y[f+345|0]);bf(Xb(x[a+484360>>2],y[d|0]),y[f+346|0]);cd(b,y[f+909|0]|y[f+910|0]<<8);j=a+484344|0;q=c&1;e=0;while(1){c:{if((e|0)==256){if(!(c&2)){break a}t0(b,f+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[f+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}c=f+12|0;if(!OD(b,c)){break a}d=d+1|0;w[a+480190>>1]=d;We(f,1,c);h=f+68|0;Cc(h,f);zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);e=(D(d,104)+a|0)+484380|0;ld(e,0);j=y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24);x[e>>2]=j;g=y[c+38|0]|y[c+39|0]<<8|(y[c+40|0]<<16|y[c+41|0]<<24);x[e+4>>2]=g;i=y[c+42|0]|y[c+43|0]<<8|(y[c+44|0]<<16|y[c+45|0]<<24);x[e+24>>2]=16726;x[e+8>>2]=i;w[e+30>>1]=y[c+37|0]<<4;if(v[c+46|0]&1){i=i>>>1|0;x[e+8>>2]=i;g=g>>>1|0;x[e+4>>2]=g;x[e>>2]=j>>>1}if(!(!(y[c+47|0]&8)|g>>>0>=i>>>0)){w[e+34>>1]=z[e+34>>1]|2}Xc(h,v[f+58|0]&1?16:8,1,0,0);fg(h,e,b);continue}}d:{d=(e<<1)+f|0;h=y[d+347|0]|y[d+348|0]<<8;if(h){g=f+68|0;fe(g,b,h);i=ic(f+12|0,g);ub(g);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[31725]=0;d=U(198,j|0,e&65535,n|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!d){break e}x[31725]=0;d=R(199,i|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}x[31725]=0;P(185,i|0,1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;g=0;f:while(1){if((g|0)!=(n|0)){d=Wb(x[j>>2],e);cf(f+68|0,x[d>>2],x[x[d+48>>2]+12>>2],g);t=f,u=wb(x[f+68>>2]),x[t>>2]=u;s=hw(x[f+68>>2],x[f+72>>2]);while(1){d=x[f>>2];if(!Ib(d,s)){g=g+1|0;continue f}x[31725]=0;h=f+60|0;O(359,h|0,i|0);k=x[31725];x[31725]=0;if((k|0)==1){break c}l=af(h);k=ej(h);o=y[f+60|0];if((o-1&255)>>>0<=71){v[d|0]=o+36;t=d,u=y[Jc(h)|0]+1|0,v[t+1|0]=u}if((y[l|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[l|0]<<6)+-64>>>0)/15}l=y[k|0];h=l&15;v[d+5|0]=h;g:{h:{switch((y[k|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=l|240;break g;case 2:v[d+5|0]=h<<2;break g;case 3:v[d+5|0]=(6/(h+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=h<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(h<<2)+4;break g;case 10:v[d+5|0]=h|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(h+1>>>0)|0)+1|13}v[d+3|0]=y[(y[k|0]>>>4|0)+24736|0];vg(f);continue}}break}ye(Wb(x[j>>2],e),Yh(Ye(Ne(f+68|0,14,0),r)))}ub(i)}e=e+1|0;continue}}break}}}else{e=(d<<5)+a|0;g=e+480280|0;Xe(g);h=g;g=(f+862|0)+d|0;x[h>>2]=!y[g+50|0]<<10;w[e+480284>>1]=(y[g+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=f+960|0;return m|0}function z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-560|0;fb=f;xc(b);d=fb-16|0;fb=d;g=f+63|0;oF(d+8|0,g);e=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(e|0)==(j|0);if(!d){nF(g)}a:{if(!d){break a}if(!qF(g)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(pF(y[f+173|0],y[f+174|0]),hb))){break a}Bd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=f+36|0;g=tc(d,14642);Ab(a+1298344|0,g);tb(g);g=tc(d,14675);Ab(a+1298356|0,g);tb(g);bi(a+1298368|0,(y[f+63|0]|y[f+64|0]<<8)==26217?14642:14670);o=a+1298404|0,p=x[Fc(d,4)>>2],x[o>>2]=p;e=y[f+173|0];w[a+480190>>1]=e;g=1;while(1){j=g&65535;if(j>>>0<=e>>>0){e=fb-16|0;fb=e;d=f+36|0;bc(e+8|0,d,25);k=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(k|0)){Vb(b,x[e+12>>2])}fb=e+16|0;if((i|0)!=(k|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[f+49|0]|y[f+50|0]<<8|(y[f+51|0]<<16|y[f+52|0]<<24))>>>0>67108863){break a}e=(D(j,104)+a|0)+484380|0;ld(e,0);x[e+24>>2]=8363;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[e>>2]=i;l=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[e+4>>2]=l;k=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[e+8>>2]=k;c:{if(!(l|i>>>0>=k>>>0)){x[e+8>>2]=0;break c}if(k){w[e+34>>1]=2;$k(e)}}e=f+12|0;lk(e,2,d);d=f+24|0;Cc(d,e);zc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[a+480190>>1];continue}break}g=f+24|0;h=f+65|0;wg(g,3,h,36);d=f+36|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);g=0;mF(a+1298332|0,h,108,36,0);d=a+484376|0;Ew(Xb(x[a+484360>>2],y[d|0]),f+176|0,128,255,254);d=Xb(x[a+484360>>2],y[d|0]);h=y[f+175|0];if(z[_b(x[d>>2],h)>>1]<y[f+174|0]){bf(d,h)}while(1)if((g|0)==8){j=a+484344|0;Vf(j,y[f+174|0]);n=c&1;e=0;while(1)if(y[f+174|0]<=e>>>0){h=1;if(!(c&2)){break a}c=Xc(f+36|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}fg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{d:{e:{if(n){if(Ng(j,e&65535,64)){break e}}Vb(b,1536);break d}x[f+24>>2]=-1;x[f+28>>2]=-1;k=0;f:while(1){if((k|0)==64){d=x[j>>2];g=(f+63|0)+e|0;h=y[g+369|0];if(h>>>0<63){ye(Wb(d,e),Yh(Ye(Ne(f+36|0,14,0),h)));d=x[j>>2]}ye(Wb(d,e),Yh(Ne(f+36|0,16,y[g+241|0])));break d}g=0;d=Wb(x[j>>2],e);h=jd(x[d>>2],x[x[d+48>>2]+12>>2],k,0);while(1){if((g|0)==8){k=k+1|0;continue f}d=f+36|0;Wr(d,b);i=Jc(d);l=af(d);i=y[i|0];d=y[f+36|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(f+24|0)+g|0]=255;d=y[f+36|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[l|0];if((d|0)!=255){v[(f+24|0)+g|0]=d}i=(f+24|0)+g|0;g:{h:{if(!(d&15)&(d|0)!=48){break h}l=y[i|0];if((l|0)==255){break g}m=l<<24>>24;d=m&15;v[h+5|0]=d;i:{if((m|0)<0){break i}l=l>>>4|0;v[h+3|0]=y[l+24536|0];j:{switch(l-3|0){case 0:v[h+5|0]=d|32;break h;case 1:v[h+5|0]=d|m<<4;break g;case 2:break h;case 3:break j;default:break g}}k:{switch(d|0){case 0:v[h+5|0]=79;break g;case 1:break k;default:break i}}v[h+5|0]=244;break g}v[h+3|0]=0;break g}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}e=e+1|0;continue}}else{d=(g<<5)+a|0;Xe(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}fb=f+560|0;return h|0}function Ts(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Kf(x[d+8>>2],1,v[f|0])){x[31725]=0;O(117,g|0,32);a=x[31725];x[31725]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Kf(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31725]=0;x[e>>2]=0;a=ea(1362,e+4|0,h|0,k|0,j|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31725]=0;O(117,g|0,37);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(117,g|0,((a|0)<84?65:97)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break q}break c}x[31725]=0;x[e+4>>2]=f;a=ea(1362,e+4|0,h|0,j|0,i|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31725]=0;O(117,g|0,37);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;O(117,g|0,((a|0)<144?66:98)|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}if(m){break q}if(!Kf(x[d+8>>2],64,v[cc((D(c,12)+b|0)+172|0,0)|0])){break q}n=xz(g),o=109,v[n|0]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31725]=0;x[e+4>>2]=f;a=ea(1362,e+4|0,h|0,i|0,l|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(117,g|0,112);a=x[31725];x[31725]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Kf(x[d+8>>2],64,a)){x[31725]=0;a=ba(1363,e+8|0,h|0,e|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31725]=0;O(117,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(117,g|0,37);break u}x[31725]=0;O(117,g|0,a|0)}a=x[31725];x[31725]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=89;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=106;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=121;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=83;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=77;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=100;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=72;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=109;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=73;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=117;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=119}if((a|0)==1){break c}x[31725]=0;O(117,g|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function $A(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;f=fb-16|0;fb=f;g=D(b,872)+a|0;o=g;m=g+1075800|0;j=y[m|0];k=a+1074312|0;Kb(f+8|0,k,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[g+1075780|0])){v[m|0]=h;break i}e=y[m|0];if(e){g=e-1|0;v[m|0]=g;e=0;if(g&255){break c}}v[m|0]=h;e=1;break c}Kb(f+8|0,k,52);g=c&256;if(!(!g|!Hb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){j=ZZ(y[e+1075780|0])?1:j}i=D(b,872)+a|0;if(y[i+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>j>>>0){break c}if(!g){break d}if(Tc(y[i+1075780|0])){break c}break d}i=x[a+480180>>2];if(i&16777250){e=!(j?(j>>>0)%((h>>>0<=1?1:h)>>>0)|0:1);j=j+1|0;break c}if((i|0)==16){break g}if((i|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Tc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h>>>0<=1?1:h;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);j=j+1|0;break k}e=0;j=i&1048580?0:j}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(j&255)>>>0<h>>>0)){e=1}Kb(f+8|0,k,52);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>j>>>0){break c}}j=0;e=1}h=o+1074992|0;q=(D(b,872)+a|0)+1075068|0;l:{if(x[q>>2]){break l}Kb(f+8|0,k,38);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!Jj(x[h+656>>2])){break a}}Kb(f+8|0,k,106);i=D(b,872)+a|0;if(C=0,E=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),F=x[i+1075688>>2],F?C:E){break a}if(e){r=i+1075680|0;g=x[r>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[i+1075080>>2];break m}Kb(f+8|0,k,52);n:{if(C=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),E=0,F=y[(D(b,872)+a|0)+1075782|0]==1,F?C:E){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+32128|0])|0)/16;break n}x[f+4>>2]=g+(v[e+32144|0]<<2)}Fe(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}l=D(b,872)+a|0;s=l+1075692|0;t=x[s>>2];g=y[l+1075794|0];i=0;if(e&512){Kb(f+8|0,k,108);i=Hb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((i^-1)&x[a+480180>>2]==2|(!x[q>>2]|(g-1&255)>>>0>119))){VS(a,b,0,g,1)}o:{if(!(x[a+480180>>2]&1048580)){o=0;break o}o=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}o=1;Qo(a,h,e,0,0,1)}l=l+1075080|0;Kb(f+8|0,k,85);p:{if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=D(b,872)+a|0;n=y[e+1075781|0];if(!n){break p}e=e+1075764|0;p=z[e>>1];Qo(a,h,n,0,0,1);w[e>>1]=p}n=D(b,872)+a|0;p=n+1075652|0;u=x[p>>2];B=x[l>>2];x[p>>2]=0;Kb(f+8|0,k,23);e=1;q:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break q}e=0;if(x[a+480180>>2]!=2){break q}e=(i^1)&x[q>>2]!=0}Ru(a,h,g,e,o,0,b);if(!y[n+1075781|0]){x[p>>2]=u}if(!(!(B&4096)|x[a+480180>>2]!=4)){x[l>>2]=x[l>>2]|4096}i=n+1075780|0;x[r>>2]=x[f+4>>2];if(z[a+480192>>1]){v[i|0]=g;TS(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[i|0]|!t))){x[s>>2]=t}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;r:{if(d-11>>>0<4294967286){break r}g=D(b,872)+a|0;i=x[g+1075096>>2];if(!i){break r}s:{if((d|0)==1){b=x[g+1075656>>2];break s}g=(D(b,872)+a|0)+1075656|0;b=x[yb(i+68|0,d-2|0)>>2];x[g>>2]=b}Po(a,h,b)}j=e?j:0}a=f+8|0;Kb(a,k,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Kb(a,k,23);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}j=(Hb(b,d)&c>>>8)+j|0}v[m|0]=j}fb=f+16|0}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=fb-48|0;fb=g;xc(b);o=Zd(b);a:{if((o-5&255)>>>0<253){break a}if(!Mb(x[b>>2],x[b+8>>2],4355)){break a}i=1;while(1){if((i&65535)>>>0<=256){l=g+32|0;fE(b,l);if(!HV(l,o)){break a}d=e;e=0;f=fb-32|0;fb=f;m=y[l+11|0];j=y[l+9|0]|y[l+10|0]<<8;v[f+14|0]=0;v[f+18|0]=m;w[f+16>>1]=j;w[f+12>>1]=0;while(1){if((e|0)!=3){j=y[xb(f+16|0,e)|0];p=xb(f+12|0,e),q=j,v[p|0]=q;e=e+1|0;continue}break}n=eg(f+12|0);m=y[l+8|0];j=y[l+6|0]|y[l+7|0]<<8;e=0;v[f+10|0]=0;v[f+26|0]=m;w[f+24>>1]=j;w[f+8>>1]=0;while(1){if((e|0)!=3){j=y[xb(f+24|0,e)|0];p=xb(f+8|0,e),q=j,v[p|0]=q;e=e+1|0;continue}break}e=eg(f+8|0);fb=f+32|0;e=e>>>0<n>>>0?i:d;i=i+1|0;continue}break}if(!(e&65535)){break a}b:{if(!c){break b}Bd(a,1);w[a+480190>>1]=e;x[a+480228>>2]=(o|0)==3?192:48;x[a+480208>>2]=x[a+480208>>2]&-25165825|16777216;cd(b,1);l=e+1|0;n=l&65535;i=1;while(1)if((i|0)==(n|0)){cd(b,4097);hk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);d=Zd(b);if(d>>>0>31){break a}w[a+480188>>1]=d+1;i=Zd(b);d=z[a+480188>>1];n=i+1|0;if(!Mb(x[b>>2],x[b+8>>2],D(D(d,n),384)+d|0)){break a}while(1)if(z[a+480188>>1]<=k>>>0){m=a+484344|0;Vf(m,n);j=c&1;k=0;while(1){c:{if((k|0)!=(n|0)){d:{if(j){if(Ng(m,k&65535,64)){break d}}Vb(b,D(z[a+480188>>1],384));break c}e=bh(g+32|0);d=Wb(x[m>>2],k);p=g,q=wb(x[d>>2]),x[p+16>>2]=q;i=wb(x[d+4>>2]);while(1){f=x[g+16>>2];if(!Ib(f,i)){break c}d=g+20|0;Z_(d,b);d=y[xb(d,0)|0];if((d-1&255)>>>0<=76){v[f|0]=d+36}d=g+20|0;p=f,q=y[xb(d,1)|0],v[p+1|0]=q;e:{if(!GV(f,y[xb(d,2)|0],y[xb(d,5)|0],o)){break e}if(!GV(e,y[xb(d,3)|0],y[xb(d,4)|0],o)){break e}d=y[g+35|0];if(d){Gn(g+14|0,f,y[f+3|0],y[f+5|0],d,y[g+37|0])}vg(g+16|0);continue}break}k=0;break a}f:{if(!(c&2)){break f}d=l&65535;i=1;while(1){if((d|0)==(i|0)){break f}c=D(i,104)+a|0;fg(Xc(g+32|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);i=i+1|0;continue}}bi(a+1298344|0,14170);bi(a+1298356|0,11136);tf(a+1298368|0);p=a+1298404|0,q=x[Fc(g+32|0,4)>>2],x[p>>2]=q;break b}k=k+1|0;continue}}else{d=(k<<5)+a|0;Xe(d+480280|0);p=d+480284|0,q=D(Zd(b),17),w[p>>1]=q;k=k+1|0;continue}}else{fE(b,g+32|0);e=0;h=fb-16|0;fb=h;f=(D(i,104)+a|0)+484380|0;ld(f,1);j=y[g+43|0];d=y[g+41|0]|y[g+42|0]<<8;v[h+6|0]=0;v[h+10|0]=j;w[h+8>>1]=d;w[h+4>>1]=0;while(1){if((e|0)!=3){d=y[xb(h+8|0,e)|0];p=xb(h+4|0,e),q=d,v[p|0]=q;e=e+1|0;continue}break}m=eg(h+4|0);j=y[g+40|0];d=y[g+38|0]|y[g+39|0]<<8;e=0;v[h+2|0]=0;v[h+10|0]=j;w[h+8>>1]=d;w[h>>1]=0;while(1){if((e|0)!=3){d=y[xb(h+8|0,e)|0];p=xb(h,e),q=d,v[p|0]=q;e=e+1|0;continue}break}p=f,q=m-eg(h)|0,x[p>>2]=q;j=y[g+34|0];d=y[g+32|0]|y[g+33|0]<<8;e=0;v[h+6|0]=0;v[h+10|0]=j;w[h+8>>1]=d;w[h+4>>1]=0;while(1){if((e|0)!=3){d=y[xb(h+8|0,e)|0];p=xb(h+4|0,e),q=d,v[p|0]=q;e=e+1|0;continue}break}p=f,q=eg(h+4|0)+1|0,x[p+4>>2]=q;j=y[g+37|0];d=y[g+35|0]|y[g+36|0]<<8;e=0;v[h+6|0]=0;v[h+10|0]=j;w[h+8>>1]=d;w[h+4>>1]=0;while(1){if((e|0)!=3){d=y[xb(h+8|0,e)|0];p=xb(h+4|0,e),q=d,v[p|0]=q;e=e+1|0;continue}break}p=f,q=eg(h+4|0)+1|0,x[p+8>>2]=q;e=y[g+45|0];d=e>>>2|0;d=z[f+34>>1]&-7|d&2|d&4;w[f+34>>1]=d;if(e&4){w[f+34>>1]=d|1;x[f>>2]=x[f>>2]>>>1}w[f+30>>1]=y[g+44|0];if((o|0)!=2){x[f+24>>2]=y[g+46|0]|y[g+47|0]<<8}FV(f);fb=h+16|0;d=Dc(g+20|0,22267);zc(((i<<5)+a|0)+946304|0,d);tb(d);i=i+1|0;continue}}k=1}fb=g+48|0;return k|0}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-96|0;fb=e;h=e+76|0;i=a+140|0;ak(h,i,1296125513);x[31725]=0;f=R(174,x[e+76>>2])|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((g|0)!=1){if(f){f=Fb(e+28|0);x[31725]=0;g=R(156,x[e+76>>2])|0;j=x[31725];x[31725]=0;if((j|0)==1){break p}x[31725]=0;S(817,h|0,f|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break p}g=z[a+174>>1];x[31725]=0;h=e- -64|0;S(818,h|0,g|0,f|0);g=x[31725];x[31725]=0;if((g|0)==1){break o}x[31725]=0;g=e+4|0;S(819,g|0,c|0,h|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}zc(d,g);tb(g);tb(h);tb(f)}if(y[a+176|0]){x[31725]=0;c=e+28|0;O(820,c|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}ze(b+43|0,c);tb(c)}x[31725]=0;c=e+28|0;S(812,c|0,i|0,1413894985);f=x[31725];x[31725]=0;if((f|0)==1){break l}x[31725]=0;h=R(821,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}ub(c);f=a+40|0;xc(f);x[31725]=0;c=P(822,f|0,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break j}if(c){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31725]=0;c=e+4|0;g=P(823,f|0,c|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break i}if(!g){break q}KR(c,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,h)}x[31725]=0;c=e+4|0;f=P(823,f|0,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}if(f){KR(c,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,h)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;$k(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31725]=0;c=P(680,c|0,7)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);x[31725]=0;c=P(824,c|0,e+4|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31725]=0;c=R(174,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}if(!c){break f}x[31725]=0;g=a+120|0;c=R(153,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[e+64>>2]=c;wc(e- -64|0,9);f=b+68|0;h=x[e+64>>2];c=0;while(1){if((c|0)==(h|0)){break g}x[31725]=0;O(825,g|0,e+4|0);i=x[31725];x[31725]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);k=yb(f,c),l=i,x[k>>2]=l;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Yz(f+(h<<2)|0,RZ(f),41140)}c=a+80|0;xc(c);x[31725]=0;f=P(826,c|0,e+4|0)|0;h=x[31725];x[31725]=0;s:{if((h|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+28>>1]=l;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+30>>1]=l;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+32>>1]=l;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31725]=0;a=U(152,a|0,f|0,32)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}if(!a){break b}x[31725]=0;O(827,c|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break s}x[31725]=0;a=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break s}x[31725]=0;S(828,c|0,b+43|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function fua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-128|0;fb=f;xc(b);a:{d=f- -64|0;if(!Fr(b,d)){break a}if(!p$(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],o$(d))){break a}if(!c){j=1;break a}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]|16777216;w[a+480188>>1]=y[f+109|0];w[a+480190>>1]=y[f+110|0];n=a,o=Bc((((y[f+113|0]<<8|48)&65328)>>>0)/100|0,0),x[n+480200>>2]=o;e=f+52|0;vi(e,3,f+69|0);d=f+16|0;Cc(d,e);Ab(a+1298308|0,d);tb(d);vi(e,3,f+89|0);Lr(d,4,e);Ab(a+1298320|0,d);tb(d);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=a+484376|0;hk(Xb(x[a+484360>>2],y[d|0]),b,y[f+111|0],65535,65535);w[f+50>>1]=0;d=Xb(x[a+484360>>2],y[d|0]);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;d=wb(x[d+4>>2]);while(1){e=x[f+16>>2];if(Ib(e,d)){w[f+52>>1]=z[e>>1];n=f,o=z[qe(f+52|0,f+50|0)>>1],w[n+50>>1]=o;Md(f+16|0);continue}else{d=z[f+50>>1]+1|0;w[f+50>>1]=d;j=Mb(x[b>>2],x[b+8>>2],D(D(z[a+480188>>1],d&65535),264)+(z[a+480190>>1]<<5)|0);if(!j){break a}d=0;while(1){e=z[a+480188>>1];if(e>>>0<=d>>>0){Vb(b,D(e,z[f+50>>1]-1|0)<<3);d=1;while(1){i=d&65535;if(i>>>0>z[a+480190>>1]){k=a+484344|0;Vf(k,z[f+50>>1]);l=c&1;g=0;while(1){b:{c:{if(z[f+50>>1]<=g>>>0){if(!(c&2)){break c}d=1;while(1){c=d&65535;if(c>>>0>A[a+480228>>2]){break c}c=D(c,104)+a|0;fg(Xc(f+16|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);d=d+1|0;continue}}d:{if(l){if(Ng(k,g&65535,64)){break d}}Vb(b,z[a+480188>>1]<<8);break b}d=Wb(x[k>>2],g);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;m=wb(x[d+4>>2]);while(1){d=x[f+16>>2];if(!Ib(d,m)){break b}e=f+52|0;sm(e,b);e:{if(!y[xb(e,1)|0]){break e}if(y[xb(e,1)|0]>168){break e}n=d,o=(y[xb(e,1)|0]>>>1|0)+36|0,v[n|0]=o}h=f+52|0;n=d,o=y[xb(h,0)|0],v[n+1|0]=o;e=y[xb(h,3)|0];v[d+5|0]=e;f:{if(y[xb(h,2)|0]==8){g:{switch(e>>>4|0){case 0:v[d+3|0]=19;v[d+5|0]=e|128;break f;case 1:v[d+3|0]=11;v[d+5|0]=e<<4;break f;case 2:v[d+3|0]=19;v[d+5|0]=e|160;break f;case 3:case 4:break g;default:break f}}v[d+3|0]=19;v[d+5|0]=e-32;break f}if(y[xb(f+52|0,2)|0]==19){v[d+3|0]=9;i=e<<1&254;h=i+128|0;h:{if(e>>>0<=64){break h}h=384-i|0;if(e<<24>>24>=0){break h}h=128-i|0;if(e>>>0<=191){break h}h=i-128|0}n=d,o=yi(h),v[n+5|0]=o;break f}if((y[xb(f+52|0,2)|0]&240)==32){v[d+2|0]=1;v[d+3|0]=10;n=d,o=(y[xb(f+52|0,2)|0]<<2&60)+4|0,v[n+4|0]=o;break f}i:{if(y[xb(f+52|0,2)|0]<16){break i}if(y[xb(f+52|0,2)|0]==17){break i}if(y[xb(f+52|0,2)|0]!=18){break f}}e=d;d=f+52|0;Bf(e,y[xb(d,2)|0]&15,y[xb(d,3)|0])}vg(f+16|0);continue}}b=f+16|0;c=tc(b,9510);Ab(a+1298344|0,c);tb(c);c=tc(b,10141);Ab(a+1298356|0,c);tb(c);n=a+1298404|0,o=x[Fc(b,4)>>2],x[n>>2]=o;break a}g=g+1|0;continue}}else{e=f+16|0;Er(b,e);h=fb-16|0;fb=h;v[h+15|0]=64;g=(D(i,104)+a|0)+484380|0;n=g,o=y[Rb(e+26|0,h+15|0)|0]<<2,w[n+30>>1]=o;v[g+37|0]=y[e+25|0]<<4;x[g>>2]=y[e+23|0]|y[e+24|0]<<8;x[g+4>>2]=y[e+27|0]|y[e+28|0]<<8;x[g+8>>2]=(y[e+29|0]|y[e+30|0]<<8)+(y[e+27|0]|y[e+28|0]<<8);w[g+34>>1]=z[g+34>>1]&65532|((y[e+29|0]|y[e+30|0]<<8)>>>0>2)<<1|y[e+22|0]==16;fb=h+16|0;g=f+4|0;Yk(g,3,e);e=f+52|0;Cc(e,g);zc(((i<<5)+a|0)+946304|0,e);d=d+1|0;tb(e);continue}}}else{e=f+4|0;n$(e,b);g=f+52|0;tF(g,e);e=f+16|0;Cc(e,g);om(((d<<5)+a|0)+480289|0,e);d=d+1|0;tb(e);continue}}}}}else{e=(d<<5)+a|0;Xe(e+480280|0);n=e+480284|0,o=D(Zd(b)&15,17),w[n>>1]=o;d=d+1|0;continue}}fb=f+128|0;return j|0}function qpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-176|0;fb=f;xc(b);d=f+128|0;a:{if(!OD(b,d)){break a}if(!$W(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(_W(y[f+159|0],y[f+161|0]),hb))){break a}b:{if(!c){break b}Bd(a,256);g=f+16|0;vi(g,2,d);d=f+48|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);e=tc(d,15337);Ab(a+1298344|0,e);tb(e);e=tc(d,10120);Ab(a+1298356|0,e);tb(e);ig(g,4271);x[31725]=0;e=f+116|0;O(251,e|0,f+159|0);h=x[31725];x[31725]=0;c:{d:{if((h|0)!=1){x[31725]=0;V(702,d|0,g|0,f+158|0,e|0);h=x[31725];x[31725]=0;if((h|0)!=1){Ab(a+1298368|0,d);tb(d);tb(e);Eb(g);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);e=y[f+160|0];d=y[f+159|0];if(d>>>0<=20){g=((e&255)>>>0)/10|0;e=g<<4|D(g,-10)+e}g=(e&255?e:96)&255;e=xC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=e;if(d>>>0>=11){v[f+48|0]=64;o=a,q=y[Rb(f+162|0,f+48|0)|0]<<2,x[o+480200>>2]=q}e=0;while(1)if((e|0)==4){e=1;while(1){if((e|0)!=32){d=f+16|0;Er(b,d);g=y[f+28|0];if(g?(g|0)!=46:0){break c}h=fb-32|0;fb=h;g=(D(e,104)+a|0)+484380|0;ld(g,0);j=h+8|0;Qk(j,2,d);i=h+20|0;Cc(i,j);ze(g+43|0,i);tb(i);x[g+24>>2]=y[d+24|0]|y[d+25|0]<<8;v[h+20|0]=y[d+22|0];v[h+8|0]=64;o=g,q=y[Rb(i,j)|0]<<2,w[o+30>>1]=q;i=y[d+16|0]|y[d+17|0]<<8;x[g>>2]=i;j=y[d+18|0]|y[d+19|0]<<8;x[g+4>>2]=j;k=y[d+20|0]|y[d+21|0]<<8;x[g+8>>2]=k;e:{if(i>>>0<=1){x[g>>2]=0;break e}if((k|0)==65535|i>>>0<=j>>>0|j>>>0>=k>>>0){break e}w[g+34>>1]=2;o=g,q=x[Gb(g+8|0,g)>>2],x[o+8>>2]=q}fb=h+32|0;g=f+4|0;Qk(g,2,d);d=f+116|0;Cc(d,g);zc(((e<<5)+a|0)+946304|0,d);tb(d);w[((e<<1)+f|0)+46>>1]=y[f+30|0]|y[f+31|0]<<8;e=e+1|0;continue}break}d=a+484376|0;hk(Xb(x[a+484360>>2],y[d|0]),b,y[f+159|0]?128:64,65535,65535);e=0;if(!YW(Xb(x[a+484360>>2],y[d|0]))){break a}m=c&1;if(m){Vf(a+484344|0,y[f+161|0])}j=a+484344|0;h=0;while(1)if(y[f+161|0]<=h>>>0){e=1;if(!(c&2)){break a}c=Xc(f+16|0,8,1,0,0);while(1){if((e|0)==32){break b}d=D(e,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((e<<1)+f|0)+46>>1];if(d>>>0<4){break f}if(!cd(b,d<<4)){break f}fg(c,g,b)}e=e+1|0;continue}}else{g:{h:{if(m){if(Ng(j,h&65535,64)){break h}}e=0;while(1){if((e|0)==256){break g}if((Zd(b)+2&255)>>>0<=252){Vb(b,3)}e=e+1|0;continue}}o=f,q=wb(x[Wb(x[j>>2],h)>>2]),x[o+116>>2]=q;w[f+2>>1]=65535;x[f+4>>2]=63;i=0;i:while(1){e=0;if((i|0)==64){d=z[f+2>>1];if((d|0)==65535){break g}ye(Wb(x[j>>2],h),Fn(Ye(Ne(f+16|0,12,d&255),x[f+4>>2])));break g}while(1){j:{k:{l:{if((e&65535)>>>0<=3){d=0;k=0;l=0;n=0;m:{n:{o:{p:{g=Zd(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[f+116>>2]]=254;break j}d=f+16|0;Wr(d,b);k=y[xb(d,0)|0];l=y[xb(d,1)|0];n=y[xb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[f+116>>2];v[d|0]=g;break k}i=i+1|0;continue i}d=x[f+116>>2]}v[d+1|0]=(k&248)>>>3;g=l>>>1&120|k&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;XW(d,l&15,i,y[f+159|0],f+2|0,f+4|0)}e=e+1|0;JC(f+116|0);continue}}}h=h+1|0;continue}}else{d=(e<<5)+a|0;Xe(d+480280|0);w[d+480284>>1]=e&1?64:192;e=e+1|0;continue}}e=N()|0;tb(f+116|0);break d}e=N()|0}Eb(f+16|0);Q(e|0);p()}e=0;break a}e=1}fb=f+176|0;return e|0}function fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=fb-32|0;fb=l;t=x[a+4>>2];k=Ve(x[a+8>>2],b);u=x[k>>2];a:{if(u+1>>>0<2){break a}h=D(b,872)+t|0;i=h+616|0;if(!(Ti(x[i+8>>2],x[i+12>>2])|y[k+4|0])|!x[h+720>>2]){break a}o=x[h+704>>2]&2;e=x[(o?h+700|0:h+692|0)>>2];n=x[h+700>>2];f=x[h+696>>2];w=Ob(x[a>>2]+1074312|0,31);g=vf(x[h+624>>2],x[h+628>>2],c);p=y[h+704|0]&128;k=p?0-g|0:g;m=hb;m=p?0-(m+((g|0)!=0)|0)|0:m;g=0;p=e;e=o;o=e?g:0;s=e?f:0;n=n-f|0;B=n<<1;C=h+1316|0;q=h+1467|0;A=h+1362|0;F=(y[A|0]&17)!=1;b:{c:{while(1){if((r|0)!=(u|0)){d:{if(d>>>0>r>>>0){e=(y[A|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=r-d;v[q|0]=y[q|0]&254|(d|0)==(r|0);e=x[a>>2];j=x[a+4>>2];f=Wb(x[e+484344>>2],z[j+70>>1]);f=jd(x[f>>2],x[x[f+48>>2]+12>>2],x[j+48>>2],b);g=y[f+3|0];e:{f:{switch(y[f+2|0]-11|0){case 0:j=l+8|0;vB(j,e,g,y[f+4|0],0);j=af(j);Nu(x[a>>2],x[a+4>>2],b,z[l+8>>1]);e=1;if(!y[j|0]){break e}break d;case 1:qB(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12));break e;case 2:break f;default:break e}}pB(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12))}e=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}f=y[f+5|0];e=f&240;if((e|0)==32){break i}if((e|0)!=16){break g}oB(x[a>>2],i,f&15);break g;case 2:Nu(x[a>>2],x[a+4>>2],b,y[f+5|0]);break g;case 4:Nu(x[a>>2],x[a+4>>2],b,0);break g;case 0:f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}qB(g,x[a+4>>2],b,f,0);break g;case 1:break k;case 3:break d}}f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}pB(g,x[a+4>>2],b,f,0);break g}e=y[f+5|0];f=e&15;if(!(f|x[x[a>>2]+480180>>2]&1048580)){break g}e=e&240;if((e|0)!=32){if((e|0)!=16){break g}nB(x[a>>2],i,f);break g}mB(x[a>>2],i,f);break g}lB(x[a>>2],i,f&15);break g}oT(x[a>>2],i,y[f+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}e=1}x[l+28>>2]=x[C>>2];if(w){Mu(x[a>>2],i)}if(!F){nT(x[a>>2],i,l+28|0);e=1}if(!w){Mu(x[a>>2],i)}x[l+24>>2]=0;mT(i,l+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!e){if(!y[Ve(x[a+8>>2],b)+4|0]){break m}}if(y[q|0]&96){uV(i,E(1),0,x[a>>2]);k=y[q|0];v[q|0]=(k&64?-65:-33)&k}wB(l+8|0,x[a>>2],i,x[l+28>>2],0);k=x[l+12>>2];x[h+624>>2]=x[l+8>>2];x[h+628>>2]=k;H=Ve(x[a+8>>2],b),I=0,v[H+4|0]=I;f=vf(x[h+624>>2],x[h+628>>2],c);e=y[h+704|0]&128;k=e?0-f|0:f;g=hb;m=e?0-(g+((f|0)!=0)|0)|0:g}Pb(i,k,m);g=x[i>>2];e=x[i+4>>2];if((g>>>0<G>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(s|0)&g>>>0>=o>>>0|(e|0)>(s|0)|((m|0)>0|(m|0)>=0))){break l}j=x[h+704>>2];if(!(j&2)){break c}if(j&4){f=x[h+696>>2];if(g>>>0<o>>>0&(e|0)<=(s|0)|(e|0)<(s|0)){H=i,I=ih(0,f<<1,g,e),x[H>>2]=I;e=hb;x[i+4>>2]=e;x[h+704>>2]=j^128;g=k;k=0-g|0;m=0-(((g|0)!=0)+m|0)|0}f=(e-f>>>0)%(B-Ob(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(f>>>0<n>>>0){e=f+x[h+696>>2]|0;break n}e=x[h+700>>2]+(n-f|0)|0}x[i+4>>2]=e;e=x[h+704>>2];if((e&128)>>>7^f>>>0<n>>>0){break l}x[h+704>>2]=e^128;f=k;k=0-f|0;m=0-(((f|0)!=0)+m|0)|0;break l}j=x[h+700>>2];if(j+n>>>0<=e>>>0){e=j+((e-j>>>0)%(n>>>0)|0)|0}while(1){f=e;e=f-n|0;if(f>>>0>=j>>>0){continue}break}x[i>>2]=g;x[i+4>>2]=f}r=r+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;wV(i);x[(D(b,872)+t|0)+1324>>2]=0}H=Ve(x[a+8>>2],b),I=0,x[H>>2]=I}fb=l+32|0}function cQ(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=fb-16|0;fb=j;b=a+4208|0;i=Ik(E(B[yb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[yb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=De(E(10),E(E(bQ(a)+E(E(B[yb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Ym(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=De(E(10),E(E(E(E(B[yb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=Bq(E(E(aQ(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=BB(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[yb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[yb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Wz(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[yb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Ym(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=De(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){eQ((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+45408>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=Qh(a,5);e=Qh(a,11);c=E(d*Qh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Qh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Qh(a,3);l=Qh(a,9);g=E(c*g);c=E(g*Qh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Qh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Qh(a,12);g=B[a+4496>>2];l=Qh(a,1);m=Qh(a,7);q=Qh(a,0);r=Qh(a,6);t=b,u=De(E(10),E(E(bQ(a)+E(E(B[yb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Ym(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));fb=b+16|0;v[a+5046|0]=0;fb=j+16|0}function gH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-32|0;fb=g;d=x[b+28>>2];x[g+24>>2]=x[b+24>>2];x[g+28>>2]=d;d=x[b+20>>2];x[g+16>>2]=x[b+16>>2];x[g+20>>2]=d;d=x[b+12>>2];x[g+8>>2]=x[b+8>>2];x[g+12>>2]=d;d=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=d;d=fb-144|0;fb=d;k=Fb(d+132|0);n=Fb(d+120|0);x[31725]=0;b=P(1,d+108|0,c|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=Ab(n,b);tb(b);if(!x[g>>2]){break b}x[31725]=0;b=d+96|0;O(75,b|0,g|0);e=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){x[31725]=0;i=P(76,k|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}tb(b);x[31725]=0;e=P(1,d+84|0,16809)|0;f=x[31725];x[31725]=0;if((f|0)==1){break p}x[31725]=0;f=d+72|0;O(77,f|0,g+4|0);h=x[31725];x[31725]=0;if((h|0)==1){break o}x[31725]=0;S(2,b|0,e|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break n}x[31725]=0;i=P(76,i|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}tb(b);tb(f);tb(e);x[31725]=0;e=P(1,f|0,16809)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}x[31725]=0;f=d+60|0;O(77,f|0,g+8|0);h=x[31725];x[31725]=0;if((h|0)==1){break i}x[31725]=0;S(2,b|0,e|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break h}x[31725]=0;i=P(76,i|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break g}tb(b);tb(f);tb(e);e=x[g+28>>2];o=e;b=x[g+24>>2];if(x[g+12>>2]|(x[g+16>>2]|!(e|b))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(e);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(e);break c}x[31725]=0;e=P(1,d+96|0,13717)|0;f=x[31725];x[31725]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)!=1){x[31725]=0;l=P(76,i|0,e|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break J}tb(e);x[31725]=0;f=d+36|0;O(78,f|0,g+12|0);e=x[31725];x[31725]=0;if((e|0)==1){break I}x[31725]=0;e=P(1,d+24|0,14629)|0;i=x[31725];x[31725]=0;if((i|0)==1){break H}x[31725]=0;i=d+48|0;S(2,i|0,f|0,e|0);h=x[31725];x[31725]=0;if((h|0)==1){break G}x[31725]=0;h=d+12|0;O(78,h|0,g+16|0);j=x[31725];x[31725]=0;if((j|0)==1){break F}x[31725]=0;j=d+60|0;S(2,j|0,i|0,h|0);m=x[31725];x[31725]=0;if((m|0)==1){break E}x[31725]=0;l=P(76,l|0,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break D}tb(j);tb(h);tb(i);tb(e);tb(f);if(b|o){break y}x[31725]=0;S(79,a|0,l|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31725]=0;b=P(1,d+48|0,14629)|0;e=x[31725];x[31725]=0;if((e|0)==1){break w}x[31725]=0;e=d+36|0;O(80,e|0,g+24|0);f=x[31725];x[31725]=0;if((f|0)==1){break v}x[31725]=0;f=d+60|0;S(2,f|0,b|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break u}x[31725]=0;i=P(76,l|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break t}tb(f);tb(e);tb(b);x[31725]=0;P(76,i|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(n);tb(k);Q(a|0);p()}_c(a,k)}tb(c);tb(k);fb=d+144|0;fb=g+32|0}function Pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-240|0;fb=e;v[e+239|0]=c;g=x[b+4>>2];a:{if(!g){f=x[b>>2];break a}f=x[b>>2];h=y[Hl(f,g)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tl(e+80|0,f,g,g-1|0);g=x[e+84>>2];f=x[e+80>>2];x[b>>2]=f;x[b+4>>2]=g}h=e+80|0;ge(h);i=x[e+80>>2];j=e+216|0;ge(j);i=Gl(i,x[e+220>>2],b);ge(h);b:{c:{d:{e:{f:{g:{h:{if(x[e+84>>2]==(i|0)){a=qc(e+228|0,22267);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Ic(f,g,e)){g=ac(8);x[31725]=0;O(1010,j|0,e+239|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[31725]=0;S(1017,h|0,18246,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(g,h);f=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(h);break e}if(!d){break h}g=ac(8);a=x[b>>2];b=x[b+4>>2];x[31725]=0;a=fi(e+192|0,a,b);b=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31725]=0;b=e+204|0;S(1017,b|0,18282,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break p}x[31725]=0;f=e+216|0;O(1019,f|0,b|0);b=x[31725];x[31725]=0;c=1;if((b|0)==1){break o}x[31725]=0;b=e+180|0;O(1010,b|0,e+239|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}x[31725]=0;d=e+80|0;S(1021,d|0,f|0,b|0);b=x[31725];x[31725]=0;c=1;if((b|0)==1){break m}pc(g,d);x[31725]=0;S(99,g|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(d);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;c=1;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=qc(e+172|0,22267);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Ic(f,g,e+72|0)){g=ac(8);x[31725]=0;b=e+216|0;O(1010,b|0,e+239|0);a=x[31725];x[31725]=0;q:{r:{if((a|0)!=1){x[31725]=0;a=e+80|0;S(1017,a|0,18246,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break r}pc(g,a);f=0;x[31725]=0;S(99,g|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(a);break q}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(f){break d}break c}b=qc(e+164|0,7462);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Ic(f,g,e- -64|0)){b=qc(e+156|0,7444);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Ic(f,g,e+56|0)){break s}}v[a+60|0]=c;break h}b=qc(e+148|0,6989);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Ic(f,g,e+48|0)){b=qc(e+140|0,6970);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Ic(f,g,e+40|0)){break t}}v[a+61|0]=c;break h}b=qc(e+132|0,7073);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(f,g,e+32|0)){v[a+62|0]=c;break h}b=qc(e+124|0,6064);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(f,g,e+24|0)){v[a+63|0]=c;break h}b=qc(e+116|0,7511);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Ic(f,g,e+16|0)){v[a+64|0]=c;break h}b=qc(e+108|0,13509);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Ic(f,g,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=dN(x[a+56>>2])}else{a=0}x[e+100>>2]=a;a=e+80|0;if(!yz(a,b+24648|0)){break h}KA(b,a)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(!f){break c}}jc(g)}Q(b|0)}p()}function vH(){var a=0,b=0,c=0,d=0;if(y[500384]){return x[125095]}b=xd(502024,1);x[b>>2]=111976;c=DJ(b+8|0);x[31725]=0;d=P(36,b+152|0,14276)|0;a=x[31725];x[31725]=0;a:{b:{c:{if((a|0)!=1){Nf(c);yJ(501696,1);x[31725]=0;W(1258,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xJ(501704,1);x[31725]=0;W(1259,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}wJ(501712,1);x[31725]=0;W(1260,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}vJ(501728,1);x[31725]=0;W(1261,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501736,1);x[125434]=113924;x[31725]=0;W(1262,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1263);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1264,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501760,1);x[125440]=114072;x[31725]=0;W(1265,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501768,1);x[125442]=114304;x[31725]=0;W(1266,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501776,1);x[125444]=114188;x[31725]=0;W(1267,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501784,1);x[125446]=114420;x[31725]=0;W(1268,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}uJ(501792,1);x[31725]=0;W(1269,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}tJ(501816,1);x[31725]=0;W(1270,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501848,1);x[125462]=115140;x[31725]=0;W(1271,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501856,1);x[125464]=115384;x[31725]=0;W(1272,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501864,1);x[125466]=115596;x[31725]=0;W(1273,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501872,1);x[125468]=115828;x[31725]=0;W(1274,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}sJ(501880,1);x[31725]=0;W(1275,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}rJ(501888,1);x[31725]=0;W(1276,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}qJ(501896,1);x[31725]=0;W(1277,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}pJ(501904,1);x[31725]=0;W(1278,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501912,1);x[125478]=118520;x[31725]=0;W(1279,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501920,1);x[125480]=118684;x[31725]=0;W(1280,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501928,1);x[125482]=118848;x[31725]=0;W(1281,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501936,1);x[125484]=119012;x[31725]=0;W(1282,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}oJ(501944,1);x[31725]=0;W(1283,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}nJ(501960,1);x[31725]=0;W(1284,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1285);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1286,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1287);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1288,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}mJ(502008,1);x[31725]=0;W(1289,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}lJ(502016,1);x[31725]=0;W(1290,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}cy(c);Q(b|0);p()}x[125094]=502024;v[500384]=1;x[125095]=500376;return 500376}function BS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0,A=0,B=0,D=0;if(b){j=a+327720|0;c=fb-352|0;fb=c;m=c+340|0;GU(m,8);x[31725]=0;n=c+328|0;la(798,n|0,9);k=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((k|0)!=1){x[31725]=0;k=P(799,c+312|0,14)|0;f=x[31725];x[31725]=0;if((f|0)==1){break l}x[31725]=0;O(800,m|0,k|0);f=x[31725];x[31725]=0;if((f|0)==1){break k}x[31725]=0;O(800,n|0,k|0);f=x[31725];x[31725]=0;if((f|0)==1){break k}g=c+240|0;EU(g,4900);l=c+168|0;EU(l,32e3);s=c+96|0;xU(s,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31725]=0;i=P(801,c+72|0,m|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}f=c+84|0;av(f,g,i);Ae(i);x[31725]=0;g=P(801,c+48|0,n|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break i}i=c+60|0;av(i,l,g);Ae(g);x[31725]=0;g=P(801,c+24|0,f|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}l=c+36|0;av(l,s,g);Ae(g);x[31725]=0;g=P(801,c|0,i|0)|0;o=x[31725];x[31725]=0;if((o|0)==1){break g}o=c+12|0;av(o,s,g);Ae(g);Tq(f);Tq(l);Tq(i);Tq(o);Tq(n);Sq(x[c+84>>2],x[c+88>>2],So(j,0));Sq(x[c+36>>2],x[c+40>>2],So(j,1));Sq(x[c+60>>2],x[c+64>>2],So(j,2));Sq(x[c+12>>2],x[c+16>>2],So(j,3));Sq(x[c+328>>2],x[c+332>>2],So(j,4));Ae(o);Ae(l);Ae(i);Ae(f);qn(k);Ae(n);Ae(m);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Ae(c+36|0)}Ae(c+60|0)}Ae(c+84|0)}qn(k)}Ae(c+328|0)}Ae(c+340|0);Q(a|0);p()}AA(a+131112|0,9.6377,.97);AA(a+196648|0,8.5,.5);AA(a+262184|0,7,.425)}c=a+368680|0;if(!(A=0,B=NR(c,a),D=b,D?A:B)){k=a+24|0;v=C[a+8>>3];m=y[a+16|0];j=fb+-64|0;fb=j;m:while(1){if((r|0)!=8193){z=+(r-4096|0)*.0001220703125;b=0;t=0;while(1)if((b|0)==8){d=1/t;f=r<<3;b=0;while(1)if((b|0)==8){r=r+1|0;continue m}else{i=k+(b+f<<1)|0;h=J(C[j+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){g=~~h;break n}g=-2147483648}w[i>>1]=g;b=b+1|0;continue}}else{h=v;e=1;d=+(b|0)-z;u=d+-3.5;if(!(F(u)<1e-8)){o:{p:{switch(m|0){case 0:e=kf(d*.8975979010256552)*-.5+.5;break o;case 1:e=kf(d*.8975979010256552)*-.46+.54;break o;case 2:e=kf(d*1.7951958020513104)*.08+(kf(d*.8975979010256552)*-.5+.42);break o;case 3:e=kf(d*1.7951958020513104)*.05677+(kf(d*.8975979010256552)*-.49364+.44959);break o;case 4:e=kf(d*1.7951958020513104)*.07922+(kf(d*.8975979010256552)*-.49755+.42323);break o;case 5:e=kf(d*1.7951958020513104);q=kf(d*.8975979010256552);e=kf(d*2.6927937030769655)*-.01168+(e*.14128+(q*-.48829+.35875));break o;case 6:e=kf(d*1.7951958020513104);q=kf(d*.8975979010256552);e=kf(d*2.6927937030769655)*-.00183+(e*.09392+(q*-.49703+.40217));break o;case 7:break p;default:break o}}e=kf(d*1.7951958020513104);q=kf(d*.8975979010256552);e=kf(d*2.6927937030769655)*-.00122+(e*.09831+(q*-.49804+.40243))}d=u*3.141592653589793;h=Wi(d*h)/d}h=e*h;C[j+(b<<3)>>3]=h;t=t+h;b=b+1|0;continue}}break}fb=j- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function nM(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(Rt(c)){h=x[b+484344>>2];if(He(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}c=Wb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Tc(d)){if(!Nl(d)){break k}}e=g+24|0;dS(e,b,d,y[c+1|0]);x[31725]=0;O(1065,g+36|0,e|0);b=x[31725];x[31725]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[31725]=0;P(36,g+36|0,16775)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}}b=9968;c=y[c|0];if(!Tc(c)){b=Nl(c)?10278:16775}x[31725]=0;b=P(36,g+12|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Fv(g+36|0,b);break l}Dc(g+36|0,16780)}b=y[b|0];x[31725]=0;b=P(36,g+24|0,(b?10801:16780)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Vg(y[c|0])){Dc(g+36|0,18429);break m}d=y[c+2|0];if(d){rf(g+36|0,1,DR(x[x[b+8>>2]+88>>2],d));break m}Dc(g+36|0,18429)}b=18429;if(!Vg(y[c|0])){b=y[c+2|0]?5505:18429}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Vg(y[c|0])){i=g,j=Kj(y[c+2|0],y[c+4|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break n}if(y[c+2|0]){Fv(g+36|0,c+4|0);break n}Dc(g+36|0,16780)}b=5489;if(!Vg(y[c|0])){b=y[c+2|0]?5489:16780}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Vg(y[c|0])){i=g,j=(Kj(y[c+3|0],y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31725]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;d=b+4|0;S(1167,g+36|0,g+12|0,d|0);e=x[31725];x[31725]=0;p:{if((e|0)!=1){Hh(d);fb=b+32|0;break p}a=N()|0;Hh(b+4|0);Q(a|0);p()}break o}d=y[c+3|0];if(d){rf(g+36|0,1,CR(x[x[b+8>>2]+84>>2],d));break o}Dc(g+36|0,16781)}b=12375;if(!Vg(y[c|0])){b=y[c+3|0]?12375:16781}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}q:{if(Vg(y[c|0])){i=g,j=Kj(y[c+3|0],y[c+5|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break q}if(y[c+3|0]){Fv(g+36|0,c+5|0);break q}Dc(g+36|0,16780)}b=11162;if(!Vg(y[c|0])){b=y[c+3|0]?11162:16780}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a)}fb=g+48|0}function csa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-192|0;fb=g;l=g+80|0;$d(l,b);i=x[g+88>>2];m=x[g+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Nk(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(Kn(14123)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;Tx(h+8|0,h+28|0);Rm(h+20|0,b,x[h+8>>2],x[h+12>>2]);Qm(e+24|0,x[h+28>>2]);fb=h+32|0;h=-1;f=x[e+24>>2];if(f-3>>>0<4294967294){break c}d:{e:{f:{if(f>>>0<=1){f=Fb(e+12|0);x[31725]=0;j=U(497,b|0,f|0,256)|0;k=x[31725];x[31725]=0;if((k|0)==1){break b}if(!j){break e}x[31725]=0;S(498,e|0,d|0,f|0);j=x[31725];x[31725]=0;if((j|0)!=1){break f}break b}f=Fb(e+12|0);x[31725]=0;j=P(500,b|0,f|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break b}if(!j){break d}x[31725]=0;S(498,e|0,d|0,f|0);j=x[31725];x[31725]=0;if((j|0)==1){break b}}Ab(c,e);tb(e);tb(f);pg(b,e);f=0;x[e+12>>2]=0;Nk(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((f|0)==(j|0)){break g}f=f+1|0;if($Q(a,b,d)){continue}break}break c}x[e+12>>2]=0;Nk(b,e+12|0);h=x[e+12>>2]==(Kn(14161)|0)?1:-1;break c}tb(f);break c}tb(f)}fb=e+32|0;break a}a=N()|0;tb(f);Q(a|0);p()}h:{if(h){break h}kg(x[x[b>>2]-12>>2]+b|0,0);b=Pm(l,Hi(b,i,m,0));x[31725]=0;h=P(463,g+68|0,14272)|0;i=x[31725];x[31725]=0;i:{if((i|0)!=1){x[31725]=0;x[g+48>>2]=3;x[g+52>>2]=0;i=g+48|0;S(464,b|0,h|0,i|0);e=x[31725];x[31725]=0;if((e|0)!=1){Eb(h);v[g+67|0]=0;x[31725]=0;h=P(463,i|0,14728)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;S(465,b|0,g+67|0,h|0);i=x[31725];x[31725]=0;if((i|0)!=1){Eb(h);h=Fc(g+44|0,y[g+67|0]?0:d);x[31725]=0;d=R(478,b|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;i=R(479,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){x[g+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=vl(y[b|0]);Bh(b);h=a?-1:1;break h}x[31725]=0;d=P(463,g+24|0,15844)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}e=x[b+44>>2];f=x[b+40>>2];x[31725]=0;e=ba(480,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31725]=0;V(481,b|0,g+40|0,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){break o}break j}x[31725]=0;d=P(463,g+12|0,15534)|0;e=x[31725];x[31725]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];f=x[b+40>>2];x[31725]=0;e=ba(480,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break q}Eb(d);if(!e){break p}x[31725]=0;S(482,b|0,g+40|0,g+38|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31725]=0;d=P(463,g|0,15374)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}e=x[b+44>>2];f=x[b+40>>2];x[31725]=0;e=ba(480,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31725]=0;V(483,b|0,g+40|0,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}}fA(g+40|0);d=x[g+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}Bh(b);Q(a|0);p()}fb=g+192|0;return h|0}function Oz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){g=x[b>>2];break a}g=x[b>>2];h=y[Hl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tl(e+128|0,g,f,f-1|0);f=x[e+132>>2];g=x[e+128>>2];x[b>>2]=g;x[b+4>>2]=f}j=e+128|0;ge(j);h=x[e+128>>2];i=e+116|0;ge(i);h=Gl(h,x[e+120>>2],b);ge(j);b:{c:{d:{e:{if(x[e+132>>2]==(h|0)){h=qc(e+144|0,22267);a=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=a;if(Ic(g,f,e+8|0)){b=ac(8);x[31725]=0;O(1014,i|0,e+152|0);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,j|0,18246,i|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(b,j);g=0;x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(j);break g}f=N()|0;break f}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(b);break c}if(!d){break e}i=ac(8);d=x[b>>2];a=x[b+4>>2];x[31725]=0;h=fi(e+92|0,d,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31725]=0;b=e+104|0;S(1017,b|0,18282,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;d=e+116|0;O(1019,d|0,b|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break p}x[31725]=0;b=e+80|0;O(1014,b|0,e+152|0);a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;g=e+128|0;S(1021,g|0,d|0,b|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break n}pc(i,g);x[31725]=0;S(99,i|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(g);a=0;break m}f=N()|0;break i}f=N()|0;a=1;break j}f=N()|0;break k}f=N()|0;a=1;break l}f=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(h);if(!a){break c}}jc(i);break c}d=qc(e+72|0,22267);b=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=b;if(Ic(g,f,e+40|0)){h=ac(8);x[31725]=0;b=e+116|0;O(1014,b|0,e+152|0);a=x[31725];x[31725]=0;r:{s:{t:{if((a|0)!=1){x[31725]=0;d=e+128|0;S(1017,d|0,18246,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}pc(h,d);g=0;x[31725]=0;S(99,h|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(d);break s}f=N()|0;break r}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(h);break c}d=qc(e- -64|0,7759);b=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=b;if(Ic(g,f,e+32|0)){if(!Ed(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31725]=0;b=P(36,e+128|0,7854)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(d,b);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}a=x[a+24>>2];k=a,l=_e(65536/c),x[k+480244>>2]=l;Hq(a);break e}d=qc(e+56|0,7811);b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;if(Ic(g,f,e+24|0)){if(!Ed(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31725]=0;b=P(36,e+128|0,7875)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(d,b);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(d);break c}a=x[a+24>>2];k=a,l=_e(c*65536),x[k+480240>>2]=l;Hq(a);break e}d=qc(e+48|0,7829);b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;if(!Ic(g,f,e+16|0)){break e}k=x[a+24>>2],l=Zi(c*65536),x[k+480236>>2]=l}fb=e+160|0;return}f=N()|0;jc(d)}Q(f|0)}p()}function psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;rD(d,b);Sn(g+4|0,d);x[31725]=0;f=e+216|0;S(477,f|0,x[g+4>>2],x[g+8>>2]);b=x[31725];x[31725]=0;a:{if((b|0)!=1){Kc(d);fb=g+32|0;break a}a=N()|0;Kc(g+12|0);Q(a|0);p()}x[31725]=0;b=e+104|0;S(459,b|0,x[e+216>>2],x[e+220>>2]);g=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){x[31725]=0;g=P(105,e+228|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}tb(b);dc(f);if(c>>>0<2189){break g}b=Pm(b,g);x[31725]=0;c=P(463,f|0,10124)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}x[31725]=0;x[e+88>>2]=19989505;x[e+92>>2]=0;d=e+88|0;S(464,b|0,c|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break w}Eb(c);v[e+103|0]=0;x[31725]=0;c=P(463,d|0,11047)|0;d=x[31725];x[31725]=0;if((d|0)==1){break v}x[31725]=0;S(465,b|0,e+103|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break u}Eb(c);d=Fc(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31725]=0;c=P(463,e+72|0,15844)|0;h=x[31725];x[31725]=0;if((h|0)==1){break i}h=x[d>>2];x[31725]=0;V(466,b|0,f|0,c|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break t}Eb(c);x[31725]=0;c=P(463,e+60|0,15534)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}d=x[d>>2];x[31725]=0;V(467,b|0,a|0,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break r}Eb(c);x[31725]=0;c=P(463,e+48|0,15374)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;d=a+484360|0;S(468,b|0,d|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break p}Eb(c);x[31725]=0;c=P(463,e+36|0,25014)|0;f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;S(469,b|0,a+484344|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31725]=0;c=P(463,e+24|0,25020)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}x[31725]=0;V(470,b|0,d|0,c|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break l}Eb(c);if(vl(y[b|0])){x[31725]=0;c=P(1,e+12|0,16318)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}tb(c)}Bh(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}dc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}Bh(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31725]=0;d=ba(471,f|0,g|0,b|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31725]=0;c=P(1,e+216|0,16624)|0;d=x[31725];x[31725]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31725]=0;V(472,g|0,a|0,d|0,c>>>0<2188|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}}tb(b)}Ff(g);fb=e+368|0;return}a=N()|0}tb(b)}Ff(g)}Q(a|0);p()}function Sg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-112|0;fb=j;k=i&2147483647;a:{b:{m=e&2147483647;l=2147418112;n=!(b|c);if(!(d|m?m-l>>>0<2147549184:n)){p=k-l|0;if(!h&(p|0)==-2147418112?f|g:(p|0)==-2147418112&(h|0)!=0|p>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){l=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:l;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}l=f|h;if(!(l|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(g|k|l){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);s=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;n=s;m=n?f:b;p=n?g:c;l=n?i:e;t=l;n=n?h:d;q=l&65535;d=s?d:h;e=s?e:i;r=e;l=e>>>16&32767;o=t>>>16&32767;if(!o){e=!(n|q);i=e;k=e?m:n;e=e<<6;i=G(i?p:q);e=e+((i|0)==32?G(k)+32|0:i)|0;bg(j+96|0,m,p,n,q,e-15|0);n=x[j+104>>2];q=x[j+108>>2];p=x[j+100>>2];o=16-e|0;m=x[j+96>>2]}f=s?b:f;g=s?c:g;h=d;i=r&65535;if(!l){b=!(d|i);e=b;k=b?f:d;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;bg(j+80|0,f,g,d,i,b-15|0);l=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;e=q<<3|n>>>29;q=n<<3|p>>>29;h=e;i=r^t;k=g<<3|f>>>29;d=f<<3;c:{if((l|0)==(o|0)){break c}e=o-l|0;if(e>>>0>127){b=0;c=0;k=0;d=1;break c}bg(j- -64|0,d,k,b,c,128-e|0);fn(j+48|0,d,k,b,c,e);b=x[j+56>>2];c=x[j+60>>2];k=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}n=d;l=k;r=h|524288;k=p<<3|m>>>29;m=m<<3;d:{if((i|0)<0){f=0;g=0;h=0;i=0;if(!(m^n|b^q|(k^l|c^r))){break a}d=m-n|0;e=k-((m>>>0<n>>>0)+l|0)|0;f=q-b|0;g=(k|0)==(l|0)&m>>>0<n>>>0|k>>>0<l>>>0;h=f-g|0;b=(r-((b>>>0>q>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}c=!(b|h);g=c;i=g?d:h;c=g<<6;g=G(g?e:b);c=c+((g|0)==32?G(i)+32|0:g)|0;f=b;b=c-12|0;bg(j+32|0,d,e,h,f,b);o=o-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}k=k+l|0;d=m+n|0;e=d>>>0<m>>>0?k+1|0:k;f=(l|0)==(e|0)&d>>>0<n>>>0|e>>>0<l>>>0;k=c+r|0;b=b+q|0;k=b>>>0<q>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=n&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;o=o+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;b=t&-2147483648;p=b;if((o|0)>=32767){h=c;i=b|2147418112;f=0;g=0;break a}l=0;e:{if((o|0)>0){l=o;break e}bg(j+16|0,d,e,h,i,o+127|0);fn(j,d,e,h,i,1-o|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}m=d&7;d=(e&7)<<29|d>>>3;f=(m>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=p|(i>>>3&65535|l<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((m|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!m){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=j+112|0}function xua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-720|0;fb=e;xc(b);f=fb-16|0;fb=f;g=e+110|0;_$(f+8|0,g);h=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(i|0);if(!f){Z$(g)}a:{if(!f){break a}if(!$$(g)){break a}b:{if(!c){break b}Bd(a,67108864);gg(a);d=y[e+135|0];w[a+480190>>1]=31;w[a+480188>>1]=d;x[a+480228>>2]=256/(d>>>0);d=tc(e,8179);Ab(a+1298344|0,d);tb(d);d=tc(e,10804);Ab(a+1298356|0,d);tb(d);f=e+84|0;ig(f,4174);g=y[e+134|0];x[e+64>>2]=g>>>4;d=0;x[31725]=0;x[e+104>>2]=g&15;V(309,e|0,f|0,e- -64|0,e+104|0);g=x[31725];x[31725]=0;c:{d:{if((g|0)!=1){Ab(a+1298368|0,e);tb(e);Eb(f);n=a+1298404|0,o=x[Fc(e,28)>>2],x[n>>2]=o;iw(Xb(x[a+484360>>2],y[a+484376|0]),e+158|0,y[e+157|0]+1|0);while(1){e:{if((d|0)==31){wE(b,a+1298308|0,32);d=1;break e}f=d+1|0;h=D(f,104)+a|0;i=h+484380|0;ld(i,1);g=(e+110|0)+(d<<2)|0;n=i,o=$b(y[g+176|0]|y[g+177|0]<<8|(y[g+178|0]<<16|y[g+179|0]<<24)),x[n>>2]=o;k=$b(y[g+300|0]|y[g+301|0]<<8|(y[g+302|0]<<16|y[g+303|0]<<24));x[h+484384>>2]=k;g=$b(y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24));x[h+484388>>2]=g+k;if(g){g=h+484414|0;w[g>>1]=z[g>>1]|2}$k(i);d=(e+110|0)+d|0;v[e|0]=y[d+548|0];v[e+84|0]=64;n=h+484410|0,o=y[Rb(e,e+84|0)|0]<<2,w[n>>1]=o;v[h+484417|0]=y[d+579|0]<<4;d=f;continue}break}while(1){if((d|0)!=32){X$(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}k=c&1;if(k){Vf(a+484344|0,y[e+156|0]+1|0)}i=a+484344|0;g=0;while(1){if(y[e+156|0]<g>>>0){d=1;if(!(c&2)){break a}c=Xc(e,8,1,1,0);while(1){if((d|0)==32){break b}fg(c,(D(d,104)+a|0)+484380|0,b);d=d+1|0;continue}}h=ai(e+84|0);f:{g:{if(y[e+136|0]){x[31725]=0;f=R(275,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;d=e- -64|0;S(187,d|0,b|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break f}break g}f=z[a+480188>>1];x[31725]=0;d=e- -64|0;S(187,d|0,b|0,f<<8);f=x[31725];x[31725]=0;if((f|0)==1){break d}}f=ic(e,d);hd(h,f);ub(f);ub(d);h:{if(!k){break h}x[31725]=0;d=U(198,i|0,g&65535,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!d){break h}f=0;if(y[e+136|0]){x[31725]=0;O(310,h|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}i:while(1){if((f|0)==64){break h}d=Wb(x[i>>2],g);cf(e- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],f);n=e,o=wb(x[e+64>>2]),x[n+104>>2]=o;l=e+f|0;d=128;j=hw(x[e+64>>2],x[e+68>>2]);while(1){m=x[e+104>>2];if(!Ib(m,j)){f=f+1|0;continue i}j:{if(!(y[l|0]&d)){break j}x[31725]=0;O(311,h|0,m|0);m=x[31725];x[31725]=0;if((m|0)!=1){break j}break d}d=d>>>1|0;vg(e+104|0);continue}}}k:while(1){d=0;l=f&65535;if(l>>>0>=z[a+480188>>1]){break h}while(1){if((d|0)==64){f=f+1|0;continue k}j=Wb(x[i>>2],g);j=jd(x[j>>2],x[x[j+48>>2]+12>>2],d,l);x[31725]=0;O(311,h|0,j|0);j=x[31725];x[31725]=0;if((j|0)!=1){d=d+1|0;continue}break}break}break d}ub(h);g=g+1|0;continue}break}break d}d=N()|0;Eb(e+84|0);break c}d=N()|0;ub(h)}Q(d|0);p()}d=1}fb=e+720|0;return d|0}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31605]){break a}a=a+b|0;c:{d:{if(x[31606]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=126404,j=x[31601]&qva(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}h=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[31603]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!h){break b}c=x[d+28>>2];e=(c<<2)+126708|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=126408,j=x[31602]&qva(-2,c),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[31607]==(f|0)){x[31607]=d;a=x[31604]+a|0;x[31604]=a;x[d+4>>2]=a|1;if(x[31606]!=(d|0)){break a}x[31603]=0;x[31606]=0;return}if(x[31606]==(f|0)){x[31606]=d;a=x[31603]+a|0;x[31603]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=126404,j=x[31601]&qva(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}h=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!h){break g}c=x[f+28>>2];e=(c<<2)+126708|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=126408,j=x[31602]&qva(-2,c),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31606]!=(d|0)){break f}x[31603]=a;return}if(a>>>0<=255){b=(a&-8)+126444|0;c=x[31601];a=1<<(a>>>3);k:{if(!(c&a)){x[31601]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+126708|0;l:{m:{e=x[31602];g=1<<c;n:{if(!(e&g)){x[31602]=e|g;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}g=c>>>29|0;c=c<<1;g=b+(g&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[31609]-1|0;x[31609]=a?a:-1}}function aS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){LA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;fS(a)}$R(a+24648|0);o=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+45984|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(o>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){h=j;j=k+600|0;x[c+4>>2]=h-j;x[c>>2]=d-j}i=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(i))<E(2147483648)){d=~~i;break a}d=-2147483648}x[c+16>>2]=d- -8192;i=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(i))<E(2147483648)){d=~~i;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;i=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;h=k-7500|0;n=k>>>0>=h>>>0?h:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){h=~~l;break d}h=-2147483648}d=n+(h+((d|0)<96?d-96|0:0)|0)|0;h=(d|0)<=128?128:d;p=h>>>0>=3800?3800:h;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;i=E(i*m);e:{if(E(F(i))<E(2147483648)){q=~~i;break e}q=-2147483648}d=h-3800|0;h=(q+n|0)+(d>>>0<=h>>>0?d:0)|0;x[c+32>>2]=h;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){i=E(h|0);l=E(De(E(.0010000000474974513),(h|0)<4721?E(1):E(E(4720)/i))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;i=E(B[g+12>>2]*i);s=c,t=De(E(.0010000000474974513),i<=E(4720)?E(1):E(E(4720)/i)),B[s+28>>2]=t}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+47274>>1];w[k+36>>1]=z[d+47268>>1];w[k+40>>1]=z[d+47272>>1];w[k+38>>1]=z[d+47270>>1];x[k+44>>2]=n+((D(x[d+47264>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=SP(TP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=RP(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=RP(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Fe(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=SP(+E(m*m),r),x[s+4>>2]=u;Fe(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;g=(f+12|0)+D(c,12)|0;j=x[g+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[g+36>>1];w[d+110>>1]=z[g+42>>1];w[d+112>>1]=z[g+40>>1];w[d+114>>1]=z[g+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;WP(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(Dd(b)){RU(b,x[a+24620>>2])}}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(Ad(g,h)){break a}f=y[xz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;sx(f,b,0,Yc(g,h)-1|0);Ab(b,f);tb(f)}f=e+100|0;ge(f);g=x[e+100>>2];ge(e+88|0);g=eN(g,x[e+92>>2],b);ge(f);b:{c:{d:{e:{if((g|0)==x[e+104>>2]){if(Ld(b,22267)){a=ac(8);x[31725]=0;S(1008,f|0,18246,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,f);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(f);break c}if(!d){break e}a=ac(8);x[31725]=0;d=e+76|0;S(1008,d|0,18282,b|0);b=x[31725];x[31725]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31725]=0;b=e+88|0;O(1019,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}x[31725]=0;f=e+100|0;S(545,f|0,b|0,c|0);b=x[31725];x[31725]=0;d=1;if((b|0)==1){break i}pc(a,f);x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(f);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}jc(a);break c}k:{switch(x[g+4>>2]){case 0:ee(e+68|0,b);b=fb-176|0;fb=b;g=b+12|0;Wf(g,c);x[31725]=0;f=b+24|0;O(126,f|0,g|0);c=x[31725];x[31725]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31725]=0;c=P(105,b+36|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break p}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31725]=0;h=ca(106)|0;i=x[31725];x[31725]=0;if((i|0)==1){break n}x[31725]=0;i=b+8|0;S(107,i|0,c+g|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break n}Zb(i);x[31725]=0;f=P(127,c|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}c=vk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Ff(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Ff(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Pz(a,e,b,d);break e;case 1:ee(e+60|0,b);b=fb-176|0;fb=b;g=b+12|0;Wf(g,c);x[31725]=0;f=b+24|0;O(126,f|0,g|0);c=x[31725];x[31725]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31725]=0;c=P(105,b+36|0,f|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break u}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31725]=0;h=ca(106)|0;i=x[31725];x[31725]=0;if((i|0)==1){break s}x[31725]=0;i=b+8|0;S(107,i|0,c+g|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break s}Zb(i);x[31725]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1135,c|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break s}c=vk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Ff(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Ff(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Nz(a,e+8|0,b,c,d);break e;case 2:ee(e+52|0,b);j=o_(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Oz(a,e+16|0,j,d);break e;case 3:break k;default:break e}}ee(e+44|0,b);ee(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Mz(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function Yoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,D=0;h=fb-4128|0;fb=h;i=Bb(y[a+14|0]|y[a+15|0]<<8);if(!(!i|i>>>0>20|z[b+480190>>1]<=y[a+23|0])){ld(d,32);w[d+34>>1]=1;j=h+12|0;g=j;i=a+20|0;x[g>>2]=i;x[g+4>>2]=(i+80|0)-i>>2;xW(h+4120|0,x[h+12>>2],x[h+16>>2],Bb(y[a+14|0]|y[a+15|0]<<8));f=x[h+4120>>2];i=y[yb(f,0)+3|0];x[h+12>>2]=1;g=x[ad(ti(b,i+1|0)+24|0,g)>>2];i=x[h+4124>>2];xW(j,f,i,c?i:1);C=h,D=wb(x[h+12>>2]),x[C+4108>>2]=D;r=1/+(g>>>0);i=fb-16|0;fb=i;o=x[vb(i+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=i+16|0;f=x[d>>2];q=x[h+4120>>2];l=z[b+480190>>1];while(1){g=x[h+4108>>2];if(Ib(g,o)){i=y[g+3|0];a:{if(i>>>0>=l>>>0){break a}j=v[g+1|0];if((j|0)<0){break a}g=ti(b,i+1|0);i=x[g>>2];f=_e(r*(Ci(+(j-v[yb(q,0)+1|0]|0)/-12)*+(i>>>0)*+A[g+24>>2]))+f|0;x[d>>2]=f}Je(h+4108|0);continue}else{b:{s=Fh(d);if(!s){break b}i=(e<<12>>>0)/1e4|0;g=x[h+4124>>2];f=fb-16|0;fb=f;k=h+4108|0;x[k>>2]=0;x[k+4>>2]=0;sc(k+8|0);Rd(f+8|0,x[vb(f+4|0,k)>>2]);c:{if(!g){break c}x[31725]=0;O(756,k|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;jW(k,g);e=x[31725];x[31725]=0;if((e|0)!=1){break c}}a=N()|0;iW(f+8|0);Q(a|0);p()}e=f+8|0;Qd(e);iW(e);fb=f+16|0;o=x[k>>2];t=x[h+4120>>2];q=x[h+4124>>2];f=0;while(1){if((f|0)==(q|0)){i=b+24648|0}else{g=yb(t,f);e=wW(o,f);l=y[g+3|0];d:{if(l>>>0>=z[b+480190>>1]){break d}j=v[g+1|0];if((j|0)<0){break d}u=0;g=y[g+2|0];if((g+14&255)>>>0<=5){u=v[g+25166|0]}n=ti(b,l+1|0);g=x[n+24>>2];B=r*(Ci(+(u<<24>>24)/96+ +(j-v[yb(t,0)+1|0]|0)/12)*+(g>>>0));if(B<=0){break d}l=vW(B);x[e+8>>2]=l;j=hb;x[e+12>>2]=j;x[e+16>>2]=x[n+20>>2];g=x[n>>2];x[e+76>>2]=g;x[e+88>>2]=z[n+34>>1]&1023;e:{if(c){x[e+664>>2]=m;m=_e(+(g>>>0)/rC(l,j))+m|0;g=i;break e}g=(i>>>0)/(Bb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){f:{a=x[d>>2];if(a>>>0>b>>>0){Sb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;j=x[Gb(h+8|0,h+4|0)>>2];C=h,D=wb(x[k>>2]),x[C+8>>2]=D;c=wb(x[k+4>>2]);while(1){f=x[h+8>>2];if(!Ib(f,c)){break f}g:{h:{if(!x[f+16>>2]){break h}g=x[f+664>>2];if(g>>>0>=j>>>0){x[f+664>>2]=g-j;break h}e=x[f+88>>2];x[h+4>>2]=j-g;C=h,D=_e((+A[f+76>>2]-rC(x[f>>2],x[f+4>>2]))/rC(x[f+8>>2],x[f+12>>2])),x[C>>2]=D;a=x[Gb(h+4|0,h)>>2];x[31725]=0;V(x[((e&1|(e&64?18:16))<<2)+25760>>2],f|0,i|0,(h+12|0)+(g<<3)|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[f+664>>2]=0;if(A[f+76>>2]>A[f+4>>2]){break h}x[f+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;uW(k);Q(a|0);p()}uW(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;c=fb-16|0;fb=c;x[c+12>>2]=j;wc(c+12|0,512);m=x[c+12>>2];while(1){if(m){a=qd(x[f>>2]+2048|0,12);a=(a|0)>=32767?32767:a;w[e>>1]=(a|0)<=-32768?-32768:a;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=c+16|0;b=b+j|0;continue}}f=(s|0)!=0}break}}fb=h+4128|0;return f|0}function Bv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[31606]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=126404,j=x[31601]&qva(-2,c>>>3|0),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[31603]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!h){break b}d=x[a+28>>2];e=(d<<2)+126708|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=126408,j=x[31602]&qva(-2,d),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[31607]==(f|0)){x[31607]=a;b=x[31604]+b|0;x[31604]=b;x[a+4>>2]=b|1;if(x[31606]!=(a|0)){break a}x[31603]=0;x[31606]=0;return}if(x[31606]==(f|0)){x[31606]=a;b=x[31603]+b|0;x[31603]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=126404,j=x[31601]&qva(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}h=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!h){break h}d=x[f+28>>2];e=(d<<2)+126708|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=126408,j=x[31602]&qva(-2,d),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31606]!=(a|0)){break g}x[31603]=b;return}if(b>>>0<=255){c=(b&-8)+126444|0;d=x[31601];b=1<<(b>>>3);l:{if(!(d&b)){x[31601]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+126708|0;m:{e=x[31602];g=1<<d;n:{if(!(e&g)){x[31602]=e|g;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}g=d>>>29|0;d=d<<1;g=c+(g&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-32|0;fb=j;a:{b:{if(ev(a)>>>0<b>>>0){if((b|0)<0){break b}m=Yo(j+20|0);x[31725]=0;O(763,m|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}sn(j+12|0,x[a>>2]);er(j+4|0,x[a>>2],x[a+4>>2]);l=fb-48|0;fb=l;e=x[m+4>>2];c=gc(l+40|0,x[j+12>>2],x[j+16>>2]);f=gc(l+32|0,x[j+4>>2],x[j+8>>2]);b=fb-16|0;fb=b;c=gc(b+8|0,x[c>>2],x[c+4>>2]);f=gc(b,x[f>>2],x[f+4>>2]);c=tX(x[c>>2],x[c+4>>2],x[f>>2],x[f+4>>2]);fb=b+16|0;c=c+e|0;x[m+4>>2]=c;c:{d:{if(!e){b=c-1|0;break d}b=c-1|0;if((b^e-1)>>>0<32){break c}}x[x[m>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}c=gc(l+24|0,x[j+12>>2],x[j+16>>2]);g=gc(l+16|0,x[j+4>>2],x[j+8>>2]);b=l+8|0;Ep(b,x[m>>2],e);e=x[c>>2];n=fb-48|0;fb=n;c=x[c+4>>2];e:{if((c|0)==x[b+4>>2]){f=gc(n+40|0,e,c);c=gc(n+32|0,x[g>>2],x[g+4>>2]);b=gc(n+24|0,x[b>>2],x[b+4>>2]);e=fb-16|0;fb=e;g=x[f>>2];d=x[f+4>>2];c=rn(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;h=c;c=x[ud(e+8|0,e+12|0)>>2];x[e+12>>2]=h-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}h=g;g=(c|0)/32|0;iD(h,g,x[b>>2]);d=c-(g<<5)|0;x[e+12>>2]=d;g=g<<2;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}gc(l,c,x[b+4>>2]);fb=e+16|0;break e}c=gc(n+16|0,e,c);e=gc(n+8|0,x[g>>2],x[g+4>>2]);g=gc(n,x[b>>2],x[b+4>>2]);f=fb-16|0;fb=f;h=x[e>>2];d=x[e+4>>2];b=x[c>>2];e=x[c+4>>2];d=rn(h,d,b,e);x[f+12>>2]=d;g:{if((d|0)<=0){e=x[g+4>>2];c=x[g>>2];break g}h:{if(!e){e=x[g+4>>2];break h}k=32-e|0;x[f+8>>2]=k;i=f+8|0;h=x[ud(i,f+12|0)>>2];x[f+12>>2]=d-h;d=x[g+4>>2];q=x[b>>2];x[f+8>>2]=h;o=32-d|0;x[f+4>>2]=o;b=x[g>>2];r=x[b>>2];i=x[Gb(i,f+4|0)>>2];k=q&(-1<<e&-1>>>k-h);x[b>>2]=(-1<<d&-1>>>o-i^-1)&r|(e>>>0<d>>>0?k<<d-e:k>>>e-d|0);d=d+i|0;e=d&31;x[g+4>>2]=e;d=b+(d>>>3&536870908)|0;x[g>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|k>>>i+x[c+4>>2];x[g+4>>2]=b;e=b}b=x[c>>2]+4|0;x[c>>2]=b;d=x[f+12>>2]}h=32-e|0;i=-1<<e;k=i^-1;while(1){if((d|0)>=32){d=x[g>>2];b=x[b>>2];x[d>>2]=k&x[d>>2]|b<<e;x[g>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[f+12>>2]-32|0;x[f+12>>2]=d;b=x[c>>2]+4|0;x[c>>2]=b;continue}break}c=x[g>>2];if((d|0)<=0){break g}k=x[b>>2];x[f+8>>2]=h;o=x[c>>2];b=x[ud(f+12|0,f+8|0)>>2];i=o&(i&-1>>>h-b^-1);h=k&-1>>>32-d;x[c>>2]=i|h<<e;d=b+e|0;e=d&31;x[g+4>>2]=e;c=(d>>>3&536870908)+c|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|h>>>b;e=x[f+12>>2];x[g+4>>2]=e}gc(l,c,e);fb=f+16|0}fb=n+48|0;fb=l+48|0;iC(a,m);uf(m)}fb=j+32|0;return}dd();p()}a=N()|0;uf(m);Q(a|0);p()}function LZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-128|0;fb=f;i=qg(f+116|0);a:{b:{c:{if(d){x[31725]=0;S(484,a|0,i|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}break b}x[31725]=0;S(485,a|0,i|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}}m=Nb(f+104|0);c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{k=c&65535;if(k>>>0<=z[b+480192>>1]){x[31725]=0;w[f+102>>1]=0;j=f+102|0;O(486,a|0,j|0);d=x[31725];x[31725]=0;t:{u:{v:{w:{if((d|0)!=1){e=fb-16|0;fb=e;l=z[j>>1];d=ce(i);h=ec(i);g=fb-16|0;fb=g;while(1){if(d){n=ep(z[d+16>>1],l);h=n?h:d;d=x[(n?d+4|0:d)>>2];continue}break}d=x[vb(g+12|0,h)>>2];fb=g+16|0;x:{if(Ib(d,rg(i))){if(!ep(z[j>>1],z[td(d)>>1])){break x}}d=rg(i)}d=vb(e+12|0,d);fb=e+16|0;j=((k<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Zg(d,Rf(i))){break u}x[31725]=0;h=P(3,f+88|0,td(d)+4|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break t}x[31725]=0;d=P(1,f+76|0,16791)|0;e=x[31725];x[31725]=0;if((e|0)==1){break v}e=nr(h,d);tb(d);if(e){break p}d=x[b+4>>2];x[31725]=0;d=P(487,d|0,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break r}x[x[j>>2]+44>>2]=d;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31725]=0;d=P(1,f- -64|0,13543)|0;e=x[31725];x[31725]=0;y:{z:{A:{if((e|0)!=1){B:{if(!nr(h,d)){x[31725]=0;e=P(1,f+52|0,13703)|0;g=x[31725];x[31725]=0;if((g|0)==1){break A}g=nr(h,e);tb(e);tb(d);if(g){break B}break s}tb(d)}x[31725]=0;d=R(488,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}x[f+36>>2]=d;d=x[b+4>>2];e=f+36|0;g=x[re(f+48|0,e)>>2];x[31725]=0;d=P(489,d|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break y}og(e);if(d){break e}break s}c=N()|0;break g}c=N()|0;tb(d);break g}c=N()|0;break g}c=N()|0;og(f+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Td(m);IZ(i);fb=f+128|0;return}d=wb(x[m>>2]);g=wb(x[m+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){C:{D:{if(Ib(d,g)){if(!nr(d,h)){break D}d=x[e+12>>2]}fb=e+16|0;break C}d=x[il(e+12|0)>>2];continue}break}if(Ib(d,wb(x[m+4>>2]))){break p}x[31725]=0;O(490,m|0,h|0);d=x[31725];x[31725]=0;if((d|0)!=1){break q}}c=N()|0;break g}x[31725]=0;d=P(1,f+12|0,17508)|0;e=x[31725];x[31725]=0;if((e|0)==1){break o}x[31725]=0;g=f+24|0;S(491,g|0,d|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break n}x[31725]=0;e=P(1,f|0,16367)|0;k=x[31725];x[31725]=0;if((k|0)==1){break m}x[31725]=0;k=f+36|0;S(2,k|0,g|0,e|0);l=x[31725];x[31725]=0;if((l|0)==1){break l}l=x[b+1298472>>2];x[31725]=0;S(387,l|0,2,k|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}tb(k);tb(e);tb(g);tb(d)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(f+36|0)}tb(e)}tb(f+24|0)}tb(d)}tb(h)}Td(m);break a}tb(h)}c=c+1|0;continue}}c=N()|0}IZ(i);Q(c|0);p()}function P1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Gb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;wo(c,x[Gb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Jh(a,b,i);h=Jh(a,b,i+4|0);f=Jh(a,b,i+5|0);u=e,w=Jh(a,b,i+6|0)<<8|Jh(a,b,i+7|0),x[u+28>>2]=w;o=h<<8|f;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<o>>>0){i=ac(8);x[31725]=0;a=R(190,i|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(o|0)){u=e,w=Jh(a,b,i+t|0),v[u+24|0]=w;uo(c,e+24|0);i=i+1|0;continue}break};s=o;break b;case 1:break g;default:break e}}Ai(e+28|0,d);s=x[e+28>>2];q=Jh(a,b,i+10|0);v[e+24|0]=q;uo(c,e+24|0);j=i+11|0;o=o+3&65532;i=s-1|0;h=0;l=0;r=0;n=0;while(1){if((i|0)<=0){break c}f=Og(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;n=8;break l}g=h+1|0;m:{if(!f){m=e+8|0;if(!Og(j,g,1,m)){break i}k=2;n:{o:{f=h+2|0;if(!Og(j,f,1,m)){break o}k=3;f=h+3|0;if(!Og(j,f,1,m)){break o}k=Og(j,f,3,m);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((n<<3)+k|0)-17|0;s:{if((h|0)<0){a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break q}}b=N()|0;jc(a);Q(b|0);p()}da(b|0,24440,164);p()}da(b|0,24440,164);p()}n=y[h+24480|0];if((n|0)!=8){break k}break m}f=4;if((n|0)!=8){break k}}n=8;f=1;if((r|0)>19){break k}}f=0;break j}r=r+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;m=Jh(x[e+8>>2],x[e+12>>2],h);q=q-qd((Jh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|m<<16|Jh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-n|0)|0;v[e+24|0]=q;uo(c,e+24|0);f=f-1|0;i=i-1|0;g=g+n|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Og(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Og(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Og(j,f,1,e+8|0)){h=6;break v}f=g+5|0;h=e+8|0;if(!Og(j,g+4|0,1,h)){g=g+8|0;f=Og(j,f,3,h)+8|0;break t}g=g+10|0;h=16;f=Og(j,f,5,e+8|0);break u}g=f+2|0;f=Og(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Og(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Og(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}m=g+1|0;g=Og(j,m,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Sc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+m|0;while(1){if((f|0)<=0|(i|0)<=0){break h}q=y[xb(x[c>>2],g)|0];v[e+24|0]=q;uo(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ac(8);x[31725]=0;a=R(190,i|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}da(a|0,24440,164);p()}r=r-(r>>3)|0;continue}}da(a|0,24440,164);p()}i=lc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;jc(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=o+t|0;continue}}fb=e+32|0;return i|0}function W1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;xc(b);Sp(a);a:{f=d+108|0;if(!Zw(b,f)){break a}if(!eG(f)){break a}n=x[b+8>>2];b:{if(!cd(b,y[f+16|0]|y[f+17|0]<<8|(y[f+18|0]<<16|y[f+19|0]<<24))){break b}while(1){if((y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24))>>>0<=j>>>0){break b}if(!Mb(x[b>>2],x[b+8>>2],5)){break b}c:{if((y[f+4|0]|y[f+5|0]<<8)>>>0>=64){if((Ri(b)|0)<=0){break c}}g=0;e=1;while(1){l=Zd(b);if(l){m=g>>>0>4;h=m&e;if(!((e^1)&1|m)){h=(Qq(l<<24>>24)&255)==y[g+13165|0]}e=h;g=g+1|0;continue}break}Vb(b,4);i=(g|0)==5&e|i}j=j+1|0;continue}}cd(b,n);if(!(i&1)){break a}if(!Mb(x[b>>2],x[b+8>>2],dG(f))){break a}if(!c){k=1;break a}h=fb-16|0;fb=h;c=d+108|0;cd(b,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24));j=d+96|0;f=Nb(j);e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);x[31725]=0;O(178,f|0,e|0);e=x[31725];x[31725]=0;d:{e:{f:{if((e|0)!=1){e=0;g:{h:{while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=e>>>0){break g}g=x[b+8>>2];i=x[b>>2];x[31725]=0;g=U(152,i|0,g|0,5)|0;i=x[31725];x[31725]=0;if((i|0)==1){break f}if(!g){break g}i=y[c+4|0]|y[c+5|0]<<8;x[31725]=0;g=h+4|0;S(179,g|0,b|0,i|0);i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;O(180,f|0,g|0);i=x[31725];x[31725]=0;if((i|0)==1){break h}e=e+1|0;tb(g);continue}break}a=N()|0;break e}a=N()|0;tb(h+4|0);break e}fb=h+16|0;break d}a=N()|0;break e}a=N()|0}Td(f);Q(a|0);p()}x[31725]=0;V(172,d+84|0,b|0,c|0,j|0);c=x[31725];x[31725]=0;i:{if((c|0)!=1){x[31725]=0;P(151,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31725];x[31725]=0;j:{if((c|0)!=1){f=d+36|0;k:{l:{m:{n:{while(1){o:{p:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}if(c){break o}}k=lc(x[a>>2],x[a+4>>2])^1;uc(d+84|0);Td(d+96|0);break a}b=N()|0;break j}x[31725]=0;c=d+60|0;aa(173,c|0,b|0,d+108|0,d+84|0,d+96|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=Up(c);x[31725]=0;c=R(174,x[d+60>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break n}if(c){x[31725]=0;c=R(175,d+24|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}e=x[e>>2];q:{if((e|0)<0){break q}g=x[d+96>>2];if(Ud(g,x[d+100>>2])>>>0<=e>>>0){break q}x[31725]=0;h=d+12|0;O(176,h|0,Hd(g,e)|0);e=x[31725];x[31725]=0;if((e|0)==1){break l}Ab(c,h);tb(h)}Ww(f,d+60|0);x[31725]=0;O(177,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break l}Np(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break j}b=N()|0;break k}b=N()|0;break k}b=N()|0;Np(c)}ub(d+60|0);break j}b=N()|0}uc(d+84|0);break i}b=N()|0}Td(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function MG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){h=d+108|0;lx(h,b);x[31725]=0;e=P(1,d+96|0,18382)|0;b=x[31725];x[31725]=0;if((b|0)==1){break E}x[31725]=0;i=d+120|0;S(2,i|0,h|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break D}x[31725]=0;f=P(3,d+72|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break C}x[31725]=0;g=P(1,d+60|0,20187)|0;b=x[31725];x[31725]=0;if((b|0)==1){break B}x[31725]=0;c=d+84|0;S(4,c|0,f|0,g|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;j=d+132|0;S(2,j|0,i|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break z}tb(c);tb(g);tb(f);tb(i);tb(e);tb(h);b=x[a>>2];x[31725]=0;O(5,i|0,(b?b:22267)|0);b=x[31725];x[31725]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31725]=0;O(5,h|0,(b?b:22267)|0);b=x[31725];x[31725]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31725]=0;x[d+48>>2]=a;e=d+48|0;O(6,c|0,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[31725]=0;P(7,499560,18261)|0;a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;O(8,e|0,i|0);a=x[31725];x[31725]=0;if((a|0)==1){break p}x[31725]=0;P(9,499560,e|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;P(7,499560,17468)|0;a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;f=d+36|0;O(8,f|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break n}x[31725]=0;P(9,499560,f|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;P(7,499560,17466)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;P(7,499560,18382)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;g=d+24|0;O(8,g|0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break l}x[31725]=0;P(9,499560,g|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;P(7,499560,13569)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;b=d+12|0;O(8,b|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}x[31725]=0;P(9,499560,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;P(7,499560,13567)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;R(10,499560)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}tb(b);tb(g);tb(f);tb(e);tb(c);tb(h);tb(i);tb(j)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(g)}tb(f)}tb(d+120|0)}tb(e)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function $P(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;AB(yb(d,0),B[a+4272>>2]);b=E(B[yb(d,0)>>2]*E(15920));s=De(E(10),E(E(E(B[yb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(E(b+E(80))/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=qQ(c);v=Bq(c);w=b;f=E(E(c*E(E(E(B[yb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(c),j(2));a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Zy(b)&2047;j:{k:{if(Zy(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Zy(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=cG(0);break j}if(!(b<E(-103.97207641601562))){break k}c=MF(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;wo(f,32);v[e+15|0]=0;uo(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Ph(a,2,16777216);break a}$d(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Ki(f,d+e|0);e=e+1|0;continue}break}if(kd(d,24344,3)){Ph(a,2,512);break a}v[d+335|0]=0;Ki(x[a+36>>2],d+335|0);f=d+72|0;Sb(f,0,256);e=y[d+335|0];if(e){Dj(x[a+36>>2],f,e)}f=b;b=xl(d,d+72|0,e);e=Ey(f,b);Eb(b);if(!e){Ph(a,2,4096)}if(vl(y[a|0])){break a}Ki(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(xj(b,6)){Pc(d,a+32|0,9);Jf(d,1)}x[d+64>>2]=0;BK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Ki(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Ki(x[a+36>>2],d+63|0);f=-2}Tm(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!xj(b,4)){break b}ul(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Ph(a,1,4)}if(xj(b,5)){Ki(x[a+36>>2],d+71|0);Tm(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!xj(c,0)){break c}Ki(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Ph(a,1,2)}x[a+8>>2]=0;f=1;if(xj(c,1)){BK(x[a+36>>2],a+8|0)}g=xj(b,2);e=a+32|0;Pc(d,e,6);Jf(d,g);g=xj(b,3);Pc(d,e,7);Jf(d,g);g=z[a+24>>1];Pc(d,e,5);Jf(d,(g|0)!=0);b=xj(b,7);Pc(d,e,8);Jf(d,b);Pc(d,e,5);d:{if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break d}Pc(d+40|0,e,6);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Pc(d+32|0,e,7);if(Hb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Pc(d+24|0,e,8);f=Hb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Pc(b,e,11);Jf(b,f);Pc(d,e,11);if(xj(c,2)){w[d+40>>1]=0;xy(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Pc(d,e,9);Tm(b,f<<Hb(x[x[d>>2]>>2],x[d+4>>2]))}if(xj(c,3)){Tm(x[a+36>>2],5)}ul(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Ph(a,2,8192);break a}x[a+104>>2]=b;if(!b){Ph(a,1,1)}Pc(d,e,11);e:{if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break e}ul(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(ry(b,c)){break e}Ph(a,2,2048);break a}$d(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Ph(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Pc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Hb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Pc(d,e,11);if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Pc(d,e,10);Jf(d,1)}fb=d+336|0}function Nz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){h=x[b>>2];break a}h=x[b>>2];i=y[Hl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Tl(f+112|0,h,g,g-1|0);g=x[f+116>>2];h=x[f+112>>2];x[b>>2]=h;x[b+4>>2]=g}j=f+112|0;ge(j);i=x[f+112>>2];k=f+100|0;ge(k);i=Gl(i,x[f+104>>2],b);ge(j);b:{c:{d:{e:{f:{g:{h:{if(x[f+116>>2]==(i|0)){c=qc(f+128|0,22267);a=x[c+4>>2];x[f+8>>2]=x[c>>2];x[f+12>>2]=a;if(Ic(h,g,f+8|0)){g=ac(8);x[31725]=0;O(1012,k|0,f+136|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[31725]=0;S(1017,j|0,18246,k|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(g,j);h=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(j);break e}if(!e){break h}g=ac(8);c=x[b>>2];a=x[b+4>>2];x[31725]=0;e=fi(f+76|0,c,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[31725]=0;b=f+88|0;S(1017,b|0,18282,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break p}x[31725]=0;c=f+100|0;O(1019,c|0,b|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break o}x[31725]=0;b=f- -64|0;O(1012,b|0,f+136|0);a=x[31725];x[31725]=0;if((a|0)==1){break n}x[31725]=0;d=f+112|0;S(1021,d|0,c|0,b|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break m}pc(g,d);x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(d);a=0;break l}b=N()|0;break d}b=N()|0;a=1;break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(e);if(a){break d}break c}e=qc(f+56|0,22267);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(h,g,f+32|0)){g=ac(8);x[31725]=0;b=f+100|0;O(1012,b|0,f+136|0);a=x[31725];x[31725]=0;q:{r:{if((a|0)!=1){x[31725]=0;c=f+112|0;S(1017,c|0,18246,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}pc(g,c);h=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break q}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(h){break d}break c}e=qc(f+48|0,10974);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(h,g,f+24|0)){Jz(a,Gc(c,d));break h}e=qc(f+40|0,8627);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(!Ic(h,g,f+16|0)){break h}b=x[a+32>>2];a=Su(c,d);a=a>>>0>=4?1:a;c=fb-16|0;fb=c;s:{if((Ak(y[b+140|0])|0)==(a|0)){b=b+120|0;_t(y[b+20|0]);d=fb-16|0;fb=d;x[d+12>>2]=c+15;e=fb-16|0;fb=e;a=x[19879];x[e+8>>2]=x[19878];x[e+12>>2]=a;a=x[19877];x[e>>2]=x[19876];x[e+4>>2]=a;ib[x[uq(e,Ak(y[b+20|0]))>>2]](d+12|0,b);fb=e+16|0;fb=d+16|0;break s}bN(b,a,cN(b))}fb=c+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(!h){break c}}jc(g)}Q(b|0)}p()}function Rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=z[x[x[b+48>>2]+12>>2]+480188>>1];d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;sc(g+8|0);Rd(e+8|0,x[vb(e+4|0,g)>>2]);c:{d:{if(d){x[31725]=0;O(462,g|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=Jr(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){hc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;bh(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Qd(d);im(d);fb=e+16|0;break c}a=N()|0;im(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31725]=0;v[c+19|0]=0;P(922,a|0,c+19|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31725]=0;P(922,a|0,c+18|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=jd(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Wc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break u}e=Wc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Rk(g);break b}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break q}e=Wc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break n}e=Wc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break k}e=Wc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break h}e=Wc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break e}e=Wc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31725]=0;P(922,a|0,c+7|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;P(923,a|0,y[c+7|0])|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Rk(g);Q(a|0);p()}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=CB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=nf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=nf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=nf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=nf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=nf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=nf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=nf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=nf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=nf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=nf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=nf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=nf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=nf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=nf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Ed(y[f+12|0])){if(!Ed(y[f+12|0])){a=ac(4);x[a>>2]=0;a=Lj(a);x[a>>2]=121436;da(a|0,121472,844);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{e=x[f+8>>2];if(!e){Wf(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31725]=0;O(95,a|0,yh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){while(1){if(yh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[cc(b+20|0,c)|0];x[31725]=0;O(97,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}d=b+8|0;Wf(d,c);x[31725]=0;c=b+20|0;S(11,c|0,e|0,d|0);e=x[31725];x[31725]=0;n:{o:{if((e|0)!=1){x[31725]=0;O(12,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break o}Qb(c);tb(d);break l}c=N()|0;break n}c=N()|0;Qb(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}H0(a,22,c)}fb=f+16|0}function pI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=fb-48|0;fb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e&2147483647;c:{if(h>>>0<=1074752122){if((e&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0|(e|0)>=0){c=a+-1.5707963267341256;a=c+-6077100506506192e-26;C[b>>3]=a;C[b+8>>3]=c-a+-6077100506506192e-26;d=1;break a}c=a+1.5707963267341256;a=c+6077100506506192e-26;C[b>>3]=a;C[b+8>>3]=c-a+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){c=a+-3.1415926534682512;a=c+-1.2154201013012384e-10;C[b>>3]=a;C[b+8>>3]=c-a+-1.2154201013012384e-10;d=2;break a}c=a+3.1415926534682512;a=c+1.2154201013012384e-10;C[b>>3]=a;C[b+8>>3]=c-a+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){c=a+-4.712388980202377;a=c+-1.8231301519518578e-10;C[b>>3]=a;C[b+8>>3]=c-a+-1.8231301519518578e-10;d=3;break a}c=a+4.712388980202377;a=c+1.8231301519518578e-10;C[b>>3]=a;C[b+8>>3]=c-a+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){c=a+-6.2831853069365025;a=c+-2.430840202602477e-10;C[b>>3]=a;C[b+8>>3]=c-a+-2.430840202602477e-10;d=4;break a}c=a+6.2831853069365025;a=c+2.430840202602477e-10;C[b>>3]=a;C[b+8>>3]=c-a+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;k=h>>>20|0;e:{if((k-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((k-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(h>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;m=1;while(1){k=(i+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[k>>3]=c;a=(a-c)*16777216;d=1;k=m;m=0;if(k){continue}break}C[i+32>>3]=a;d=2;while(1){k=d;d=d-1|0;m=i+16|0;if(C[m+(k<<3)>>3]==0){continue}break}d=IL(m,i,(h>>>20|0)-1046|0,k+1|0,1);a=C[i>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[i+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[i+8>>3]}fb=i+48|0;return d}function Cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fb-560|0;fb=f;a:{if(!cd(b,1464)){break a}d=f+556|0;if(!qr(b,d)){break a}Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);b:{if(ne(d,25252)){e=f+32|0;d=tc(e,8430);Ab(a+1298344|0,d);tb(d);d=tc(e,14831);Ab(a+1298356|0,d);tb(d);d=tc(e,14896);Ab(a+1298368|0,d);break b}if(!ne(f+556|0,15580)){break a}e=f+32|0;d=tc(e,8604);Ab(a+1298344|0,d);tb(d);d=tc(e,12340);Ab(a+1298356|0,d);tb(d);d=tc(e,15497);Ab(a+1298368|0,d)}tb(d);r=a+1298404|0,s=x[Fc(e,28)>>2],x[r>>2]=s;e=0;cd(b,0);SZ(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(e>>>0>40){break a}d=f+554|0;Hw(d,b);m=Jc(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){bY(e);break c}xE(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Xh(a,0);xg(Xb(x[a+484360>>2],y[a+484376|0]),y[f+554|0]);l=a+484344|0;Vf(l,y[f+554|0]);g=0;while(1)if(y[f+554|0]<=g>>>0){if(!(c&2)){break a}cd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{r=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g),s=g,w[r>>1]=s;d:{if(!Ng(l,g&65535,64)){break d}q=g<<2;i=0;e:while(1){if((i|0)==4){r=f,s=wb(x[Wb(x[l>>2],g)>>2]),x[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=o;v[f+31|0]=p;d=h&255;if(d){break g}h=0;break f}}else{e=x[f+24>>2];h:{if((y[e+3|0]&254)!=16){break h}v[e+3|0]=16;h=0;j=y[e+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[e+5|0]=h;k=h;e=j&15;h=(e|0)!=(h|0)&(e|0)!=0;o=h?k:o;p=h?e:p}d=d+1|0;JC(f+24|0);continue}break}ye(Wb(x[l>>2],g),Ye(Ne(f+8|0,16,y[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}cd(b,(y[f+32+(i+q)|0]<<8)+1468|0);e=0;d=Wb(x[l>>2],g);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1)if((e|0)==64){i=i+1|0;continue e}else{k=f+8|0;W$(k,b,d);j=y[f+8|0];k=y[Jc(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){Bf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;e=e+1|0;continue}}}g=g+1|0;continue}}else{g=f+32|0;MC(b,g);e=UC(g,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+e|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function se(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(116,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31725]=0;O(117,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31725];x[31725]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(116,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;f:{if((d|0)!=1){g:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31725]=0;O(117,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31725];x[31725]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:ff(a,c,48928);return;case 4:ff(a,c,49952);return;case 5:ff(a,c,50976);return;case 6:ff(a,c,52e3);return;case 7:ff(a,c,53024);return;case 8:ff(a,c,54048);return;case 9:ff(a,c,55072);return;case 10:ff(a,c,56096);return;case 11:ff(a,c,57120);return;case 12:ff(a,c,58144);return;case 13:ff(a,c,59168);return;case 14:ff(a,c,60192);return;case 15:ff(a,c,61216);return;case 16:ff(a,c,62240);return;case 17:ff(a,c,63264);return;case 18:ff(a,c,64288);return;case 19:ff(a,c,65312);return;case 20:ff(a,c,66336);return;case 21:ff(a,c,67360);return;case 22:ff(a,c,68384);return;case 23:ff(a,c,69408);return;case 24:xx(a,c,70432);return;case 25:xx(a,c,48928);return;case 26:xx(a,c,67360);return;default:a=ac(8);x[31725]=0;b=P(16,a|0,11106)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(Yc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Wd(c,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(117,f|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31725]=0;O(117,f|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(117,f|0,(a|i)<<24>>24);h=x[31725];x[31725]=0;a=d;break l}x[31725]=0;a=a-1|0;O(117,f|0,v[a+(e+10|0)|0]|-128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,125132,17);p()}a=N()|0;tb(b);Q(a|0);p()}function pn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31725]=0;a=R(283,b|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=x[b+8>>2];c=x[b>>2];x[31725]=0;d=U(152,c|0,d|0,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}if(d){break d}x[31725]=0;a=R(204,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;P(185,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31725]=0;c=e+24|0;S(187,c|0,b|0,a|0);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){d=ic(e+44|0,c);ub(c);if(a>>>0<10){break g}x[31725]=0;b=R(738,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}if(!b){break g}x[31725]=0;b=R(283,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[e+20>>2]=b;a=a-10|0;wc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31725]=0;c=x[e+20>>2];O(289,h|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[d+8>>2];f=x[d>>2];x[31725]=0;a=P(739,f|0,a|0)|0;f=x[31725];x[31725]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31725]=0;a=R(535,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31725]=0;a=R(199,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}g=x[d+8>>2];i=x[d>>2];x[31725]=0;g=U(152,i|0,g|0,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!g){continue}oe(e+24|0,x[h>>2],x[h+4>>2]);Dr(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31725]=0;bo(473,e,d,x[e+8>>2],x[e+12>>2]);f=x[31725];x[31725]=0;if((f|0)!=1){c=c-a|0;b=a+b|0;continue i}break b}x[31725]=0;a=R(199,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>c>>>0){continue}x[31725]=0;i=P(740,d|0,e+16|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=ec(f);ov(f,i,Pe(wb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(c>>>0<8){continue}x[31725]=0;a=e+16|0;g=P(740,d|0,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!g){continue}f=ec(a);ov(a,f,Pe(wb(x[h>>2]),b));ov(a,f,Pe(Pe(wb(x[h>>2]),b),4));c=c-8|0;b=b+8|0;continue i}x[31725]=0;a=R(199,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}break}c=c-a|0;b=a+b|0;continue}c=c-g|0;continue}break}if(!c){break f}Nb(dc(h));break f}x[31725]=0;S(335,d|0,h|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}}ub(d)}fb=e- -64|0;return}a=N()|0;ub(d)}dc(h);Q(a|0);p()}function yP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-192|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];g=y[Hl(e,f)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Tl(d+168|0,e,f,f-1|0);f=x[d+172>>2];e=x[d+168>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+168|0;ge(e);g=x[d+168>>2];ge(d+156|0);g=Gl(g,x[d+160>>2],b);ge(e);b:{c:{d:{e:{if((g|0)==x[d+172>>2]){a=x[b>>2];g=qc(d+184|0,22267);h=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=h;if(Ic(a,f,d)){a=ac(8);x[31725]=0;c=P(36,e|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31725]=0;f=fi(d+156|0,b,c);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){x[31725]=0;e=d+168|0;S(1017,e|0,18282,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}pc(a,e);c=0;x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;c=1}tb(f);if(!c){break c}}jc(a);break c}if(x[g+4>>2]){a=ac(8);x[31725]=0;c=P(36,d+168|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+148|0,22267);e=x[c+4>>2];x[d+72>>2]=x[c>>2];x[d+76>>2]=e;if(Ic(b,f,d+72|0)){a=ac(8);x[31725]=0;c=P(36,d+168|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+140|0,7462);e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;i:{if(!Ic(b,f,d- -64|0)){c=qc(d+132|0,7444);e=x[c+4>>2];x[d+56>>2]=x[c>>2];x[d+60>>2]=e;if(!Ic(b,f,d+56|0)){break i}}e=y[a+60|0]!=0;break e}c=qc(d+124|0,6989);e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;j:{if(!Ic(b,f,d+48|0)){c=qc(d+116|0,6970);e=x[c+4>>2];x[d+40>>2]=x[c>>2];x[d+44>>2]=e;if(!Ic(b,f,d+40|0)){break j}}e=y[a+61|0]!=0;break e}c=qc(d+108|0,7073);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){e=y[a+62|0]!=0;break e}c=qc(d+100|0,6064);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){e=y[a+63|0]!=0;break e}c=qc(d+92|0,7511);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){e=y[a+64|0]!=0;break e}c=qc(d+84|0,13509);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;if(!Ic(b,f,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function Vka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=42032;x[a+4>>2]=0;x[a>>2]=30576;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Zq(a+24604|0);HS(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Sb(b+28|0,0,40);Sb(b+68|0,0,49824);Sb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[31725]=0;i=P(852,a+484360|0,a|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[31725]=0;b=R(711,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[31725]=0;R(853,a+901404|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){AS(D(b,160)+d|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=cv(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;gs(a+1074312|0);x[31725]=0;X(854);b=x[31725];x[31725]=0;if((b|0)==1){break g}s=a,t=zS(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;qS(b,4);x[31725]=0;e=R(855,a+1074376|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;j=U(605,a+1298264|0,a|0,255)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}k=sc(a+1298300|0);l=sc(a+1298304|0);m=Fb(a+1298308|0);n=Fb(a+1298320|0);o=Fb(a+1298332|0);q=FS(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;Iq(a+12|0);VA(a+8204|0);VA(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Sb(c,0,1024);yS(g);x[31725]=0;b=R(856,12)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;ES(r);YA(q);tb(o);tb(n);tb(m);XA(l);WA(k);Pu(j)}kB(e)}DS(d)}_B(i)}vS(f);uc(h);Q(b|0);p()}function noa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Gf(d+62|0,32);j=Nb(a);x[31725]=0;n=z[d+62>>1];O(539,j|0,n|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){c:{d:{while(1){if((o&65535)>>>0>=n>>>0){break d}f=1;c=z[b+480190>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){g=f&65535;if(g>>>0>c>>>0){break h}i:{e=ti(b,g);if(!je(x[e>>2],x[e+20>>2])){if(!Ib(LC(wb(x[j>>2]),wb(x[j+4>>2]),f),wb(x[j+4>>2]))){break i}c=z[b+480190>>1]}f=f+1|0;continue}break}w[d+60>>1]=f;a=1;while(1){c=a&65535;if(c>>>0>z[b+480192>>1]){a=f}else{j:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;e=zr(c);while(1){if((c|0)==(e|0)){break j}if((g|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}f=Yo(d+48|0);x[31725]=0;a=P(779,b|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}if(!a){break e}x[31725]=0;O(780,b|0,f|0);c=x[31725];x[31725]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[b+480192>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;g=zr(c);while(1){if((c|0)==(g|0)){break k}e=z[c>>1];l:{if(e>>>0>=A[d+52>>2]){break l}Kb(d+40|0,x[f>>2],e);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}sn(d+24|0,x[f>>2]);KV(d+32|0,x[d+24>>2],x[d+28>>2],1);er(d+16|0,x[f>>2],x[d+52>>2]);l=fb-16|0;fb=l;g=d+40|0;e=gc(l,x[d+32>>2],x[d+36>>2]);a=rn(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);c=fb-16|0;fb=c;x[c+12>>2]=a;h=x[e+4>>2];m:{if(h){i=32-h|0;x[c+8>>2]=i;m=x[Gb(c+8|0,c+12|0)>>2];k=-1<<h&-1>>>i-m;i=x[e>>2];k=k&(x[i>>2]^-1);if(k){gc(g,i,mva(k));break m}if((a|0)==(m|0)){KV(g,i,h,a);break m}a=a-m|0;x[c+12>>2]=a;x[e>>2]=i+4}while(1){if(a>>>0>=32){h=x[e>>2];i=x[h>>2];if((i|0)!=-1){gc(g,h,mva(i^-1));break m}else{x[e>>2]=h+4;a=a-32|0;x[c+12>>2]=a;continue}}break}e=x[e>>2];if(!a){gc(g,e,0);break m}h=(x[e>>2]^-1)&-1>>>32-a;if(!h){gc(g,e,a);break m}gc(g,e,mva(h))}fb=c+16|0;fb=l+16|0;sn(d+8|0,x[f>>2]);a=rn(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;uf(f);if((a&65535)>>>0>3999){break f}}x[31725]=0;O(259,j|0,d+60|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}if(z[b+480190>>1]>=(a&65535)>>>0){break f}w[b+480190>>1]=a}o=o+1|0;continue}break}uf(f)}fb=d- -64|0;return}c=N()|0;break a}c=N()|0;break a}c=N()|0;uf(f)}md(j);Q(c|0);p()}function Ypa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){Ng(c+484344|0,b,64);break a}l=c+484344|0;m=Kd(Vk(a),1,1024);if(!Ng(l,b,m)){break a}n=z[c+480188>>1];b:while(1){if((k|0)==(m|0)){break a}e=Wb(x[l>>2],b);cf(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],k);i=0;while(1)if((i|0)==(n|0)){k=k+1|0;continue b}else{e=Wc(x[g+8>>2],i);h=g+4|0;sm(h,a);o=af(h);f=ej(h);j=y[g+4|0];c:{if((j-1&255)>>>0>35){break c}v[e|0]=j+48;j=y[Jc(h)|0];h=j+1|0;v[e+1|0]=h;p=h;h=h&255;if((p|0)!=(h|0)|h>>>0>z[c+480190>>1]){break c}h=ti(c,h);if(!(!y[xb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[yb(h,0)>>2]==1){if(y[xb(d,i)|0]){break d}}if(x[yb(h,0)>>2]){break c}if(y[xb(d,i)|0]){break c}}v[e+1|0]=j+101}e:{f:{switch(y[o|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|16,v[q+5|0]=r;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|16,v[q+5|0]=r;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|80,v[q+5|0]=r;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|80,v[q+5|0]=r;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:$o(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){q=e,r=y[xb(d,i)|0]?22:11,v[q+3|0]=r;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[xb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;q=e,r=y[Rb(g,g+3|0)|0]|240,v[q+5|0]=r;break g;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;q=e,r=y[Rb(g,g+3|0)|0]<<4|15,v[q+5|0]=r;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=xb(d,i);f=Wc(x[g+8>>2],v[f|0]+i|0);pw(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}fb=g+16|0}function bba(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;d:{e:{f:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[d+152>>2]=c;zo(e,c);a=Ge(d+132|0,a);x[31725]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1145,e|0,d+48|0,15)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=1;if((a|0)==1){break f}}vh(d+152|0);wh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;vh(d+152|0);break d}c=T(0)|0}wh(d+72|0);break c}if(b>=.6){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;g:{h:{i:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}x[d+152>>2]=c;zo(e,c);a=Ge(d+112|0,a);x[31725]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1145,e|0,d+24|0,2)|0;c=x[31725];x[31725]=0;if((c|0)==1){break i}if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=.8;if((a|0)==1){break i}}vh(d+152|0);wh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;vh(d+152|0);break g}c=T(0)|0}wh(d+72|0);break c}g=.2;if(b>=.2){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;j:{k:{l:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}x[d+152>>2]=c;zo(e,c);a=Ge(d+92|0,a);x[31725]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1145,e|0,d|0,0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}g=0;if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=.6;if((a|0)==1){break l}}vh(d+152|0);wh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;vh(d+152|0);break j}c=T(0)|0}wh(d+72|0);break c}if(!(b>=.1)){break b}x[31725]=0;c=d+72|0;S(188,c|0,a|0,2048);e=x[31725];x[31725]=0;if((e|0)!=1){e=$e(c);a=x[a>>2];x[31725]=0;f=x[d+72>>2];a=R(156,a|0)|0;h=x[31725];x[31725]=0;m:{if((h|0)==1){break m}x[31725]=0;a=jI(1154,3,0,e,f,a,0);e=x[31725];x[31725]=0;if((e|0)==1){break m}g=C[(a<<3)+79528>>3];Kc(c);break b}c=T(0)|0;Kc(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;g=0;if((a|0)==1){break a}}Vc(d+156|0);fb=d+160|0;return+g}a=N()|0;Vc(d+156|0);Q(a|0);p()}function MS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-48|0;fb=i;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;g=fb-16|0;fb=g;e=fb-16|0;fb=e;k=x[d>>2];f=x[d+4>>2];j=vb(e+12|0,ova(k,f,500654080,20));fb=e+16|0;h=fb-16|0;fb=h;e=x[j>>2];j=JS(h+8|0,e);l=x[j>>2];fb=h+16|0;h=x[j+4>>2];if(k>>>0<l>>>0&(h|0)>=(f|0)|(f|0)<(h|0)){h=x[vb(g+12|0,1)>>2];f=fb-16|0;fb=f;e=x[vb(f+12|0,e-h|0)>>2];fb=f+16|0}fb=g+16|0;e=x[vb(d+12|0,e)>>2];fb=d+16|0;f=fb-16|0;fb=f;d=fb-16|0;fb=d;g=e+719468|0;j=(((e|0)>-719469?g:e+573372|0)|0)/146097|0;g=D(j,-146097)+g|0;h=((g>>>0)/36524|0)+g-(((g>>>0)/146096|0)+((g>>>0)/1460|0))|0;k=(h>>>0)/365|0;h=((g-((h>>>0)/1460|0)|0)+((h>>>0)/36500|0)|0)+D(k,-365)|0;l=D(h,5)+2|0;g=(l>>>0)/153|0;j=k+D(j,400)|0;k=g+(l>>>0<1530?3:-9)|0;j=Fw(d+14|0,j+(k>>>0<3)|0);k=qq(d+13|0,k);g=qq(d+12|0,(h-((D(g,153)+2>>>0)/5|0)|0)+1|0);IS(f+12|0,z[j>>1],k,g);fb=d+16|0;d=x[f+12>>2];w[i+44>>1]=d;w[i+46>>1]=d>>>16;fb=f+16|0;d=fb-16|0;fb=d;e=JS(d,e);g=x[e>>2];c=we(d+8|0,b-g|0,c-(x[e+4>>2]+(b>>>0<g>>>0)|0)|0);b=x[c>>2];fb=d+16|0;g=fb-16|0;fb=g;c=x[c+4>>2];d=ZA(g+8|0,0);m=i,n=KS(b,c,x[d>>2],x[d+4>>2]),v[m+8|0]=n;d=fb-16|0;fb=d;e=we(d+8|0,0,0);f=x[e>>2];fb=d+16|0;if(!(KS(b,c,f,x[e+4>>2])^1)){d=fb-16|0;fb=d;c=we(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[vb(d+12|0,ova(b,c,-694967296,0))>>2];fb=d+16|0;x[i+12>>2]=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;e=we(f+8|0,nva(e,e>>31,-694967296,0),hb);h=x[e>>2];e=x[e+4>>2];fb=f+16|0;x[d>>2]=h;x[d+4>>2]=e;e=x[d>>2];b=we(d+8|0,b-e|0,c-(x[d+4>>2]+(b>>>0<e>>>0)|0)|0);c=x[b>>2];e=x[b+4>>2];f=e;fb=d+16|0;b=fb-16|0;fb=b;d=x[vb(b+12|0,ova(c,e,6e7,0))>>2];fb=b+16|0;x[i+16>>2]=d;b=fb-16|0;fb=b;e=fb-16|0;fb=e;d=we(e+8|0,nva(d,d>>31,6e7,0),hb);h=x[d>>2];d=x[d+4>>2];fb=e+16|0;x[b>>2]=h;x[b+4>>2]=d;d=x[b>>2];d=we(b+8|0,c-d|0,f-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0);c=x[d>>2];fb=b+16|0;d=x[d+4>>2];e=_A(c,d);x[i+24>>2]=e;f=hb;x[i+28>>2]=f;b=fb-16|0;fb=b;e=Du(b,e,f);f=x[e>>2];c=we(b+8|0,c-f|0,d-(x[e+4>>2]+(c>>>0<f>>>0)|0)|0);d=x[c>>2];fb=b+16|0;m=i,n=rR(d,x[c+4>>2]),x[m+32>>2]=n;x[i+36>>2]=hb;fb=g+16|0;a=LS(a);x[a>>2]=z[i+44>>1]<<16>>16;m=a,n=Pf(y[i+46|0]),x[m+4>>2]=n;m=a,n=Pf(y[i+47|0]),x[m+8>>2]=n;x[a+12>>2]=x[i+12>>2];x[a+16>>2]=x[i+16>>2];b=x[i+28>>2];x[a+24>>2]=x[i+24>>2];x[a+28>>2]=b;fb=i+48|0}function HV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;e=y[a+13|0];a:{if(e&227|(e&24)==16){break a}e=y[a+8|0];f=y[a+6|0]|y[a+7|0]<<8;v[c+22|0]=0;v[c+26|0]=e;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+20|0);f=y[a+11|0];g=y[a+9|0]|y[a+10|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+16|0)>>>0<e>>>0){break a}e=a+6|0;d=a+9|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+20>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}f=eg(c+20|0);g=y[e+2|0];e=y[e|0]|y[e+1|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=g;w[c+24>>1]=e;w[c+16>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+16|0);b:{if(!((b|0)==2|(e|0)==(f|0))){d=0;if((y[a+14|0]|y[a+15|0]<<8)>>>0>=100){break b}break a}if((e|0)==(f|0)|(b|0)!=2){break b}d=0;if((y[a+14|0]|y[a+15|0]<<8)<<16>>16<0){break a}}b=y[a+13|0];e=f-e|0;if(e&1){d=0;if(b&4){break a}}c:{if(b&8){b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;w[c+24>>1]=f;v[c+26|0]=b;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(!eg(c+20|0)){break c}}b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=b;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+20|0)){b=a+3|0;f=y[b+2|0];g=y[b|0]|y[b+1|0]<<8;d=0;v[c+18|0]=0;w[c+24>>1]=g;v[c+26|0]=f;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+16|0)>>>0>=e>>>0){break c}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;d=0;v[c+14|0]=0;w[c+24>>1]=a;v[c+26|0]=e;w[c+12>>1]=0;while(1){if((d|0)!=3){a=y[xb(c+24|0,d)|0];h=xb(c+12|0,d),i=a,v[h|0]=i;d=d+1|0;continue}break}a=eg(c+12|0);e=y[b+2|0];b=y[b|0]|y[b+1|0]<<8;d=0;v[c+10|0]=0;v[c+26|0]=e;w[c+24>>1]=b;w[c+8>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+8|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+8|0)>>>0<=a>>>0){break a}}d=1;break a}d=0}fb=c+32|0;return d}function y_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(Ad(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31725]=0;n=R(38,h|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Pk(n);f=fb-16|0;fb=f;x[f+12>>2]=j;x[f+8>>2]=0;j=x[Ze(f+8|0,f+12|0)>>2];fb=f+16|0;x[31725]=0;O(39,k|0,D(i,j+1|0)|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}o=(i<<2)+h|0;i=x[k>>2];m=i+Sc(i,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31725]=0;f=h+4|0;j=za(40,n|0,g+56|0,h|0,f|0,g+52|0,i|0,m|0,g+48|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break f}if((j|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{i=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31725]=0;j=za(40,n|0,g+56|0,h|0,o|0,g+52|0,i|0,m|0,g+48|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}l=1;if((j|0)==1){break k}}l=2;f=x[g+48>>2];if((j|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31725]=0;O(39,k|0,Sc(f,h)<<1);h=x[31725];x[31725]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];i=h+(f-i|0)|0;m=Sc(h,x[k+4>>2])+h|0;j=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(i|0)|(j|0)!=2){break p}x[31725]=0;v[g+47|0]=1;h=P(41,g+8|0,22268)|0;f=x[31725];x[31725]=0;r:{s:{t:{if((f|0)!=1){x[31725]=0;f=g+20|0;S(42,f|0,h|0,b|0);i=x[31725];x[31725]=0;if((i|0)==1){break t}x[31725]=0;i=g+32|0;aa(43,i|0,f|0,c|0,1,g+47|0);l=x[31725];x[31725]=0;if((l|0)==1){break s}tb(i);Qb(f);Qb(h);if(y[g+47|0]){break o}x[31725]=0;aa(43,a|0,b|0,c|0,2,0);a=x[31725];x[31725]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Qb(g+20|0)}Qb(h);break a;case 1:break q;default:break p}}v[e|0]=(j|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(i|0);Fb(a);break h}if((j|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}i=f}h=x[g+52>>2];l=o>>>0>h>>>0;if(l&f>>>0<m>>>0&(j|0)==2|l&(d|0)==2){continue}break}b=x[k>>2];x[31725]=0;U(44,a|0,b|0,f|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}}dc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}dc(k);Q(f|0);p()}function x1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-368|0;fb=e;xc(b);d=fb-16|0;fb=d;g=e+330|0;hF(d+8|0,g);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){gF(g)}a:{if(!d){break a}if(!jF(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(iF(y[e+365|0]),hb))){break a}b:{if(!c){break b}Bd(a,2097152);gg(a);Xh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);w[a+480190>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){bf(Xb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;f=tc(d,6554);Ab(a+1298344|0,f);tb(f);f=tc(d,11148);Ab(a+1298356|0,f);tb(f);n=a+1298404|0,o=x[Fc(d,4)>>2],x[n>>2]=o;Cw(b,d);Ur(Xb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);f=1;while(1){i=f&65535;if(i>>>0>z[a+480190>>1]){Vb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;Vf(h,y[e+365|0]);i=c&1;f=0;while(1)if(y[e+365|0]<=f>>>0){if(!(c&2)){break b}c=Xc(e+24|0,8,1,0,0);f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break b}fg(c,(D(d,104)+a|0)+484380|0,b);f=f+1|0;continue}}else{c:{d:{if(i){if(Ng(h,f&65535,64)){break d}}Vb(b,2048);break c}d=Wb(x[h>>2],f);n=e,o=wb(x[d>>2]),x[n+24>>2]=o;j=wb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,j)){break c}g=e+12|0;sm(g,b);l=Jc(g);m=af(g);g=ej(g);k=y[e+12|0];if((k-1&255)>>>0<=106){v[d|0]=k+13}v[d+1|0]=y[l|0];Bf(d,y[m|0],y[g|0]);vg(e+24|0);continue}}f=f+1|0;continue}}else{d=e+24|0;fF(b,d);h=fb-16|0;fb=h;g=(D(i,104)+a|0)+484380|0;ld(g,0);v[g+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=g,o=y[Rb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[g+36|0]=y[d+24|0];x[g>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);j=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(j>>>0<3|j+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[g+34>>1]=z[g+34>>1]|2;x[g+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[g+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;Yk(e,2,d);d=e+12|0;Cc(d,e);zc(((i<<5)+a|0)+946304|0,d);f=f+1|0;tb(d);continue}}}f=1}fb=e+368|0;return f|0}function Kua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;m=fb-32|0;fb=m;d=b;b=x[a>>2];b=(rp(d,wb(b))<<1)+b|0;f=x[a+4>>2];a:{b:{if(f>>>0<A[zb(a)>>2]){if((b|0)!=(f|0)){break b}d=fb-16|0;fb=d;a=_h(d+4|0,a,1);hj(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=d+16|0;break a}d=zb(a);g=mk(m+12|0,nk(a,Zc(x[a>>2],f)+1|0),b-x[a>>2]>>1,d);x[31725]=0;O(296,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[g+4>>2];k=zb(a);d=vb(h+12|0,b);f=vb(h+8|0,x[a>>2]);i=vb(h+4|0,x[g+4>>2]);e=x[d>>2];j=x[f>>2];d=fb+-64|0;fb=d;f=x[i>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;f=Se(d+24|0,k,d+52|0,d+56|0);x[d+16>>2]=x[f+8>>2];i=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=i;Re(d+36|0,d+8|0);while(1){if(pd(e,j)){f=nE(x[d+56>>2]);e=Nn(e);hj(f,y[e|0]|y[e+1|0]<<8);e=ij(d+60|0);ij(d+56|0);e=x[e>>2];continue}break}Qe(d+36|0);n=x[d+56>>2];if(!y[d+48|0]){i=fb-16|0;fb=i;e=vb(i+12|0,x[x[d+44>>2]>>2]);l=x[vb(i+8|0,x[x[d+40>>2]>>2])>>2];j=fb-16|0;fb=j;e=x[e>>2];x[j+12>>2]=e;while(1){if(ci(e,l)){f=fb-16|0;fb=f;x[f+12>>2]=e;x[f+12>>2]=x[f+12>>2]+2;fb=f+16|0;nE(x[f+12>>2]);e=x[Md(j+12|0)>>2];continue}break}fb=j+16|0;fb=i+16|0}fb=d- -64|0;x[g+4>>2]=n;f=x[a+4>>2];d=fb-48|0;fb=d;e=x[g+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=Se(d+12|0,k,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;Re(d+24|0,d);while(1){if((b|0)!=(f|0)){hj(x[d+44>>2],y[b|0]|y[b+1|0]<<8);x[d+44>>2]=x[d+44>>2]+2;b=b+2|0;continue}break}b=d+24|0;Qe(b);e=x[d+44>>2];oE(b);fb=d+48|0;x[g+8>>2]=e;Ub(a,g+4|0);Ub(a+4|0,g+8|0);Ub(zb(a),nc(g));x[g>>2]=x[g+4>>2];fb=h+16|0;b=c;jj(g);break a}a=N()|0;jj(g);Q(a|0);p()}i=fb-16|0;fb=i;e=x[a+4>>2];g=(e-(b+2|0)|0)+b|0;j=_h(i+4|0,a,f-g>>1);h=x[j+4>>2];d=g;while(1){if(d>>>0>=f>>>0){hc(j);h=fb-16|0;fb=h;j=h+8|0;d=e;e=fb-32|0;fb=e;Id(e+24|0,b,g);k=e+16|0;n=x[e+24>>2];g=fb-16|0;fb=g;l=x[e+28>>2];f=l;while(1){if((f|0)!=(n|0)){f=f-2|0;d=g0(d-2|0,f);continue}break}x[g+12>>2]=d;Ac(k,l,g+12|0);fb=g+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(j,d,e+12|0);fb=e+32|0;fb=h+16|0;fb=i+16|0}else{hj(h,y[d|0]|y[d+1|0]<<8);h=h+2|0;x[j+4>>2]=h;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}wb(b);fb=m+32|0}function zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;i=WM(d+128|0);x[i>>2]=48700;Nb(i+4|0);zo(x[a+24>>2],i);e=x[a+24>>2];f=y[a+62|0];g=y[a+61|0];h=y[a+60|0];b=Ge(d+108|0,b);x[31725]=0;k=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=k;x[d+16>>2]=x[b+16>>2];k=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=k;b=h?13:15;b=g?b&14:b;b=U(1145,e|0,d|0,(f?b&3:b)|0)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ac(8);x[31725]=0;c=P(36,d+96|0,12010)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}if(!y[a+63|0]){x[31725]=0;O(1146,a|0,a+36|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}}v[a+28|0]=1;zo(x[a+24>>2],x[a+4>>2]);x[31725]=0;O(1147,d+96|0,i|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}m=d,n=wb(x[d+96>>2]),x[m+92>>2]=n;k=a+68|0;l=wb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,l)){m=d,n=_i(x[c>>2]),x[m+80>>2]=n;c=Rf(c);while(1){b=x[d+80>>2];if(!Zg(b,c)){break d}x[31725]=0;e=td(b);b=P(72,d+20|0,e|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}x[31725]=0;V(1018,a|0,b|0,e+12|0,0);e=x[31725];x[31725]=0;if((e|0)==1){break g}tb(b);ah(d+80|0);continue}}e=x[a+24>>2];f=x[b>>2];x[31725]=0;j=b+4|0;S(1148,e|0,f|0,j|0);e=x[31725];x[31725]=0;if((e|0)!=1){b=x[b>>2];x[31725]=0;e=d+44|0;O(1149,e|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break r}x[31725]=0;f=d+56|0;O(1065,f|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break q}x[31725]=0;b=P(36,d+32|0,18382)|0;g=x[31725];x[31725]=0;if((g|0)==1){break p}x[31725]=0;g=d+68|0;S(1021,g|0,f|0,b|0);h=x[31725];x[31725]=0;if((h|0)==1){break o}x[31725]=0;h=d+80|0;S(545,h|0,g|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break n}x[31725]=0;O(180,k|0,h|0);j=x[31725];x[31725]=0;if((j|0)==1){break m}tb(h);tb(g);tb(b);tb(f);tb(e);_o(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}vz(d+96|0);break b}a=N()|0;break b}vz(d+96|0);Yt(i);fb=d+144|0;return}a=N()|0}Yt(i);Q(a|0)}p()}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=fb-16|0;fb=k;e=x[b>>2];d=Lg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;d=c-d|0;f=x[zb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){h=fb-16|0;fb=h;e=jC(h+4|0,b,d);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=h+16|0}else{UV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}h=zb(b);h=fv(n+12|0,$q(b,Lg(x[b>>2],e)+d|0),Lg(x[b>>2],x[b+4>>2]),h);g=fb-16|0;fb=g;d=VV(g+4|0,h+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){UV(e);e=x[d>>2]+32|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;l=fb-16|0;fb=l;d=vb(l+12|0,x[b+4>>2]);e=vb(l+8|0,x[b>>2]);f=x[vb(l+4|0,x[h+4>>2])>>2];m=fb-16|0;fb=m;o=m+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];j=fb-16|0;fb=j;x[j+8>>2]=f;x[j+12>>2]=d;while(1){if(pd(d,q)){d=mn(d);e=mn(x[j+8>>2]);f=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);i=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);v[e+24|0]=i;v[e+25|0]=i>>>8;v[e+26|0]=i>>>16;v[e+27|0]=i>>>24;v[e+28|0]=f;v[e+29|0]=f>>>8;v[e+30|0]=f>>>16;v[e+31|0]=f>>>24;f=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);i=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);v[e+16|0]=i;v[e+17|0]=i>>>8;v[e+18|0]=i>>>16;v[e+19|0]=i>>>24;v[e+20|0]=f;v[e+21|0]=f>>>8;v[e+22|0]=f>>>16;v[e+23|0]=f>>>24;f=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);i=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);v[e+8|0]=i;v[e+9|0]=i>>>8;v[e+10|0]=i>>>16;v[e+11|0]=i>>>24;v[e+12|0]=f;v[e+13|0]=f>>>8;v[e+14|0]=f>>>16;v[e+15|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;v[e+4|0]=f;v[e+5|0]=f>>>8;v[e+6|0]=f>>>16;v[e+7|0]=f>>>24;d=Zo(j+12|0);Zo(j+8|0);d=x[d>>2];continue}break}Ac(p,d,j+8|0);fb=j+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=m+16|0;x[h+4>>2]=x[m+12>>2];Ub(b,h+4|0);Ub(b+4|0,h+8|0);Ub(zb(b),nc(h));x[h>>2]=x[h+4>>2];fb=l+16|0;XV(h)}fb=n+32|0;break a}if(c>>>0<d>>>0){iY(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];bc(k+8|0,c,Lg(c,x[b+4>>2])<<5);rd(k,a,x[k+8>>2],x[k+12>>2])}fb=k+16|0}function rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;m=fb-32|0;fb=m;j=rf(m+20|0,1,0);a:{b:{while(1){e=Jb(j);i=e+Cb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=SN(g,d);d=hb}k=m+12|0;c:{d:{switch(c<<31|c-2>>>1){case 4:RN(k,e,i,g,d);break c;case 0:f=64-bu(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15483|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{e=e-4|0;hn((g<<2&60)+78800|0,4,e);f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-bu(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14762|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{e=e-2|0;hn((g<<1&126)+78864|0,2,e);f=d;d=d>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:f=67-bu(g|1,d)>>>2|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<257){while(1){e=e-1|0;v[e|0]=y[(g&15)+11165|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}else{e=e-2|0;hn((g<<1&510)+78992|0,2,e);f=d;d=d>>>8|0;g=(f&255)<<24|g>>>8;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;default:break d}}f=g;h=d;n=D(c,c);q=D(n,c);r=D(n,n);o=0;e:{while(1){l=o|1;if(!h&c>>>0>f>>>0){break e}l=o|2;if(!h&f>>>0<n>>>0){break e}l=o|3;if(!h&f>>>0<q>>>0){break e}if(!h&f>>>0<r>>>0){l=o+4|0}else{o=o+4|0;f=pva(f,h,r,0);h=hb;continue}break}}h=l;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=pva(g,d,c,0);f=hb;s=e,t=y[(g-nva(h,f,c,0)|0)+4895|0],v[s|0]=t;n=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(n){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[m+16>>2]){break b}d=qi(Cb(x[j+4>>2],y[j+11|0]));x[31725]=0;O(45,j|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break a}c=x[m+12>>2];b=Jb(j);x[31725]=0;O(46,j|0,c-b|0);b=x[31725];x[31725]=0;f:{if((b|0)!=1){x[31725]=0;O(47,a|0,j|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break a}break a}tb(j);fb=m+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function fka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31725]=0;f=P(623,e|0,f|0)|0;e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31725]=0;f=R(199,a|0)|0;e=x[31725];x[31725]=0;c:{if((e|0)==1){break c}x[31725]=0;j=d+484344|0;k=Kd(f+1|0,1,1024);f=U(198,j|0,b|0,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31725]=0;f=U(152,e|0,f|0,1)|0;e=x[31725];x[31725]=0;d:{if((e|0)!=1){if(!f){break b}x[31725]=0;i=R(199,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Wb(e,b);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Nc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41152|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Kd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Dh(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:qw(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31725]=0;g=h+10|0;O(200,g|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Jc(g)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Wu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-16|0;fb=j;g=x[a+24>>2];h=OB(g,y[a+32|0]);i=x[h>>2];a:{if(Zc(i,x[h+4>>2])>>>0<=b>>>0){break a}if(qU(x[g+484344>>2],x[g+484348>>2],z[_b(i,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Ud(h,x[a+4>>2])>>>0>b>>>0){if(A[Hd(h,b)+4>>2]>c>>>0){break b}}Ro(a,0);if(Ud(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}bc(j,x[d>>2],z[g+480188>>1]);h=j+8|0;l=x[j>>2];d=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;e=x[j+4>>2];while(1){if(!f&(e|0)==(k|0)){x[h>>2]=d;x[h+4>>2]=i}else{g=y[wW(l,k)+841|0];m=g^nva(d^k,f^i,435,256);g=!g;d=(q=d,r=nva(m,hb,435,256),s=g,s?q:r);i=g?i:hb;k=k+1|0;f=k?f:f+1|0;continue}break}g=0;d=jn(j,b,c);i=fb-16|0;fb=i;k=a+12|0;e=k;f=fU(z[d>>1],x[d+4>>2],ce(e),ec(e));c:{if(Ib(f,rg(e))){l=z[d>>1];m=x[d+4>>2];d=td(f);if(!Vl(l,m,z[d>>1],x[d+4>>2])){break c}}f=rg(e)}d=x[vb(i+12|0,f)>>2];fb=i+16|0;if(Zg(d,Rf(k))){e=td(d);g=lc(x[e+8>>2],x[e+12>>2])^1}i=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Kb(j,x[Hd(x[a>>2],b)>>2],c);f=1;n=Hb(x[x[j>>2]>>2],x[j+4>>2])^1;e=g|i;if(!(n|e)){break a}d:{e:{f:{g:{if(g){m=td(d);e=wb(x[m+8>>2]);o=wb(x[m+12>>2]);d=x[h>>2];p=x[h+4>>2];l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){h:{if(!Ib(e,o)){break h}if(fo(x[e>>2],x[e+4>>2],d,p)){break h}e=x[Zu(l+12|0)>>2];continue}break}fb=l+16|0;if(Ib(e,wb(x[m+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|n){break e}d=dU(k,jn(j,b,c));i:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=cU(e+4|0,d);aU(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break i}f=fb-32|0;fb=f;e=zb(d);e=ls(f+12|0,ms(d,jh(x[d>>2],x[d+4>>2])+1|0),jh(x[d>>2],x[d+4>>2]),e);aU(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ks(e);fb=f+32|0}}d=dU(k,jn(j,b,c));j:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=cU(e+4|0,d);bU(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=zb(d);e=ls(f+12|0,ms(d,jh(x[d>>2],x[d+4>>2])+1|0),jh(x[d>>2],x[d+4>>2]),e);bU(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ks(e);fb=f+32|0}}Kb(j,x[Hd(x[a>>2],b)>>2],c);Jf(j,1);f=0}fb=j+16|0;return f|0}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Gg(k,g,r);t=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=nva(h,G,e,e>>31);m=hb;n=e;e=Yb(l,-16777216,16776704);e=nva(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=nva(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31725]=0;X(86);c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){c=Ua(48492,125e3,125584,0)|0;d=gb;c:{d:{e:{if(($(48492)|0)==(d|0)){c=Y(c|0)|0;x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;d=P(991,b|0,18358)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22267)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(125e3)|0)==(d|0)){c=Y(c|0)|0;x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;d=P(991,b|0,18333)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22267)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125584)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;d=P(991,b|0,18349)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22267)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31725]=0;b=P(991,a|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;b=P(991,b|0,18382)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;P(991,b|0,13775)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)==1){break c}break a}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}}T(0)|0;Tb()}p()}return}tb(a);Q(b|0);p()}function b1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=bh(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){cf(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=Zd(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(e>>>0<z[x[x[a+48>>2]+12>>2]+480188>>1]){g=Wc(x[f+32>>2],e)}d=1;if(!(k&64)){e=Zd(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=Zd(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=Zd(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=Zd(c);v[e|0]=d;if(h>>>0<=15){Bf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[ud(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}qw(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24592|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Rb(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[ud(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[ud(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}GE(i,e,m,l);d=y[f+27|0];p=xi(d);h=y[i|0];if(p>>>0<=xi(h)>>>0){break e}if(!y[g+2|0]){pw(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function Pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(zi(a+44|0)){f=x[a+44>>2];y=Hc(f,0);z=Hc(f,1);f=x[a+56>>2];A=Hc(f,0);C=Hc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[yb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[yb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[yb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[yb(f,3)>>2];g=x[yb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[yb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[yb(i,0)>>2];G=B[g+4>>2];j=yb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[yb(i,1)>>2];G=B[p+4>>2];S=yb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[yb(i,2)>>2])+E(P*B[yb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[yb(i,4)>>2])+E(O*B[yb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[yb(i,6)>>2])+E(N*B[yb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[yb(i,8)>>2])+E(M*B[yb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];Pi(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Sz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Sb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31725]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(979,e|0,67,5,c|0,b|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31725]=0;aa(979,a+4528|0,62,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31725]=0;aa(979,a+4552|0,53,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31725]=0;aa(979,a+4576|0,43,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31725]=0;aa(979,a+4600|0,32,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31725]=0;aa(979,a+4624|0,22,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31725]=0;aa(979,a+4648|0,75,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31725]=0;aa(979,a+4672|0,69,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31725]=0;aa(979,a+4696|0,60,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31725]=0;aa(979,a+4720|0,48,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31725]=0;aa(979,a+4744|0,36,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31725]=0;aa(979,a+4768|0,25,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4792|0,0,0,0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31725]=0;aa(979,a+4816|0,3,0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31725]=0;aa(979,a+4840|0,3,0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4864|0,407,1,c|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4888|0,400,1,c|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4912|0,10,0,c|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4936|0,10,0,c|0,-1);c=x[31725];x[31725]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=E(0),l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=E(0),w=0,z=0,A=0,C=0,D=0,G=0,H=E(0),I=0,J=0,K=0,L=0,M=0,N=E(0),O=0,P=E(0);a:{if(!x[a+4316>>2]){break a}if(!zi(a+44|0)){break a}D=a+4300|0;G=a+4288|0;I=a+4264|0;J=a+4276|0;e=x[a+44>>2];r=Hc(e,0);s=Hc(e,1);e=x[a+56>>2];t=Hc(e,0);u=Hc(e,1);K=ib[x[x[a>>2]+196>>2]](a)|0;v=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));H=E(ib[x[x[a>>2]+192>>2]](a));w=ib[x[x[a>>2]+216>>2]](a)|0;L=w&1;o=x[a+4324>>2];l=x[a+4320>>2];m=x[a+4328>>2];j=x[a+4312>>2];M=x[a+4276>>2];p=x[a+4264>>2];z=x[a+4256>>2];A=y[a+4260|0];C=d;while(1){if(C){h=B[s>>2];k=B[r>>2];i=x[a+4316>>2];e=Co(i,j+z|0);i=Co(i,j);b:{if(A){O=yb(G,m),P=k,B[O>>2]=P;O=yb(D,m),P=h,B[O>>2]=P;q=yb(p,e);O=yb(p,i),P=E(E(B[q>>2]*v)+k),B[O>>2]=P;g=E(E(B[yb(M,e)>>2]*v)+h);e=J;break b}g=E(E(B[yb(p,e)>>2]*v)+E(E(k+h)*E(.5)));e=I}O=yb(x[e>>2],i),P=g,B[O>>2]=P;c:{if(K){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(A){e=(m+2|0)%3|0;k=B[yb(G,e)>>2];h=B[yb(D,e)>>2]}e=x[a+4316>>2];i=yb(p,Co(e,j+l|0));q=e;e=j+4096|0;N=B[yb(p,Co(q,e+l|0))>>2];n=B[i>>2];B[t>>2]=E(E(E(E(E(N-n)*E(E(l&4095)*E(.000244140625)))+n)-k)*H)+k;l=x[(A?4276:4264)+a>>2];i=x[a+4316>>2];q=yb(l,Co(i,j+o|0));n=B[yb(l,Co(i,e+o|0))>>2];k=B[q>>2];B[u>>2]=E(E(E(E(E(n-k)*E(E(o&4095)*E(.000244140625)))+k)-h)*H)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;j=(((j|0)<=0?x[a+4316>>2]<<12:0)+j|0)-4096|0;x[a+4312>>2]=j;h=L?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(w>>>0>1?e:0-e|0)+z|0;x[a+4324>>2]=o;s=s+4|0;r=r+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}l=(w>>>0<4?e:0-e|0)+z|0;x[a+4320>>2]=l;C=C-1|0;u=u+4|0;t=t+4|0;continue}else{e=a;a=x[a+56>>2];Pi(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Gg(i,g,q);s=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;be(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=nva(h,G,e,e>>31);l=hb;m=e;e=Yb(k,-16777216,16776704);e=nva(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=nva(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;be(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,4);Pb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function NQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!ln(f,g,h,i,0,0,0,0)){break c}k=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|k)?3:2;break d}l=!(f|h|(g|k))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(l){break b}}Vd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];sR(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}l=d;p=e&2147483647;k=p;n=h;m=i&2147483647;if((ln(b,c,l,k,f,g,h,m)|0)<=0){if(ln(b,c,l,k,f,g,h,m)){h=b;i=c;break a}Vd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Vd(j+96|0,b,c,l,p,0,0,0,1081540608);l=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Vd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;f:{if((k|0)>0|(k|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|n|(i|k))){Vd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}k=k<<1|n>>>31;l=n<<1|i>>>31;break f}k=p<<1|l>>>31;l=l<<1|i>>>31}p=k;k=i<<1|h>>>31;h=h<<1;i=k;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;m=k;g:{if((k|0)<0){n=l;m=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|n|(i|m)){break g}Vd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Vd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];w=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Gg(k,g,p);r=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=nva(h,G,e,e>>31);m=hb;n=e;e=Yb(l,-16777216,16776704);e=nva(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=nva(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function nra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;a:{b:{if(!c){break b}n=f,o=Zd(a),v[n+8|0]=o;uo(b,f+8|0);j=c-1|0;while(1){e=1;if(!j){break a}c:{c=g<<1&254;d:{if(!c){if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0<256){break d}break c}if((g&65535)>>>0>127){break c}}d=f+8|0;if(!Af(a,d)){break b}e$(b,d);j=j-1|0;g=c;continue}e=1;while(1){e:{f:{g:{g=c<<1&254;if(g){c=(c&65535)>>>0>127}else{if(!Af(a,f+8|0)){break g}c=y[f+8|0]<<1|1;g=c&255;c=c>>>0>255}e=lr(e,1)+c|0;c=g<<1&254;if(c){break f}if(!Af(a,f+8|0)){break g}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(g>>>0>127){continue}}break}h:{if((e|0)<=2){h=0;d=e-2|0;break h}if(!Af(a,f+8|0)){break b}d=lr(e-3|0,8)|y[f+8|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;l=d^-1;d=0}e=c<<1&254;if(e){c=c>>>0>127}else{if(!Af(a,f+8|0)){break b}c=y[f+8|0]<<1|1;e=c&255;c=c>>>0>255}i=lr(d,1);g=e<<1&254;if(g){d=e>>>0>127}else{if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;g=d&255;d=d>>>0>255}e=1;c=lr(c+i|0,1)+d|0;if(!c){while(1){i:{j:{k:{c=g<<1&254;if(c){d=(g&65535)>>>0>127}else{if(!Af(a,f+8|0)){break k}d=y[f+8|0]<<1|1;c=d&255;d=d>>>0>255}e=lr(e,1)+d|0;g=c<<1&254;if(g){break j}if(!Af(a,f+8|0)){break k}c=y[f+8|0]<<1|1;g=c&255;if(c>>>0>255){continue}break i}g=0;break i}if(c>>>0>127){continue}}break}c=e+2|0}d=c+h|0;e=0;if(d>>>0>j>>>0|(d|0)<=0|(l|0)>=0){break a}c=x[b+4>>2];e=0;if((0-Sc(x[b>>2],c)|0)>(l|0)){break a}c=vb(f+12|0,wb(c));v[f+8|0]=0;i=f+8|0;m=fb-32|0;fb=m;e=x[c>>2];c=x[b>>2];h=Gk(e,wb(c))+c|0;c=x[zb(b)>>2];k=x[b+4>>2];l:{if(d>>>0<=c-k>>>0){c=d;e=k-h|0;if(c>>>0>e>>>0){Gp(b,c-e|0,i);c=e;if(!c){break l}}g$(b,h,k,d+h|0);Uh(h,c,i+(h>>>0<=i>>>0?i>>>0<A[b+4>>2]?d:0:0)|0);break l}c=zb(b);c=vn(m+12|0,bm(b,Sc(x[b>>2],k)+d|0),h-x[b>>2]|0,c);tZ(c,d,i);h=f$(b,c,h);tn(c)}wb(h);fb=m+32|0;n=f,o=Pe(YC(wb(x[b+4>>2]),d),l),x[n+8>>2]=o;n=f,o=YC(wb(x[b+4>>2]),d),x[n+4>>2]=o;c=d;while(1){e=y[zY(f+8|0)|0];n=zY(f+4|0),o=e,v[n|0]=o;e=c>>>0>1;c=c-1|0;if(e){continue}break}j=j-d|0;continue}}e=0}fb=f+16|0;return e|0}
function xP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-112|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];h=y[Hl(e,f)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Tl(d+88|0,e,f,f-1|0);f=x[d+92>>2];e=x[d+88>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+88|0;ge(e);h=x[d+88>>2];ge(d+76|0);h=Gl(h,x[d+80>>2],b);ge(e);b:{c:{d:{e:{if((h|0)==x[d+92>>2]){a=x[b>>2];h=qc(d+104|0,22267);i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;if(Ic(a,f,d)){a=ac(8);x[31725]=0;c=P(36,e|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}c=ac(8);a=x[b+4>>2];b=x[b>>2];x[31725]=0;f=fi(d+76|0,b,a);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;e=d+88|0;S(1017,e|0,18282,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(c,e);a=0;x[31725]=0;S(99,c|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;a=1}tb(f);if(!a){break c}}jc(c);break c}if(x[h+4>>2]!=2){a=ac(8);x[31725]=0;c=P(36,d+88|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+68|0,22267);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){a=ac(8);x[31725]=0;c=P(36,d+88|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+60|0,7759);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){g=1;if(!Ed(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}c=qc(d+52|0,7811);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){g=1;if(!Ed(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}c=qc(d+44|0,7829);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;g=0;if(!Ic(b,f,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;jc(a)}Q(b|0)}p()}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=nva(j,H,e,e>>31);i=hb;v=e;e=Yb(g,-16777216,16776704);e=nva(l,G,e,e>>31);g=v+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(y,-16777216,16776704);i=nva(z,F,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(x[a+4>>2]!=x[zb(a)>>2]){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[31725]=0;O(684,a|0,b|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;hc(c);fb=e+16|0;break a}a=N()|0;hc(c);Q(a|0);p()}return}k=fb-32|0;fb=k;i=zb(a);c=k+12|0;d=xv(x[a>>2],x[a+4>>2])+1|0;h=fb-16|0;fb=h;x[h+12>>2]=d;f=fb-16|0;fb=f;x[f+12>>2]=76695844;x[f+8>>2]=2147483647;e=x[Gb(f+12|0,f+8|0)>>2];fb=f+16|0;b:{if(e>>>0>=d>>>0){d=zX(a);if(d>>>0<e>>>1>>>0){x[h+8>>2]=d<<1;e=x[ad(h+8|0,h+12|0)>>2]}fb=h+16|0;break b}dd();p()}f=xv(x[a>>2],x[a+4>>2]);h=fb-16|0;fb=h;Kg(c+12|0,i);c:{if(!e){i=0;e=0;break c}if(e>>>0>=76695845){$j();p()}d=Ec(D(e,56));x[h+12>>2]=e;x[h+8>>2]=d;i=x[h+12>>2];e=x[h+8>>2]}x[c>>2]=e;d=e+D(f,56)|0;x[c+8>>2]=d;x[c+4>>2]=d;l=nc(c),m=e+D(i,56)|0,x[l>>2]=m;fb=h+16|0;e=x[c+8>>2];x[31725]=0;O(684,e|0,b|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+56;h=fb-16|0;fb=h;f=zb(a);d=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);b=vb(h+4|0,x[c+4>>2]);i=x[d>>2];e=x[e>>2];g=fb+-64|0;fb=g;b=x[b>>2];x[g+56>>2]=b;x[g+60>>2]=i;x[g+52>>2]=b;d=Se(g+24|0,f,g+52|0,g+56|0);x[g+16>>2]=x[d+8>>2];b=x[d+4>>2];x[g+8>>2]=x[d>>2];x[g+12>>2]=b;Re(g+36|0,g+8|0);while(1){if(pd(i,e)){b=wX(x[g+56>>2]);f=AX(i);d=_l(b,f);_l(d+12|0,f+12|0);AC(d+24|0,f+24|0);w[d+52>>1]=z[f+52>>1];b=x[f+48>>2];x[d+44>>2]=x[f+44>>2];x[d+48>>2]=b;b=x[f+40>>2];x[d+36>>2]=x[f+36>>2];x[d+40>>2]=b;b=xX(g+60|0);xX(g+56|0);i=x[b>>2];continue}break}Qe(g+36|0);d=x[g+56>>2];if(!y[g+48|0]){i=fb-16|0;fb=i;b=vb(i+12|0,x[x[g+44>>2]>>2]);e=x[vb(i+8|0,x[x[g+40>>2]>>2])>>2];f=fb-16|0;fb=f;b=x[b>>2];x[f+12>>2]=b;while(1){if(ci(b,e)){j=fb-16|0;fb=j;x[j+12>>2]=b;x[j+12>>2]=x[j+12>>2]+56;fb=j+16|0;gr(wX(x[j+12>>2]));b=f+12|0;x[b>>2]=x[b>>2]+56;b=x[b>>2];continue}break}fb=f+16|0;fb=i+16|0}fb=g- -64|0;x[c+4>>2]=d;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;yX(c);fb=k+32|0;break d}a=N()|0;yX(c);Q(a|0);p()}}function Soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];i=d,j=GD(c,+y[a+2|0]*1e4/240),v[i+12|0]=j;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;i=d,j=x[ud(d+88|0,d+76|0)>>2],v[i+111|0]=j;e:{switch(((e>>>0)%5|0)-1|0){case 0:a=d+76|0;kw(a,15638);x[31725]=0;c=d- -64|0;O(560,c|0,d+12|0);e=x[31725];x[31725]=0;f:{g:{h:{i:{if((e|0)!=1){x[31725]=0;e=d+52|0;O(560,e|0,d+111|0);f=x[31725];x[31725]=0;if((f|0)==1){break i}x[31725]=0;f=d+88|0;V(561,f|0,a|0,c|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break h}ee(d+100|0,f);sf(b,x[d+100>>2],x[d+104>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:a=d+76|0;kw(a,15585);x[31725]=0;c=d- -64|0;O(560,c|0,d+12|0);e=x[31725];x[31725]=0;j:{k:{l:{m:{if((e|0)!=1){x[31725]=0;e=d+52|0;O(560,e|0,d+111|0);f=x[31725];x[31725]=0;if((f|0)==1){break m}x[31725]=0;f=d+88|0;V(561,f|0,a|0,c|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break l}ee(d+44|0,f);sf(b,x[d+44>>2],x[d+48>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=qc(d+36|0,15665);sf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=d+76|0;e=Dc(a+4|0,4048);_c(c,e);tb(e);fb=a+16|0;x[31725]=0;a=d- -64|0;O(560,a|0,d+111|0);e=x[31725];x[31725]=0;n:{o:{p:{q:{r:{s:{if((e|0)!=1){x[31725]=0;e=d+52|0;O(560,e|0,d+35|0);f=x[31725];x[31725]=0;if((f|0)==1){break s}x[31725]=0;f=d+12|0;O(560,f|0,d+34|0);g=x[31725];x[31725]=0;if((g|0)==1){break r}x[31725]=0;g=d+88|0;aa(742,g|0,c|0,a|0,e|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break q}ee(d+24|0,g);sf(b,x[d+24>>2],x[d+28>>2]);tb(g);tb(f);tb(e);tb(a);Eb(c);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=nva(j,I,e,e>>31);i=hb;y=e;e=Yb(g,-16777216,16776704);e=nva(l,H,e,e>>31);g=y+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(z,-16777216,16776704);i=nva(A,G,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function ye(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(lc(e,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}i=z[b+8>>1];j=x[x[a+48>>2]+12>>2];c=z[j+480188>>1];if(i>>>0>=c>>>0&(i|0)!=65535){break a}d=c-1|0;c=(i|0)==65535;l=c?d:i;c=c?0:i;e=jd(e,j,f,c);g=y[b+12|0];k=g&4;b:{c:{if(g&2){break c}i=y[b+10|0];f=e;d=c;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!k){if((i|0)!=y[f+3|0]){break d}break b}if((i|0)==y[f+2|0]){break b}}f=f+6|0;d=d+1|0;continue}}i=l&65535;d=e;f=c;while(1){if(i>>>0>=(f&65535)>>>0){e:{if(!k){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;f=f+1|0;continue}break}f:{if(!(g&1)){break f}d=x[j+480180>>2]&2;g:{h:{i:{if(!k){while(1){if((c&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[e+3|0]-9|0){case 4:if(!Vv(x[x[j+8>>2]+88>>2],1)){break j}d=1;v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+3|0]=y[b+10|0];v[e+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){f=y[e+5|0];if(f>>>0>128){break j}v[e+2|0]=2;v[e+3|0]=y[b+10|0];a=1;break l}v[e+2|0]=2;v[e+3|0]=y[b+10|0];f=y[e+5|0];a=2}v[e+4|0]=a+(f&255)>>>a;v[e+5|0]=y[b+11|0];break b}e=e+6|0;c=c+1|0;continue}break}if(!k){break i}}f=y[b+11|0];c=13;m:{switch(y[b+10|0]-1|0){case 1:c=9;f=yi(f<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=f;v[b+10|0]=c;g=g&254;break h}v[h+15|0]=0;v[h+14|0]=0;e=b;c=y[b+10|0];n:{if(!(!d|(c|0)!=9)){c=y[b+11|0];if(c>>>0>128){break g}d=2;c=c>>>1|0;break n}f=h+12|0;pw(f,c,y[b+11|0],1);c=h+4|0;VD(c,h+15|0,h+14|0);UD(c,f);g=y[b+12|0];d=y[h+15|0];if(!d){break g}c=y[h+14|0]}v[e+11|0]=c;v[b+10|0]=d;g=g&254}v[b+12|0]=g}d=1;if(g&1){break f}v[b+12|0]=g^4;if(ye(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=ye(a,b);break a}d=1}fb=h+16|0;return d}function AU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Xd(d,h<<1);MR(c+160|0,C[e>>3],C[e+8>>3]);d=Xd(d,h);MR(c+144|0,C[d>>3],C[d+8>>3]);Si(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Xd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Xd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Xd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Xd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Ll(g,f,o,n);j=c- -64|0;Fj(j,f,o,n);l=c+96|0;Ll(c+48|0,l,u,t);f=c+16|0;Fj(f,l,u,t);Si(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Ll(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Ll(c,j,C[c+32>>3],C[c+40>>3]);Si(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Fj(c,g,C[c+48>>3],C[c+56>>3]);Si(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Fj(c,j,C[c+32>>3],C[c+40>>3]);Si(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Xd(h,d+i|0);m=Xd(h,d);n=C[a>>3];o=C[a+8>>3];Fj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;yA(Xd(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];v=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Gg(i,g,o);q=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;be(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=nva(h,G,e,e>>31);l=hb;m=e;e=Yb(k,-16777216,16776704);e=nva(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=nva(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;be(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function n8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Ny(x[g>>2]);o=ty(x[g>>2]);sh(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31725]=0;g=P(1234,k|0,g<<24>>24)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31725]=0;i=P(1234,k|0,48)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=v[g+1|0];x[31725]=0;i=P(1234,k|0,i|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=g+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!SK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!Nh(h)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31725]=0;V(1228,k|0,i|0,g|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Hm(i,g);x[31725]=0;r=R(1226,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){it((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,l)|0]<=0){break f}if(v[cc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31725]=0;q=P(1234,k|0,q|0)|0;n=x[31725];x[31725]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[31725]=0;i=R(1229,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31725]=0;i=P(1234,k|0,i<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31725]=0;V(1228,k|0,g|0,c|0,h|0);i=x[31725];x[31725]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function Pi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!DQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=DQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function DK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[124231]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Cf(e)}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111520>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111520>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[31600]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[31600]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function osa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);e=fb-96|0;fb=e;d=fb-16|0;fb=d;c=b+16|0;pZ(d+8|0,c);g=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(g|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)!=(g|0)){Sb(c,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=e+56|0;fe(d,a,Pg(a));g=ic(e+76|0,d);ub(d);x[31725]=0;c=R(204,g|0)|0;f=x[31725];x[31725]=0;a:{b:{if((f|0)==1){break b}x[31725]=0;O(289,b+4|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}oe(e+48|0,x[b+4>>2],x[b+8>>2]);x[31725]=0;bo(473,d,g,x[e+48>>2],x[e+52>>2]);c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;f=R(153,a|0)|0;c=x[31725];x[31725]=0;c:{if((c|0)==1){break c}x[31725]=0;c=e+28|0;S(187,c|0,a|0,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}d=ic(d,c);ub(c);a=x[d>>2];x[31725]=0;a=R(174,a|0)|0;c=x[31725];x[31725]=0;d:{if((c|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[d+8>>2];c=x[d>>2];x[31725]=0;a=U(152,c|0,a|0,5)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}if(!a){break g}x[31725]=0;P(474,d|0,e+24|0)|0;a=x[31725];x[31725]=0;h:{if((a|0)!=1){a=4;c=y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24);if((c|0)==1414682436|(c|0)==1196380752){break h}x[31725]=0;a=R(153,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31725]=0;f=e+4|0;S(187,f|0,d|0,a|0);a=x[31725];x[31725]=0;i:{j:{if((a|0)!=1){c=ic(e+28|0,f);ub(f);if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1414682436){break j}x[31725]=0;h=E(xa(475,c|0));a=x[31725];x[31725]=0;if((a|0)==1){break e}i=b,j=Pd(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1196380752){break i}x[31725]=0;a=R(153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[b+148>>2]=a}ub(c);continue}}ub(d);ub(g);fb=e+96|0;return}a=N()|0;break d}a=N()|0;ub(c);break d}a=N()|0}ub(d);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function x8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=zw(x[g>>2]);o=Ay(x[g>>2]);sh(j+4|0,o);x[f>>2]=d;a:{b:{c:{h=a;g=y[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31725]=0;g=P(29,k|0,g<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;h=a+1|0}d:{g=h;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31725]=0;h=P(29,k|0,48)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[g+1|0];x[31725]=0;h=P(29,k|0,h|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=g+2|0;g=h;while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!SK(i)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!Nh(i)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){i=x[f>>2];x[31725]=0;V(1215,k|0,h|0,g|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break a}x[f>>2]=x[f>>2]+(g-h|0);break e}Hm(h,g);x[31725]=0;r=R(1213,o|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=h;while(1){if(g>>>0<=i>>>0){Hm((h-a|0)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,m)|0]<=0){break f}if(v[cc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[i|0];x[31725]=0;q=P(29,k|0,q|0)|0;n=x[31725];x[31725]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;i=i+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){h=y[g|0];if((h|0)!=46){break g}x[31725]=0;h=R(1216,o|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0}h=x[f>>2];x[31725]=0;V(1215,k|0,g|0,c|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}h=f;f=x[f>>2]+(c-g|0)|0;x[h>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31725]=0;h=P(29,k|0,h<<24>>24)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function iga(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=fr(1,32);d:{e:{if(!k){a=Xm(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31725]=0;e=P(36,j+56|0,e|0)|0;m=x[31725];x[31725]=0;j:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break j}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31725]=0;e=P(36,j+44|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break g}gu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31725]=0;a=R(856,104)|0;m=x[31725];x[31725]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31725]=0;b=P(995,f|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[j+20>>2]=b;d=j+20|0;b=x[re(j+24|0,d)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31725]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;b=ba(1025,a|0,j|0,b|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break k}i=T(0)|0;Vc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Vc(j+20|0);x[k+24>>2]=b+8;Ul(c);break d}i=T(0)|0}Ul(c);Y(i|0)|0;x[31725]=0;V(989,11340,k|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31725]=0;V(989,11340,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Tb()}p()}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=nva(j,F,e,e>>31);i=hb;t=e;e=Yb(g,-16777216,16776704);e=nva(l,E,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=nva(v,C,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Ev(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Fd(b)}if(b>>>0>=4294967232){x[31600]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[31721]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;Bv(d,c);break b}if(x[31607]==(g|0)){d=d+x[31604]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[31604]=d;x[31607]=c;break b}if(x[31606]==(g|0)){d=d+x[31603]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31606]=h;x[31603]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=126404,o=x[31601]&qva(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+126708|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=126408,o=x[31602]&qva(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;Bv(c,l)}c=e}if(c){return c+8|0}c=Fd(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;yc(c,a,b>>>0>e>>>0?e:b);Db(a);return c}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-112|0;fb=d;xc(b);Sp(a);f=d+104|0;a:{if(!Bi(b,f)){break a}if(!iG(f)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}ox(a);o=d,q=nx(),x[o+84>>2]=q;c=d+84|0;mx(lj(x[a+4>>2])+32|0,c);qs(c);l=x[lj(x[a+4>>2])+32>>2];c=kh(x[b>>2]);if(c&1){break a}e=c-4|0;cd(b,e);f=fb-16|0;fb=f;c=f+13|0;$w(c,b);h=y[xb(c,0)|0];i=y[xb(c,1)|0];c=xb(c,2);fb=f+16|0;h=y[c|0]|(i<<8|h<<16);if(!h){break a}x[31725]=0;O(39,l|0,h|0);c=x[31725];x[31725]=0;c:{if((c|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break c}Y(b|0)|0;Z();break a}cd(b,4);j=d+84|0;hG(j,b,e);Sn(d- -64|0,j);mf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];i=x[l>>2];e=fb-32|0;fb=e;b=x[d+76>>2];o=e,q=y[xb(b,0)|0],v[o+28|0]=q;o=e,q=y[xb(b,1)|0],v[o+29|0]=q;o=e,q=y[xb(b,2)|0],v[o+30|0]=q;o=e,q=y[xb(b,3)|0],v[o+31|0]=q;f=gs(e+12|0);c=b+c|0;x[f+12>>2]=c-4;x[f+8>>2]=b;qk(f,y[c-1|0]);c=h;d:while(1){e:{f:{g:{if(!c){break g}if(qk(f,1)){break f}b=1;while(1){g=qk(f,2);b=g+b|0;if((g|0)==3){continue}break}x[e+8>>2]=b;wc(e+8|0,c);b=0;g=x[e+8>>2];while(1)if((b|0)==(g|0)){if(!c){break g}break f}else{c=c-1|0;o=i+c|0,q=qk(f,8),v[o|0]=q;b=b+1|0;continue}}fb=e+32|0;break e}g=qk(f,2);b=g+2|0;x[e+8>>2]=b;h:{if((g|0)==3){i:{if(!qk(f,1)){b=5;g=7;break i}g=y[xb(e+28|0,3)|0]}g=qk(f,g);while(1){k=qk(f,3);b=k+b|0;if((k|0)==7){continue}break}x[e+8>>2]=b;break h}g=qk(f,y[xb(e+28|0,g)|0])}wc(e+8|0,c);b=0;n=x[e+8>>2];while(1){if((b|0)==(n|0)){continue d}k=0;m=c+g|0;if(h>>>0>m>>>0){k=y[i+m|0]}c=c-1|0;v[i+c|0]=k;b=b+1|0;continue}}break}oe(d+24|0,x[l>>2],x[l+4>>2]);mf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Nd(d+16|0);x[31725]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=jg(162,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31725];x[31725]=0;if((c|0)!=1){hd(lj(x[a+4>>2])+12|0,b);ub(b);Kc(j);break b}b=N()|0;Kc(d+84|0)}Q(b|0);p()}j=1}fb=d+112|0;return j|0}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;e=x[b>>2];d=Kk(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;e=c-d|0;d=x[zb(b)>>2];f=x[b+4>>2];b:{if(e>>>0<=d-f>>4>>>0){f=fb-16|0;fb=f;e=gv(f+4|0,b,e);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=f+16|0}else{Kr(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}d=zb(b);f=_V(n+12|0,$V(b,Kk(x[b>>2],f)+e|0),Kk(x[b>>2],x[b+4>>2]),d);g=fb-16|0;fb=g;d=g+4|0;x[d>>2]=x[f+8>>2];i=x[f+8>>2];x[d+8>>2]=f+8;x[d+4>>2]=i+(e<<4);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){Kr(e);e=x[d>>2]+16|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;k=fb-16|0;fb=k;d=vb(k+12|0,x[b+4>>2]);e=vb(k+8|0,x[b>>2]);h=x[vb(k+4|0,x[f+4>>2])>>2];l=fb-16|0;fb=l;o=l+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];i=fb-16|0;fb=i;x[i+8>>2]=h;x[i+12>>2]=d;while(1){if(pd(d,q)){e=kC(d);d=kC(x[i+8>>2]);h=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);v[d+8|0]=m;v[d+9|0]=m>>>8;v[d+10|0]=m>>>16;v[d+11|0]=m>>>24;v[d+12|0]=h;v[d+13|0]=h>>>8;v[d+14|0]=h>>>16;v[d+15|0]=h>>>24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;v[d+4|0]=h;v[d+5|0]=h>>>8;v[d+6|0]=h>>>16;v[d+7|0]=h>>>24;d=ar(i+12|0);ar(i+8|0);d=x[d>>2];continue}break}Ac(p,d,i+8|0);fb=i+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=l+16|0;x[f+4>>2]=x[l+12>>2];Ub(b,f+4|0);Ub(b+4|0,f+8|0);Ub(zb(b),nc(f));x[f>>2]=x[f+4>>2];fb=k+16|0;d=x[f+4>>2];e=x[f+8>>2];while(1){if((d|0)!=(e|0)){e=e-16|0;x[f+8>>2]=e;continue}break}d=x[f>>2];if(d){xs(f);Db(d)}}fb=n+32|0;break a}if(c>>>0<d>>>0){aW(b,e+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];bc(j+8|0,c,Kk(c,x[b+4>>2])<<4);rd(j,a,x[j+8>>2],x[j+12>>2])}fb=j+16|0}function Nu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=D(c,872)+b|0;g=e+704|0;x[g>>2]=x[g>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}f=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[f+1427|0]=d;v[f+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{h=e+616|0;i=x[h+656>>2];if(Sj(i)){d=D(c,872)+b|0;a=z[d+1384>>1];if(!a){break c}e=0;f=x[b+16>>2];e=f?x[d+1472>>2]:e;k=+(f>>>0)+1;j=0-a|0;d=a;h=D(c,872)+b|0;f=h+1324|0;a=x[f>>2];k=k*+(((a|0)<0?j:d)|0)/+A[b+40>>2];d:{if(F(k)<2147483648){d=~~k;break d}d=-2147483648}h=h+1472|0;x[h>>2]=d;if(y[g+2|0]&16){d=D(x[x[i+44>>2]+36>>2]+1|0,d);x[h>>2]=d}d=d-e|0;g=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^g)-g>>>0){if(!a){break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[f>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;return 0}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[f>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break c}f=a+1074312|0;e:{if(!(!Ob(f,118)|!(y[g+1|0]&2))){d=0;if(Tc(y[(D(c,872)+b|0)+1404|0])){break e}}g=1;i=D(c,872)+b|0;e=i+1467|0;f:{if(!(v[e|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Ob(f,6)){break f}d=x[a+480180>>2]}g=0;if((d|0)!=8){break f}g=(y[a+480208|0]&2)>>>1|0}j=x[a+480180>>2];d=z[i+1384>>1];if(!((j|0)!=268435456|d>>>0<240)){g=v[e|0]&1;d=d-240|0}d=d<<((j|0)==64?1:2);i=D(c,872)+b|0;b=i+1316|0;g:{if(!x[b>>2]){break g}c=i+1324|0;if(!(x[c>>2]!=0&g)){break g}j=Hj(a)?d:0-d|0;l=x[b>>2];m=x[c>>2];if(!(!(y[e|0]&16)&(l|0)>=(m|0))){Ek(a,h,b,j,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((l|0)<=(m|0)){break g}Ek(a,h,b,0-j|0,1);h=x[b>>2];c=x[c>>2];h:{if((h|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(h|0)){break g}}if(!Ob(f,112)){break g}v[e|0]=y[e|0]|16}c=x[b>>2];b=i+1324|0;i:{if((c|0)!=x[b>>2]){break i}if(!Ob(f,25)&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=g?d:0}return d}return 0}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=nva(j,G,e,e>>31);i=hb;t=e;e=Yb(g,-16777216,16776704);e=nva(l,F,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=nva(y,E,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function DP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=fr(1,28);if(!k){a=Xm(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31725]=0;e=P(36,j+56|0,e|0)|0;m=x[31725];x[31725]=0;k:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break k}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31725]=0;e=P(36,j+44|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}gu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31725]=0;a=R(856,80)|0;m=x[31725];x[31725]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31725]=0;b=P(995,f|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=j+20|0;d=x[re(j+24|0,b)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31725]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;d=ba(996,a|0,j|0,d|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break l}i=T(0)|0;Vc(b);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=d;Vc(j+20|0);Ul(c);i=k;break d}i=T(0)|0}Ul(c);Y(i|0)|0;x[31725]=0;V(989,15182,k|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(Aq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31725]=0;V(989,15182,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Tb()}p()}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-16|0;fb=j;c=Hf(a,c);$d(j,x[a+36>>2]);a:{if(!c){Pc(j,a+32|0,5);f=0;if(Hb(x[x[j>>2]>>2],x[j+4>>2])){break a}}f=fb-240|0;fb=f;h=Pm(f+128|0,x[a+36>>2]);x[31725]=0;g=P(463,f+116|0,26168)|0;e=x[31725];x[31725]=0;b:{c:{d:{e:{if((e|0)!=1){x[31725]=0;x[f+96>>2]=19989505;x[f+100>>2]=0;S(464,h|0,g|0,f+96|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}Eb(g);if(!vl(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[f+115|0]=0;x[31725]=0;g=P(463,f+96|0,5505)|0;e=x[31725];x[31725]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)!=1){x[31725]=0;S(465,h|0,f+115|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break p}Eb(g);g=Fb(f+84|0);x[31725]=0;e=P(463,f+72|0,10094)|0;i=x[31725];x[31725]=0;if((i|0)==1){break o}x[31725]=0;S(789,h|0,g|0,e|0);i=x[31725];x[31725]=0;if((i|0)==1){break n}Eb(e);x[31725]=0;e=f+60|0;S(260,e|0,(y[f+115|0]?0:d)|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break m}vp(b,e);tb(e);w[f+58>>1]=0;x[31725]=0;d=P(463,f+44|0,10783)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;e=f+58|0;U(493,h|0,e|0,d|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break l}Eb(d);Gf(e,4e3);x[31725]=0;d=P(463,f+32|0,13541)|0;e=x[31725];x[31725]=0;if((e|0)==1){break k}i=z[f+58>>1];e=x[vb(f+28|0,i)>>2];x[31725]=0;V(790,h|0,b|0,d|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}Eb(d);w[f+26>>1]=65535;x[31725]=0;d=P(463,f+12|0,8964)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;k=U(493,h|0,f+26|0,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}e=z[f+26>>1];Eb(d);if(e>>>0<i>>>0&k){bf(b,e)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(e);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}Bh(h);Q(a|0);p()}Bh(h);fb=f+240|0;f=c}gf(a,f);fb=j+16|0}function $ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=aE(d+40|0,b);r=Hr(i);f=Nb(a);x[31725]=0;a=R(204,b|0)|0;c=x[31725];x[31725]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;a=d+12|0;t=d,u=D(x[Gb(a,d+36|0)>>2],50),x[t+24>>2]=u;c=d+24|0;e=x[Gb(d+1100|0,c)>>2];x[31725]=0;O(330,f|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;h=R(342,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;g=P(343,a|0,8192)|0;a=x[31725];x[31725]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){e=yb(a,c);v[e+2|0]=c;w[e>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){e=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31725]=0;o=P(160,i|0,s|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Sc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:e;a=x[h>>2];l=8192;while(1){c=c&65535;a=yb(a,c);l=l-1|0;q=l&65535;t=xb(x[g>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[yb(a,c)>>1];if(c>>>0<8192){continue}break}a=vb(d+8|0,wb(x[f+4>>2]));c=Pe(wb(x[g>>2]),q);l=wb(x[g+4>>2]);a=x[a>>2];x[31725]=0;V(331,f|0,a|0,c|0,l|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[g>>2];x[31725]=0;O(344,f|0,xb(a,q)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){e=o;continue}if(Sc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[xb(x[g>>2],q)|0];c=yb(x[h>>2],j);w[c>>1]=e;v[c+2|0]=a;a=n+1|0;n=8192;e=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=Hr(i);x[31725]=0;P(151,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}dc(g);uc(h);ub(i);fb=d+1104|0;return}c=N()|0;dc(g);break b}c=N()|0}uc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}dc(f);ub(i);Q(c|0);p()}function SO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!((q(b),j(2))&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ac(8);x[31725]=0;c=P(36,c+4|0,5123)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79544>>2];break h}d=N()|0;jc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Ze(n,c)>>2];l:{if((a|0)==x[Zq(n)+32>>2]){a=-1;if(x[Zq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=ac(8);x[31725]=0;d=P(36,d+4|0,10385)|0;a=x[31725];x[31725]=0;m:{if((a|0)!=1){pc(c,d);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;jc(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function BU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Xd(i,e+l|0);d=Xd(i,e);o=C[h>>3];p=C[h+8>>3];Fj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;yA(Xd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Xd(d,j<<1);d=Xd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Si(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Xd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Xd(f,t);Si(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Xd(f,u);Si(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Xd(f,v);Si(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Ll(k,f,m,n);q=c- -64|0;Fj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Ll(c+48|0,g,m,n);f=c+16|0;Wl(f,-0,-1);Fj(c,g,m,n);Si(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Ll(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Fj(f,k,C[c+48>>3],C[c+56>>3]);d=Xd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Ll(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Fj(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function wP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;g=x[b+4>>2];a:{if(!g){break a}e=x[b>>2];f=y[Hl(e,g)|0];if((f|0)==33){c=1}else{if((f|0)!=63){break a}c=0}Tl(d+72|0,e,g,g-1|0);g=x[d+76>>2];e=x[d+72>>2];x[b>>2]=e;x[b+4>>2]=g}e=d+72|0;ge(e);f=x[d+72>>2];ge(d+60|0);f=Gl(f,x[d+64>>2],b);ge(e);b:{c:{d:{e:{if((f|0)==x[d+76>>2]){a=x[b>>2];f=qc(d+88|0,22267);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Ic(a,g,d)){a=ac(8);x[31725]=0;c=P(36,e|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31725]=0;e=fi(d+60|0,b,c);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){x[31725]=0;g=d+72|0;S(1017,g|0,18282,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}pc(a,g);c=0;x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(g);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[f+4>>2]!=1){a=ac(8);x[31725]=0;c=P(36,d+72|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+52|0,22267);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,g,d+24|0)){a=ac(8);x[31725]=0;c=P(36,d+72|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+44|0,10974);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,g,d+16|0)){e=x[a+8>>2];f=e>>31;break e}c=qc(d+36|0,8627);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;f=0;if(!Ic(b,g,d+8|0)){break e}e=Ak(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function uP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){g=x[c>>2];break a}g=x[c>>2];h=y[Hl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tl(e+72|0,g,f,f-1|0);f=x[e+76>>2];g=x[e+72>>2];x[c>>2]=g;x[c+4>>2]=f}i=e+72|0;ge(i);h=x[e+72>>2];ge(e+60|0);h=Gl(h,x[e+64>>2],c);ge(i);b:{c:{d:{e:{if(x[e+76>>2]==(h|0)){h=qc(e+88|0,22267);b=x[h+4>>2];x[e>>2]=x[h>>2];x[e+4>>2]=b;if(Ic(g,f,e)){c=ac(8);x[31725]=0;b=P(36,i|0,10482)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}if(d){g=ac(8);b=x[c>>2];a=x[c+4>>2];x[31725]=0;d=fi(e+60|0,b,a);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;b=e+72|0;S(1017,b|0,18282,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(g,b);c=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break g}f=N()|0;break f}f=N()|0;c=1}tb(d);if(!c){break c}}jc(g);break c}Fb(a);break e}d=qc(e+52|0,22267);c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;if(Ic(g,f,e+24|0)){c=ac(8);x[31725]=0;b=P(36,e+72|0,10482)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(c);break c}d=qc(e+44|0,12421);c=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=c;if(Ic(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Dc(a,5601);break e;case 1:Dc(a,11285);break e;case 2:Dc(a,9206);break e;default:break i}}Fb(a);break e}d=qc(e+36|0,11522);c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;if(Ic(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Dc(a,15627);break e;case 1:Dc(a,15632);break e;case 2:Dc(a,12695);break e;case 3:Dc(a,9270);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}f=N()|0;jc(c)}Q(f|0)}p()}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(Ad(g,h)){break a}e=y[xz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;sx(e,c,0,Yc(g,h)-1|0);Ab(c,e);tb(e)}e=d+84|0;ge(e);g=x[d+84>>2];ge(d+72|0);g=eN(g,x[d+76>>2],c);ge(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(Ld(c,22267)){a=ac(8);x[31725]=0;b=P(36,e|0,10482)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=ac(8);x[31725]=0;b=d+84|0;S(1008,b|0,18282,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;jc(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ee(d- -64|0,c);x[31725]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1009,b|0,d+8|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;v[d+72|0]=b;O(1010,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 1:ee(d+56|0,c);x[31725]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=kI(b,d+16|0,f);c=hb;f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1012,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 2:ee(d+48|0,c);x[31725]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1013,b|0,d+24|0,f|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;C[d+72>>3]=i;O(1014,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ee(d+40|0,c);x[31725]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1015,a|0,b|0,d+32|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}_c(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function Gra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];b=Kv(e,x[a+4>>2]);if(b>>>0<=63){h=fb-32|0;fb=h;g=64-b|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=(b-c|0)/33>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+D(g,33);c=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{_Y(c);c=c+33|0;x[b+4>>2]=c;continue}break}break a}i=zb(a);e=h+12|0;f=Kv(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=cZ(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}f=Kv(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Kg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=130150525){$j();p()}c=Ec(D(b,33));x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+12>>2];b=x[d+8>>2]}x[e>>2]=b;f=b+D(f,33)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=b+D(c,33)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[e+8>>2];c=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=c+D(g,33);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){_Y(c);c=x[b>>2]+33|0;x[b>>2]=c;continue}break}he(b);fb=d+16|0;g=fb-16|0;fb=g;b=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;c=fb-32|0;fb=c;Id(c+24|0,x[b>>2],x[d>>2]);j=c+16|0;b=x[c+24>>2];k=x[c+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=i;x[d+12>>2]=b;while(1){if(pd(b,k)){b=aZ(b);yc(aZ(x[d+8>>2]),b,33);b=$Y(d+12|0);$Y(d+8|0);b=x[b>>2];continue}break}Ac(j,b,d+8|0);fb=d+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ac(f+8|0,b,c+12|0);fb=c+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if((b|0)!=64){bZ(a,e+2112|0)}}function BW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=x[a>>2];e=Sh(c,x[a+4>>2]);if(e>>>0<b>>>0){h=fb-32|0;fb=h;g=b-e|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=b-c>>8>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{cW(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=zb(a);e=h+12|0;f=Sh(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=lC(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}f=Sh(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Kg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=16777216){$j();p()}c=Ec(b<<8);x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+8>>2];b=x[d+12>>2]}x[e>>2]=c;f=c+(f<<8)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=c+(b<<8)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=x[e+8>>2];b=x[e+8>>2];x[c+8>>2]=e+8;x[c+4>>2]=b+(g<<8);b=x[c>>2];while(1){if(x[c+4>>2]!=(b|0)){cW(b);b=x[c>>2]+256|0;x[c>>2]=b;continue}break}he(c);fb=d+16|0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;b=fb-32|0;fb=b;Id(b+24|0,x[c>>2],x[d>>2]);j=b+16|0;d=x[b+24>>2];k=x[b+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=i;x[c+12>>2]=d;while(1){if(pd(d,k)){d=eW(d);yc(eW(x[c+8>>2]),d,256);d=dW(c+12|0);dW(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(f+8|0,c,b+12|0);fb=b+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-256|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if(b>>>0<e>>>0){fW(a,c+(b<<8)|0)}}function H7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+944|0;x[a+940>>2]=k;j=Gy(k,100,11182,a+16|0);x[a+48>>2]=1205;l=a+48|0;o=Be(a+520|0,0,l);x[a+48>>2]=1205;l=Be(a+512|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=rj(a+940|0,j,11182,a);if((j|0)!=-1){k=x[a+940>>2];Te(o,k);Te(l,Fd(j<<2));h=x[l>>2];if(!Nj(h)){break d}}x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+508|0,x[d+28>>2]);x[31725]=0;r=R(1217,x[a+508>>2])|0;f=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31725]=0;V(1228,r|0,k|0,j+k|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}q=(j|0)>0?y[k|0]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31725]=0;ka(1256,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}x[a+36>>2]=1205;c=Be(a+40|0,0,a+36|0);k=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Te(c,Fd(m<<2));k=x[c>>2];if(k){break h}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31725]=0;ma(1257,k|0,a+36|0,a+32|0,m|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;b=ea(1237,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}Qb(g);Qb(f);tb(i)}Zb(a+508|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);Qb(g);Qb(f);tb(i);Zb(a+508|0);Lc(l);Lc(o);fb=a+1056|0;return b|0}p()}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],r)+D(w[i+4>>1],s)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=nva(m,F,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=nva(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=nva(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function L7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+336|0;x[a+332>>2]=k;j=Gy(k,100,11182,a+16|0);x[a+48>>2]=1205;l=a+48|0;o=Be(a+216|0,0,l);x[a+48>>2]=1205;l=Be(a+208|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=rj(a+332|0,j,11182,a);if((j|0)!=-1){k=x[a+332>>2];Te(o,k);Te(l,Fd(j));h=x[l>>2];if(!Nj(h)){break d}}x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+204|0,x[d+28>>2]);x[31725]=0;r=R(28,x[a+204>>2])|0;f=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31725]=0;V(1215,r|0,k|0,j+k|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}q=(j|0)>0?y[k|0]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31725]=0;ka(1254,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}x[a+36>>2]=1205;c=Be(a+40|0,0,a+36|0);k=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Te(c,Fd(m));k=x[c>>2];if(k){break h}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31725]=0;ma(1255,k|0,a+36|0,a+32|0,m|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;b=ea(23,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}tb(g);tb(f);tb(i)}Zb(a+204|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);tb(g);tb(f);tb(i);Zb(a+204|0);Lc(l);Lc(o);fb=a+448|0;return b|0}p()}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],s)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=nva(m,G,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=nva(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=nva(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function gga(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=fr(1,32);d:{e:{if(!j){a=Xm(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31725]=0;e=P(36,k+24|0,e|0)|0;m=x[31725];x[31725]=0;j:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break j}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31725]=0;e=P(36,k+12|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break g}gu(c,e)}tb(e);i=i+8|0;continue}}x[31725]=0;e=R(856,104)|0;i=x[31725];x[31725]=0;k:{l:{m:{if((i|0)!=1){x[31725]=0;d=P(995,f|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=k+4|0;f=x[re(k+8|0,d)>>2];x[31725]=0;a=ha(1026,e|0,a|0,b|0,f|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break k}i=T(0)|0;Vc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Vc(k+4|0);x[j+24>>2]=a+8;Ul(c);break d}i=T(0)|0}Ul(c);Y(i|0)|0;x[31725]=0;V(989,4973,j|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31725]=0;V(989,4973,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Tb()}p()}function YX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Rb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Bf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Dh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Dh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Dh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}xD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}fb=f+16|0;return g}function z7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;r=fb-16|0;fb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=fb-16|0;fb=s;v=Mh(s+12|0,x[a+8>>2]);m=j-c|0;k=0;n=0;o=fb-1040|0;fb=o;q=x[e>>2];x[o+12>>2]=q;p=f?f:o+16|0;l=f?g-f>>2:256;e:{f:{g:{if(!(!q|!l)){while(1){i=m>>>2|0;if(!(m>>>0>131|i>>>0>=l>>>0)){i=q;break f}t=DK(p,o+12|0,i>>>0<l>>>0?i:l,b);i=x[o+12>>2];if((t|0)==-1){l=0;k=-1;break g}u=(o+16|0)!=(p|0)?t:0;l=l-u|0;p=(u<<2)+p|0;m=i?(m+q|0)-i|0:0;k=k+t|0;if(!i){break g}q=i;if(l){continue}break}break g}i=q}if(!i){break e}}if(!(!l|!m)){n=i;i=k;while(1){h:{k=xt(p,n,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:n=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}n=k+n|0;x[o+12>>2]=n;i=i+1|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}n=i}if(f){x[e>>2]=n}fb=o+1040|0;Lh(v);fb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=dy(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!dy(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=r+16|0;return a|0}f=x[h>>2];continue}}function ZR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){e=x[a+480180>>2];i=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(e&16777248)){break e}i=!(h&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}h=a+480180|0;if(!i){break c}Kb(f+8|0,a+1074312|0,21);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break c}e=D(b,872)+a|0;g=e+1075811|0;v[g|0]=y[g|0]+(y[e+1075815|0]<<2)}g=D(b,872)+a|0;k=g+1075814|0;l=g+1075811|0;e=JA(a,y[k|0],y[l|0]);f:{if(Sj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[g+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=g+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}g=x[h>>2];if(d&4096?g&67633152:0){break a}e=g&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Kb(f+8|0,k,21);g=x[a+480208>>2];g:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){d=g&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(g&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?g&4?6:7:6}Kb(f+8|0,k,80);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;Ek(a,j,c,d,0);e=x[j+656>>2];c=Jq(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=Jq(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}fb=f+16|0}function CP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=fr(1,28);if(!j){a=Xm(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31725]=0;e=P(36,k+24|0,e|0)|0;m=x[31725];x[31725]=0;k:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break k}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31725]=0;e=P(36,k+12|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}gu(c,e)}tb(e);i=i+8|0;continue}}x[31725]=0;e=R(856,80)|0;i=x[31725];x[31725]=0;l:{m:{n:{if((i|0)!=1){x[31725]=0;d=P(995,f|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=k+4|0;f=x[re(k+8|0,d)>>2];x[31725]=0;a=ha(1e3,e|0,a|0,b|0,f|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break l}i=T(0)|0;Vc(d);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Vc(k+4|0);Ul(c);i=j;break d}i=T(0)|0}Ul(c);Y(i|0)|0;x[31725]=0;V(989,15081,j|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(Aq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31725]=0;V(989,15081,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Tb()}p()}function uX(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;g=x[b>>2];h=x[b+4>>2];a:{if((h|0)==(f|0)){j=gc(l+8|0,e,f);b=fb-16|0;fb=b;c=rn(c,d,g,f);x[b+12>>2]=c;e=x[j>>2];b:{if((c|0)<=0){break b}if(f){d=32-f|0;x[b+8>>2]=d;h=c;c=x[ud(b+8|0,b+12|0)>>2];x[b+12>>2]=h-c;d=-1<<f&-1>>>d-c;x[e>>2]=x[e>>2]&(d^-1)|d&x[g>>2];c=c+x[j+4>>2]|0;x[j+4>>2]=c&31;e=(c>>>3&536870908)+e|0;x[j>>2]=e;g=g+4|0;c=x[b+12>>2]}d=(c|0)/32|0;iD(g,d,e);c=c-(d<<5)|0;x[b+12>>2]=c;d=d<<2;e=d+x[j>>2]|0;x[j>>2]=e;if((c|0)<=0){break b}c=-1>>>32-c|0;x[e>>2]=x[e>>2]&(c^-1)|c&x[d+g>>2];x[j+4>>2]=x[b+12>>2]}gc(a,e,x[j+4>>2]);fb=b+16|0;break a}j=a;i=gc(l,e,f);f=fb-16|0;fb=f;e=rn(c,d,g,h);x[f+12>>2]=e;c:{if((e|0)<=0){a=x[i+4>>2];b=x[i>>2];break c}d:{if(!h){a=x[i+4>>2];break d}k=32-h|0;x[f+8>>2]=k;c=f+8|0;b=x[ud(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[i+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[i>>2];n=x[d>>2];c=x[Gb(c,f+4|0)>>2];e=e&(-1<<h&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>h>>>0?e<<a-h:e>>>h-a|0);k=a+c|0;a=k&31;x[i+4>>2]=a;d=d+(k>>>3&536870908)|0;x[i>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+h;x[i+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;h=d^-1;while(1){if((e|0)>=32){b=x[i>>2];e=x[g>>2];x[b>>2]=h&x[b>>2]|e<<a;x[i>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}b=x[i>>2];if((e|0)<=0){break c}g=x[g>>2];x[f+8>>2]=c;k=x[b>>2];h=c;c=x[ud(f+12|0,f+8|0)>>2];e=g&-1>>>32-e;x[b>>2]=k&(d&-1>>>h-c^-1)|e<<a;d=a+c|0;a=d&31;x[i+4>>2]=a;b=(d>>>3&536870908)+b|0;x[i>>2]=b;d=x[f+12>>2]-c|0;x[f+12>>2]=d;if((d|0)<=0){break c}x[b>>2]=x[b>>2]&(-1>>>32-d^-1)|e>>>c;a=x[f+12>>2];x[i+4>>2]=a}gc(j,b,a);fb=f+16|0}fb=l+16|0}function TS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;d=a+1074376|0;e=D(b,872);a:{if(x[(d+e|0)+704>>2]&134218752){break a}f=a+e|0;g=x[f+1075648>>2];if(!Jj(g)|y[g+15|0]&2){break a}d=vm(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}h=x[vd(a+906300|0,d)>>2];if(!h){break a}d=f;j=d+1075780|0;e=y[j|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;d=y[Rb(d+1075784|0,c+8|0)|0];break b}f=y[d+1075783|0];if((f|0)!=46){d=255;if((f|0)!=13){break b}v[c+8|0]=64;d=y[Rb((D(b,872)+a|0)+1075785|0,c+8|0)|0];break b}d=y[(D(b,872)+a|0)+1075785|0]+3>>>2|0}i=a+1074312|0;Kb(c+8|0,i,2);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(Tc(e)){e=y[xb(g+108|0,e-1|0)|0]}cn(a,b,e&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((d|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,d,b);break a}k=x[g+4>>2];c:{if(!e){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Kb(c+8|0,i,28);m=c,n=f+(Hb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;Fe(c+4|0,0,256);f=e;if(Tc(e)){f=y[xb(g+108|0,e-1|0)|0]}Kb(c+8|0,i,117);if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Ql(y[j+2|0],y[j+3|0])){break c}}cn(a,b,f&255,z[c+4>>1])}a=y[g+35|0];Kb(c+8|0,i,101);a=(a|0)==1;f=(d|0)!=255;if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){e=Tc(e)}if(((e?a:f)|0)!=1){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((d|0)!=255){Hu(a,E(E(E(d<<1)/E(-127))+E(1)));break a}Hu(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((d|0)!=255){v[c+8|0]=127;v[c+4|0]=d<<1;n=h,o=7,p=y[Rb(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Gb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function Dg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=i;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];h=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;j=z[a+28>>1];if((j|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=j}h=((c+h|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:g=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 1:g=0;b=z[((b&512?0:b&256?c^255:c)<<1)+26768>>1];break e;case 2:g=0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 3:g=0;b=z[((b&256?0:c)<<1)+26768>>1];break e;case 4:g=0;if(b&512){b=0}else{g=(d&256)>>>8|0;b=(c<<1^b<<24>>31)&254}b=z[(b<<1)+26768>>1];break e;case 5:g=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+26768>>1];break e;case 6:g=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;g=(b&512)>>>9|0;b=g?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+h&65535;a=a>>>0>=8191?8191:a;b=0-g^z[((a&255)<<1)+26256>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],p)+D(w[i+4>>1],q)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=nva(m,C,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=nva(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=nva(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&z);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function lt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=kt(c,d);x[i+4>>2]=1205;n=jt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break b}Te(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31725]=0;h=P(1207,a|0,i+124|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}if((!k|h)==1){x[31725]=0;b=P(1207,a|0,i+124|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31725]=0;o=R(1208,b|0)|0;b=x[31725];x[31725]=0;g:{if((b|0)!=1){if(g){break g}x[31725]=0;o=P(1209,e|0,o|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=v[cc(b,q)|0];j:{if(g){break j}x[31725]=0;r=P(1209,e|0,r<<24>>24)|0;t=x[31725];x[31725]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(r&255)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function ht(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=kt(c,d);x[i+4>>2]=1205;n=jt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break b}Te(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31725]=0;h=P(1222,a|0,i+124|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}if((!k|h)==1){x[31725]=0;b=P(1222,a|0,i+124|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31725]=0;o=R(1223,b|0)|0;b=x[31725];x[31725]=0;g:{if((b|0)!=1){if(g){break g}x[31725]=0;o=P(1224,e|0,o|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Wd(b,q)>>2];j:{if(g){break j}x[31725]=0;r=P(1224,e|0,r|0)|0;t=x[31725];x[31725]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;Vf(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Pg(a);Vb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Zd(a)+1|0;break c}c=hh(a)}d=hh(a);cd(a,e+f|0);e=h+8|0;fe(e,a,d);f=ic(h+28|0,e);ub(e);x[31725]=0;c=U(198,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Wb(x[k>>2],j);m=h,n=wb(x[c>>2]),x[m+8>>2]=n;l=wb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31725]=0;d=R(199,f|0)|0;e=x[31725];x[31725]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31725]=0;d=R(199,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31725]=0;e=R(199,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31725]=0;e=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}}if(d&8){x[31725]=0;i=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}}if(d&16){x[31725]=0;d=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Bf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25502|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}vg(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],p)+D(v[i+2|0],q)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=nva(m,E,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=nva(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=nva(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&A);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function T4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Wd(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Wd(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Wd(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Wd(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Wd(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=nva(s,B,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=nva(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=nva(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Pm(c+80|0,a);x[31725]=0;d=P(463,c+68|0,42271)|0;a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31725]=0;x[c+56>>2]=19989505;x[c+60>>2]=0;a=c+56|0;S(464,e|0,d|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}Eb(d);if(vl(y[e|0])){break e}x[31725]=0;d=P(463,a|0,13434)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;V(495,e|0,b|0,d|0,918);a=x[31725];x[31725]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31725]=0;d=P(463,c+36|0,16760)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;S(919,e|0,c+52|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}Eb(d);x[31725]=0;d=P(463,c+24|0,16750)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;S(919,e|0,c+48|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31725]=0;f=P(463,c|0,14133)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}x[31725]=0;S(920,e|0,d|0,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}Eb(f);if(lc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31725]=0;O(870,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31725]=0;O(921,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}uc(d)}Bh(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}uc(d)}Bh(e);Q(a|0);p()}function dsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;j=Hf(a,c);$d(g,x[a+36>>2]);k=a;a:{if(!j){Pc(g,a+32|0,5);c=0;if(Hb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Pm(e+80|0,x[a+36>>2]);x[31725]=0;a=P(463,e+68|0,26175)|0;c=x[31725];x[31725]=0;b:{c:{d:{e:{if((c|0)!=1){x[31725]=0;x[e+8>>2]=19989505;x[e+12>>2]=0;S(464,f|0,a|0,e+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}Eb(a);if(!vl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31725]=0;a=P(463,e+52|0,10094)|0;c=x[31725];x[31725]=0;f:{g:{h:{i:{if((c|0)!=1){x[31725]=0;c=e+67|0;S(505,f|0,c|0,a|0);h=x[31725];x[31725]=0;if((h|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}Qf(c,50);x[31725]=0;a=P(463,e+40|0,13288)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}x[31725]=0;S(505,f|0,e+66|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Oj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=$B(e+8|0,x[b+12>>2]);x[31725]=0;S(506,b|0,h|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break h}Hk(a);a=x[b>>2]}l=z[Vj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];o=b,q=Oj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[o+16|0]=q;break b}bf(Vj(x[b>>2],a),l);m=x[b>>2];x[31725]=0;i=e+8|0;O(507,i|0,c|0);n=x[31725];x[31725]=0;if((n|0)!=1){x[31725]=0;V(508,f|0,Vj(m,a)|0,i|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}c=c+1|0;Eb(i);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Hk(a);break c}c=N()|0;Eb(a);break c}c=N()|0}Bh(f);Q(c|0);p()}Bh(f);fb=e+192|0;c=j}gf(k,c);fb=g+16|0}function y4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[cc(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=v[cc(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=v[cc(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[cc(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[cc(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=nva(s,C,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=nva(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=nva(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function pw(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;de(a,1,Rb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;de(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42208|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Rb(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;de(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}de(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;de(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;de(a,3,e+14|0);break a}d=c&240;if(!d){de(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;de(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;de(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;de(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;de(a,1,e+14|0);break a}v[e+14|0]=0;de(a,0,e+14|0)}fb=e+16|0}function qV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Th(d);d=x[d+8>>2];if(!g){continue}break}break c}d=g_(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Th(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Th(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Cn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Cn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Th(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ur(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Th(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;tr(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;ur(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;tr(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Th(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;ur(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;tr(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function R7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1238;b=a+16|0;h=Be(a+200|0,a+208|0,b);i=a+192|0;bd(i,x[e+28>>2]);x[31725]=0;j=R(1217,x[a+192>>2])|0;k=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+191|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1247,a+620|0,c|0,d|0,i|0,e|0,f|0,a+191|0,j|0,h|0,a+196|0,a+608|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(!c){break e}c=y[14638]|y[14639]<<8|(y[14640]<<16|y[14641]<<24);v[a+183|0]=c;v[a+184|0]=c>>>8;v[a+185|0]=c>>>16;v[a+186|0]=c>>>24;c=y[14635]|y[14636]<<8|(y[14637]<<16|y[14638]<<24);x[a+176>>2]=y[14631]|y[14632]<<8|(y[14633]<<16|y[14634]<<24);x[a+180>>2]=c;x[31725]=0;V(1228,j|0,a+176|0,a+186|0,a+128|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}x[a+4>>2]=1205;d=Be(a+8|0,0,a+4|0);e=b;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Te(d,Fd((c>>2)+2|0));e=x[d>>2];if(e){break f}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((LK(a+16|0,a)|0)!=1){x[31725]=0;W(1240,8e3);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+128|0;l=e,m=y[(a+176|0)+(sy(b,b+40|0,x[c>>2])-b>>2)|0],v[l|0]=m;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31725]=0;b=P(1222,a+620|0,a+616|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Zb(a+192|0);Lc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+192|0);Lc(h);Q(c|0);p()}p()}function Y7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1238;b=a+16|0;h=Be(a+152|0,a+160|0,b);j=a+144|0;bd(j,x[e+28>>2]);x[31725]=0;i=R(28,x[a+144>>2])|0;k=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+143|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1239,a+268|0,c|0,d|0,j|0,e|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(!c){break e}c=y[14638]|y[14639]<<8|(y[14640]<<16|y[14641]<<24);v[a+135|0]=c;v[a+136|0]=c>>>8;v[a+137|0]=c>>>16;v[a+138|0]=c>>>24;c=y[14635]|y[14636]<<8|(y[14637]<<16|y[14638]<<24);x[a+128>>2]=y[14631]|y[14632]<<8|(y[14633]<<16|y[14634]<<24);x[a+132>>2]=c;x[31725]=0;V(1215,i|0,a+128|0,a+138|0,a+118|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}x[a+4>>2]=1205;d=Be(a+8|0,0,a+4|0);e=b;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Te(d,Fd(c+2|0));e=x[d>>2];if(e){break f}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((LK(a+16|0,a)|0)!=1){x[31725]=0;W(1240,8e3);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+118|0;i=q_(b);l=e,m=y[((Li(b,i,y[c|0])-a|0)+a|0)+10|0],v[l|0]=m;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Zb(a+144|0);Lc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+144|0);Lc(h);Q(c|0);p()}p()}function MQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=fb-16|0;fb=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;Yz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=oc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[ad(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(nu(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;l=i>>>0<=1?1:i;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(l|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(nu(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(nu(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(nu(o^(x[p>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[yb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[p>>2]=j;h=h+1|0;continue}}fb=m+16|0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];d=pm(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{h=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(h>>>0<=(b-e|0)/52>>>0){pA(a,h,c);break c}f=zb(a);d=tR(a,pm(x[a>>2],e)+h|0);g=pm(x[a>>2],x[a+4>>2]);e=fb-16|0;fb=e;b=i+12|0;Kg(b+12|0,f);d:{if(!d){f=0;d=0;break d}qR(e+8|0,d);f=x[e+12>>2];d=x[e+8>>2]}x[b>>2]=d;g=d+D(g,52)|0;x[b+8>>2]=g;x[b+4>>2]=g;l=nc(b),m=d+D(f,52)|0,x[l>>2]=m;fb=e+16|0;x[31725]=0;S(928,b|0,h|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);c=x[c>>2];g=x[d>>2];d=fb+-64|0;fb=d;f=x[f>>2];x[d+56>>2]=f;x[d+60>>2]=c;x[d+52>>2]=f;e=Se(d+24|0,e,d+52|0,d+56|0);x[d+16>>2]=x[e+8>>2];f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;Re(d+36|0,d+8|0);while(1){if(pd(c,g)){c=c-52|0;e=_l(nR(x[d+56>>2]),c);x[e+20>>2]=x[c+20>>2];f=x[c+16>>2];x[e+12>>2]=x[c+12>>2];x[e+16>>2]=f;EW(e+24|0,c+24|0);_c(e+36|0,c+36|0);x[e+48>>2]=x[c+48>>2];c=oR(d+60|0);oR(d+56|0);c=x[c>>2];continue}break}Qe(d+36|0);j=x[d+56>>2];if(!y[d+48|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+44>>2]>>2]);k=x[vb(f+8|0,x[x[d+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ci(c,k)){e=fb-16|0;fb=e;x[e+12>>2]=c;x[e+12>>2]=x[e+12>>2]+52;fb=e+16|0;Dk(nR(x[e+12>>2]));c=x[am(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=d- -64|0;x[b+4>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0;pR(b)}fb=i+32|0;break a}a=N()|0;pR(b);Q(a|0);p()}return}if(b>>>0<d>>>0){uR(a,e+D(b,52)|0)}}function F7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=IJ(Lk(zd(n),1),tl(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=At(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}h=x[Wd(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=IJ(zd(m),tl(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!yj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=At(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=At(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}s=-1;if(!Ad(x[l+4>>2],y[l+11|0])){s=v[cc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[cc(l,t)|0]==127){break f}s=v[cc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}it(A,h)}u=u+1|0;continue}break}}function pe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(53,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[cc(c,a)|0];x[31725]=0;O(35,b|0,((d|0)<0?65533:d&255)|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(53,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;f:{if((d|0)!=1){while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[cc(c,a)|0];x[31725]=0;O(35,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:jf(a,c,48928);return;case 4:jf(a,c,49952);return;case 5:jf(a,c,50976);return;case 6:jf(a,c,52e3);return;case 7:jf(a,c,53024);return;case 8:jf(a,c,54048);return;case 9:jf(a,c,55072);return;case 10:jf(a,c,56096);return;case 11:jf(a,c,57120);return;case 12:jf(a,c,58144);return;case 13:jf(a,c,59168);return;case 14:jf(a,c,60192);return;case 15:jf(a,c,61216);return;case 16:jf(a,c,62240);return;case 17:jf(a,c,63264);return;case 18:jf(a,c,64288);return;case 19:jf(a,c,65312);return;case 20:jf(a,c,66336);return;case 21:jf(a,c,67360);return;case 22:jf(a,c,68384);return;case 23:jf(a,c,69408);return;case 24:hB(a,c,70432);return;case 25:hB(a,c,48928);return;case 26:hB(a,c,67360);return;default:a=ac(8);x[31725]=0;b=P(16,a|0,11106)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}F_(a,c);return}da(b|0,125132,17);p()}a=N()|0;Qb(b);Q(a|0);p()}function Ika(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(Dd(x[a+24>>2])){break f}i=Yc(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;h=f+8|0;x[h>>2]=-1;x[h+4>>2]=-1;x[31725]=0;g=iI(66);d=x[31725];x[31725]=0;b=hb;if((d|0)==1){T(0)|0;Tb();p()}e=fb-16|0;fb=e;d=we(e+8|0,nva(g,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=sA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=vR(h,f,zb(f));x[31725]=0;g=iI(67);d=x[31725];x[31725]=0;b=hb;if((d|0)==1){T(0)|0;Tb();p()}h=a+24|0;j=f,k=sA(rR(g,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=vR(e,f,zb(f));g=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31725]=0;x[c+8>>2]=b;d=c+8|0;O(60,e|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;x[c+8>>2]=g;O(60,e|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}d=a+4|0;g=0;g:{while(1){if(Yc(x[a+8>>2],y[a+15|0])>>>0<=g>>>0){b=wb(x[e>>2]);a=wb(x[e+4>>2]);x[31725]=0;d=U(61,c+8|0,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break g}a=N()|0;break b}b=y[cc(d,g)|0];x[31725]=0;x[c+8>>2]=b;O(60,e|0,c+8|0);b=x[31725];x[31725]=0;if((b|0)!=1){g=g+1|0;continue}break}a=N()|0;break b}x[31725]=0;b=R(62,d|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;wA(h,a);Gj(a);bn(d);uc(e);break f}a=N()|0;bn(d);break b}hb=g;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31725]=0;S(65,b|0,c+8|0,c+16|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;uc(b);Q(a|0);p()}x[31725]=0;d=R(62,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;wA(h,a);Gj(a);bn(b)}fb=c+32|0;return}a=N()|0;bn(b);break a}a=N()|0;break b}a=N()|0}uc(e)}Q(a|0);p()}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;h=fb-32|0;fb=h;e=DU(h+20|0,1<<x[b+12>>2]);f=x[e>>2];while(1){c=x[a>>2];if(jh(c,x[a+4>>2])>>>0>d>>>0){c=Ve(c,d);CU(Xd(f,d),C[c>>3]);d=d+1|0;continue}break}BU(b,e);q=h,r=wb(x[e>>2]),x[q>>2]=r;p=wb(x[e+4>>2]);while(1){f=x[h>>2];if(Ib(f,p)){l=fb-32|0;fb=l;m=F(C[f+8>>3]);i=F(C[f>>3]);o(+i);n=j(1)|0;g=j(0)|0;o(+m);d=j(1)|0;c=j(0)|0;d=(d|0)==(n|0)&c>>>0>g>>>0|d>>>0>n>>>0;k=d?i:m;o(+k);c=j(1)|0;g=j(0)|0;n=c>>>20|0;a:{if((n|0)==2047){break a}i=d?m:i;b:{if(!(c|g)){break b}o(+i);c=j(1)|0;j(0)|0;c=c>>>20|0;if((c|0)==2047){break b}if((c-n|0)>=65){k=i+k;break a}c:{if(c>>>0>=1534){k=k*190109156629516e-225;i=i*190109156629516e-225;m=5.260135901548374e210;break c}m=1;if(n>>>0>572){break c}k=k*5.260135901548374e210;i=i*5.260135901548374e210;m=190109156629516e-225}NL(l+24|0,l+16|0,i);NL(l+8|0,l,k);k=m*M(C[l>>3]+C[l+16>>3]+C[l+8>>3]+C[l+24>>3]);break a}k=i}fb=l+32|0;CU(f,rq(k));_o(h);continue}break}AU(b,e);zU(e);g=x[e>>2];f=Kk(g,x[e+4>>2])>>>1|0;c=f>>>0<=1?1:f;d=1;while(1){if((d|0)!=(c|0)){PB(Xd(g,d),2);PB(Xd(g,d+f|0),0);d=d+1|0;continue}break}BU(b,e);q=h,r=wb(x[e>>2]),x[q+16>>2]=r;f=wb(x[e+4>>2]);while(1){g=x[h+16>>2];if(Ib(g,f)){yU(h,C[g>>3],C[g+8>>3]);c=x[h+12>>2];x[g+8>>2]=x[h+8>>2];x[g+12>>2]=c;c=x[h+4>>2];x[g>>2]=x[h>>2];x[g+4>>2]=c;_o(h+16|0);continue}break}AU(b,e);zU(e);f=x[a>>2];c=jh(f,x[a+4>>2]);b=x[e>>2];d=0;while(1){if((d|0)==(c|0)){qn(e);fb=h+32|0}else{a=Xd(b,d);q=Ve(f,d),s=C[a>>3],C[q>>3]=s;d=d+1|0;continue}break}}function wna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=nva(q,B,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=nva(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=nva(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function kQ(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=fb-16|0;fb=c;e=a+4208|0;b=Uz(B[yb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=Bq(E(B[Ym(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[yb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=De(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Uz(B[yb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Ym(c+12|0,c+8|0)>>2];m=c,n=E(Uz(B[yb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Ym(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=fb-16|0;fb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=qo(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=qo(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=qo(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=qo(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=qo(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Xy(b,f+8|0);b=qo(C[f+8>>3],d&1)}fb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=Bq(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44064>>2];fb=c+16|0}function GH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-432|0;fb=d;a:{f=Ss(d+428|0,b);e=x[f>>2];b:{if(!Dd(e)){x[31725]=0;b=P(36,d+416|0,b|0)|0;a=x[31725];x[31725]=0;c:{d:{e:{if((a|0)!=1){x[31725]=0;a=d+16|0;S(1017,a|0,17691,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}jq(e);if(!fq(a+8|0,22267,x[f>>2])){x[a+8>>2]=2147483647}if(!fq(a+12|0,22267,x[f>>2])){x[a+12>>2]=2147483647}x[31725]=0;O(274,a+16|0,22267);b=x[31725];x[31725]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22267;e=Gi(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)==-1){x[31725]=0;W(1240,12661);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31725]=0;b=d+16|0;e=U(1352,a+28|0,b|0,b+(e<<2)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22267;x[d+8>>2]=0;x[d+12>>2]=0;h:{g=d+4|0;i=d+8|0;h=Gi(b,g,100,i,x[f>>2]);if((h|0)!=-1){x[31725]=0;U(1352,a+40|0,b|0,b+(h<<2)|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break f}x[d+4>>2]=22267;x[d+8>>2]=0;x[d+12>>2]=0;b=Gi(b,g,100,i,x[f>>2]);if((b|0)!=-1){break h}}x[31725]=0;W(1240,12661);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[31725]=0;g=d+16|0;U(1352,a+52|0,g|0,g+(b<<2)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;b=P(1353,d+416|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}hi(a+68|0,c);hi(a+72|0,c);Qb(b);ol(f);fb=d+432|0;return}a=N()|0}ol(f);Q(a|0);p()}p()}function Mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=nva(q,C,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=nva(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=nva(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=nva(q,B,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=nva(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=nva(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Oq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Fe(h+12|0,0,127);Fe(h+8|0,0,127);k=a+1074312|0;j=Ob(k,1);i=x[h+8>>2];l=x[h+12>>2];if(!j){v[b+838|0]=i;v[b+837|0]=l;x[b+780>>2]=0}m=D(d+256|0,l);j=(m|0)/256|0;a:{if(!(i|!Ob(k,36)|(m|0)<65024)){j=-1;if(!(y[b+851|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;e=De(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,l)>>>0);b:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(De(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;PT(d,E(120),E(2e4));AB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));c:{if(!(!Ob(k,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break c}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;AB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);d:{if(y[b+845|0]==1){n=b,p=Rl(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Rl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Rl(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break d}d=Rl(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Rl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Rl(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return j}function J7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=lp(Pe(zd(n),1),Df(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=qm(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}p=y[cc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=lp(zd(m),Df(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Kf(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=qm(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=qm(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}q=-1;if(!Ad(x[l+4>>2],y[l+11|0])){q=v[cc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[cc(l,t)|0]==127){break e}q=v[cc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Hm(A,x[c>>2])}u=u+1|0;continue}break}}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Zj(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=ce(a);a:{if(c){g=ec(a);while(1){a=c;c=a+14|0;if(jv(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!jv(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=ec(h);j=Ch(e,Ec(48),Mg(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=ec(j),l=1,v[k+4|0]=l;fb=i+16|0;$g(h,x[e+12>>2],g,x[e>>2]);b=le(e);dm(e);d=1}_g(f+8|0,x[vb(e,b)>>2],d);fb=e+16|0;a=ip(x[f+8>>2]);fb=f+16|0;return a+32|0}function zu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=ac(8);x[31725]=0;b=P(51,a|0,22267)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break g}b=N()|0;jc(a);break a}if(!x[b>>2]){a=ac(8);x[31725]=0;b=R(859,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break f}b=N()|0;jc(a);break a}d=x[b>>2];j=x[b+4>>2];b=fb-16|0;fb=b;mf(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;DG(g,h,x[b+12>>2]);x[g+12>>2]=0;fb=b+16|0;i:{j:{if(a&2){b=Rn(f+88|0,g);x[31725]=0;b=R(860,b|0)|0;e=x[31725];x[31725]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Rn(f+68|0,g);x[31725]=0;e=R(861,d|0)|0;h=x[31725];x[31725]=0;d=1;if((h|0)==1){break e}if((e|0)==1){break j}d=Rn(f+48|0,g);x[31725]=0;h=P(862,d|0,c|0)|0;i=x[31725];x[31725]=0;d=1;if((i|0)==1){break d}if((h|0)==1){break j}d=Rn(f+28|0,g);x[31725]=0;i=P(863,d|0,c|0)|0;k=x[31725];x[31725]=0;d=1;if((k|0)==1){break c}if((i|0)==1){break j}e=0-((b|0)==-1|(e|0)==-1|(h|0)==-1|(i|0)==-1)|0}k:{if(!(a&1)){break k}b=29920;while(1){if((b|0)==30496){break k}a=x[b>>2];if(a){d=Rn(f+8|0,g);x[31725]=0;a=P(a|0,d|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}fb=f+128|0;return d}b=N()|0;break a}da(b|0,125292,17);p()}da(b|0,125188,17);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=nva(q,z,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=nva(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=nva(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function W4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-576|0;fb=c;Sb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;while(1){a:{if((d|0)==7){d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Gi(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14278,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Gi(f,h,100,i,x[a>>2]);if(j+1>>>0<=1){break a}k=D(d,12)+a|0;Gm(k+172|0,f,f+(j<<2)|0);fa(e|0,100,13333,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Gi(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Gm(k+316|0,f,(e<<2)+f|0);d=d+1|0;continue}break}d=c+32|0;Gm(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;e=Gi(d,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){Gm(a+472|0,d,(e<<2)+d|0);d=c+8|0;Vs(d,a,99,b);ph(a+484|0,d);Qb(d);Vs(d,a,114,b);ph(a+496|0,d);Qb(d);Vs(d,a,120,b);ph(a+508|0,d);Qb(c+8|0);Vs(d,a,88,b);ph(a+520|0,d);Qb(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14291,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Gi(f,h,100,i,x[a>>2]);if(j+1>>>0>1){k=D(d,12)+a|0;Gm(k+4|0,f,f+(j<<2)|0);fa(e|0,100,13540,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Gi(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Gm(k+88|0,f,(e<<2)+f|0);d=d+1|0;continue}}break}jo(12661);p()}function U1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Ri(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){xu(a);break a}Ri(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Vb(b,4)}j=f,k=Ri(b),x[j+44>>2]=k;Vb(b,4);h=Ri(b);i=Ri(b);if(!((h|0)>0&(i|0)>36)){xu(a);break a}if(!Ld(Hd(x[e>>2],x[yb(x[d>>2],g)>>2]),13165)){xu(a);break a}e=f+4|0;vF(e,b,i,h);d=ic(f+24|0,e);ub(e);b=x[d>>2];x[31725]=0;b=R(174,b|0)|0;e=x[31725];x[31725]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31725]=0;R(184,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31725]=0;P(185,d|0,8)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31725]=0;P(185,d|0,16)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}}x[31725]=0;R(186,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31725]=0;R(186,d|0)|0;c=x[31725];x[31725]=0;b=8;break g}h:{if(b>>>0>=100){x[31725]=0;P(185,d|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31725]=0;R(186,d|0)|0;c=x[31725];x[31725]=0;b=4}if((c|0)==1){break b}x[31725]=0;P(185,d|0,b|0)|0;break e}x[31725]=0;R(186,d|0)|0}b=x[31725];x[31725]=0;if((b|0)==1){break b}x[31725]=0;c=R(186,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;b=f+4|0;S(187,b|0,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}j=ic(a,b),k=x[f+44>>2],x[j+20>>2]=k;ub(b)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function Nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=nva(q,C,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=nva(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=nva(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function zh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){To(f,g);break b}To(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];TU(x[a>>2],d);TU(x[a+4>>2],d);w[a+22>>1]=h;UB(a);VU(a);v[a+21|0]=f;UB(a);VU(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;UB(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27360|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Uo(a);w[a+14>>1]=z[((e&15)<<1)+27392>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22252|0];UU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Uo(a);w[a+26>>1]=e&15;Uo(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Uo(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];o=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((o|0)==1&h>>>0>2147483648|o>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+44>>2];k=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=k;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){k=b;if(d){b=Yb(b,-16777216,16776704);l=nva(r,A,b,b>>31);m=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=nva(b,b>>31,s,B);l=b+l|0;n=hb+m|0;n=b>>>0>l>>>0?n+1|0:n;b=Yb(e,-16777216,16776704);e=nva(q,z,b,b>>31);m=e+l|0;b=hb+n|0;b=e>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;j=j+v|0;x[c>>2]=D(b,j>>12)+x[c>>2];i=i+u|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(g+8|0,h,o);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=k;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=k;x[a+24>>2]=i>>12;fb=g+16|0}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=nva(q,A,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=nva(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=nva(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];m=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((m|0)==1&h>>>0>2147483648|m>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];k=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=k;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){k=e;if(d){e=Yb(e,-16777216,16776704);f=nva(p,A,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=nva(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];l=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=nva(b,b>>31,q,B);l=l+f|0;b=hb+e|0;b=f>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;j=j+u|0;x[c>>2]=D(b,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,b);Pb(g+8|0,h,m);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=k;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=b;x[a+44>>2]=k;x[a+24>>2]=i>>12;fb=g+16|0}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;yc(a,d+24604|0,40);x[e+8>>2]=b;MA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ac(8);x[31725]=0;b=P(36,d+4|0,10830)|0;a=x[31725];x[31725]=0;i:{if((a|0)!=1){pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;jc(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;b=e+8|0;a=x[a+24>>2];if(!yz(b,a+24648|0)){break d}KA(a,b);break d;case 3:f=e+8|0;d=x[a+24>>2];yc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){$t(f,x[Zq(b+8|0)+32>>2]);To(f,x[Zq(b+8|0)+36>>2]);break j}if((c|0)<=0){$t(f,0);To(f,0);break j}a=D(c,1e3);$t(f,a);To(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}MA(d,e+8|0);break d;default:d=ac(8);x[31725]=0;c=P(36,e+8|0,10385)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(d,c);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=De(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;jc(d)}Q(b|0)}p()}function Ek(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{if(y[a+480208|0]&16){if((f|0)==4){break g}f=d>>31;x[i+12>>2]=(f^d)-f;wc(i+12|0,1020);h=x[i+12>>2];f=c;h:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35440:35504)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?35568:36592)>>2];break h}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35504:35440)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?36592:35568)>>2]}j=nva(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Gc(ova(j,h,65536,0),hb);x[k>>2]=f;if((g|0)!=(f|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!((d|0)>0^f)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!f){break g}if((d|0)<0){f=nva(g,0,14317456,0);h=hb;g=nva(g,0,0-d|0,0);d=hb;g=g+14317456|0;d=g>>>0<14317456?d+1|0:d;f=bT(pva(f,h,g,d),hb);break d}d=nva(g,g>>31,d,0);f=hb;if((f|0)>=0&d>>>0>=14317456|(f|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=bT(pva(nva(g,0,14317456,0),hb,14317456-d|0,0-(f+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)<=0){break b}break a}f=g-d|0;break d}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function Z0(){var a=0,b=0,c=0;if(!y[500080]){a=fb-16|0;fb=a;Jt(499728);x[124944]=-1;x[124942]=499784;x[124940]=126088;x[124932]=94636;v[499780]=0;b=a+12|0;bd(b,x[124933]);c=x[x[124932]+8>>2];x[31725]=0;O(c|0,499728,b|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){Zb(b);fb=a+16|0;break a}b=N()|0;Zb(a+12|0);lo(499728);Q(b|0);p()}Nt(499056);x[124764]=94768;x[124762]=94748;x[124763]=0;so(499056,499728);$K(499792,126232,499840);Iy(499224,499792);$K(499848,125936,499896);Iy(499392,499848);Iy(499560,x[x[x[124848]-12>>2]+499416>>2]);_K(x[x[124762]-12>>2]+499048|0);XK(x[x[124848]-12>>2]+499392|0);_K(x[x[124848]-12>>2]+499392|0);a=fb-16|0;fb=a;mL(499904);x[124988]=-1;x[124986]=499960;x[124984]=126088;x[124976]=95028;v[499956]=0;b=a+12|0;bd(b,x[124977]);c=x[x[124976]+8>>2];x[31725]=0;O(c|0,499904,b|0);c=x[31725];x[31725]=0;b:{if((c|0)!=1){Zb(b);fb=a+16|0;break b}b=N()|0;Zb(a+12|0);Dt(499904);Q(b|0);p()}WK(499144);x[124786]=95160;x[124784]=95140;x[124785]=0;so(499144,499904);ZK(499968,126232,500016);Hy(499308,499968);ZK(500024,125936,500072);Hy(499476,500024);Hy(499644,x[x[x[124869]-12>>2]+499500>>2]);YK(x[x[124784]-12>>2]+499136|0);XK(x[x[124869]-12>>2]+499476|0);YK(x[x[124869]-12>>2]+499476|0);v[500080]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Fd((x[a+12>>2]<<2)+4|0);x[125022]=b;if(!b){break c}b=Fd(x[a+8>>2]);if(b){c=x[125022];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125022]=0}fb=a+16|0;x[124213]=42;x[124231]=500180}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[xb(g,b)|0];if((d|0)==255){break c}if(v[xb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[_b(f,d)>>1]!=65535){if(z[_b(f,d)>>1]!=(b|0)){break c}}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[_b(f,d)>>1]!=65535){if(!(y[xb(i,d)|0]&32)){h=v[xb(g,z[_b(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=xb(g,z[_b(f,e)>>1]),k=255,v[j|0]=k;j=_b(f,e),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k}d=Xl(a,b)}g=d&255;if((g|0)==255){break a}if(Nj(x[a>>2])){break a}e=Hd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=OU(g);h=f+3|0;d=0;while(1){if((d|0)==2){zh(x[a>>2],x[a+4>>2],b,bv(g)|192,y[xb(c,10)|0])}else{e=d?h:f;zh(x[a>>2],x[a+4>>2],b,(e|32)&65535,y[xb(c,d)|0]);zh(x[a>>2],x[a+4>>2],b,(e|64)&65535,y[xb(c,d+2|0)|0]);zh(x[a>>2],x[a+4>>2],b,(e|96)&65535,y[xb(c,d+4|0)|0]);zh(x[a>>2],x[a+4>>2],b,(e|128)&65535,y[xb(c,d+6|0)|0]);zh(x[a>>2],x[a+4>>2],b,(e|224)&65535,y[xb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function PO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-32|0;fb=d;g=Nb(a);a:{b:{c:{a=x[b+36>>2];c=x[b+40>>2];d:{if(Ib(a,c)){sc(d+28|0);break d}x[31725]=0;a=d+16|0;O(1078,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;c=R(1062,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[d+28>>2]=c;of(a);c=x[b+40>>2];a=x[b+36>>2]}e:{if(Ib(a,c)){c=b+36|0;break e}c=x[d+28>>2];a=x[c>>2]}e=x[c+4>>2];x[31725]=0;O(178,g|0,oj(a,e)|0);a=x[31725];x[31725]=0;f:{if((a|0)!=1){j=d,k=wb(x[c>>2]),x[j+12>>2]=k;h=wb(x[c+4>>2]);g:{h:{i:{j:{k:{while(1){c=x[d+12>>2];if(!Ib(c,h)){Fl(d+28|0);fb=d+32|0;return}a=y[c+16|0];e=x[x[b+24>>2]+484360>>2];x[31725]=0;e=Vj(e,a);O(1079,d|0,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[31725]=0;a=d+16|0;O(1065,a|0,d|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;O(180,g|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break k}tb(a);tb(d);f=jl(x[g+4>>2]);l:{if(!Ad(x[f+4>>2],y[f+11|0])){break l}c=x[c+12>>2];if(!bj(e,c&255)){break l}f=x[b+24>>2];i=x[f+1298404>>2];c=z[_b(x[e>>2],c)>>1];e=x[f+484344>>2];x[31725]=0;O(1072,d|0,Wb(e,c)|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}x[31725]=0;S(1080,a|0,i|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break h}Ab(jl(x[g+4>>2]),a);tb(a);tb(d)}fA(d+12|0);continue}break}a=N()|0;break j}a=N()|0;tb(d+16|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(d);break f}a=N()|0;break f}a=N()|0}Fl(d+28|0);break a}a=N()|0;of(d+16|0);break a}a=N()|0}Td(g);Q(a|0);p()}function G8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;qy(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31725]=0;b=P(1222,a+380|0,a+376|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+204>>2]=b+c}x[31725]=0;b=R(1223,x[a+380>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(py(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31725]=0;R(1225,a+380|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}oK(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+220|0,a+32|0,x[a+28>>2],e);x[31725]=0;b=P(1222,a+380|0,a+376|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function Cla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];g=x[c>>2];x[31725]=0;b=U(152,g|0,b|0,l|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(!(n>>>0<o>>>0&b)){break g}x[31725]=0;b=f+8|0;S(187,b|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break c}g=ic(f+28|0,b);ub(b);x[31725]=0;O(576,b|0,g|0);j=x[31725];x[31725]=0;if((j|0)==1){break e}z=$e(b);q=x[f+8>>2];A=q-4|0;j=0;while(1){if((e|0)==(j|0)){Kc(f+8|0);ub(g);n=(q-l<<1)+n|0;continue h}x[31725]=0;h=R(569,g|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;b=R(199,g|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break f}x[f>>2]=b;Fe(f,0,89);x[31725]=0;P(185,g|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}k=j+n|0;b=e+j<<2;i:while(1){j:{if(k>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28632|0];B=h;h=w[(r<<1)+28640>>1];h=(((0-(i&1)&h>>2)+(h>>3)|0)+(i<<30>>31&h>>1)|0)+(h&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?h:0-h|0);Fe(f,0,88);Fe(f+4|0,-32768,32767);h=x[f+4>>2];w[(k<<1)+a>>1]=h;m=m+1|0;k=e+k|0;b=b+s|0;continue}}break}j=j+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Kc(f+8|0);break d}b=N()|0}ub(g);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function goa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Pj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(c+8|0,x[vb(c+4|0,f)>>2]);a:{b:{if(d){x[31725]=0;O(642,f|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}QE(f,d)}g=c+8|0;Qd(g);_j(g);fb=c+16|0;break a}a=N()|0;_j(c+8|0);Q(a|0);p()}c=x[a>>2];g=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(h&65535)){break c}b=wb(c);d=wb(x[a+4>>2]);c=fb-16|0;fb=c;b=LC(b,d,z[e+30>>1]);x[c+12>>2]=b;if(Ib(b,d)){x[c+8>>2]=b;while(1){b=x[Md(c+8|0)>>2];if(Ib(b,d)){b=z[b>>1];if((b|0)==z[e+30>>1]){continue}w[x[c+12>>2]>>1]=b;Md(c+12|0);continue}break}b=x[c+12>>2]}fb=c+16|0;b=vb(e+12|0,b);c=x[vb(e+8|0,wb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(rp(d,wb(b))<<1)+b|0;if(Ib(d,c)){Jn(a,Wg(b+(rp(c,d)<<1)|0,x[a+4>>2],b))}wb(b);k=e,l=wb(x[a>>2]),x[k+4>>2]=l;d=wb(x[a+4>>2]);while(1){b=x[e+4>>2];if(Ib(b,d)){d:{c=x[a+24>>2];h=x[c+484344>>2];b=z[b>>1];if(!He(h,x[c+484348>>2],b)){break d}b=Wb(h,b);k=e,l=wb(x[b>>2]),x[k>>2]=l;h=wb(x[b+4>>2]);g=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,h)){break d}e:{if(y[b+3|0]!=12){break e}j=Zc(c,g);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[_b(c,i)|0],v[k+5|0]=l}vg(e);continue}}Md(e+4|0);continue}else{b=x[f>>2];d=Zc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[_b(b,c)>>1],w[k+28>>1]=l}break}}}else{k=_b(g,b),l=b-h|0,w[k>>1]=l;h=(z[_b(c,b)>>1]==254)+h|0;b=b+1|0;continue}break}md(f);fb=e+32|0}function P8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;vy(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+192>>2]=b+c}x[31725]=0;b=R(1208,x[a+268>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(uy(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31725]=0;R(1210,a+268|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}oK(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+208|0,a+32|0,x[a+28>>2],e);x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=Ud(c,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;b=b-d|0;d=x[zb(a)>>2];c=x[a+4>>2];a:{if(b>>>0<=(d-c|0)/12>>>0){d=fb-16|0;fb=d;b=tv(d+4|0,a,b);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{HW(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}d=zb(a);d=Dm(i+12|0,Xp(a,Ud(x[a>>2],c)+b|0),Ud(x[a>>2],x[a+4>>2]),d);f=fb-16|0;fb=f;b=FW(f+4|0,d+8|0,b);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){HW(c);c=x[b>>2]+12|0;x[b>>2]=c;continue}break}he(b);fb=f+16|0;f=fb-16|0;fb=f;e=zb(a);b=vb(f+12|0,x[a+4>>2]);g=vb(f+8|0,x[a>>2]);h=vb(f+4|0,x[d+4>>2]);c=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;h=x[h>>2];x[b+56>>2]=h;x[b+60>>2]=c;x[b+52>>2]=h;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];h=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=h;Re(b+36|0,b+8|0);while(1){if(pd(c,g)){EW(Wp(x[b+56>>2]),jl(c));c=sk(b+60|0);sk(b+56|0);c=x[c>>2];continue}break}Qe(b+36|0);h=x[b+56>>2];if(!y[b+48|0]){e=fb-16|0;fb=e;c=vb(e+12|0,x[x[b+44>>2]>>2]);j=x[vb(e+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ci(c,j)){vC(tx(c));c=x[il(g+12|0)>>2];continue}break}fb=g+16|0;fb=e+16|0}fb=b- -64|0;x[d+4>>2]=h;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=f+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-12|0;x[d+8>>2]=b;vC(b);continue}break}a=x[d>>2];if(a){xs(d);Db(a)}}fb=i+32|0;return}if(b>>>0<d>>>0){IW(a,c+D(b,12)|0)}}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;ak(c+76|0,b,1413829443);x[31725]=0;b=R(174,x[c+76>>2])|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31725]=0;d=c+56|0;S(812,d|0,a+140|0,1413894985);a=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31725]=0;a=P(895,d|0,13691)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31725]=0;a=R(204,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break m}x[31725]=0;S(272,d|0,b|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;d=P(72,c+20|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break l}x[31725]=0;e=c+8|0;W(896,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;a=c+32|0;S(897,a|0,d|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}f=Ab(b,a);tb(a);tb(e);tb(d);x[31725]=0;S(260,a|0,2,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;d=R(775,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}tb(a);tb(f);b=d-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31725]=0;a=U(152,x[c+76>>2],x[c+84>>2],2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31725]=0;b=R(191,c+76|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=nva(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=nva(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=nva(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function m8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;n=b;i=fb-416|0;fb=i;x[i+408>>2]=37;x[i+412>>2]=0;b=i+408|0;l=ft(b|1,13905,x[c+4>>2]);j=i+368|0;x[i+364>>2]=j;a=Od();a:{if(l){k=x[c+8>>2];m=i- -64|0;x[m>>2]=g;x[m+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;j=qh(j,30,a,b,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=qh(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1205;k=Be(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=rj(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=rj(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Te(k,a)}f=a+j|0;g=sj(a,f,x[c+4>>2]);x[i+116>>2]=1205;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Fd(j<<3);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1236,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31725];x[31725]=0;i:{if((b|0)!=1){Zb(a);x[31725]=0;a=ea(1237,n|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+416|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function F8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);g=a+16|0;bd(g,x[d+28>>2]);x[31725]=0;b=R(1217,x[a+16>>2])|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;V(1228,b|0,111728,111754,a+208|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(g);c=Fb(a+184|0);b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+316|0,a+312|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31725]=0;O(46,c|0,d<<1);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31725]=0;d=R(1223,x[a+316>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!go(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31725]=0;O(46,c|0,d-b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}b=Jb(c);d=Od();x[a>>2]=f;if((nK(b,d,a)|0)!=1){x[e>>2]=4}x[31725]=0;b=P(1222,a+316|0,a+312|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}x[31725]=0;R(1225,a+316|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function Ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=nva(o,z,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=nva(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=nva(m,v,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function w8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;n=b;i=fb-256|0;fb=i;x[i+248>>2]=37;x[i+252>>2]=0;b=i+248|0;l=ft(b|1,13905,x[c+4>>2]);j=i+208|0;x[i+204>>2]=j;a=Od();a:{if(l){k=x[c+8>>2];m=i- -64|0;x[m>>2]=g;x[m+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;j=qh(j,30,a,b,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=qh(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1205;k=Be(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=rj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=rj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Te(k,a)}f=a+j|0;g=sj(a,f,x[c+4>>2]);x[i+116>>2]=1205;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Fd(j<<1);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1231,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31725];x[31725]=0;i:{if((b|0)!=1){Zb(a);x[31725]=0;a=ea(23,n|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+256|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function O8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);g=a+16|0;bd(g,x[d+28>>2]);x[31725]=0;b=R(28,x[a+16>>2])|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;V(1215,b|0,111728,111754,a+208|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(g);c=Fb(a+184|0);b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+252|0,a+248|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31725]=0;O(46,c|0,d<<1);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31725]=0;d=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!ho(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31725]=0;O(46,c|0,d-b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}b=Jb(c);d=Od();x[a>>2]=f;if((nK(b,d,a)|0)!=1){x[e>>2]=4}x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}x[31725]=0;R(1210,a+252|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=nva(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=nva(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=nva(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function Qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=nva(o,A,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=nva(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=nva(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&v);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function Bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=nva(o,z,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=nva(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=nva(m,w,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function AD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-16|0;fb=i;a:{if(b&4){break a}d=y[a+14|0];b:{if(d>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|d>>>0<=y[a+13|0]){break a}f=x[a>>2];c=x[a+4>>2];if(Sd(f,c)>>>0<=d>>>0){break a}f=z[Oc(f,c,d)>>1];c=Oc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);d=y[a+14|0];if(z[c>>1]<(f-1|0)){d=z[Oc(x[a>>2],x[a+4>>2],d)>>1]-1&65535;f=Wq(a,d,64,64);c=vb(i+12|0,Lk(wb(x[a>>2]),y[a+14|0]));j=em(i+8|0,d,f&255);m=fb-32|0;fb=m;g=x[c>>2];c=x[a>>2];g=(Hv(g,wb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[zb(a)>>2]){if((c|0)!=(g|0)){break d}dZ(a,j);break c}f=zb(a);e=$f(m+12|0,Mf(a,oc(x[a>>2],c)+1|0),g-x[a>>2]>>2,f);x[31725]=0;O(782,e|0,j|0);c=x[31725];x[31725]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[e+4>>2];k=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[e+4>>2]);n=e,o=NF(x[k>>2],x[d>>2],x[f>>2]),x[n+4>>2]=o;n=e,o=Br(g,x[a+4>>2],x[e+8>>2]),x[n+8>>2]=o;Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;g=c;_f(e);break c}a=N()|0;_f(e);Q(a|0);p()}e=fb-16|0;fb=e;k=x[a+4>>2];f=(k-(g+4|0)|0)+g|0;h=Tg(e+4|0,a,c-f>>2);l=x[h+4>>2];d=f;while(1){if(c>>>0<=d>>>0){hc(h);Cr(g,f,k);fb=e+16|0}else{hp(l,z[d>>1]|z[d+2>>1]<<16);l=l+4|0;x[h+4>>2]=l;d=d+4|0;continue}break}v[g+2|0]=y[j+2|0];w[g>>1]=z[j>>1]}wb(g);fb=m+32|0;break a}v[a+14|0]=d-1}if((b|0)!=16777216){v[a+17|0]=255}fb=i+16|0}function RA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=gs(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function v3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;tu(d+48|0);a:{b:{c:{if(Kp(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}g=vM(c);if(g){b=tM(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!uM(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[Dj(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(Kp(e)){a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(VF(e)){break f}if(!vk(e)){break f}a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=gc(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=zu(a,d+8|0,g?d+24|0:0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;c=P(36,d+36|0,8057)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}fb=d+2096|0;break a}b=N()|0;jc(a)}Q(b|0)}p()}return a|0}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;xc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Wr(d,c);i=Jc(d);h=af(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=jd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+24576|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+8|0]=64;e=y[Rb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[fk(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}fb=f+16|0}function OS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;b=Fw(f+30|0,x[a>>2]);c=qq(f+29|0,x[a+4>>2]);LY(f+32|0,z[b>>1],c);c=qq(f+28|0,x[a+8>>2]);d=z[f+32>>1];b=fb-16|0;fb=b;v[b+15|0]=y[f+34|0];IS(f+36|0,d,b+15|0,c);fb=b+16|0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;h=z[f+36>>1]<<16>>16;g=y[f+38|0];b=Pf(g);e=Pf(2);g=Pf(g);b=h-(((b|0)!=(e|0)?b>>>0<e>>>0?-1:1:0)<<24>>24<=0)|0;e=(((b|0)<0?b-399|0:b)|0)/400|0;b=D(e,-400)+b|0;b=x[vb(d+12|0,((((Pf(y[f+39|0])+D(e,146097)|0)+((D(g+(g>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(b>>>2)|0)+D(b,365)|0)-((b>>>0)/100|0)|0)-719469|0)>>2];fb=d+16|0;e=x[vb(c+12|0,b)>>2];fb=c+16|0;g=vb(f+24|0,x[a+12>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,24))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;e=x[vb(c+12|0,d)>>2];fb=c+16|0;g=vb(f+20|0,x[a+16>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,60))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;b=x[vb(c+12|0,d)>>2];fb=c+16|0;c=we(f+8|0,x[a+24>>2],x[a+28>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;e=fb-16|0;fb=e;b=we(e+8|0,nva(b,b>>31,60,0),hb);g=x[b>>2];b=x[b+4>>2];fb=e+16|0;x[a>>2]=g;x[a+4>>2]=b;b=x[a>>2];e=b+x[c>>2]|0;c=x[c+4>>2]+x[a+4>>2]|0;b=we(a+8|0,e,b>>>0>e>>>0?c+1|0:c);c=x[b>>2];fb=a+16|0;a=we(d+8|0,c,x[b+4>>2]);b=x[a>>2];fb=d+16|0;a=Du(f+40|0,b,x[a+4>>2]);b=x[a>>2];fb=f+48|0;hb=x[a+4>>2];return b}function Rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=nva(o,A,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=nva(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=nva(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&w);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function WO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];h=Pj(Xb(x[c+484360>>2],y[c+484376|0]));x[31725]=0;O(178,g|0,h|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(h|0)){c=x[b+24>>2];f=x[c+484344>>2];d=x[c+484348>>2];c=z[_b(x[Xb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(xp(f,d,c)){x[31725]=0;d=e+40|0;O(1072,d|0,Wb(f,c)|0);c=x[31725];x[31725]=0;c:{d:{e:{if((c|0)!=1){f=x[b+24>>2];x[31725]=0;c=e+52|0;S(1059,c|0,f|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;O(180,g|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}tb(c);tb(d);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31725]=0;c=P(36,e+28|0,9240)|0;d=x[31725];x[31725]=0;g:{if((d|0)!=1){x[31725]=0;O(180,g|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31725]=0;c=P(36,e+16|0,9202)|0;d=x[31725];x[31725]=0;h:{if((d|0)!=1){x[31725]=0;O(180,g|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31725]=0;c=P(36,e+4|0,14600)|0;d=x[31725];x[31725]=0;i:{if((d|0)!=1){x[31725]=0;O(180,g|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Td(g);Q(a|0);p()}function Vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=fb-32|0;fb=m;e=b;b=x[a>>2];g=D(wu(e,wb(b)),6)+b|0;a:{if(!c){break a}b=x[zb(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-g|0)/6|0;if(e>>>0<c>>>0){tD(a,c-e|0,d);b=e;if((g|0)==(i|0)){break a}}n=fb-16|0;fb=n;o=x[a+4>>2];h=D((o-(D(c,6)+g|0)|0)/6|0,6)+g|0;f=Jr(n+4|0,a,(i-h|0)/6|0);k=x[f+4>>2];e=h;while(1){if(e>>>0>=i>>>0){hc(f);i=fb-16|0;fb=i;j=fb-32|0;fb=j;Id(j+24|0,g,h);l=fb-16|0;fb=l;k=x[j+28>>2];f=x[j+24>>2];h=k-f|0;e=D((h|0)/-6|0,6)+o|0;x[l+12>>2]=e;ml(e,f,h);Ac(j+16|0,k,l+12|0);fb=l+16|0;e=BR(g,x[j+16>>2]);p=j,q=tA(o,x[j+20>>2]),x[p+12>>2]=q;Ac(i+8|0,e,j+12|0);fb=j+32|0;fb=i+16|0;fb=n+16|0}else{Ov(k,e);k=k+6|0;x[f+4>>2]=k;e=e+6|0;continue}break}e=g;c=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=zb(a);f=zZ(m+12|0,oD(a,Ok(x[a>>2],i)+c|0),(g-x[a>>2]|0)/6|0,b);yZ(f,c,d);h=fb-16|0;fb=h;b=x[f+4>>2];e=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);c=vb(h+4|0,x[f+4>>2]);p=f,q=vZ(x[e>>2],x[d>>2],x[c>>2]),x[p+4>>2]=q;p=f,q=uA(g,x[a+4>>2],x[f+8>>2]),x[p+8>>2]=q;Ub(a,f+4|0);Ub(a+4|0,f+8|0);Ub(zb(a),nc(f));x[f>>2]=x[f+4>>2];fb=h+16|0;g=b;xZ(f)}wb(g);fb=m+32|0}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];m=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((m|0)==1&h>>>0>2147483648|m>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];i=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=i;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){i=b;if(d){b=Yb(b,-16777216,16776704);j=nva(p,y,b,b>>31);k=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=nva(b,b>>31,q,z);j=b+j|0;l=hb+k|0;l=b>>>0>j>>>0?l+1|0:l;b=Yb(e,-16777216,16776704);e=nva(o,v,b,b>>31);k=e+j|0;b=hb+l|0;b=e>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(g+8|0,h,m);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=i;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=i;fb=g+16|0}function I8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;qy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31725]=0;b=R(1223,x[a+364>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(py(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31725]=0;R(1225,a+364|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+188>>2],e),B[j>>2]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function R8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;vy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31725]=0;b=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(uy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31725]=0;R(1210,a+252|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+176>>2],e),B[j>>2]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function H8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;qy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31725]=0;b=R(1223,x[a+364>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(py(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31725]=0;R(1225,a+364|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=pK(c,x[a+188>>2],e),C[j>>3]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function Q8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;vy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31725]=0;b=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(uy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31725]=0;R(1210,a+252|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=pK(c,x[a+176>>2],e),C[j>>3]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function wG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=x[a>>2];e=jh(c,x[a+4>>2]);if(e>>>0<b>>>0){j=fb-32|0;fb=j;c=b-e|0;b=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=b-d>>3>>>0){e=fb-16|0;fb=e;b=js(e+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{fl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);e=ls(j+12|0,ms(a,jh(x[a>>2],d)+c|0),jh(x[a>>2],x[a+4>>2]),b);d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[e+8>>2];f=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=f+(c<<3);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){fl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}he(b);fb=d+16|0;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);g=x[vb(h+4|0,x[e+4>>2])>>2];i=fb-16|0;fb=i;c=fb-32|0;fb=c;Id(c+24|0,x[b>>2],x[d>>2]);k=c+16|0;b=x[c+24>>2];l=x[c+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=g;x[f+12>>2]=b;while(1){if(pd(b,l)){d=Pp(b);g=Pp(x[f+8>>2]);b=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;v[g+4|0]=b;v[g+5|0]=b>>>8;v[g+6|0]=b>>>16;v[g+7|0]=b>>>24;b=Op(f+12|0);Op(f+8|0);b=x[b>>2];continue}break}Ac(k,b,f+8|0);fb=f+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ac(i+8|0,b,c+12|0);fb=c+32|0;fb=i+16|0;x[e+4>>2]=x[i+12>>2];Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;ks(e)}fb=j+32|0;return}if(b>>>0<e>>>0){uG(a,c+(b<<3)|0)}}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];k=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|(e|0)==-1){break d}break b}if((k|0)==1&h>>>0>2147483648|k>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];i=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=i;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){i=e;if(d){e=Yb(e,-16777216,16776704);f=nva(m,y,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=nva(l,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];j=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=nva(b,b>>31,n,z);j=j+f|0;b=hb+e|0;b=f>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Pb(g+8|0,h,k);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=i;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=i;fb=g+16|0}function E7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;bd(a+476|0,x[d+28>>2]);x[31725]=0;n=R(1217,x[a+476>>2])|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=x[Wd(f,0)>>2];x[31725]=0;h=P(1234,n|0,45)|0;j=x[31725];x[31725]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31725]=0;ka(1256,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+4>>2]=1205;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Te(c,Fd(i<<2));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31725]=0;ma(1257,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;b=ea(1237,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}Lc(c);Qb(h);Qb(g);tb(j);Zb(a+476|0);fb=a+480|0;return b|0}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}Qb(h);Qb(g);tb(j)}Zb(a+476|0);Q(f|0);p()}function A7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=Mh(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=f?j:0;while(1){l=Wy(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}yc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;Lh(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=ey(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=ey(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=xb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=_b(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=_b(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}XC(a+484|0,b+48|0,0,c);XC(a+590|0,b+68|0,0,c);XC(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Rb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Nc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Nc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];kk(b,c&127,c>>>7|0);a=y[a+825|0];jk(b,a&127,a>>>7|0);fb=e+16|0}function L8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=wj(x[d+4>>2]);i=mq(x[d+28>>2],a+208|0);lq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(go(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=xK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function J8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=wj(x[d+4>>2]);i=mq(x[d+28>>2],a+208|0);lq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(go(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=tK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function I7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;bd(a+172|0,x[d+28>>2]);x[31725]=0;n=R(28,x[a+172>>2])|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=y[cc(f,0)|0];x[31725]=0;h=P(29,n|0,45)|0;j=x[31725];x[31725]=0;if((j|0)==1){break e}o=(h&255)==(g|0)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31725]=0;ka(1254,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+4>>2]=1205;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Te(c,Fd(i));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31725]=0;ma(1255,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}Lc(c);tb(h);tb(g);tb(j);Zb(a+172|0);fb=a+176|0;return b|0}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}tb(h);tb(g);tb(j)}Zb(a+172|0);Q(f|0);p()}function rY(a,b){var c=0;a:{b:{c:{if(ne(a,16755)){break c}if(ne(a,17522)){break c}if(ne(a,13681)){break c}if(ne(a,13761)){break c}if(!ne(a,14243)){break b}}w[b+10>>1]=4;x[b>>2]=12036;break a}d:{e:{if(ne(a,17517)){break e}if(ne(a,13686)){break e}if(!ne(a,16745)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8391;w[b+10>>1]=4;break a}f:{if(!ne(a,14281)){if(!ne(a,14286)){break f}}w[b+10>>1]=8;x[b>>2]=8169;break a}g:{if(!ne(a,15381)){if(!ne(a,15386)){break g}}x[b>>2]=17109;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!ne(a,25242)){if(!ne(a,25247)){break h}}x[b+4>>2]=1;x[b>>2]=16915;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(kd(a,15541,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8509;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(kd(a,13699,3)){if(kd(a,13818,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8268;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!kd(a+1|0,13839,3)){v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=v[a|0]-48;break a}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(kd(a,13572,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8418;break i}if(ne(a,13911)){v[b+16|0]=1;w[b+10>>1]=4;break a}if(ne(a,14238)){v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=8;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function Xoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-16|0;fb=i;ld(d,32);h=i+8|0;sW(h,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);h=ec(h);sW(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{h=x[h>>2];if(h-838861>>>0<4294128436){break a}e=x[ec(i)>>2];x[d>>2]=D(h,320);w[d+34>>1]=1;if(!Fh(d)){break a}k=h<<2;f=+(k>>>0);o=+(e>>>0)/f;p=+(h>>>0)/f;q=1/+A[d>>2];r=+A[i>>2];s=+A[i+8>>2];h=0;b:while(1){if((h|0)==(k|0)){a=1;break a}l=+(h>>>0);m=0;n=0;a=x[b+20>>2];if(je(x[b>>2],a)){f=l*p+s;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}e=g;f=f-+(e>>>0);e=z[b+34>>1];j=_d(e);g=D(g,j);d:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break d}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}a=x[c+20>>2];if(je(x[c>>2],a)){f=l*o+r;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}e=g;f=f-+(e>>>0);e=z[c+34>>1];j=_d(e);g=D(g,j);f:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break f}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}m=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=q*+(a>>>0);t=x[d+20>>2]+(a<<1)|0,u=qC(n*(1-f)+m*f),w[t>>1]=u;a=a+k|0;e=e+1|0;continue}}}fb=i+16|0;return a|0}function Eua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31725]=0;k=yh(g,a);O(112,i|0,k|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[cc(b,a)|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31725]=0;O(304,i|0,Hd(c,g)|0);h=x[31725];x[31725]=0;g=e;if((h|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[31725]=0;O(304,i|0,Hd(c,j)|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[31725]=0;O(113,i|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31725]=0;a=R(98,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;S(99,a|0,40244,17);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(i);Q(a|0)}p()}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;ld(b,2);f=e+24|0;Qk(f,2,a+1|0);d=e+36|0;Cc(d,f);ze(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Gb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Gb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;oh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);oh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);oh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;Zk(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Rb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function lK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=wj(x[d+4>>2]);i=mq(x[d+28>>2],a+208|0);lq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(go(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=uK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function M8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=wj(x[d+4>>2]);i=mq(x[d+28>>2],a+208|0);lq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(go(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=zK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function K8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=wj(x[d+4>>2]);i=mq(x[d+28>>2],a+208|0);lq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(go(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=wK(c,x[a+180>>2],e,b),w[j>>1]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function $I(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function U8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=wj(g);nq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=xK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function S8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=wj(g);nq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=tK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31725]=0;k=yh(g,a);O(95,h|0,k|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[cc(b,a)|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31725]=0;O(96,h|0,Hd(c,g)|0);j=x[31725];x[31725]=0;g=e;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[31725]=0;O(96,h|0,Hd(c,i)|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[31725]=0;O(97,h|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31725]=0;a=R(98,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;S(99,a|0,40244,17);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(h);Q(a|0)}p()}function zN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=x[a+32>>2];f=zq(g);if(!f){f=yq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ac(8);x[31725]=0;c=P(36,h+4|0,6e3)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=ac(8);x[31725]=0;c=P(36,h+4|0,11318)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}f=dB(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Vo(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;dn(i);Qo(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Ru(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Zi(Tv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Zi(Tv(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=IB(i,c),w[l+480212>>1]=m;fb=h+16|0;return j|0}a=N()|0;jc(b)}Q(a|0)}p()}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;n=fb-16|0;fb=n;e=vb(n+12|0,wb(x[a+4>>2]));k=fb-32|0;fb=k;f=x[e>>2];e=x[a>>2];j=(rp(f,wb(e))<<1)+e|0;l=IB(b,c);a:{if((l|0)<=0){break a}e=x[zb(a)>>2];m=x[a+4>>2];if((l|0)<=e-m>>1){p=m-j|0;g=p>>1;b:{if((g|0)>=(l|0)){e=c;break b}x[k+12>>2]=b;_T(k+12|0,g);e=x[k+12>>2];f=e;o=fb-16|0;fb=o;g=_h(o+4|0,a,l-g|0);h=zb(a);d=fb-48|0;fb=d;i=x[g+4>>2];x[d+44>>2]=i;x[d+40>>2]=i;h=Se(d+12|0,h,d+40|0,d+44|0);x[d+8>>2]=x[h+8>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Re(d+24|0,d);while(1){if((c|0)!=(f|0)){fj(x[d+44>>2],z[f>>1]);x[d+44>>2]=x[d+44>>2]+2;f=f+2|0;continue}break}Qe(d+24|0);q=x[d+44>>2];if(!y[d+36|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+32>>2]>>2]);r=x[vb(f+8|0,x[x[d+28>>2]>>2])>>2];h=fb-16|0;fb=h;c=x[c>>2];x[h+12>>2]=c;while(1){if(pd(c,r)){i=fb-16|0;fb=i;x[i+12>>2]=c;_T(i+12|0,-1);fb=i+16|0;c=x[ij(h+12|0)>>2];continue}break}fb=h+16|0;fb=f+16|0}fb=d+48|0;x[g+4>>2]=q;hc(g);fb=o+16|0;if((p|0)<=0){break a}}gV(a,j,m,(l<<1)+j|0);Mk(b,e,j);break a}e=zb(a);g=mk(k+12|0,nk(a,Zc(x[a>>2],m)+l|0),j-x[a>>2]>>1,e);d=fb-16|0;fb=d;c=Hp(d+4|0,g+8|0,IB(b,c));e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){fj(e,z[b>>1]);e=x[c>>2]+2|0;x[c>>2]=e;b=b+2|0;continue}break}he(c);fb=d+16|0;j=fV(a,g,j);jj(g)}wb(j);fb=k+32|0;fb=n+16|0;return a|0}function s8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Ny(x[g>>2]);g=ty(x[g>>2]);sh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31725]=0;V(1228,l|0,a|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31725]=0;j=P(1234,l|0,h<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31725]=0;h=P(1234,l|0,48)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31725]=0;h=P(1234,l|0,h|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Hm(j,c);i=0;x[31725]=0;o=R(1226,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){it((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31725]=0;n=P(1234,l|0,n|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=nva(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=nva(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=nva(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function fz(a){var b=0,c=0,d=0,e=0;Ie(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){Ie(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}Ie(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){Ie(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;Ie(x[a+80>>2],x[b+8>>2]);Ie(x[a+80>>2],x[b+28>>2]);Ie(x[a+80>>2],x[b+32>>2]);Ie(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];Ie(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[a+260>>2]);Ie(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){Ie(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}Ie(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;Ie(x[a+80>>2],x[d+800>>2]);Ie(x[a+80>>2],x[d+928>>2]);Ie(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;Ie(x[a+80>>2],x[b+1068>>2]);Ie(x[a+80>>2],x[b+1076>>2]);Ie(x[a+80>>2],x[b+1084>>2]);Ie(x[a+80>>2],x[b+1092>>2]);Ie(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function RU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Nj(c)){i=fb-16|0;fb=i;e=Ec(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Uo((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+27280>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;XU(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;XU(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}WU(e,b)}else{yd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[yf(i+12|0,e)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;wA(a,b);Gj(b);break a}WU(c,b)}QU(a);fb=h+16|0}function YE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-16|0;fb=h;d=x[b>>2];e=Zc(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){l=fb-32|0;fb=l;d=c-e|0;e=x[zb(b)>>2];f=x[b+4>>2];b:{if(d>>>0<=e-f>>1>>>0){f=fb-16|0;fb=f;d=_h(f+4|0,b,d);e=x[d+4>>2];g=x[d+8>>2];while(1){if((e|0)==(g|0)){hc(d);fb=f+16|0}else{yp(e);e=e+2|0;x[d+4>>2]=e;continue}break}break b}e=zb(b);e=mk(l+12|0,nk(b,Zc(x[b>>2],f)+d|0),Zc(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=Hp(g+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){yp(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}he(d);fb=g+16|0;i=fb-16|0;fb=i;f=vb(i+12|0,x[b+4>>2]);g=vb(i+8|0,x[b>>2]);j=x[vb(i+4|0,x[e+4>>2])>>2];k=fb-16|0;fb=k;m=k+8|0;d=fb-32|0;fb=d;Id(d+24|0,x[f>>2],x[g>>2]);n=d+16|0;g=x[d+24>>2];o=x[d+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=j;x[f+12>>2]=g;while(1){if(pd(g,o)){g=Nn(g);j=Nn(x[f+8>>2]);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;g=ij(f+12|0);ij(f+8|0);g=x[g>>2];continue}break}Ac(n,g,f+8|0);fb=f+16|0;f=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(m,f,d+12|0);fb=d+32|0;fb=k+16|0;x[e+4>>2]=x[k+12>>2];Ub(b,e+4|0);Ub(b+4|0,e+8|0);Ub(zb(b),nc(e));x[e>>2]=x[e+4>>2];fb=i+16|0;jj(e)}fb=l+32|0;break a}if(c>>>0<e>>>0){Jn(b,d+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){e=x[b>>2];bc(h+8|0,e,Zc(e,x[b+4>>2])<<1);rd(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0;return c|0}function Tsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=nva(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=ova(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=fb-16|0;fb=e;h=d+48|0;f=tc(e+4|0,4451);_c(h,f);tb(f);fb=e+16|0;x[31725]=0;f=(D(c,100)+52|0)/3060|0;e=f+2|0;g=(e|0)/12|0;x[d+32>>2]=g+b;b=d+36|0;O(75,b|0,d+32|0);i=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((i|0)!=1){x[31725]=0;x[d+16>>2]=(e+D(g,-12)|0)+1;e=d+20|0;O(78,e|0,d+16|0);g=x[31725];x[31725]=0;if((g|0)==1){break j}x[31725]=0;x[d>>2]=(((D(f,306)+5|0)/-10|0)+c|0)+1;c=d+4|0;O(78,c|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break i}x[31725]=0;aa(415,a|0,h|0,b|0,e|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}tb(c);tb(e);tb(b);Eb(h);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}b=d+48|0;ig(b,4431);x[31725]=0;c=d+36|0;O(416,c|0,d+62|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;S(141,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(c);Eb(b)}fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function vK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=wj(g);nq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=uK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function V8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=wj(g);nq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=zK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function T8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=wj(g);nq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=wK(c,x[a+184>>2],e,b),w[i>>1]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function VP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[127064]){if(!y[126936]){b=fb-16|0;fb=b;Fb(126912);x[31731]=0;v[126928]=0;x[31733]=0;x[31725]=0;a=ca(56)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;OA(126924,le(a));Gj(a);v[126928]=0;break f}a=ta(125e3,125584)|0;c=gb;if(($(125e3)|0)==(c|0)){Y(a|0)|0;x[31725]=0;X(57);b=x[31725];x[31725]=0;if((b|0)==1){break d}p()}if(($(125584)|0)!=(c|0)){break c}Y(a|0)|0;x[31725]=0;v[126928]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;break c}if(y[126928]){break e}}x[31725]=0;W(58,126908);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}}Gj(126932);Gj(126924);tb(126912);Q(a|0);p()}T(0)|0;Tb();p()}v[126936]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=BP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=tP(vP(f+12|0,32));break g}d=G(a);d=vP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=tP(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=yb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=KP(l,b,NP(b));EP(j,b);bn(b);fb=c- -64|0;yc(126944,yc(e,j,120),116);v[127064]=1}fb=e+240|0}function VI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){tc(a,9750);break j}f=b>>>24|0;if(!(b&65535)){d=fb-16|0;fb=d;g=c+68|0;e=tc(d+4|0,4399);_c(g,e);tb(e);fb=d+16|0;x[31725]=0;x[c+24>>2]=f;f=c+56|0;O(89,f|0,c+24|0);d=x[31725];x[31725]=0;k:{l:{m:{n:{if((d|0)!=1){x[31725]=0;x[c+8>>2]=b>>>16&255;b=c+44|0;O(90,b|0,c+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break n}x[31725]=0;V(91,a|0,g|0,f|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}tb(b);tb(f);Eb(g);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}d=fb-16|0;fb=d;g=c+68|0;e=tc(d+4|0,4123);_c(g,e);tb(e);fb=d+16|0;x[31725]=0;x[c+40>>2]=f;f=c+56|0;O(89,f|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}x[31725]=0;x[c+36>>2]=b>>>16&255;d=c+44|0;O(90,d|0,c+36|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}x[31725]=0;x[c+20>>2]=b>>>8&255;e=c+24|0;O(90,e|0,c+20|0);h=x[31725];x[31725]=0;if((h|0)==1){break g}x[31725]=0;x[c+4>>2]=b&255;b=c+8|0;O(90,b|0,c+4|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}x[31725]=0;ja(92,a|0,g|0,f|0,d|0,e|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}tb(b);tb(e);tb(d);tb(f);Eb(g)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function PU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:HB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15483|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;hn((d<<2&60)+78800|0,4,b);d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14762|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;hn((d<<1&126)+78864|0,2,b);d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11165|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;hn((d<<1&510)+78992|0,2,b);d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4895|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function C8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=zw(x[g>>2]);g=Ay(x[g>>2]);sh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31725]=0;V(1215,l|0,a|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31725]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31725]=0;h=P(29,l|0,48)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31725]=0;h=P(29,l|0,h|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Hm(j,c);i=0;x[31725]=0;o=R(1213,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Hm((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31725]=0;n=P(29,l|0,n|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function wB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Sj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32368>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(Dn(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Bc(pva(nva(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Hj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(pva(nva(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(pva(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=_e(Ci(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=nva(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Gc(ova(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}wc(h+12|0,2147483647);c=x[h+12>>2];b=mg(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function IA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=YR(b,c);a:{if(!x[b+656>>2]|!(v[i+6|0]&1)){break a}e=x[i>>2];j=a+1074312|0;f=Ob(j,31);d=Iw(x[b+656>>2],c);if(lc(x[d>>2],x[d+4>>2])){break a}f=(f^1)+e|0;g=Ob(j,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}h=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[yb(x[d>>2],h)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(h|0)!=y[d+16|0]))){g=Ob(j,70)}if(g|(f|0)!=(k|0)){break d}f=z[yb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[yb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[yb(a,y[d+15|0])>>1];if(!Ob(j,93)|(c|0)!=1|y[b+89|0]&8){break b}v[i+6|0]=y[i+6|0]&254;break b}h=0;e=z[xf(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[i+4>>1]==65535){break f}if(Ob(j,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[yb(g,y[d+13|0])>>1];h=1;g=z[yb(g,y[d+14|0])>>1]+1|0;break e}e=z[xf(x[d+4>>2])>>1];h=f>>>0<=e>>>0;g=e;break e}g=x[d>>2];e=z[yb(g,y[d+15|0])>>1];h=1;g=z[yb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(c|h){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[xf(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=i,m=Ob(j,31)+f|0,x[l>>2]=m}}function ac(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=NY(a+24|0);a=h;i=a>>>0<=1?1:a;a=i;b=a+15&-16;a=a>>>0<b>>>0?b:a;b=0;f=fb-16|0;fb=f;if(!(a&15)){if(a>>>0>4294967216){a=48}else{a:{if(a>>>0>=4294967216){x[31600]=48;b=0;break a}d=a>>>0<11?16:a+11&-8;a=Fd(d+28|0);b=0;if(!a){break a}b=a-8|0;b:{if(!(a&15)){a=b;break b}g=a-4|0;j=x[g>>2];a=(a+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;e=(j&-8)-c|0;if(!(j&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+c;break b}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;e=b+c|0;x[e+4>>2]=x[e+4>>2]|1;Bv(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}x[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;x[b+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;Bv(b,d)}b=a+8|0}if(b){x[f+12>>2]=b;a=0}else{a=48}}b=a?0:x[f+12>>2]}fb=f+16|0;a=b;if(!a){d:{b=0;a=x[125550];if(!a){x[125550]=502220;w[251111]=125;k=502220,l=Px(502720),w[k>>1]=l;a=x[125550]}d=(i+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502720){a=0}else{c=z[a+2>>1];f=d+(d>>>0<c>>>0?c-d&3:0)|0;if(c>>>0>f>>>0){b=c-f|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=f;w[a>>1]=0;a=a+4|0;break d}if(d>>>0>c>>>0){break e}d=z[a>>1];f:{if(!b){k=502200,l=Qx(d),x[k>>2]=l;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=Qx(z[a>>1]);continue}}}if(!a){Tb();p()}return bS(Sb(a,0,h))}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=nva(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=nva(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=nva(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function E4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=kt(c,d);x[k+4>>2]=1205;n=jt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Fd(j);if(!i){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}Te(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=x[g>>2];x[31725]=0;s=P(1224,e|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Wd(g,o)>>2];x[31725]=0;q=P(1224,e|0,q|0)|0;t=x[31725];x[31725]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function t4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=kt(c,d);x[k+4>>2]=1205;n=jt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Fd(j);if(!i){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}Te(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=v[g|0];x[31725]=0;s=P(1209,e|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[cc(g,o)|0];x[31725]=0;q=P(1209,e|0,q|0)|0;t=x[31725];x[31725]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function _O(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Dc(e+4|0,11600);x[31725]=0;b=d+12|0;P(36,b|0,11005)|0;c=x[31725];x[31725]=0;a:{if((c|0)==1){break a}x[31725]=0;b=d+24|0;P(36,b|0,11430)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+36|0;P(36,b|0,10997)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+48|0;P(36,b|0,8243)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+60|0;P(36,b|0,10982)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+72|0;P(36,b|0,8309)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+84|0;P(36,b|0,5620)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+96|0;P(36,b|0,12004)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+108|0;P(36,b|0,11373)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+120|0;P(36,b|0,12273)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+132|0;P(36,b|0,5472)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+144|0;P(36,b|0,7335)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;U(1069,a|0,d|0,13)|0;a=x[31725];x[31725]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-32|0;fb=d;c=z[a+480190>>1];v[d+20|0]=0;e=c+1|0;c=d+20|0;oU(b,e,c);if(z[a+480192>>1]){h=Nb(c);m=d,n=wb(x[a+484344>>2]),x[m+16>>2]=n;l=wb(x[a+484348>>2]);while(1){i=x[d+16>>2];if(Ib(i,l)){a:{if(!Ib(x[i>>2],x[i+4>>2])){break a}c=z[a+480188>>1];x[31725]=0;v[d+4|0]=0;S(781,h|0,c|0,d+4|0);c=x[31725];x[31725]=0;if((c|0)!=1){m=d,n=wb(x[i>>2]),x[m+12>>2]=n;j=0;b:while(1){f=0;if(A[i+12>>2]<=j>>>0){break a}while(1)if(z[a+480188>>1]<=f>>>0){j=j+1|0;continue b}else{c:{c=x[d+12>>2];if(!Tc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[a+480192>>1];break e}g=z[a+480192>>1];c=y[xb(x[h>>2],f)|0];if(c){break e}c=1;break d}m=xb(x[h>>2],f),n=c,v[m|0]=n;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[_b(e+236|0,y[x[d+12>>2]]-1|0)>>1];if(e>>>0>z[a+480190>>1]){break f}k=d+4|0;Kb(k,x[b>>2],e);Jf(k,1)}c=c+1|0;continue}}f=f+1|0;JC(d+12|0);continue}}}a=N()|0;dc(h);Q(a|0);p()}am(d+16|0);continue}else{c=z[a+480190>>1];while(1){if(c){Kb(d+4|0,x[b>>2],c);if(!Hb(x[x[d+4>>2]>>2],x[d+8>>2])){e=f;f=D(c,104)+a|0;f=e+je(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{dc(h)}break}}break}}fb=d+32|0;return f&65535}function esa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;i=Hf(a,c);$d(e,x[a+36>>2]);j=a;a:{if(!i){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Pm(d+48|0,x[a+36>>2]);x[31725]=0;a=P(463,d+36|0,42276)|0;c=x[31725];x[31725]=0;b:{c:{d:{e:{if((c|0)!=1){x[31725]=0;x[d+16>>2]=19989505;x[d+20>>2]=0;S(464,f|0,a|0,d+16|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}Eb(a);if(!vl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}l=d,m=ek(x[b>>2],x[b+4>>2]),w[l+34>>1]=m;w[d+32>>1]=65535;x[31725]=0;a=P(463,d+16|0,10105)|0;c=x[31725];x[31725]=0;f:{if((c|0)!=1){x[31725]=0;c=U(493,f|0,d+32|0,a|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Gf(d+34|0,4e3);a=z[d+34>>1];g:{if(ek(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31725]=0;O(225,b|0,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}h=x[b>>2];x[31725]=0;g=d+4|0;O(494,g|0,c|0);k=x[31725];x[31725]=0;if((k|0)!=1){x[31725]=0;V(495,f|0,Wb(h,c)|0,g|0,496);h=x[31725];x[31725]=0;if((h|0)==1){break h}c=c+1|0;Eb(g);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}Bh(f);Q(c|0);p()}Bh(f);fb=d+160|0;c=i}gf(j,c);fb=e+16|0}function aJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function De(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=oI(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(oI(e)){h=E(a*a);if((e|0)<0){h=(nI(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=yx(E(E(1)/h));break a}if((e|0)<0){c=nI(d);if(!c){a=wI(a);break a}e=(q(a),j(2))&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125624>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125632>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=cG(i);break a}if(!(f<=-150)){break f}a=MF(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(n,y,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=nva(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function TL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=te(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=te(a,k),x[p>>2]=q;i=te(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(kf(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Wi(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(kf(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Wi(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(kf(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Wi(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=te(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Wi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Wi(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=te(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Om(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Mm(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}fc(a,3);return 0}function M3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(nh(a,x[b+8>>2],e)){Nx(b,c,d);return}a:{if(nh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;c:{d:{while(1){e:{if(f>>>0>=h>>>0){break e}w[b+52>>1]=0;Kx(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break e}f:{if(!y[b+53|0]){break f}if(y[b+52|0]){if(x[b+24>>2]!=1){d=1;g=1;if(y[a+8|0]&2){break f}}x[b+44>>2]=3;return}d=1;if(!(v[a+8|0]&1)){break d}}f=f+8|0;continue}break}if(!d){break c}}x[b+44>>2]=3;if(!g){break b}break a}x[b+44>>2]=4;if(g){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];Qs(x[a+16>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=(a+16|0)+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Qs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Qs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Qs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;j=fb-32|0;fb=j;f=j+28|0;e=j+24|0;k=c;g=fb-16|0;fb=g;a:{b:{c=b;if(!lc(b,x[vb(g+12|0,rg(a))>>2])){b=z[k>>1];h=x[k+4>>2];i=td(c);m=z[i>>1];i=x[i+4>>2];if(!Vl(b,h,m,i)){break b}}x[g+12>>2]=c;e=vb(g+8|0,wb(x[a>>2]));c:{b=x[g+12>>2];if(!lc(b,x[e>>2])){b=x[MB(g+12|0)>>2];e=td(b);i=z[e>>1];m=x[e+4>>2];e=z[k>>1];h=x[k+4>>2];if(!Vl(i,m,e,h)){break c}}if(!x[c>>2]){x[f>>2]=c;break a}x[f>>2]=b;c=b+4|0;break a}c=LB(a,f,e,h);break a}if(Vl(m,i,b,h)){d:{b=KB(c);if(!lc(b,x[vb(g+12|0,rg(a))>>2])){e=z[k>>1];h=x[k+4>>2];i=td(b);if(!Vl(e,h,z[i>>1],x[i+4>>2])){break d}}if(!x[c+4>>2]){x[f>>2]=c;c=c+4|0;break a}x[f>>2]=b;c=b;break a}c=LB(a,f,e,h);break a}x[f>>2]=c;x[e>>2]=c;c=e}fb=g+16|0;b=x[c>>2];if(!b){b=fb-16|0;fb=b;f=ec(a);e=j+12|0;g=Ch(e,Ec(36),Mg(b+8|0,f));f=x[g>>2]+16|0;h=x[k+4>>2];x[f>>2]=x[k>>2];x[f+4>>2]=h;_l(f+8|0,d);o=ec(g),p=1,v[o+4|0]=p;fb=b+16|0;$g(a,x[j+28>>2],c,x[j+12>>2]);b=le(e);iU(e);n=1}a=l+4|0;_g(a,x[vb(j+12|0,b)>>2],n);fb=j+32|0;if(!y[ec(a)|0]){a=td(x[l+4>>2])+8|0;hU(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=zb(d);o=zb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=vb(l+12|0,x[l+4>>2]);fb=l+16|0;return x[a>>2]}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;s=x[a+16>>2];t=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;h=x[a+76>>2];hg(b,f,vf(k,l,d),hb);p=hb>>>0>h>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;p=p-1|0;g=p;n=g?n:0;o=g?o:0;r=(((f&2147483647)<<1|b>>>31)&-2)+s|0;f=m;a:{b:while(1){c:{if((f|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break a}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break c}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){be(h,g>>>3<<16>>16);ae(h,4);Pb(e+8|0,n,o);f=f-1|0;continue b}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}be(h,g>>>3<<16>>16);ae(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,t);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,k,l);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function N1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=ai(a);Sb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(_d(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31725]=0;a=U(152,f|0,a|0,2)|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}if(!a){break j}x[31725]=0;a=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}if(!a){break e}x[31725]=0;f=g+8|0;S(187,f|0,b|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}a=ps(g+28|0,f);h=hd(e,a);yc(h+20|0,a+20|0,1040);ub(a);ub(f);x[e+1076>>2]=0;x[e+1080>>2]=0;f=x[e+1060>>2];a=x[f+20>>2];if(Pn(z[f+34>>1])>>>0>=2){x[31725]=0;O(192,h|0,a+(d<<1)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break f}x[31725]=0;O(193,h|0,a+d|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break b}Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function IM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=D(h,k);s=D(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d+r<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+Bn(i)|0;t=e;e=Xt(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d+s<<1)+o|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=ed(e),w[u>>1]=v;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Qj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!je(x[a>>2],x[a+20>>2])){break a}$k(a);b:{switch(Pn(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;pV(h+28|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;pV(h+8|0,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;oV(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;oV(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function OM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(f>>>0>x[c+24>>2]-l>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=h+l|0;r=D(h,k);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d+r<<3)+o>>3])*134217728);j=e;e=(x[e>>2]>>1)+Bn(i)|0;s=e;e=Xt(m)+e&-4096;x[j>>2]=s-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<2)+n|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}t=x[j>>2]+(q<<1)|0,u=ed(e),w[t>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=gv(c+4|0,a,1);zz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);d=_V(i+12|0,$V(a,Kk(x[a>>2],x[a+4>>2])+1|0),Kk(x[a>>2],x[a+4>>2]),c);zz(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+16;h=fb-16|0;fb=h;e=zb(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(b,g)){zz(Az(x[c+56>>2]),kC(b));b=ar(c+60|0);ar(c+56|0);b=x[b>>2];continue}break}Qe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(ci(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+16;fb=e+16|0;Xj(Az(x[e+12>>2]));b=x[_o(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[d+8>>2]=b;Xj(b);continue}break}a=x[d>>2];if(a){xs(d);Db(a)}fb=i+32|0}function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(n,z,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=nva(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function xh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!Dn(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31680>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Hj(a)){a=((e&255)>>>0)/12|0;b=nva(x[(D(a,-12)+e<<6&960)+35568>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;wc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31680>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Bc(pva(nva(z[((D(a,-12)+e&255)<<1)+31680>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Fe(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32176>>1])+D(z[(x[f+4>>2]<<1)+32160>>1],16-b|0)<<1>>>c|0;break a}if(!(!(c&240)&b-25>>>0<84)){a=((e&255)>>>0)/12|0;e=z[(D(c>>>4&15,12)+(D(a,-12)+e&255)<<1)+31280>>1]<<5>>>a|0;break a}e=z[(b<<1)+31054>>1]<<2}fb=f+16|0;return e}function oQ(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=De(E(10),E(E(E(B[yb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=De(E(10),E(E(-1)/E(k*E(E(B[yb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=De(E(10),E(E(-1)/E(k*E(E(B[yb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(De(E(10),E(E(E(B[yb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(yx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=wI(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Ym(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[yb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[yb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function OK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{c=x[a+4>>2];g:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break g}c=sd(a)}switch(c-43|0){case 0:case 2:break f;default:break e}}d=(c|0)==45;f=!b;c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=sd(a)}b=c-58|0;if(f|b>>>0>4294967285){break d}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break c}break a}b=c-58|0}f=d;if(b>>>0<=4294967285){if(x[a+116>>2]<0){break a}break b}i:{if(c-48>>>0>=10){break i}while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}g=e>>31;if(b>>>0>=10){break i}while(1){b=c;c=nva(e,g,10,0);d=b+c|0;b=hb;e=d-48|0;d=(c>>>0>d>>>0?b+1|0:b)-(d>>>0<48)|0;g=d;d=e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836;c=x[a+4>>2];k:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break k}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}if(b>>>0>=10){break i}while(1){b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break l}b=sd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+g|0)|0:g;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function Esa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-48|0;fb=d;l=b+484344|0;m=b+480280|0;n=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){qr(c,d+43|0);e=Pg(c);d:{f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);if(!((f|0)==1229999433|(f|0)==1397771593|((f|0)==1297110104|(f|0)==1297110099))){if(Mb(x[c>>2],x[c+8>>2],e)){break d}}v[d+47|0]=j;Gh(c,8);break c}fe(d,c,e);f=ic(d+20|0,d);ub(d);e=m;e:{if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))==1481001027){while(1){if((e|0)==(l|0)){h=1;break a}x[31725]=0;h=R(153,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break e}v[e+8|0]=h;e=e+32|0;continue}}if(y[d+43|0]!=70){break b}g=y[d+44|0];k=(g|0)==88;f:{if(!k){if((g-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break f}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}h=1;e=((i&255)+(k?-528:D(g,100)-5328|0)|0)+D(e&255,10)&65535;if(e>>>0>249){break a}e=vd(n,e);x[31725]=0;O(452,f|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}vD(a,h,d+47|0);fb=d+48|0;return}if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))!=1430540109){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=hC(c+4|0,a);eA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);d=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);eA(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+4;h=fb-16|0;fb=h;e=zb(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(b,g)){eA(rA(x[c+56>>2]),xf(b));b=Mi(c+60|0);Mi(c+56|0);b=x[b>>2];continue}break}Qe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(ci(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+4;fb=e+16|0;og(rA(x[e+12>>2]));b=x[Je(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[d+8>>2]=b;og(b);continue}break}a=x[d>>2];if(a){Tz(d);Db(a)}fb=i+32|0}function zO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb+-64|0;fb=e;a:{b:{c:{d:{d=x[a+36>>2];c=x[a+40>>2];e:{if(Ib(d,c)){sc(e+60|0);break e}c=e+24|0;Ao(c,a);x[31725]=0;f=R(1062,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}x[e+60>>2]=f;of(c);c=x[a+40>>2];d=x[a+36>>2]}c=(k=a+36|0,l=x[e+60>>2],m=Ib(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=pl(d);g=x[c>>2];i=oj(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=wf(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=wf(x[c>>2],f);break b}d=N()|0;of(e+24|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[31725]=0;O(1096,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=cS(lY(e+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31725]=0;g=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=g;g=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=g;g=e+48|0;V(1097,g|0,f|0,(d?7:1)|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break f}c=mn(x[e+52>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Xi(g);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;Fl(e+60|0);fb=e- -64|0;return+b}}d=N()|0;Fl(e+60|0)}Q(d|0);p()}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=yr(a);xr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){dg(a+1074312|0,120)}Au(a+8|0,c);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;SA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;Cu(b);f=pm(x[b>>2],x[b+4>>2]);c=qA(d+12|0,b);x[31725]=0;S(858,b|0,f|0,c|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){Dk(c);fb=d- -64|0;break a}a=N()|0;Dk(c);Q(a|0);p()}eV(a+484360|0);tf(a+1298308|0);tf(a+1298320|0);tf(a+1298332|0);b=e+12|0;Sb(b,0,68);b=FS(b);c=Ab(a+1298344|0,b);Ab(c+12|0,b+12|0);Ab(c+24|0,b+24|0);Ab(c+36|0,b+36|0);Ab(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;YA(b);ew(a+1298412|0);Nf(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Db(Iv(d))}x[c>>2]=0;b=b+1|0;continue}}function H1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){ld(b,32);Dp(b);c=d+8|0;lk(c,1,a+4|0);e=d+20|0;Cc(e,c);ze(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Gf(b+30|0,256);w[b+32>>1]=y[a+17|0];Gf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Gf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);$k(b);v[b+38|0]=y[(y[a+79|0]&7)+38128|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;e=x[b+1298304>>2];if(!Dd(e)){c=fb-16|0;fb=c;d=Ec(12);x[31725]=0;e=R(957,d|0)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){d=yf(c+12|0,e);fb=c+16|0;c=x[d>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;d=i+12|0;xS(c,le(d));XA(d);e=x[c>>2]}f=fb-32|0;fb=f;c=f+8|0;mS(c,a);x[31725]=0;O(958,f+20|0,c|0);d=x[31725];x[31725]=0;b:{c:{if((d|0)!=1){tb(c);m=f,n=wb(x[e>>2]),x[m+4>>2]=n;l=wb(x[e+4>>2]);c=0;e=0;while(1){d:{h=x[f+4>>2];if(!Ib(h,l)){e:{if(!e){break e}c=x[e+4>>2];if(!c){break e}x[31725]=0;b=U(c|0,e|0,b|0,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){c=x[e>>2];x[b+4>>2]=c;if(c){x[c+8>>2]=b}x[e>>2]=b}x[a>>2]=b}tb(f+20|0);fb=f+32|0;break b}j=0;d=x[h>>2];if(x[d+32>>2]==x[a+16>>2]){j=x[d+36>>2]==x[a+20>>2]}x[31725]=0;k=f+8|0;O(959,k|0,d+8|0);d=x[31725];x[31725]=0;if((d|0)!=1){g=fb-16|0;fb=g;ee(g+8|0,k);ee(g,f+20|0);d=RR(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);fb=g+16|0;tb(k);f:{if(!(!j|(d|0)!=0)){e=x[h>>2];c=3;break f}if((c|0)<2&j){e=x[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?x[h>>2]:e;c=d?1:c}Je(f+4|0);continue}}break}e=N()|0;tb(f+20|0);break c}e=N()|0;tb(f+8|0)}Q(e|0);p()}fb=i+16|0}
function o8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;x[f+360>>2]=37;x[f+364>>2]=0;b=f+360|0;h=ft(b|1,22267,x[c+4>>2]);g=f+320|0;x[f+316>>2]=g;a=Od();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;g=qh(g,30,a,b,f+32|0);break a}C[f+48>>3]=e;g=qh(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1205;i=Be(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=rj(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=rj(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Te(i,a)}j=a+g|0;l=sj(a,j,x[c+4>>2]);x[f+68>>2]=1205;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Fd(g<<3);if(!g){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1236,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31725];x[31725]=0;i:{if((b|0)!=1){Zb(a);x[31725]=0;a=ea(1237,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+368|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function y8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;x[f+200>>2]=37;x[f+204>>2]=0;b=f+200|0;h=ft(b|1,22267,x[c+4>>2]);g=f+160|0;x[f+156>>2]=g;a=Od();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;g=qh(g,30,a,b,f+32|0);break a}C[f+48>>3]=e;g=qh(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1205;i=Be(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=rj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=rj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Te(i,a)}j=a+g|0;l=sj(a,j,x[c+4>>2]);x[f+68>>2]=1205;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Fd(g<<1);if(!g){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1231,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31725];x[31725]=0;i:{if((b|0)!=1){Zb(a);x[31725]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+208|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function Yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Rf(a);while(1){if(Zg(b,c)){b=x[vb(l+8|0,q)>>2];k=td(x[l+12>>2]);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;i=fb-32|0;fb=i;g=i+28|0;d=i+24|0;e=fb-16|0;fb=e;a:{b:{if(!lc(b,x[vb(e+12|0,rg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(b);n=y[h|0];h=x[h+4>>2];if(!Go(f,j,n,h)){break b}}x[e+12>>2]=b;f=vb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!lc(d,x[f>>2])){d=x[MB(e+12|0)>>2];f=td(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Go(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=eB(a,g,f,j);break a}if(Go(n,h,f,j)){d:{d=KB(b);if(!lc(d,x[vb(e+12|0,rg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(d);if(!Go(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=eB(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;e=ec(a);g=i+12|0;e=Ch(g,Ec(28),Mg(d+8|0,e));uC(x[e>>2]+16|0,k);r=ec(e),s=1,v[r+4|0]=s;fb=d+16|0;$g(a,x[i+28>>2],b,x[i+12>>2]);d=le(g);dm(g);p=1}_g(m+8|0,x[vb(i+12|0,d)>>2],p);fb=i+32|0;fb=m+16|0;vb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[ah(l+12|0)>>2];continue}else{fb=l+16|0}break}}function Gja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((g|0)>(j|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=yb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=lR(i),w[m+30>>1]=n;B[a+32>>2]=F(l);Kl(a+4|0,(h-g|0)+1|0);c=wb(x[b>>2]);h=wb(x[b+4>>2]);f=Lk(wb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;Id(b+24|0,c,h);xn(b+16|0,x[b+24>>2],x[b+28>>2],f);c=kA(c,x[b+16>>2]);m=b,n=kR(f,x[b+20>>2]),x[m+12>>2]=n;Ac(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=yb(c,b+g|0);m=yb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=yb(b,f-h|0);m=yb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{Dq(a)}break}}break}f=1}return f|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;c=wb(x[a>>2]);x[g+44>>2]=c;k=wb(x[a+4>>2]);while(1){if(Ib(c,k)){i=g+24|0;a=wb(x[c>>2]);l=wb(x[c+4>>2]);c=vX(g+4|0,b);v[c+16|0]=y[b+16|0];x[c+12>>2]=x[b+12>>2];h=fb-16|0;fb=h;x[h+12>>2]=a;while(1){if(Ib(a,l)){f=fb-16|0;fb=f;if(!(y[a+5|0]|y[a+3|0]!=4)){e=f+8|0;Kb(e,x[c>>2],z[c+14>>1]);Jf(e,0);v[a+3|0]=0}e=y[a+2|0];if(!(y[a+4|0]|(e|0)!=11)){d=f+8|0;Kb(d,x[c>>2],z[c+14>>1]);Jf(d,0);v[a+2|0]=0;e=0}a:{b:{if(!y[a|0]){Kb(f+8|0,x[c>>2],z[c+14>>1]);e=y[a+2|0];d=y[a+3|0];if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break b}if(!((e|0)==11|d)){v[a+5|0]=0;d=4;v[a+3|0]=4;break a}if((d|0)==4|e){break a}v[a+4|0]=0;v[a+2|0]=11;break a}d=y[a+3|0]}j=f+8|0;Kb(j,x[c>>2],z[c+14>>1]);Jf(j,(d|0)==4|(e|0)==11);d=y[a+3|0]}c:{d:{e:{if(!(!y[c+16|0]|d)){v[a+3|0]=17;d=125;e=0;break e}e=0;f:{switch(d-16|0){case 1:break d;case 0:break f;default:break c}}if(y[a+5|0]){break c}d=6;e=1}v[a+5|0]=d}v[c+16|0]=e}a=z[c+14>>1]+1|0;w[c+14>>1]=z[c+12>>1]>(a&65535)>>>0?a:0;fb=f+16|0;a=x[vg(h+12|0)>>2];continue}break}a=AC(i,c);v[a+16|0]=y[c+16|0];x[a+12>>2]=x[c+12>>2];fb=h+16|0;uf(i);uf(c);c=x[am(g+44|0)>>2];continue}else{fb=g+48|0}break}}function jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){h=x[c+20>>2];if(h>>>0<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=D(b,g);q=D(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(Bn(Ee(Ig(C[(d+o<<3)+n>>3])*134217728))+qd(Wt(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d+q<<1)+m|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=ed(k),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(e>>>0>x[c+24>>2]-h>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=D(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Bn(Ee(Ig(C[(d+o<<3)+m>>3])*134217728))+qd(Wt(k),21)|0)*7.450580596923828e-9,C[r+24>>3]=s;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(d<<2)+l|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}r=x[q>>2]+(n<<1)|0,t=ed(j),w[r>>1]=t;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function cJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){b=x[a+12>>2];if(!(d>>>0<=b>>>0|f>>>0>=g>>>0)){i=v[b|0];c=i&255;c:{if((i|0)>=0){i=1;break c}k=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-b|0)<2){break b}i=y[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-b|0)<3){break b}j=y[b+2|0];i=y[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}c=j&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-b|0)<4){break b}l=y[b+3|0];m=y[b+2|0];j=y[b+1|0];f:{g:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=b+i;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}k=b>>>0<d>>>0;break a}k=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return k|0}function cra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);Dp(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=_e(Ci(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Rb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38128|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Rb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function vM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;tz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+80|0,x[d+4>>2]);a:{b:{c=x[d+4>>2];if(!vk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=gi(b- -64|0,-1,-1);if(!fo(x[b+88>>2],x[b+92>>2],x[a+8>>2],x[a+12>>2])){break b}}kg(c+x[x[c>>2]-12>>2]|0,0);break a}Hi(c,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(vk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;_m(c,b);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}Hi(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(vk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;_m(c,b+16|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}$d(b- -64|0,c);c=x[d+4>>2];c:{if(!vk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2])){a=gi(b+48|0,-1,-1);f=1;if(!fo(x[b+72>>2],x[b+76>>2],x[a+8>>2],x[a+12>>2])){break c}}kg(x[x[c>>2]-12>>2]+c|0,0);c=x[d+4>>2];f=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;_m(c,b+32|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=e+16|0;return f|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(zi(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[yb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Gb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Gb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Pi(a,b,c,t,n,d)}break}}fb=i+16|0}function jS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Xb(x[a+484360>>2],y[a+484376|0]);f=Zc(x[c>>2],x[c+4>>2]);a:{while(1){e=b&65535;if(e>>>0>=f>>>0){break a}if(!bj(c,e)){b=b+1|0;continue}break}f=a+1074312|0;e=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(e|0)){iS(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Ro(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;sB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Vo((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Kb(d+8|0,f,23);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=d+16|0}function Yqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){lD(d);break a}oh(c+8|0,d);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!AV(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25736>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25512|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25520>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25712>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25748|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Sb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Gb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=lf(b)}h=c+8|0;es(h,e);i=gc(c+16|0,x[c+8>>2],f);kc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);es(h,e);Sb(x[c+8>>2]+f|0,0,36-f|0);Vb(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}fb=g+48|0;return a|0}function xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2160|0;fb=b;tu(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ac(8);x[31725]=0;b=P(36,b+100|0,10453)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=EM(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=xM(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=gc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=zu(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+100|0,8057)|0;c=x[31725];x[31725]=0;if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a);break b}fb=b+2160|0;return a|0}c=N()|0;jc(a)}Q(c|0)}p()}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;h=x[a+76>>2];hg(b,g,vf(i,j,d),hb);n=hb>>>0>h>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;n=n-1|0;f=n;l=f?l:0;m=f?m:0;d=d-1|0;p=(((g&2147483647)<<1|b>>>31)&-2)+q|0;g=k;a:{b:while(1){c:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;f=0;b=0;break c}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){be(h,f>>>3<<16>>16);ae(h,4);Pb(e+8|0,l,m);g=g-1|0;continue b}else{f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}break}be(h,f>>>3<<16>>16);ae(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(e,i,j);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=Gg(l,m,n);p=hb;g=x[a+76>>2];hg(b,f,vf(l,m,d),hb);k=hb>>>0>g>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;k=k-1|0;o=k?o:0;p=k?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);ae(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Eg(g,r);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);ae(g,4);Pb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=nva(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;XS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;hc(c);fb=d+16|0;return}j=fb-32|0;fb=j;c=zb(a);c=fv(j+12|0,$q(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);XS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);f=x[vb(h+4|0,x[c+4>>2])>>2];i=fb-16|0;fb=i;d=fb-32|0;fb=d;Id(d+24|0,x[b>>2],x[e>>2]);k=d+16|0;b=x[d+24>>2];l=x[d+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=f;x[g+12>>2]=b;while(1){if(pd(b,l)){b=mn(b);e=mn(x[g+8>>2]);f=y[b+23|0]|y[b+24|0]<<8|(y[b+25|0]<<16|y[b+26|0]<<24);v[e+23|0]=f;v[e+24|0]=f>>>8;v[e+25|0]=f>>>16;v[e+26|0]=f>>>24;f=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=f;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;b=Zo(g+12|0);Zo(g+8|0);b=x[b>>2];continue}break}Ac(k,b,g+8|0);fb=g+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(i+8|0,b,d+12|0);fb=d+32|0;fb=i+16|0;x[c+4>>2]=x[i+12>>2];Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;XV(c);fb=j+32|0}function hta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);mp(b);f=b,g=xe((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(pva(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=$b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Bb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{if($b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break b}c=z[b+34>>1];if($b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Bb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){gm(b,+(c|0)/96);c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){Zz(a);a:{if(!y[a+4240|0]){break a}e=PA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;ou(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Xz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Wi(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];QT(h+8|0,1);g=Ej(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|fm(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Pi(g,b,c,Hc(a,0),Hc(a,1),d);fb=h+16|0}function gZ(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;de(a,0,d+14|0);break a}e=y[b+25040|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Rb(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Rb(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}de(a,e,d+15|0)}fb=d+16|0}function N7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1238;i=a+20|0;b=Be(a+24|0,a+32|0,i);j=a+16|0;bd(j,x[e+28>>2]);x[31725]=0;h=R(1217,x[a+16>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1247,a+444|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+432|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Cd(y[g+11|0])){yd(x[g>>2],0);Yd(g,0);break d}yd(g,0);Me(g,0)}if(y[a+15|0]){x[31725]=0;c=P(1234,h|0,45)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;O(35,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}x[31725]=0;d=P(1234,h|0,48)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31725]=0;U(1252,g|0,c|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break c}break a}x[31725]=0;c=P(1222,a+444|0,a+440|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Zb(a+16|0);Lc(b);fb=a+448|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=nva(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);k=nva(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384<<8;e=h;e=nva(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Yb(f,-16777216,16776704);e=nva(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(m,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38146>>1])+D(v[g-1|0],w[e+38144>>1])|0)+D(v[g+1|0],w[e+38148>>1])|0)+D(v[g+2|0],w[e+38150>>1])<<8)/16384<<8;e=o;g=nva(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Rf(a);while(1){if(Zg(b,c)){b=x[vb(i+8|0,o)>>2];j=td(x[i+12>>2]);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;e=fb-16|0;fb=e;a:{b:{if(!lc(b,x[vb(e+12|0,rg(a))>>2])){g=y[j|0];l=y[td(b)|0];if(!Ho(g,l)){break b}}x[e+12>>2]=b;g=vb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!lc(d,x[g>>2])){d=x[MB(e+12|0)>>2];l=y[td(d)|0];g=y[j|0];if(!Ho(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=fB(a,f,g);break a}if(Ho(l,g)){d:{d=KB(b);if(!lc(d,x[vb(e+12|0,rg(a))>>2])){g=y[j|0];if(!Ho(g,y[td(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=fB(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;e=ec(a);f=h+12|0;e=Ch(f,Ec(24),Mg(d+8|0,e));YS(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=ec(e),q=1,v[p+4|0]=q;fb=d+16|0;$g(a,x[h+28>>2],b,x[h+12>>2]);d=le(f);dm(f);n=1}_g(k+8|0,x[vb(h+12|0,d)>>2],n);fb=h+32|0;fb=k+16|0;vb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[ah(i+12|0)>>2];continue}else{fb=i+16|0}break}}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function CK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!yl(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}i=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){o=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;j=v[f|0];f:{if((j-48&255)>>>0<10){break f}g=-87;if((j-97&255)>>>0<26){break f}g=-55;if((j-65&255)>>>0>25){break e}}n=g+j|0;if((n|0)>=(m|0)){break e}Of(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}p=nva(k,h,m,0);j=hb;if((j|0)==-1&(n^-1)>>>0<p>>>0){break g}h=j;k=n+p|0;h=k>>>0<n>>>0?h+1|0:h;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=o?f:a}h:{i:{j:{if(c){x[31600]=68;a=d&1;i=a?0:i;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|i)){x[31600]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[31600]=68;break h}a=i^k;d=a-i|0;b=i>>31;e=(b^h)-((a>>>0<i>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=D(f,g);o=D(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c+o<<1)+l|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=ed(k),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function BT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}f=(f|0)!=65535;if(h=Ob(e,103),i=0,j=f,j?h:i){break c}if(h=Ob(e,49),i=0,j=f,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Zc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function Po(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!Tc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Tc(e)){break c}if((z[_b(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];d=0;x[b>>2]=d;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=d;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=D(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+l>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=(c<<2)+k|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}q=x[o>>2]+(m<<1)|0,r=ed(j),w[q>>1]=r;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-32|0;fb=f;m=x[d>>2];g=x[d+4>>2];x[f+28>>2]=g;k=b+36|0;d=m;while(1){a:{if(!g){break a}h=0;j=fb-32|0;fb=j;i=b+36|0;e=b+228|0;l=c&-4096;b:{c:{while(1){if((h|0)==16){break c}d:{g=x[yb(e,h)>>2];if(y[Hd(i,g)+8|0]){if(x[Hd(i,g)>>2]==(l|0)){break d}}h=h+1|0;continue}break}i=x[yb(e,h)>>2];h=e+(h<<2)|0;Cr(e,h,h+4|0);o=yb(e,0),p=i,x[o>>2]=p;break b}h=x[yb(e,15)>>2];Cr(e,b+288|0,b+292|0);o=yb(e,0),p=h,x[o>>2]=p;g=x[yb(e,0)>>2];e=Hd(i,g);x[e>>2]=l;mz(j+16|0,x[b+24>>2],g);i=x[x[b>>2]+44>>2];h=x[j+20>>2];x[j+8>>2]=x[j+16>>2];x[j+12>>2]=h;ib[i|0](j+24|0,b,l,j+8|0);x[e+4>>2]=x[j+28>>2];v[e+8|0]=1}fb=j+32|0;i=c-x[Hd(k,g)>>2]|0;x[f+12>>2]=4096-i;o=f,p=x[Gb(f+12|0,f+28|0)>>2],x[o+24>>2]=p;if(i>>>0<A[Hd(k,g)+4>>2]){e=x[Hd(k,g)+4>>2]-i|0}else{e=0}x[f+20>>2]=e;e=x[Gb(f+24|0,f+20|0)>>2];mz(f+12|0,x[b+24>>2],g);h=x[f+12>>2];mz(f+4|0,x[b+24>>2],g);Wg(h+i|0,e+(i+x[f+4>>2]|0)|0,d);g=x[f+28>>2]-e|0;x[f+28>>2]=g;n=e+n|0;if(e>>>0<A[f+24>>2]){break a}c=c+e|0;d=d+e|0;continue}break}bc(a,m,n);fb=f+32|0}function _ua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=G0(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Gb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function _ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=Zd(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;e=d+4|0;h=y[ef(c,e)|0];f=aE(c,b);l=Hr(f);x[31725]=0;c=R(204,b|0)|0;g=x[31725];x[31725]=0;a:{if((g|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;wc(d+1068|0,x[Gb(e,d)>>2]<<3);x[31725]=0;m=x[d+1068>>2];k=P(343,a|0,m|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;c=8;i=P(160,f|0,8)|0;a=x[31725];x[31725]=0;b:{if((a|0)!=1){c:{o=xb(x[k>>2],0),q=i,v[o|0]=q;g=1;a=h;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(g>>>0>=m>>>0){break d}x[31725]=0;j=P(160,f|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=h;continue}break}break c}a=j>>>1|0;i=(j&1?0-a|0:a)+i|0;o=xb(x[k>>2],g),q=i,v[o|0]=q;g=g+1|0;a=h;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:h;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Hr(f);x[31725]=0;P(151,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}}c=N()|0;dc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function xY(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function HQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Nd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=kx(c+60|0,d,b,c+8|0);x[31725]=0;d=R(204,b|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;d=U(955,b|0,c+19|0,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Pd((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Pd((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Pd((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;pu(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);h=x[a+44>>2];g=Hc(h,0);h=Hc(h,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);e=oc(x[a+4208>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Kl(a+4208|0,k)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;v=yb(k,i);f=B[yb(k,i|1)>>2];s=B[g>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;w=yb(k,i),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=yb(k,i|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;Mk(e,e+g|0,n);Mk(h,h+g|0,j)}g=a;a=x[a+56>>2];Pi(g,b,c,Hc(a,0),Hc(a,1),d)}function xD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function T7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1238;i=a+20|0;b=Be(a+24|0,a+32|0,i);j=a+16|0;bd(j,x[e+28>>2]);x[31725]=0;h=R(28,x[a+16>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1239,a+140|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+132|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}tf(g);if(y[a+15|0]){x[31725]=0;c=P(29,h|0,45)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;O(117,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}x[31725]=0;d=P(29,h|0,48)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31725]=0;U(1245,g|0,c|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break c}break a}x[31725]=0;c=P(1207,a+140|0,a+136|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Zb(a+16|0);Lc(b);fb=a+144|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!zi(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=yb(k,f);g=B[l>>2];B[h>>2]=g;y=yb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(nQ(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[yb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[yb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Pi(a,b,c,q,r,d)}break}}}function Ao(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Oj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Oj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=cS(mY(c+40|0,1),f&255,0,0);x[31725]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1097,c+68|0,a|0,0,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}j=c,k=wb(x[c+68>>2]),x[j+36>>2]=k;d=wb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Xi(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31725]=0;O(1132,g|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){dr(c+36|0);continue}break}break}a=N()|0;Xi(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=ac(8);x[31725]=0;d=P(36,c+40|0,7310)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;jc(b)}of(g);Q(a|0)}p()}function Q1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;xc(b);Sp(a);e=d+60|0;a:{if(!Zw(b,e)){break a}if(!_F(e)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}ox(a);g=d,h=nx(),x[g+40>>2]=h;c=d+40|0;mx(lj(x[a+4>>2])+32|0,c);qs(c);e=x[lj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31725]=0;S(188,c|0,b|0,$b(f)-28|0);b=x[31725];x[31725]=0;c:{d:{if((b|0)!=1){Sn(d+32|0,c);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31725]=0;b=ba(189,x[d+32>>2],x[d+36>>2],e|0,$b(b)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}Kc(c);f=0;if(!b){break a}oe(d+16|0,x[e>>2],x[e+4>>2]);mf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Nd(d+8|0);e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=kx(c,x[d+24>>2],x[d+28>>2],d);hd(lj(x[a+4>>2])+12|0,b);ub(b);break b}a=ta(125e3,24440)|0;b=gb;break c}a=ta(125e3,24440)|0;b=gb;Kc(d+40|0)}e:{if(($(125e3)|0)==(b|0)){break e}if(($(24440)|0)==(b|0)){break e}Q(a|0);p()}Y(a|0)|0;Z();f=0;break a}f=1}fb=d+96|0;return f|0}function zia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=fb+-64|0;fb=b;g=Nb(a);x[31725]=0;W(960,g|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=43040;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==43352){fb=b- -64|0;return g|0}k:{h=yu(44);if(h){x[31725]=0;d=P(36,b+36|0,x[a+4>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=x[a>>2];x[31725]=0;i=b+48|0;O(961,i|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;e=P(36,b+12|0,x[a+8>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}x[31725]=0;f=b+24|0;O(961,f|0,e|0);j=x[31725];x[31725]=0;if((j|0)==1){break h}x[31725]=0;c=ba(962,h|0,c|0,i|0,f|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}Eb(f);tb(e);Eb(i);tb(d);x[b+60>>2]=c;x[31725]=0;O(963,g|0,b+60|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Eb(b+24|0)}tb(e)}Eb(b+48|0)}tb(d)}Db(h);break a}a=N()|0;break a}a=N()|0}uc(g);Q(a|0);p()}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);i=hb>>>0>f>>>0?d:0}f=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;g=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,k);c=c+8|0;continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function bC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(b&5){if((b|0)==1){e=nva(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(pva(e,c,8287,0),hb),x[f+24>>2]=g}FV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Qf(a+40|0,15);Qf(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=yi(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Zk(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=xb(a,8);v[b|0]=y[b|0]&3;a=xb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function Vo(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Ob(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;$o(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function F0(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{if((y[a|0]-16&255)>>>0<241){break a}c=a+1954|0;d=a+1698|0;while(1){if((d|0)==(c|0)){d=0;c=0;while(1){if((d|0)==32){g=c;break a}g=0;e=D(d,13)+a|0;if(y[nc(e+2|0)|0]){break a}b=(d<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break a}h=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(h>>>0>1048575){break a}if(y[nc(e+930|0)|0]){break a}e=(D(d,11)+a|0)+1346|0;if(y[xb(e,0)|0]>15){break a}if(y[xb(e,5)|0]>3){break a}if(y[xb(e,10)|0]>3){break a}b:{c:{d:{if(h){i=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(i>>>0<=1048574&(h>>>0<i>>>0|(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0>i>>>0)){break a}if(c|h){break c}break d}if(c){break c}}v[f+7|0]=0;v[f+8|0]=0;v[f+9|0]=0;v[f+10|0]=0;x[f>>2]=0;x[f+4>>2]=0;g=e+11|0;c=f;while(1){e:{b=(e|0)==(g|0);if(b){break e}if(!E0(y[e|0],y[c|0])){break e}c=c+1|0;e=e+1|0;continue}break}c=0;if(b){break b}}c=1}d=d+1|0;continue}}b=v[d|0];d=d+1|0;if((b|0)>-2){continue}break}}fb=f+16|0;return g&1}function IT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=nva(c,c>>31,5e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(ova(c,e,b,b>>31),hb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=nva(c,c>>31,1e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(ova(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(nva(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!He(c,x[a+484348>>2],e)){break d}c=Wb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=bS(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!lc(e,c)){f=f*+A[yb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=nva(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function ZL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){Dl(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Nm(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}fc(a,21);return 0}_(7552,13258,1887,6586);p()}function yS(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=cv(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function UL(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;f=b<<2;a:{if(!f){break a}x[d+16>>2]=4;x[d+20>>2]=4;a=4;b=4;e=2;while(1){g=a;a=(a+b|0)+4|0;x[(d+16|0)+(e<<2)>>2]=a;e=e+1|0;b=g;if(a>>>0<f>>>0){continue}break}f=(h+f|0)-4|0;b:{if(f>>>0<=h>>>0){b=0;e=1;f=0;a=1;g=0;break b}e=1;a=1;while(1){c:{if((e&3)==3){_y(h,c,a,d+16|0);Mt(d+8|0,2);a=a+2|0;break c}b=d+16|0;g=a-1|0;d:{if(A[b+(g<<2)>>2]>=f-h>>>0){Lt(h,c,e,x[d+12>>2],a,0,b);break d}_y(h,c,a,d+16|0)}if((a|0)==1){Kt(d+8|0,1);a=0;break c}Kt(d+8|0,g);a=1}b=x[d+8>>2];e=b|1;x[d+8>>2]=e;h=h+4|0;if(f>>>0>h>>>0){continue}break}f=b>>>0>1;b=x[d+12>>2];g=(b|0)!=0}Lt(h,c,e,b,a,0,d+16|0);if(!(g|((a|0)!=1|f))){break a}while(1){e:{if((a|0)<=1){g=ML(e,b);Mt(d+8|0,g);b=x[d+12>>2];e=x[d+8>>2];a=a+g|0;break e}e=d+8|0;Kt(e,2);x[d+8>>2]=x[d+8>>2]^7;Mt(e,1);b=h-4|0;f=d+16|0;g=a-2|0;Lt(b-x[f+(g<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],a-1|0,1,f);Kt(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;a=b;b=x[d+12>>2];Lt(a,c,e,b,g,1,f);a=g}h=h-4|0;if((a|0)!=1|(e|0)!=1|b){continue}break}}fb=d+208|0}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}e=0;x[31725]=0;W(1028,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}a=Sb(c,0,d);if(!y[b|0]){break b}if(ni(b,47360)|(d|0)!=8){break d}x[a+4>>2]=1029;x[a>>2]=1030;break c}Y(T(0)|0)|0;x[31725]=0;V(989,12344,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();return 0}if(!(ni(b,47372)|(d|0)!=64)){x[a+60>>2]=1031;x[a+56>>2]=1032;x[a+52>>2]=1033;x[a+48>>2]=1034;x[a+44>>2]=1035;x[a+40>>2]=1036;x[a+36>>2]=1037;x[a+32>>2]=1038;x[a+28>>2]=1039;x[a+24>>2]=1040;x[a+20>>2]=1041;x[a+16>>2]=1042;x[a+12>>2]=1043;x[a+8>>2]=1044;x[a+4>>2]=1045;x[a>>2]=1046;break c}if(!(ni(b,47384)|(d|0)!=24)){x[a+20>>2]=1047;x[a+16>>2]=1048;x[a+12>>2]=1049;x[a+8>>2]=1050;x[a+4>>2]=1051;x[a>>2]=1052;break c}if(ni(b,47397)|(d|0)!=4){break b}x[a>>2]=1053}e=1}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Dia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-32|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}x[b+148>>2]=-1;j=c,k=ib[x[x[a>>2]+40>>2]](a)|0,x[j+16>>2]=k;x[c+8>>2]=1073741822;b=c+16|0;d=c+8|0;g=x[Gb(b,d)>>2];e=g<<2;if(!e){break b}h=x[a+20>>2];x[31725]=0;O(289,h+4|0,e+4|0);e=x[31725];x[31725]=0;c:{d:{if((e|0)!=1){e=d;d=x[a+20>>2];oe(e,x[d+4>>2],x[d+8>>2]);x[c>>2]=0;x[c+4>>2]=0;d=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=d;d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;d=fb-16|0;fb=d;x[d+12>>2]=0;EQ(b,d+12|0);fb=d+16|0;b=x[x[a>>2]+184>>2];x[31725]=0;O(b|0,a|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break d}while(1){if((f|0)==(g|0)){b=x[x[a>>2]+188>>2];x[31725]=0;W(b|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31725]=0;i=E(_a(b|0,a|0,f|0));b=x[31725];x[31725]=0;if((b|0)!=1){B[c+8>>2]=i;f=f+1|0;EQ(c+16|0,c+8|0);continue}break}b=T(125e3)|0;break c}b=T(125e3)|0;break c}b=T(125e3)|0}if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;fp(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(b|0);p()}function zna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(k<<16)|0;e=k;g=nva(e,e>>31,o,w);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function jX(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;gC(a,DV(a),c+48|0);b=qc(c+40|0,14192);sf(Oe(a,0),x[b>>2],x[b+4>>2]);b=qc(c+32|0,14275);sf(Oe(a,1),x[b>>2],x[b+4>>2]);b=qc(c+24|0,5496);sf(Oe(a,3),x[b>>2],x[b+4>>2]);b=qc(c+16|0,15744);sf(Oe(a,4),x[b>>2],x[b+4>>2]);b=qc(c+8|0,9265);sf(Oe(a,8),x[b>>2],x[b+4>>2]);d=Oe(a+288|0,0);b=fb-16|0;fb=b;e=d;d=qc(b+8|0,4932);sf(e,x[d>>2],x[d+4>>2]);fb=b+16|0;d=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){e=a+28|0;kw(e,4084);x[31725]=0;g=a+16|0;O(291,g|0,a+60|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;f=a+40|0;S(292,f|0,e|0,g|0);h=x[31725];x[31725]=0;if((h|0)!=1){ee(a+52|0,f);sf(Oe(d,b),x[a+52>>2],x[a+56>>2]);tb(f);tb(g);Eb(e);break d}b=N()|0;tb(a+16|0);break b}e=qc(a+8|0,22267);sf(Oe(d,b),x[e>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function yna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=nva(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function pva(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>mva(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=mva(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;ld(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Nc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Nc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41178|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function Ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=nva(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=nva(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=nva(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function NM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=D(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);i=d;d=x[(a+o<<2)+m>>2]+(x[d>>2]>>1)|0;q=d;d=Xt(k)+d&-4096;x[i>>2]=q-d;i=x[(a<<2)+l>>2]+(n<<1)|0;d=qd(d|2048,12);d=(d|0)>=32767?32767:d;w[i>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function HM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=D(e,h);o=D(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);q=d;d=x[(a+n<<2)+m>>2]+(x[d>>2]>>1)|0;r=d;d=Xt(k)+d&-4096;x[q>>2]=r-d;d=qd(d|2048,12);d=(d|0)>=32767?32767:d;w[(a+o<<1)+l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function YL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15833,13258,2423,9211);p()}function Pna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=nva(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=nva(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=nva(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function ata(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=Zh(b,c);n=e,o=Bb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;gh(d,z[Nc(e+14|0,e+12|0)>>1]);n=d,o=Bb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Bb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Bb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Bb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;i=x[d>>2];f=x[d+4>>2];b=y[d+12|0]&-2|lc(i,f)^1;v[d+12|0]=b;b=Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&2|b&-3;v[d+12|0]=b;n=d,o=Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&4|b&251,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:j=-128;b=127;break a;case 1:break b;default:break a}}j=-1616;b=1616}d=b-j|0;k=d>>>1|0;m=Sd(i,f);b=0;while(1){if(b>>>0>=m>>>0){fb=e+16|0}else{f=yb(i,b);w[f>>1]=l;g=(b<<2)+a|0;c=xe((y[g+28|0]|y[g+29|0]<<8)<<16>>16)+j|0;h=c;c=c>>31<<6|c>>>26;h=k+(h<<6)|0;c=h>>>0<k>>>0?c+1|0:c;n=f,o=Dh(Gc(ova(h,c,d,0),hb)),v[n+2|0]=o;n=e,o=Bb(y[g+26|0]|y[g+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;l=z[qe(e+10|0,e+8|0)>>1]+l|0;continue}break}}function gC(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Gua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;c=x[a+8>>2];h=nc(a);a:{if((c|0)!=x[h>>2]){break a}k=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){f=fb-16|0;fb=f;l=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,c);m=a+16|0;c=x[a+24>>2];h=x[a+28>>2];j=((d-e>>1)+1|0)/-2<<1;d=d+j|0;e=fb-16|0;fb=e;while(1){if((c|0)!=(h|0)){d=g0(d,c)+2|0;c=c+2|0;continue}break}x[e+12>>2]=d;Ac(m,h,e+12|0);fb=e+16|0;c=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(l,c,a+12|0);fb=a+32|0;fb=f+16|0;c=x[f+12>>2];x[i>>2]=c;x[k>>2]=x[k>>2]+j;break a}x[g+8>>2]=c-e;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=mk(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);e=x[vb(g,x[a+8>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;e=Hp(f,c+8|0,mE(d,e));d=x[e>>2];while(1){if(x[e+4>>2]!=(d|0)){j=d;d=x[f+12>>2];hj(j,y[d|0]|y[d+1|0]<<8);d=x[e>>2]+2|0;x[e>>2]=d;Md(f+12|0);continue}break}he(e);fb=f+16|0;Ub(a,c);Ub(k,c+4|0);Ub(i,c+8|0);Ub(h,nc(c));jj(c);c=x[a+8>>2]}hj(c,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);i=nva(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384<<8;e=h;e=nva(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Yb(f,-16777216,16776704);e=nva(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Pb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function cL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;l=fb-1040|0;fb=l;r=x[31600];a:{b:{i=l+16|0;m=z[((b>>>0<=153?b:0)<<1)+123456>>1]+121532|0;c=x[x[124231]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];f=x[c>>2]+1794895138|0;h=Im(x[c+8>>2],f);g=Im(x[c+12>>2],f);d=Im(x[c+16>>2],f);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=g>>>2|0;g=0;while(1){k=h>>>1|0;n=k+g|0;o=n<<1;d=c+(o+t<<2)|0;q=Im(x[d>>2],f);d=Im(x[d+4>>2],f);if(d>>>0>=j>>>0|j-d>>>0<=q>>>0|y[c+(d+q|0)|0]){break c}d=ni(m,c+d|0);if(!d){g=c+(s+o<<2)|0;h=Im(x[g>>2],f);f=Im(x[g+4>>2],f);if(f>>>0>=j>>>0|h>>>0>=j-f>>>0){break c}e=y[c+(f+h|0)|0]?0:c+f|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;g=d?g:n;continue}}}e=e?e:m;c=Cf(e);d:{if(c>>>0>=1024){yc(i,e,1023);v[i+1023|0]=0;e=68;break d}yc(i,e,c+1|0);e=0}if(e){if((e|0)!=28){break b}e=22267}else{e=i}break a}va();p()}if(!y[e|0]){x[l>>2]=b;Gy(i,1024,13075,l);e=i}x[31600]=r;Dc(a,e);fb=l+1040|0}function CD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Dh(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+24976|0]}de(e,a,d+15|0);fb=d+16|0}function Mta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-288|0;fb=f;tf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){j=f+32|0;d=j;xo(f+8|0,d,zr(d));kc(f+20|0,x[a>>2],x[a+8>>2],x[f+8>>2],x[f+12>>2]);x[f+28>>2]=x[f+24>>2];o=f,q=c-Yc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Gb(f+28|0,f+4|0)>>2];if(!d){break a}m=d+j|0;k=Li(j,m,0);d=vb(f,Df(b));l=fb-16|0;fb=l;h=Gk(x[d>>2],zd(b));b:{c:{d=j;e=Wj(d,k);d:{if(!e){zd(b);break d}if(!Lz(b,d)){i=Cb(x[b+4>>2],y[b+11|0]);g=Mc(b);e:{if(e>>>0<=g-i>>>0){g=Jb(b);if((h|0)==(i|0)){break e}n=h+g|0;Ui(e+n|0,n,i-h|0);break e}Wm(b,g,(e+i|0)-g|0,i,h,0,e);g=x[b>>2]}e=e+i|0;ng(b,e);fd(e+g|0,0);e=h+g|0;while(1){if((d|0)!=(k|0)){fd(e,y[d|0]);d=d+1|0;e=e+1|0;continue}break}Pe(zd(b),h);break d}d=si(l+4|0,d,k);i=zd(d);g=Df(d);x[31725]=0;ha(366,b|0,e|0,h|0,i|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break c}tb(d)}fb=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Vb(a,k-j|0);if(k>>>0>=m>>>0){continue}break}Vb(a,1)}fb=f+288|0}function Nua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-144|0;fb=f;x[31725]=0;l=R(275,a|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31725]=0;O(294,a|0,f+8|0);e=x[31725];x[31725]=0;if((e|0)!=1){b:{e=Bb(z[f+8>>1]);if((e-1&65535)>>>0>=z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Zh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Rb(f+4|0,f+7|0)|0];x[31725]=0;h=h+1&255;O(295,e|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;m=Bb(z[i+8>>1]);k=yb(g,e);w[k>>1]=m;i=Bb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Gf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(k,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38146>>1])+D(v[g-1|0],w[e+38144>>1])|0)+D(v[g+1|0],w[e+38148>>1])|0)+D(v[g+2|0],w[e+38150>>1])<<8)/16384<<8;e=m;g=nva(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;kN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;hc(c);fb=d+16|0;return}i=fb-32|0;fb=i;c=zb(a);c=LJ(i+12|0,OJ(a,oj(x[a>>2],x[a+4>>2])+1|0),oj(x[a>>2],x[a+4>>2]),c);kN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);e=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[c+4>>2])>>2];h=fb-16|0;fb=h;b=fb-32|0;fb=b;Id(b+24|0,x[d>>2],x[e>>2]);k=b+16|0;e=x[b+24>>2];l=x[b+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=e;while(1){if(pd(e,l)){e=pl(e);f=pl(x[d+8>>2]);x[f+16>>2]=x[e+16>>2];j=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=j;j=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=j;e=_s(d+12|0);_s(d+8|0);e=x[e>>2];continue}break}Ac(k,e,d+8|0);fb=d+16|0;d=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(h+8|0,d,b+12|0);fb=b+32|0;fb=h+16|0;x[c+4>>2]=x[h+12>>2];Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;JJ(c);fb=i+32|0}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function N8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31725]=0;b=R(1217,x[g>>2])|0;a=x[31725];x[31725]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31725]=0;a=R(1218,x[g>>2])|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}Zb(g);x[31725]=0;O(1219,g|0,a|0);d=x[31725];x[31725]=0;if((d|0)==1){b=N()|0;break d}x[31725]=0;O(1220,g|12,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=g+24|0;a=sa(1221,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Qb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;Qb(g);break d}b=N()|0;while(1){d=Qb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function Y8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31725]=0;b=R(28,x[g>>2])|0;a=x[31725];x[31725]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31725]=0;a=R(1201,x[g>>2])|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}Zb(g);x[31725]=0;O(1202,g|0,a|0);d=x[31725];x[31725]=0;if((d|0)==1){b=N()|0;break d}x[31725]=0;O(1203,g|12,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=g+24|0;a=sa(1204,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function Kra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Kv(c,d);d=b&63;if(e>>>0>d>>>0){c=hZ(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Nf(a);e=fb-32|0;fb=e;a:{b:{if(Ug(a)>>>0<=14){if(uh(1073741823)>>>0<=14){break b}f=zb(a);f=$f(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);as(a,f);_f(f)}fb=e+32|0;break a}dd();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=em(g+12|0,h&65535,y[Rb(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[zb(a)>>2]){dZ(a,f);break d}i=fb-32|0;fb=i;e=zb(a);e=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);hp(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;as(a,e);_f(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|lc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function yk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;b=i+4|0;bd(b,x[d+28>>2]);c=0;x[31725]=0;j=R(28,x[i+4>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){Zb(b);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(th(i+12|0,i+8|0)){break b}c:{if((sl(j,v[g|0])|0)==37){if((g+1|0)==(h|0)){break b}c=sl(j,v[g+1|0]);d:{if(!((c|0)==69|(c&255)==48)){b=0;k=1;break d}if((g+2|0)==(h|0)){break b}b=c;c=sl(j,v[g+2|0]);k=2}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,b)|0,x[l+12>>2]=m;g=(g+k|0)+1|0;break c}b=x[j+8>>2];if(Kf(b,1,v[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Kf(b,1,v[g|0])){continue}}break}while(1){b=i+12|0;if(th(b,i+8|0)){break c}c=Bl(x[i+12>>2]);if(!Kf(x[j+8>>2],1,c)){break c}Km(b);continue}}if((yy(j,Bl(x[i+12>>2]))|0)==(yy(j,v[g|0])|0)){g=g+1|0;Km(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(th(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(bp(a)){c=x[a>>2];k=Lg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Gb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=wb(x[b>>2]);e=wb(x[b+4>>2]);f=fb-16|0;fb=f;h=mE(i,e);b:{if(h>>>0<=On(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Zc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;hV(f+12|0,d);d=x[f+12>>2]}j=fb-16|0;fb=j;jV(j+8|0,i,d,m);d=x[j+12>>2];fb=j+16|0;if(!n){lV(c,x[f+12>>2],e,h-Zc(x[c>>2],x[c+4>>2])|0);break b}Jn(c,d);break b}kV(c);GC(c,nk(c,h));lV(c,i,e,h)}fb=f+16|0;ts(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){ZB(a,1-k|0,b);break a}aV(a,x[a>>2]+32|0);break a}if(x[a>>2]){dV(a);e=x[a>>2];bp(a);Db(e);o=zb(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=$q(a,1);e=fb-16|0;fb=e;if(uh(134217727)>>>0<d>>>0){dd();p()}WV(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=zb(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;fb=e+16|0;ZB(a,1,b)}fb=g+16|0}function vx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,h-15233|0);fn(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function Hf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];kg(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Pc(d+12|0,c,4);if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){ny(a)}a:{if(!x[a+8>>2]){break a}Pc(d+12|0,c,6);if(Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Pc(d+24|0,c,7);if(Hb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Hi(f,g,e,0)}Pc(d+12|0,c,5);c=0;b:{if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=oj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}c:{g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;f=wf(x[a+52>>2],g);h=x[f>>2];j=x[a+40>>2];if(h>>>0>=Sc(j,x[a+44>>2])>>>0){break c}f=xl(d+12|0,xb(j,h),z[f+20>>1]);h=Ey(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=wf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Hi(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=wf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function HH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=Ss(e+28|0,b);d=x[f>>2];if(!Dd(d)){x[31725]=0;b=P(36,e+4|0,b|0)|0;a=x[31725];x[31725]=0;b:{c:{d:{if((a|0)!=1){x[31725]=0;a=e+16|0;S(1017,a|0,17691,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}jq(d);if(!Rs(a+8|0,22267,x[f>>2])){v[a+8|0]=127}if(!Rs(a+9|0,22267,x[f>>2])){v[a+9|0]=127}x[31725]=0;O(274,a+12|0,22267);b=x[31725];x[31725]=0;e:{f:{if((b|0)==1){break f}x[31725]=0;b=a+24|0;O(274,b|0,22267);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31725]=0;O(274,a+36|0,22267);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;O(274,a+48|0,22267);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;b=P(72,e+16|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}hi(a- -64|0,c);hi(a+68|0,c);tb(b);ol(f);fb=e+32|0;return}ol(f);Q(a|0);p()}function pq(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=D(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=x[(a+m<<2)+k>>2];n=Wt(i);o=x[(a<<2)+j>>2]+(l<<1)|0;e=qd((qd(n,21)+e|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function Ci(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=tj(a)&2047;c=tj(5551115123125783e-32);a:{if(f-c>>>0>=tj(512)-c>>>0){if(c>>>0>f>>>0){return a+1}o(+a);c=j(1)|0;e=j(0)|0;b:{if(tj(1024)>>>0>f>>>0){break b}b=0;if(!e&(c|0)==-1048576){break a}if(tj(Infinity)>>>0<=f>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Ps(3105036184601418e216)}if(c>>>0<3230714880){break b}return Ps(12882297539194267e-247)}c=c<<1|e>>>31;f=!(e<<1)&(c|0)==-2129002496|c>>>0<2165964800?f:0}b=C[177];g=b+a;a=a-(g-b);b=a*a;h=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+g);j(1)|0;c=j(0)|0;d=c<<4&2032;a=h+(b+(a+C[d+1464>>3]));d=d+1472|0;e=0+x[d>>2]|0;d=x[d+4>>2]+(c<<13)|0;d=e>>>0<i>>>0?d+1|0:d;if(!f){c:{if(!(c&-2147483648)){l(0,e|0);l(1,d+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,e|0);l(1,d+1071644672|0);b=+n();g=b*a;a=g+b;if(a<1){gJ(PJ()*22250738585072014e-324);h=a+1;a=h+(g+(b-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,e|0);l(1,d|0);b=+n();b=b*a+b}return b}function xk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;c=i+4|0;bd(c,x[d+28>>2]);b=0;x[31725]=0;j=R(1217,x[i+4>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){Zb(c);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(li(i+12|0,i+8|0)){break b}c:{if((wk(j,x[g>>2])|0)==37){if((g+4|0)==(h|0)){break b}b=wk(j,x[g+4>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=0;k=1;break d}if((g+8|0)==(h|0)){break b}c=b;b=wk(j,x[g+8>>2]);k=2}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,c)|0,x[l+12>>2]=m;g=((k<<2)+g|0)+4|0;break c}if(yj(j,1,x[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(yj(j,1,x[g>>2])){continue}}break}while(1){b=i+12|0;if(li(b,i+8|0)){break c}if(!yj(j,1,Al(x[i+12>>2]))){break c}no(b);continue}}if((qm(j,Al(x[i+12>>2]))|0)==(qm(j,x[g>>2])|0)){g=g+4|0;no(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(li(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function kua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=aE(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[31725]=0;W(325,d|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[31725]=0;j=P(160,d|0,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31725]=0;k=P(160,d|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(28848)|0;break b}a=T(28848)|0;break b}a=T(28848)|0}if((gb|0)==($(28848)|0)){Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=Hr(d);ub(d);fb=f+2608|0;return a|0}function aA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Sc(d,b)>>>0<4){break b}oe(c+16|0,d,b);b=Nd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=l$(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31725]=0;b=R(153,d|0)|0;f=x[31725];x[31725]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31725]=0;f=R(b|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Sc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31725]=0;O(e|0,a|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31725]=0;W(b|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}x[31725]=0;g=E(xa(475,d|0));e=x[31725];x[31725]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31725]=0;wa(e|0,a|0,b|0,E($m(g)?g:E(0)));e=x[31725];x[31725]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=(g<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function Jz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{e=x[a+36>>2];c=x[a+40>>2];h:{if(Ib(e,c)){sc(d+12|0);break h}Ao(d,a);x[31725]=0;c=R(1062,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[d+12>>2]=c;of(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=a+36|0,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((oj(f,x[e+4>>2])|0)>(b|0)){break e}}b=ac(8);x[31725]=0;c=P(36,d|0,10966)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;of(d);break c}a=N()|0;jc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;ck(b+484360|0,y[wf(f,c)+16|0]);b=wf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31725]=0;+oa(1094,a|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}a=N()|0}Fl(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;Fl(d+12|0);fb=d+16|0}function hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=D(b,d);n=D(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=qd((x[(a+m<<2)+l>>2]+qd(Wt(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a+n<<1)+k>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function uV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Sj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Tc(e),n?l:m);f=Ob(d+1074312|0,34);d=x[a+656>>2];a:{if(!f){break a}f=e&255;if(!f|f>>>0>120){break a}e=y[xb(d+108|0,f-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];g=((e&255)+c|0)-61<<16>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[d+36>>2];if(h){break c}}b=an(d,c+g<<16>>16);break b}j=h+1|0;i=gA(c,j);e=hA(c,j);b=E(1);f=w[d+28>>1];c=g+i<<16>>16;d:{if((f|0)>(c|0)){break d}g=x[d+4>>2];if((c|0)>(oc(g,x[d+8>>2])+f|0)-1<<16>>16){break d}if(!e){b=B[yb(g,c-f|0)>>2];break b}e:{f:{g:{switch(z[d>>1]-1|0){case 2:h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break f}b=B[yb(h,e-1|0)>>2];break e;case 0:break g;default:break f}}i=x[d+16>>2];if(!oc(i,x[d+20>>2])){break f}b=B[yb(i,(e+D(h,lA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=De(E(an(d,c+1<<16>>16)/an(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[yb(g,c-f|0)>>2])}}l=a,m=Ik(E(E(k*b)*E(16))),x[l+700>>2]=m}}function dJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function Qta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Bb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}gm(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Rb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;c=x[b+4>>2];d=x[b+8>>2];if(v[a+40|0]&1){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1}if(y[a+41|0]>=9){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(c+1>>>0<d>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function vA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-16|0;fb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;gh(b,x[ud(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=Sd(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=yb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[yb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=yb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[fk(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}fb=d+16|0}function py(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=sy(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=v[(a>>2)+111728|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((zl(v[a-1|0])|0)!=(zl(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=zl(g);if((d|0)!=v[c|0]){break d}m=c,n=yt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=ok(d,x[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;f=b-c|0;d=x[zb(a)>>2];b=x[a+4>>2];a:{if(f>>>0<=d-b>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{tu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=zb(a);i=g+12|0;e=ok(x[a>>2],b)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=e>>>0){d=cA(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}d=YQ(i,b,ok(x[a>>2],x[a+4>>2]),h);c=d;e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[c+8>>2];h=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=h+(f<<11);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){tu(c);c=x[b>>2]+2048|0;x[b>>2]=c;continue}break}he(b);fb=e+16|0;XQ(a,d);WQ(d)}fb=g+32|0;return}if(b>>>0<c>>>0){SQ(a,d+(b<<11)|0)}}function uy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Li(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=v[a+111728|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)){if((zl(v[a-1|0])|0)!=(zl(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=zl(g);if((d|0)!=v[c|0]){break d}m=c,n=yt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function yr(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=wb(x[a+484344>>2]);x[e+12>>2]=c;a=wb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[am(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;f=fb-160|0;fb=f;d=f+24|0;c=d+56|0;e=Nt(c);x[d>>2]=94156;x[e>>2]=94176;x[d+56>>2]=94216;x[d>>2]=94196;i=c;c=d+4|0;so(i,c);x[d>>2]=94156;x[e>>2]=94176;c=Jt(c);x[c>>2]=93640;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;j=x[x[d>>2]-12>>2];x[31725]=0;i=ca(106)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[31725]=0;e=f+20|0;S(107,e|0,d+j|0,i|0);c=x[31725];x[31725]=0;if((c|0)==1){break f}Zb(e);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;Cn(d+x[x[d>>2]-12>>2]|0,x[c+12>>2]);k=C[b>>3];x[31725]=0;e=Sa(1136,d|0,+k)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=f+8|0;O(1137,c|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;O(305,h|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}tb(c);oq(e);fb=f+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(f+8|0)}oq(d);Q(a|0);p()}Rh(a,h);tb(h);fb=g+16|0}function O2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;f=Fb(a);x[31725]=0;a=ca(119)|0;b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){break b}c:{d:{if(!a){break d}x[31725]=0;b=P(1,c+24|0,8963)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;a=ca(119)|0;d=x[31725];x[31725]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31725]=0;x[c+8>>2]=a;a=c+12|0;O(128,a|0,c+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;d=c+36|0;S(2,d|0,b|0,a|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}e=Ab(f,d);tb(d);tb(a);tb(b);x[31725]=0;a=ca(121)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if(!a){break e}x[31725]=0;P(129,e|0,17525)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(c+12|0)}tb(b);break a}x[31725]=0;a=ca(120)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if(!a){break d}x[31725]=0;P(129,e|0,16811)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}}fb=c+48|0;return}a=N()|0;break a}a=N()|0}tb(f);Q(a|0);p()}function Cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];f=fb-48|0;fb=f;e=x[b+4>>2];b=y[b+8|0];d=e-(((b|0)==1|(b|0)==4)&(e|0)!=0)|0;e=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Li(c,c+d|0,0);x[31725]=0;U(71,e|0,c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31725]=0;b=U(71,e|0,c|0,c+d|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break g}c=zd(b);d=Df(b);g=zd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=me(a+12|0);me(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31725]=0;c=P(72,f+24|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=P(36,f+12|0,18429)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;a=f+36|0;S(73,a|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}Ab(b,a);tb(a);tb(d);tb(c)}fb=f+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(e);Q(a|0);p()}}function rz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=Ee(Ig(C[(a+k<<3)+i>>3])*134217728);m=x[(a<<2)+h>>2]+(j<<2)|0,n=E(+(Bn(l)|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Bf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function pz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=E(+(Bn(Ee(Ig(C[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=D(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=x[(a<<2)+i>>2]+(k<<1)|0;f=qd(x[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=g+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[g+x[e+12>>2]|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,v[g+x[e+12>>2]|0]<<6);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=D(b,g);m=D(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=qd(x[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a+m<<1)+j>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function lta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);mp(b);f=b,g=Bb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(pva(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=$b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+$b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Bb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=$b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){gm(b,+(c|0)/96);c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!zi(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Hc(e,0);x[g>>2]=o;p=Hc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[yb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=yb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}Pi(a,b,c,o,p,d)}fb=g+16|0}function Dq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Nf(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Nf(c);return}Kl(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=De(E(an(a,e+1<<16>>16)/an(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=De(g,E(b>>>0));n=yb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Nf(c);return}Kl(c,D(b,e));h=z[a+30>>1];j=lA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=lA(c+j<<16>>16,h);f=an(a,d+1<<16>>16);d=d<<16>>16;f=De(E(f/an(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=De(f,E(d>>>0));n=yb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Nf(a+16|0);return;default:break b}}Nf(a+16|0);x[a+36>>2]=0}}function wt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{e=tj(a)&2047;d=tj(5551115123125783e-32);if(e-d>>>0<tj(512)-d>>>0){h=e;break b}if(d>>>0>e>>>0){return a+1}if(tj(1024)>>>0>e>>>0){break b}o(+a);d=j(1)|0;b=0;if(!(j(0)|0)&(d|0)==-1048576){break a}if(tj(Infinity)>>>0<=e>>>0){return a+1}if((d|0)<0){return Ps(12882297539194267e-247)}return Ps(3105036184601418e216)}b=C[170];f=C[169]*a+b;b=f-b;a=b*C[172]+(b*C[171]+a);b=a*a;g=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+f);j(1)|0;e=j(0)|0;c=e<<4&2032;a=g+(b+(C[c+1464>>3]+a));c=c+1472|0;d=0+x[c>>2]|0;c=x[c+4>>2]+(e<<13)|0;c=d>>>0<i>>>0?c+1|0:c;if(!h){c:{if(!(e&-2147483648)){l(0,d|0);l(1,c-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){gJ(PJ()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Z2(){var a=0,b=0,c=0,d=0;d=fb-32|0;fb=d;a:{a=Dc(d+20|0,14771);if(!Yc(x[a+4>>2],y[a+11|0])){break a}b:{if((Rg(a,14629)|0)!=-1){b=Rg(a,14629);x[31725]=0;c=d+8|0;V(123,c|0,a|0,b+1|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,16809)|0)!=-1){b=Rg(a,16809);x[31725]=0;c=d+8|0;V(123,c|0,a|0,b+1|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13898)|0)!=-1){b=Rg(a,13898);x[31725]=0;c=d+8|0;V(123,c|0,a|0,0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13773)|0)!=-1){b=Rg(a,13773);x[31725]=0;c=d+8|0;V(123,c|0,a|0,0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13816)|0)!=-1){b=Rg(a,13816);x[31725]=0;c=d+8|0;V(123,c|0,a|0,0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}x[31725]=0;c=R(124,a|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;tb(a);Q(d|0);p()}tb(a);fb=d+32|0;return c|0}function Dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(i<<16)|0;e=i;g=nva(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;x[e+76>>2]=c;c=e+76|0;a=re(a,c);g=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];l=x[b+4>>2];m=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=m;x[e+40>>2]=f;x[e+44>>2]=l;b=Nd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31725]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+56|0;S(986,b|0,e+16|0,e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;S(998,a|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}ub(b);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Vc(c);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Td(k);of(j);Il(i);wh(h);vh(g);Vc(a);Vc(e+76|0);Q(d|0);p()}function aM(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+32>>2];a:{b:{c:{d=x[a+1380>>2];if((d|0)==-1){c=1;break c}f=x[a+1116>>2];e=(d|0)>(f|0)?d:f;c=d;while(1){d:{if((c|0)!=(e|0)){g=y[(a+c|0)+1120|0];b=g+b|0;if((g|0)==255){break d}e=c}if(A[a+40>>2]<b>>>0){fc(a,1);break b}c=(e|0)==-1|(e|0)==(f|0);break c}c=c+1|0;continue}}d=(d|0)!=-1;while(1){e=1;if(!(c&1)){break a}e=x[a+40>>2];if(e>>>0<=b+26>>>0){fc(a,1);break b}if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=(y[125924]|y[125925]<<8|(y[125926]<<16|y[125927]<<24))){fc(a,21);break b}if(y[b+4|0]){fc(a,21);break b}e:{if(!d){if(!x[a+992>>2]|!(v[b+5|0]&1)){break e}fc(a,21);break b}if(v[b+5|0]&1){break e}fc(a,21);break b}c=0;f=b+27|0;d=y[b+26|0];b=f+d|0;if(e>>>0<b>>>0){fc(a,1);break b}while(1){f:{if((c|0)==(d|0)){c=d;break f}g=y[c+f|0];b=g+b|0;if((g|0)!=255){break f}c=c+1|0;continue}break}c=(c|0)==(d|0);d=1;if(b>>>0<=e>>>0){continue}break}fc(a,1)}e=0}return e}function Cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=nva(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=nva(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=nva(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function ara(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[f+6>>1]=0;xY(a,f+15|0,f+12|0,j,f+6|0);g=z[f+6>>1];e=z[f+12>>1];c=j;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Af(a,f+5|0)){break c}e=y[f+5|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}e=15;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&65534)>>>1;e=g+z[f+8>>1]|0;w[f+6>>1]=e;w[i>>1]=e;x[f+8>>2]=((g>>1)-(k<<16>>16)|0)+(e<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[f+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[f+8>>2]=c}k=e;continue}}break}fb=f+16|0}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function X1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;e=Rn(h+12|0,a);i=fb-48|0;fb=i;j=-1;c=i+12|0;a:{if(!$F(e,c)){break a}j=0;if(!eG(c)){break a}k=Cf(13165);if(k){o=x[e+12>>2];b:{if(!cm(e,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))){break b}while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=l>>>0){break b}if(!lh(e,5)){break b}c:{if((y[c+4|0]|y[c+5|0]<<8)>>>0>=64){a=Rr(e);d=a&63;g=a<<24>>24;d:{if(!(a&64)){break d}a=6;while(1){f=Rr(e);d=(f&127)<<a|d;if(f<<24>>24>=0){break d}f=a>>>0<25;a=a+7|0;if(f){continue}break}}if((((g|0)<0?(d|0)<0?-2147483648:0-d|0:d)|0)<=0){break c}}d=0;a=1;while(1){f=Rr(e);if(f){m=d>>>0>=k>>>0;g=m&a;if(!((a^1)&1|m)){g=(Qq(f<<24>>24)&255)==y[d+13165|0]}a=g;d=d+1|0;continue}break}gd(e,4);n=(d|0)==(k|0)&a|n}l=l+1|0;continue}}cm(e,o)}if(!(n&1)){break a}j=ve(e,b,dG(c),0)}fb=i+48|0;fb=h+32|0;return j|0}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=yb(j,e);n=B[yb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=yb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=yb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Pi(a,b,c,s,t,d)}break}}}function bN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;yo(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);c:{if(c){x[31725]=0;O(1143,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}ZM(a,c)}c=b+8|0;Qd(c);cj(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;yo(b);h=wz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;yo(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);f:{if(c){x[31725]=0;O(1142,a|0,c|0);g=x[31725];x[31725]=0;if((g|0)==1){break a}ZM(a,c)}c=b+8|0;Qd(c);cj(c);fb=b+16|0;break f}Nd(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;yo(c);h=wz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;cj(b+8|0);Q(a|0);p()}function TK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ze(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=rv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(fL(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=rv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((zt(Pf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Pf(v[c+23|0]);x[a+48>>2]=d;break a}d=Pf(v[c+23|0]);break a}d=-1}fb=c+32|0;return d}function qw(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[ud(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function Sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=nva(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=nva(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=nva(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function Fba(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31725]=0;f=P(21,d+8|0,a|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Ed(y[f|0])){break d}c=d+4|0;bd(c,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;g=R(1138,x[d+4>>2])|0;e=x[31725];x[31725]=0;e:{f:{if((e|0)!=1){Zb(c);c=wp(d,a);e=x[x[a>>2]-12>>2];x[31725]=0;e=a+e|0;h=R(22,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break f}c=x[c>>2];x[31725]=0;c=Ra(1139,g|0,c|0,e|0,h|0,+b)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+c|0,5);c=x[31725];x[31725]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Zb(d+4|0);break e}c=T(0)|0}nm(f);break c}nm(f);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(969,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31725]=0;O(969,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(969,d|0,(a|i)<<24>>24);h=x[31725];x[31725]=0;a=e;break e}x[31725]=0;a=a-1|0;O(969,d|0,v[a+(c+10|0)|0]|-128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function _I(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function Tna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=nva(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=nva(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=nva(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function QV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25440|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}de(a,b,e+15|0);fb=e+16|0}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ze(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=rv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(fL(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=rv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((zt(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}fb=c+32|0;return d}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function bJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function BE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=sV(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;NA(b+48|0,c+48|0);NA(b+68|0,c+68|0);NA(b+88|0,c+88|0);yc(b+108|0,c+108|0,448);d=b;Iv(c);break b}b=yu(556);if(!b){x[e>>2]=0;break a}d=sV(b,c);x[e>>2]=d}g=a,h=z[qe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function Ut(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=E(x[(a+k<<2)+j>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function I1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(50,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31725]=0;O(50,d|0,a&255);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(50,d|0,a|i&255);h=x[31725];x[31725]=0;a=e;break e}x[31725]=0;a=a-1|0;O(50,d|0,y[a+(c+10|0)|0]|128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function zra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;xc(b);dD(b,d+380|0,d+300|0,d+16|0);k=d,l=Dh((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Rb(25168,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Bb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(cd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!cd(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!cd(b,up(b))){break d}e:{if(!c){j=Zd(b);break e}j=Vk(b)}w[d+10>>1]=j;k=d,l=z[qe(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);dD(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Rw(a);break a}LY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function Roa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;w[e+12>>1]=c;w[e+14>>1]=b;w[e+10>>1]=d;g=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(g>>>0<=b>>>0){break a}if(!c|Pj(a)>>>0>=g>>>0){break a}Gf(e+12|0,g-b&65535);k=e,l=lm(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[e+12>>1];PY(a,d+z[qe(e+14|0,e+8|0)>>1]|0);f=e+4|0;c=a;a=x[a>>2];if(Zc(a,x[c+4>>2])>>>0<b>>>0){xg(c,b);a=x[c>>2]}a=vb(f,iV(wb(a),b));h=e+10|0;j=fb-32|0;fb=j;b=x[a>>2];a=x[c>>2];f=(rp(b,wb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[zb(c)>>2];i=x[c+4>>2];if(a>>>0<=b-i>>1>>>0){b=a;d=i-f>>1;if(d>>>0<a>>>0){zp(c,a-d|0,h);b=d;if((f|0)==(i|0)){break b}}gV(c,f,i,(a<<1)+f|0);Gv(f,b,((f>>>0<=h>>>0?A[c+4>>2]>h>>>0?a:0:0)<<1)+h|0);break b}b=zb(c);b=mk(j+12|0,nk(c,Zc(x[c>>2],i)+a|0),f-x[c>>2]>>1,b);rF(b,a,h);f=fV(c,b,f);jj(b)}wb(f);fb=j+32|0;if(Zc(x[c>>2],x[c+4>>2])>>>0<=g>>>0){break a}xg(c,g)}fb=e+16|0}function Zra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Ec(64);x[31725]=0;d=R(879,c|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){c=yf(b,d);d=x[c>>2];x[31725]=0;O(880,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}a=x[c>>2];x[31725]=0;a=U(881,a|0,b+10|0,b+4|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}d:{if(!a){sc(b+12|0);break d}a=x[c>>2];x[31725]=0;O(882,a|0,15);a=x[31725];x[31725]=0;if((a|0)==1){break c}re(b+12|0,c)}og(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;og(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31725]=0;c=P(1,e|0,(a<<2)+30576|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;S(501,b|0,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}og(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function Vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=E(x[(a+k<<2)+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function Zqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[f+7|0]=0;wY(a,f+15|0,f+12|0,f+7|0);g=y[f+7|0];e=z[f+12>>1];c=k;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Af(a,f+6|0)){break c}e=y[f+6|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}e=7;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&254)>>>1;e=g+y[f+8|0]|0;v[f+7|0]=e;v[i|0]=e;x[f+8>>2]=((g>>1)-(j<<24>>24)|0)+(e<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[f+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[f+8>>2]=c}j=e;continue}}break}fb=f+16|0}function TG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,f-16129|0);fn(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=fb-16|0;fb=h;if(zi(a+44|0)){f=x[a+44>>2];g=Hc(f,0);x[h+8>>2]=g;f=Hc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Hc(j,0);x[h>>2]=m;j=Hc(j,1);x[h+4>>2]=j;a:{if(B[yb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;yc(m,e,g);yc(j,f,g);f=x[a+56>>2];m=Hc(f,0);j=Hc(f,1)}Pi(a,b,c,m,j,d)}fb=h+16|0}function pB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[g+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[g+1428|0]}f=x[a+480180>>2];if(!e){h=Iu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){eT(b,c,240-a|0);return}if(!(a>>>0<224|e)){dT(g,224-a|0);return}cT(g,0-a|0);return}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}mB(a,g,f);return}if(x[a+480180>>2]==524288){break d}lB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Ek(a,g,b+1316|0,0-(e<<2)|0,0)}}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function UC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;h=fb-16|0;fb=h;ld(b,1);g=Bb(y[a+22|0]|y[a+23|0]<<8)<<1;x[b>>2]=g;v[b+37|0]=y[a+24|0]<<4;v[h+15|0]=y[a+25|0];v[h+14|0]=64;l=b,m=y[Rb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Bb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;k=Bb(y[a+28|0]|y[a+29|0]<<8);j=k<<1;e=k>>>0>=2?e+j>>>0<=g>>>0?e:f+j>>>0>g>>>0?e:f:e;a:{b:{switch(g|0){case 2:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=g>>>0){e=g-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=h+16|0;d=i+8|0;Yk(d,3,a);b=i+20|0;Cc(b,d);c=zc(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=WC(a);fb=i+32|0;return a}function ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;JR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);JR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Nc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=y[c+d|0];j=_b(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=_b(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;Yk(d,3,a+4|0);c=g+20|0;Cc(c,d);zc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function RH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;LA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=RM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=SM(d,x[Zr(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function v0(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24656|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch((c&240)-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}de(a,d,e+15|0);fb=e+16|0}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=C[(a+k<<3)+j>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function oG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=e;x[c+52>>2]=f;d=Se(c+24|0,d,c+52|0,c+56|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(e,g)){ax(mG(x[c+56>>2]),lj(e));e=nG(c+60|0);nG(c+56|0);e=x[e>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];e=fb-16|0;fb=e;f=x[d>>2];x[e+12>>2]=f;while(1){if(ci(f,j)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]+36;fb=d+16|0;Np(mG(x[d+12>>2]));x[e+12>>2]=x[e+12>>2]+36;f=x[e+12>>2];continue}break}fb=e+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Tm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Ed(y[Lm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31725]=0;c=R(85,c|0)|0;d=x[31725];x[31725]=0;d:{if((d|0)!=1){if(!lc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31725]=0;d=R(85,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}if(lc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Jm(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break f}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Tb()}p()}c=2}dk(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Nm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Dl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Mm(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}fc(a,21);x[a+1396>>2]=0}return-1}_(11378,13258,1705,5445);p()}function Lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=c+11|0;BX(a,d);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){BX(a,d);v[b|0]=1;b=0}else{b=1}a=fb-176|0;fb=a;e=a+12|0;Qw(e,(c+11|0)+b|0);x[31725]=0;d=a+24|0;O(126,d|0,e|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31725]=0;b=P(105,a+36|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break e}tb(d);tb(e);e=x[x[b>>2]-12>>2];x[31725]=0;g=ca(106)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;f=a+8|0;S(107,f|0,b+e|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}Zb(f);x[31725]=0;w[a+24>>1]=0;d=P(688,b|0,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}b=vk(x[(d+x[x[d>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Ff(d);fb=a+176|0;a=(b?0:e)&65535;break a}c=N()|0;break d}c=N()|0;tb(a+24|0)}tb(a+12|0);break b}c=N()|0;Ff(b)}Q(c|0);p()}fb=c+16|0;return a|0}function nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=C[(a+k<<3)+i>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function tP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];vb(g+12|0,b);a:{b:{c:{d:{e:{if(Dd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31725]=0;d=ca(70)|0;e=x[31725];x[31725]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125584)|0;if((gb|0)!=($(125584)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31725]=0;W(58,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=(b<<2)+d|0;i=x[((b+397>>>0)%624<<2)+d>>2];h=(b+1>>>0)%624|0;b=x[(h<<2)+d>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Tb();p()}return x[a+28>>2]&f}function qB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[g+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[g+1427|0]}f=x[a+480180>>2];if(!e){h=Iu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){eT(b,c,a-240|0);return}if(!(a>>>0<224|e)){dT(g,a-224|0);return}cT(g,a);return}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}nB(a,g,f);return}if(x[a+480180>>2]==524288){break d}oB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Ek(a,g,b+1316|0,e<<2,0)}}function Hq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=nva(b,d,5e4,0);f=hb;b=x[ad(c+8|0,c)>>2];b=Gc(ova(e,f,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=nva(x[a+1074420>>2],0,nva(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=nva(b,0,6e5,0);d=c+8|0;f=b;e=hb;b=Mw(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=pva(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=nva(b,d,1e4,0);f=hb;b=x[ad(c+8|0,c)>>2];b=Gc(ova(e,f,b,b>>31),hb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=nva(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Gc(ova(b,a,65536,0),hb);x[d>>2]=a>>>0<=1?1:a;fb=c+16|0}function W0(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:se(a,0,c);break a;case 1:se(a,1,c);break a;case 2:se(a,2,c);break a;case 3:se(a,3,c);break a;case 4:se(a,4,c);break a;case 5:se(a,5,c);break a;case 6:se(a,6,c);break a;case 7:se(a,7,c);break a;case 8:se(a,8,c);break a;case 9:se(a,9,c);break a;case 10:se(a,10,c);break a;case 11:se(a,11,c);break a;case 12:se(a,12,c);break a;case 13:se(a,13,c);break a;case 14:se(a,14,c);break a;case 15:se(a,15,c);break a;case 16:se(a,16,c);break a;case 17:se(a,17,c);break a;case 18:se(a,18,c);break a;case 19:se(a,19,c);break a;case 20:V0(a,71456,c);break a;case 21:V0(a,72480,c);break a;case 22:se(a,20,c);break a;case 23:se(a,21,c);break a;case 24:se(a,22,c);break a;case 25:se(a,23,c);break a;case 26:se(a,24,c);break a;case 27:se(a,25,c);break a;case 28:se(a,26,c);break a;default:break b}}Fb(a)}}function VG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:pe(a,0,c);break a;case 1:pe(a,1,c);break a;case 2:pe(a,2,c);break a;case 3:pe(a,3,c);break a;case 4:pe(a,4,c);break a;case 5:pe(a,5,c);break a;case 6:pe(a,6,c);break a;case 7:pe(a,7,c);break a;case 8:pe(a,8,c);break a;case 9:pe(a,9,c);break a;case 10:pe(a,10,c);break a;case 11:pe(a,11,c);break a;case 12:pe(a,12,c);break a;case 13:pe(a,13,c);break a;case 14:pe(a,14,c);break a;case 15:pe(a,15,c);break a;case 16:pe(a,16,c);break a;case 17:pe(a,17,c);break a;case 18:pe(a,18,c);break a;case 19:pe(a,19,c);break a;case 20:UG(a,71456,c);break a;case 21:UG(a,72480,c);break a;case 22:pe(a,20,c);break a;case 23:pe(a,21,c);break a;case 24:pe(a,22,c);break a;case 25:pe(a,23,c);break a;case 26:pe(a,24,c);break a;case 27:pe(a,25,c);break a;case 28:pe(a,26,c);break a;default:break b}}Fb(a)}}function PD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(d,g)){SD(W_(x[c+56>>2]),d-20|0);d=X_(c+60|0);X_(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+20;fb=e+16|0;ub(W_(x[e+12>>2]));d=x[Sf(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function _U(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(d,g)){XB(ZU(x[c+56>>2]),mn(d));d=Zo(c+60|0);Zo(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+32;fb=e+16|0;Hk(ZU(x[e+12>>2]));d=x[dr(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function gla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Ed(y[b+223884|0])){OT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Yn(b)>>>0>=c>>>0){g=x[b>>2];h=jh(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Gb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){ZS(b,c-h|0,d);break a}uG(b,x[b>>2]+(c<<3)|0);break a}hU(b);wU(b,ms(b,c));ZS(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Vo((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function qL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);c=j(1)|0;if(!(j(0)|c&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[31725]=0;c=R(186,b|0)|0;f=x[31725];x[31725]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31725]=0;P(36,a|0,22267)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}x[31725]=0;c=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){g=d,h=uh(c),x[g+12>>2]=h;c=x[ud(d+16|0,d+12|0)>>2];x[31725]=0;O(116,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31725]=0;c=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}if(!c){break e}x[31725]=0;U(894,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}break a}x[31725]=0;P(185,b|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}_c(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[x[e+12>>2]+g|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,v[x[e+12>>2]+g|0]<<6);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Cra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=e0(c+4|0,a);gD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=c0(h+12|0,d0(a,Or(x[a>>2],x[a+4>>2])+1|0),Or(x[a>>2],x[a+4>>2]),c);gD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Re(b+36|0,b+8|0);while(1){if(pd(d,i)){gD(kE(x[b+56>>2]),Mr(d));d=jw(b+60|0);jw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Qe(d);e=x[b+56>>2];a0(d);fb=b- -64|0;x[c+4>>2]=e;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;b0(c);fb=h+32|0}function bk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=e0(c+4|0,a);lE(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=c0(h+12|0,d0(a,Or(x[a>>2],x[a+4>>2])+1|0),Or(x[a>>2],x[a+4>>2]),c);lE(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Re(b+36|0,b+8|0);while(1){if(pd(d,i)){lE(kE(x[b+56>>2]),Mr(d));d=jw(b+60|0);jw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Qe(d);e=x[b+56>>2];a0(d);fb=b- -64|0;x[c+4>>2]=e;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;b0(c);fb=h+32|0}function Pw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Gb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;JF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=gc(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Gb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;IF(e,d);c=c&31;x[a+12>>2]=c;if(c){e=b;b=x[b>>2]+(d<<2)|0;x[e>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-c^-1)}fb=a+16|0}fb=g+16|0}function Fy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=y[b|0];if((d|0)!=61){b=b+1|0;if(d){continue}}break}b=c}if((a|0)==(b|0)){return 0}f=b-a|0;c:{if(y[f+a|0]){break c}e=x[125022];if(!e){break c}b=x[e>>2];if(!b){break c}while(1){d:{g=a;c=b;h=f;d=0;e:{if(!f){break e}d=y[a|0];if(d){f:{while(1){i=y[c|0];if((i|0)!=(d|0)|!i){break f}h=h-1|0;if(!h){break f}c=c+1|0;d=y[g+1|0];g=g+1|0;if(d){continue}break}d=0}}else{d=0}d=d-y[c|0]|0}if(!d){b=b+f|0;if(y[b|0]==61){break d}}b=x[e+4>>2];e=e+4|0;if(b){continue}break c}break}j=b+1|0}return j}function z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?((i|0)==10&y[d-1|0]==13)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}tf(a);Bs(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Yp(a,e);c=c+1|0;continue}break}}function dM(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}cM(e+48|0);cM(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87600>>2];m=B[d+87636>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function cva(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=sw(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=sw(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(IE(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function ZP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[yb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[yb(e,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);e=a+4272|0;c=uk(10,f*+A[yb(e,4)>>2]);g=a+4232|0;n=yb(g,0),o=E(c),B[n>>2]=o;c=uk(10,f*+A[yb(e,5)>>2]);n=yb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=uk(10,+XP(B[yb(d,0)>>2])*.05);b=4/M(c)*f;c=uk(10,+XP(B[yb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[yb(e,d)>>2];k=d>>>1|0;i=uk(10,m*+(x[yb(e,d)>>2]+x[yb(e,k+4|0)>>2]>>>0));b=uk(10,f*+(h>>>0));j=B[yb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=yb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=yb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function n5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=oJ(a,0);h=fb-32|0;fb=h;c=TI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31725]=0;a=P(1354,h+12|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){x[31725]=0;O(1355,c|0,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Us(a);fb=h+32|0;break a}b=N()|0;break b}b=N()|0;Us(a)}tb(l);tb(k);tb(j);a=tb(g);while(1){a=tb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=tb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=tb(d-12|0);if((i|0)!=(d|0)){continue}break}Ws(c);Q(b|0);p()}x[f+8>>2]=116604;x[f>>2]=116528;return f|0}function l5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=nJ(a,0);h=fb-16|0;fb=h;c=TI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31725]=0;a=P(1356,h+4|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){x[31725]=0;O(1357,c|0,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Xs(a);fb=h+16|0;break a}b=N()|0;break b}b=N()|0;Xs(a)}Qb(l);Qb(k);Qb(j);a=Qb(g);while(1){a=Qb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=Qb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=Qb(d-12|0);if((i|0)!=(d|0)){continue}break}Ws(c);Q(b|0);p()}x[f+8>>2]=116900;x[f>>2]=116824;return f|0}function AO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Pj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[_b(x[Xb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!xp(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Wb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;jS(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;Cv(b,c,g?7:1,e);j=a,k=C[mn(x[e+56>>2])>>3],C[j+16>>3]=k;Xi(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);j=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}d=fb-32|0;fb=d;h=x[a+36>>2];e=d+30|0;pg(h,e);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){k=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;i=tc(a+4|0,15969);_c(g,i);tb(i);fb=a+16|0;x[31725]=0;a=d+16|0;S(492,a|0,g|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}e=x[k+1298472>>2];x[31725]=0;S(387,e|0,2,a|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}tb(a);Eb(g);a=4e3}xg(Vj(x[b>>2],0),a);b=Vj(x[b>>2],0);l=d,m=wb(x[b>>2]),x[l+16>>2]=m;b=wb(x[b+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){a=x[d+16>>2];if(Ib(a,b)){pg(h,d+4|0);w[a>>1]=z[d+4>>1];Md(d+16|0);continue}break}fb=d+32|0;d=c}gf(j,d);fb=f+16|0}function JR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;v[k+15|0]=c;v[k+14|0]=12;gh(b,y[Rb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=Sd(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(lc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=yb(l,c);j=z[i>>1];n=yb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+38150>>1];q=w[e+38148>>1];r=w[e+38146>>1];e=w[e+38144>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ld(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41178|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function G7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=NJ(c);b:{if(b){b=k+4|0;rl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ql(b,a);break b}b=k+4|0;at(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}ph(i,b);Qb(b);l=e,m=uj(a),x[l>>2]=m;l=f,m=vj(a),x[l>>2]=m;b=k+4|0;sh(b,a);Ab(g,b);tb(b);ki(b,a);ph(h,b);Qb(b);a=Pk(a);break a}a=MJ(c);c:{if(b){b=k+4|0;rl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ql(b,a);break c}b=k+4|0;at(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}ph(i,b);Qb(b);l=e,m=uj(a),x[l>>2]=m;l=f,m=vj(a),x[l>>2]=m;b=k+4|0;sh(b,a);Ab(g,b);tb(b);ki(b,a);ph(h,b);Qb(b);a=Pk(a)}x[j>>2]=a;fb=k+16|0}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;x[31725]=0;f=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=f;f=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=f;f=R(1155,d+32|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){a:{b:{if(f){x[31725]=0;f=d+72|0;O(1156,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=d+80|0;Qp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+88|0,b);g=Ef(d- -64|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;Rp(a,d+8|0,d);break b}break a}x[31725]=0;f=d+72|0;O(1157,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=d+80|0;Qp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+56|0,b);g=Ef(d+48|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;Rp(a,d+24|0,d+16|0)}ke(b);ke(f);ke(c);fb=d+96|0;return}}a=N()|0;ke(c);Q(a|0);p()}function oK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-32|0;fb=i;a:{b:{c:{if((b|0)!=(c|0)){k=x[31600];x[31600]=0;g=fb-16|0;fb=g;Od();f=fb-16|0;fb=f;e=fb-16|0;fb=e;By(e,b,i+28|0,2);h=x[e>>2];j=x[e+4>>2];b=f;f=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=f;x[b>>2]=h;x[b+4>>2]=j;fb=e+16|0;f=x[b>>2];h=x[b+4>>2];e=g;g=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=g;x[e>>2]=f;x[e+4>>2]=h;fb=b+16|0;g=x[e>>2];f=x[e+4>>2];h=x[e+12>>2];b=i;x[b+16>>2]=x[e+8>>2];x[b+20>>2]=h;x[b+8>>2]=g;x[b+12>>2]=f;fb=e+16|0;e=x[b+16>>2];f=x[b+20>>2];g=x[b+8>>2];h=x[b+12>>2];j=x[31600];if(!j){break c}if(x[b+28>>2]!=(c|0)){break b}l=g;m=h;n=e;o=f;if((j|0)!=68){break a}break b}x[d>>2]=4;break a}x[31600]=k;if(x[i+28>>2]==(c|0)){break a}}x[d>>2]=4;g=l;h=m;e=n;f=o}x[a>>2]=g;x[a+4>>2]=h;x[a+8>>2]=e;x[a+12>>2]=f;fb=i+32|0}function K7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=SJ(c);b:{if(b){b=k+4|0;rl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ql(b,a);break b}b=k+4|0;at(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}Ab(i,b);tb(b);l=e,m=uj(a),v[l|0]=m;l=f,m=vj(a),v[l|0]=m;b=k+4|0;sh(b,a);Ab(g,b);tb(b);ki(b,a);Ab(h,b);tb(b);a=Pk(a);break a}a=RJ(c);c:{if(b){b=k+4|0;rl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ql(b,a);break c}b=k+4|0;at(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}Ab(i,b);tb(b);l=e,m=uj(a),v[l|0]=m;l=f,m=vj(a),v[l|0]=m;b=k+4|0;sh(b,a);Ab(g,b);tb(b);ki(b,a);Ab(h,b);tb(b);a=Pk(a)}x[j>>2]=a;fb=k+16|0}function Bka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=30624;a=Nb(a);a:{while(1){b:{if((e|0)==31056){e=31056;break b}c=qc(b+40|0,x[e+4>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!lc(x[a>>2],d)){c=x[c>>2];d=qc(b+32|0,x[xf(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(Ic(c,f,b+8|0)){break c}}x[31725]=0;O(890,a|0,e+4|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}e=e+8|0;continue}break}d:{while(1){if((e|0)==31104){break d}c=qc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!lc(x[a>>2],d)){g=x[c>>2];d=qc(b+24|0,x[xf(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(Ic(g,f,b)){break f}}c=x[c>>2];x[31725]=0;x[b+20>>2]=c;O(891,a|0,b+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}fb=b+48|0;return}b=N()|0;uc(a);Q(b|0);p()}function Wka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Sb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=gW(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=iB(c+223860|0);f=b+8|0;Sb(f,0,108);nC(b+120|0,48e3);Sb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Sb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Lq(e,f)+872|0;continue}break}x[31725]=0;O(554,d|0,32);a=x[31725];x[31725]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;Mq(g);dc(d);Q(a|0);p()}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=Nb(a);a=0;a:{b:{c:{while(1){if((Jx(b,c,a)|0)==-1){break b}g=Jx(b,c,a);x[31725]=0;e=d+4|0;V(102,e|0,b|0,a|0,g-a|0);g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;O(103,f|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break c}tb(e);a=Jx(b,c,a)+Yc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(lc(x[f>>2],x[f+4>>2])){x[31725]=0;c=d+4|0;V(102,c|0,b|0,a|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break f}e=Yc(x[d+8>>2],y[d+15|0]);tb(c);if(!e){break g}}x[31725]=0;c=d+4|0;V(102,c|0,b|0,a|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;O(103,f|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}tb(c)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Td(f);Q(a|0);p()}function rW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=fb-16|0;fb=g;m=x[a+20>>2];h=z[a+34>>1]&65;x[g+12>>2]=h;x[g+8>>2]=h^65;h=b;n=d+1298224|0;e=d+1074992|0;j=Hj(d);o=a+4|0;p=a+12|0;q=a+8|0;r=a+16|0;while(1){if((e|0)!=(n|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=h}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){wc(e+76|0,c);b=x[e+104>>2]}f=x[e+88>>2];b=WF(f,b);i=x[(b?p:o)>>2];x[e+84>>2]=x[(b?r:q)>>2];x[e+80>>2]=i;b=f|x[g+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[g+8>>2]^-1);f=x[e+704>>2];b=x[a+24>>2];a:{if(!f|!b){break a}if(Dn(x[d+480180>>2])){break a}i=nva(x[e+700>>2],0,j?b:f,0);f=j?f:b;k=i+(f>>>1|0)|0;l=hb;s=e,t=Bc(pva(k,i>>>0>k>>>0?l+1|0:l,f,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=h;aC(m);fb=g+16|0}function sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;W(1003,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31725]=0;d=P(36,e+20|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;c=P(36,e+8|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;V(1018,f|0,d|0,c|0,1);b=x[31725];x[31725]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31725]=0;V(989,6409,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ao(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31725]=0;O(d|0,f+4|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Ud(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=ac(8);x[31725]=0;b=P(1057,d|0,7429)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;S(99,b|0,125360,164);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Bg(22267);break j}b=Bg(Jb(Hd(d,b)))}Td(f+4|0);break d}b=T(0)|0;jc(d)}Td(f+4|0)}Y(b|0)|0;b=0;x[31725]=0;V(989,c|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break a}T(0)|0;Tb()}p()}Q(a|0);p()}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Qi(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45212;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=yb(a,0),g=1063675494,x[f>>2]=g;f=yb(a,1),g=1065185444,x[f>>2]=g;f=yb(a,2),g=0,x[f>>2]=g;f=yb(a,3),g=1032805417,x[f>>2]=g;f=yb(a,4),g=1053079357,x[f>>2]=g;f=yb(a,5),g=1059859440,x[f>>2]=g;f=yb(a,6),g=1047457519,x[f>>2]=g;f=yb(a,7),g=1062836634,x[f>>2]=g;f=yb(a,8),g=1038174126,x[f>>2]=g;f=yb(a,9),g=1065353216,x[f>>2]=g;f=yb(a,10),g=1065353216,x[f>>2]=g;f=yb(a,11),g=1048525618,x[f>>2]=g;f=yb(a,12),g=1059760811,x[f>>2]=g;x[31725]=0;O(947,b+44|0,2);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;while(1){c=uc(c-24|0);if((e|0)!=(c|0)){continue}break}ag(b);Q(a|0);p()}return b|0}function ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38150>>1];q=w[e+38148>>1];r=w[e+38146>>1];e=w[e+38144>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function xr(a,b){var c=0;c=fb-16|0;fb=c;a=gs(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:RA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,107);break a;case 3:RA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}RA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function dB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Jj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!Dd(f)){break a}if(!WS(f,c&65535)){break a}}c=c+1|0;continue}break}g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}e=0;c=65535;while(1){if((d|0)==(h|0)){break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){f=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(f>>>0<g>>>0){b=x[b+1075716>>2];break c}if((f|0)!=(g|0)){break b}b=x[b+1075716>>2];if(e>>>0>=b>>>0){break b}}g=f;c=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((ok(x[a>>2],x[a+4>>2])|0)==2){if((ok(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31725]=0;O(949,a|0,2);c=x[31725];x[31725]=0;c:{if((c|0)==1){break c}x[31725]=0;O(949,a+12|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(950,a+24|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(950,a+36|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=ds(x[c+12>>2],a);f=yb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=ds(x[a>>2],d);f=yb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;dA(a);_Q(a);b=a+12|0;dA(b);_Q(b);b=a+24|0;Nf(b);ZQ(b);a=a+36|0;Nf(a);ZQ(a);Z()}return}Q(b|0);p()}function sd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);h=b;e=x[a+4>>2];f=x[a+44>>2];b=e-f|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=h>>>0|(b|0)>(d|0))&i)){i=Jy(a);if((i|0)>=0){break a}e=x[a+4>>2];f=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=e;g=c;c=f-e|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;h=x[a+4>>2];f=x[a+8>>2];c=x[a+116>>2];g=c;e=x[a+112>>2];b:{if(!(c|e)){break b}c=e-d|0;e=g-(b+(d>>>0>e>>>0)|0)|0;j=f-h|0;g=j>>31;if((e|0)>=(g|0)&c>>>0>=j>>>0|(e|0)>(g|0)){break b}f=c+h|0}x[a+104>>2]=f;c=x[a+44>>2];f=c-h|0;d=f+d|0;b=(f>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<f>>>0?b+1|0:b;if(c>>>0>=h>>>0){v[h-1|0]=i}return i}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(ok(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=ds(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;VA(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;l=Hf(a,c);$d(f,x[a+36>>2]);m=a;a:{if(!l){Pc(f,a+32|0,5);c=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;j=x[a+36>>2];ul(j,e+40|0);h=x[e+44>>2];if(!h&A[e+40>>2]>=257|h){x[e+40>>2]=256;x[e+44>>2]=0}h=x[e+40>>2];n=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!n&c>>>0>=h>>>0){break b}i=e+38|0;pg(j,i);a=Fb(e+24|0);x[31725]=0;P(500,j|0,a|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;g=e+12|0;S(498,g|0,d|0,a|0);k=x[31725];x[31725]=0;if((k|0)==1){break e}x[31725]=0;i=P(937,b|0,i|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}Ab(i,g);tb(g);tb(a);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(a);Q(c|0);p()}fb=e+48|0;c=l}gf(m,c);fb=f+16|0}function _pa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;i=c,j=lf(a)>>>5|0,w[i+32>>1]=j;w[c+20>>1]=3999;d=z[Nc(c+32|0,c+20|0)>>1];w[b+480190>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=ti(b,f);e=c+32|0;Er(a,e);ld(d,0);h=c+8|0;vi(h,2,e);e=c+20|0;Cc(e,h);zc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;i=c,j=Bb(y[c+60|0]|y[c+61|0]<<8),w[i+20>>1]=j;w[c+8>>1]=64;i=d,j=z[Nc(e,h)>>1]<<2,w[i+30>>1]=j;i=d,j=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[i>>2]=j;e=Bb(y[c+62|0]|y[c+63|0]<<8);i=yb(d+68|0,0),j=e,x[i>>2]=j;e=Bb(y[c+56|0]|y[c+57|0]<<8);f=Bb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[b+480190>>1];continue}break}fb=c- -64|0}function XT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);e=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;j=h+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[c>>2],x[d>>2]);k=f+16|0;c=x[f+24>>2];l=x[f+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=e;x[d+12>>2]=c;while(1){if(pd(c,l)){c=UT(c);e=UT(x[d+8>>2]);i=y[c+3|0]|y[c+4|0]<<8|(y[c+5|0]<<16|y[c+6|0]<<24);v[e+3|0]=i;v[e+4|0]=i>>>8;v[e+5|0]=i>>>16;v[e+6|0]=i>>>24;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=TT(d+12|0);TT(d+8|0);c=x[c>>2];continue}break}Ac(k,c,d+8|0);fb=d+16|0;c=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(j,c,f+12|0);fb=f+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=re(a,e+60|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){oe(e+24|0,x[b>>2],x[b+4>>2]);mf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31725]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+40|0;Ns(1001,b,x[e+32>>2],x[e+36>>2],e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;S(998,a|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}ub(b);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Td(j);of(i);Il(h);wh(g);vh(c);Vc(a);Vc(e+60|0);Q(d|0);p()}Vc(e+60|0);fb=e- -64|0;return a|0}function Kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(zi(a+44|0)){g=x[a+44>>2];r=h,s=Hc(g,0),x[r+8>>2]=s;r=h,s=Hc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=nQ(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Pi(a,b,c,l,m,d)}break}}fb=h+16|0}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;j=c,k=jN(),x[j+12>>2]=k;h=a+24|0;e=c+12|0;hN(h,le(e));wh(e);w[a+28>>1]=0;VP();g=fb-16|0;fb=g;i=Ec(144);x[31725]=0;f=P(1134,i|0,4)|0;d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=yf(g+12|0,f);fb=g+16|0;d=x[d>>2];break a}a=N()|0;Db(i);Q(a|0);p()}x[c+12>>2]=d;gN(a+32|0,le(e));Il(e);j=c,k=iN(x[a>>2]),x[j+12>>2]=k;fN(a+4|0,le(e));vh(e);zo(x[h>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;j=c,k=_i(x[b>>2]),x[j+12>>2]=k;d=Rf(b);b:{while(1){b=x[c+12>>2];if(!Zg(b,d)){break b}b=td(b);f=lg(c,b);x[31725]=0;V(1018,a|0,f|0,b+12|0,0);b=x[31725];x[31725]=0;if((b|0)!=1){tb(f);ah(c+12|0);continue}break}a=N()|0;tb(f);Q(a|0);p()}fb=c+16|0}function Ko(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=ed(Wq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[yb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function $Q(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Ec(64);x[31725]=0;g=R(879,f|0)|0;h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){f=yf(d+8|0,g);g=x[f>>2];x[31725]=0;g=U(944,g|0,b|0,c|0)|0;h=x[31725];x[31725]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}sc(d+12|0);break c}a=N()|0;og(f);break b}re(d+12|0,f)}og(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!Dd(d)){x[31725]=0;b=P(942,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;HZ(e+12|0,le(b));og(b);d=x[e+12>>2]}if(!Dd(d)){break e}x[31725]=0;O(502,a|0,e+12|0);a=x[31725];x[31725]=0;i=d;if((a|0)!=1){break e}}a=N()|0;og(e+12|0);Q(a|0);p()}og(e+12|0)}fb=e+16|0;return i}function aI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31725]=0;W(c|0,d+8|0);c=x[31725];x[31725]=0;d:{e:{if((c|0)!=1){h=d,i=wb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=wb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=Bg(Jb(e));Td(d+8|0);tb(e);break b}if(!f){x[31725]=0;P(991,e|0,14604)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31725]=0;P(842,e|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}il(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Td(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31725]=0;V(989,b|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){T(0)|0;Tb();p()}Q(a|0);p()}function Wq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;a:{e=x[a>>2];f=x[a+4>>2];if(lc(e,f)){break a}i=Sd(e,f)-1|0;while(1){b:{if(Sd(e,f)-1>>>0>g>>>0){j=Oc(e,f,g);f=x[a+4>>2];e=x[a>>2];if(z[j>>1]<(b|0)){break b}i=g}g=z[Oc(e,f,i)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(g|0)){k=h,l=(y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0,x[k+12>>2]=l;break c}e=0;if(i){e=i-1|0;f=(y[Oc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Oc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=g>>>0){break c}a=((y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;i=a>>31;a=b-e|0;b=nva(d,i,a,a>>31);a=g-e|0;k=h,l=Gc(ova(b,hb,a,a>>31),hb)+f|0,x[k+12>>2]=l}Fe(h+12|0,0,65536);g=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}g=g+1|0;continue}}fb=h+16|0;return g}function Bq(a){var b=E(0),c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Ei(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Ei(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Fi(f+1.5707963267948966);break a}b=Fi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Ei(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Fi(-4.71238898038469-+a);break a}b=Fi(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Xy(a,c+8|0)&3){case 0:b=Ei(C[c+8>>3]);break a;case 1:b=Fi(-C[c+8>>3]);break a;case 2:b=E(-Ei(C[c+8>>3]));break a;default:break b}}b=Fi(C[c+8>>3])}a=b;fb=c+16|0;return a}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Ed(y[Lm(c+27|0,a,0)|0])){bd(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;e=R(1181,x[c+16>>2])|0;d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){d=wp(c+12|0,a);f=sc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31725]=0;ja(1183,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31725];x[31725]=0;if((e|0)!=1){break b}}b=T(0)|0;Zb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Jm(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Tb()}p()}Zb(c+16|0);x[b>>2]=x[c+20>>2]}dk(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function Fda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=re(a,f+60|0);d=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,e|0);k=x[31725];x[31725]=0;a:{b:{c:{d:{if((k|0)!=1){bc(f+24|0,b,c);mf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Nd(f+16|0);x[31725]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;b=f+40|0;Ns(1001,b,x[f+32>>2],x[f+36>>2],f+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;S(998,a|0,b|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}ub(b);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Td(j);of(i);Il(h);wh(g);vh(d);Vc(a);Vc(f+60|0);Q(e|0);p()}Vc(f+60|0);fb=f- -64|0;return a|0}function AF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31725]=0;f=P(21,e+8|0,a|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Ed(y[f|0])){break e}g=wp(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31725]=0;i=R(22,d|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break d}g=x[g>>2];x[31725]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,5);b=x[31725];x[31725]=0;if((b|0)!=1){break e}break d}nm(f);break b}b=T(0)|0;nm(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){T(0)|0;Tb();p()}Q(a|0);p()}function V1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;cd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31725]=0;O(181,h|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31725]=0;e=U(152,f|0,e|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31725]=0;e=P(182,b|0,e|0)|0;f=x[31725];x[31725]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Ud(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31725]=0;O(183,h|0,g+12|0);e=x[31725];x[31725]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;uc(h);Q(a|0);p()}function PP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31725]=0;a=P(982,(d?d:983)|0,e|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=j+24|0;b=x[re(j+28|0,a)>>2];k=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=k;x[31725]=0;k=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=k;c=+pa(984,j+8|0,+c,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}Vc(a);break b}a=T(0)|0;break c}a=T(0)|0;Vc(j+24|0)}Y(a|0)|0;x[31725]=0;ga(985,15049,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];k=y[b+4244|0];Yj(b+4208|0,33);d=x[b+4208>>2];v[d+32|0]=k;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;oe(c+8|0,x[b+4208>>2],x[b+4212>>2]);gc(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function B4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;Sb(d+116|0,0,44);while(1){if((c|0)==7){a:{c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14278,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+172|0,e);fa(e|0,100,13333,f|0,x[a>>2])|0;id(g+316|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14291,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+4|0,e);fa(e|0,100,13540,f|0,x[a>>2])|0;id(g+88|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+472|0,c);c=d+4|0;Ts(c,a,99,b);Ab(a+484|0,c);tb(c);Ts(c,a,114,b);Ab(a+496|0,c);tb(c);Ts(c,a,120,b);Ab(a+508|0,c);tb(d+4|0);Ts(c,a,88,b);Ab(a+520|0,c);tb(d+4|0);fb=d+160|0}function ux(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);f=vb(h+8|0,x[a>>2]);g=vb(h+4|0,x[b+4>>2]);d=x[c>>2];f=x[f>>2];c=fb+-64|0;fb=c;g=x[g>>2];x[c+56>>2]=g;x[c+60>>2]=d;x[c+52>>2]=g;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];g=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=g;Re(c+36|0,c+8|0);while(1){if(pd(d,f)){zs(Wp(x[c+56>>2]),jl(d));d=sk(c+60|0);sk(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);g=x[c+56>>2];if(!y[c+48|0]){e=fb-16|0;fb=e;d=vb(e+12|0,x[x[c+44>>2]>>2]);i=x[vb(e+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,i)){Eb(tx(d));d=x[il(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=c- -64|0;x[b+4>>2]=g;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=z[x[x[a+48>>2]+12>>2]+480188>>1];a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Ok(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=wb(x[a>>2]);a=wb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=wu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;vg(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=TZ(e+20|0,c,e+12|0);AR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=zb(c);g=zb(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Rk(c);x[a+12>>2]=b}fb=e+32|0}function qQ(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Fi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Ei(d+1.5707963267948966));break a}a=Ei(d+-1.5707963267948966);break a}a=Fi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Ei(d+4.71238898038469);break a}a=E(-Ei(d+-4.71238898038469));break a}a=Fi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Xy(a,b+8|0)&3){case 0:a=Fi(C[b+8>>3]);break a;case 1:a=Ei(C[b+8>>3]);break a;case 2:a=Fi(-C[b+8>>3]);break a;default:break b}}a=E(-Ei(C[b+8>>3]))}fb=b+16|0;return a}function cM(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function $qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;xY(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-80|0;fb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Nd(c+72|0);e=b-d|0;g=ev(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){er(c+60|0,x[a>>2],d);gc(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=Yo(c+60|0);x[31725]=0;b=P(761,a|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[31725]=0;O(762,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;sn(c+44|0,x[a>>2]);er(c+32|0,x[a>>2],x[a+4>>2]);sn(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;uX(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);gc(f,x[c+52>>2],x[c+56>>2]);iC(a,d);uf(d)}a=gc(c+16|0,x[f>>2],x[f+4>>2]);Pw(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}fb=c+80|0;return}a=N()|0;uf(d);Q(a|0);p()}function Ds(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Ed(y[Lm(d+27|0,a,0)|0])){g=d+20|0;bd(g,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;h=R(1181,x[d+20>>2])|0;e=x[31725];x[31725]=0;d:{e:{if((e|0)==1){break e}e=wp(d+16|0,a);f=sc(d+12|0);i=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31725]=0;ja(c|0,h|0,e|0,f|0,a+i|0,d+28|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}Zb(g);break d}b=T(0)|0;Zb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Jm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}dk(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Tb()}p()}return a}function uB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Ob(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function Lo(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!He(i,x[a+484348>>2],b)){break a}g=Wb(i,b);k=x[g+48>>2];b=jd(x[g>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Gb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(z[x[k+12>>2]+480188>>1],6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function gY(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Bb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=NC(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Tt(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function rq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;f=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);d=j(1)|0;if(!(j(0)|d&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}d=1072693248;g=-1023;if((b|0)!=1072693248){d=b;break b}if(f){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;f=j(0)|0;d=b;g=-1077}b=d+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,f|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function SB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;i=Xl(a,b);a:{if((i|0)==255){break a}if(Nj(x[a>>2])){break a}b:{if(c>>>0>6208431){j=7168;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}j=f<<10;f=20-f|0;g=f&31;if((f&63)>>>0>=32){f=c<<g;c=0}else{f=(1<<g)-1&c>>>32-g;c=c<<g}g=c+24858e3|0;c=f;c=Bc(pva(g,g>>>0<24858e3?c+1|0:c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Nc(h+14|0,h+12|0)>>1]}e=bv(i);f=a+8|0;k=xb(f,i),l=(c|j)>>>8|(d?0:32),v[k|0]=l;zh(x[a>>2],x[a+4>>2],b,e|160,c&255);c=xb(f,i);zh(x[a>>2],x[a+4>>2],b,e|176,y[c|0]);v[a+534|0]=1}fb=h+16|0}function F_(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=zd(b);x[e+12>>2]=a;f=Df(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31725]=0;O(35,d|0,65533);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31725]=0;O(35,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31725]=0;O(35,d|0,65533);g=x[31725];x[31725]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31725]=0;O(35,d|0,c|0);a=x[31725];x[31725]=0;c=0;if((a|0)==1){break a}}a=x[me(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Qb(d);Q(a|0);p()}function _qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;wY(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Jl(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}aS(d,1);break a}f=e+8|0;yc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];$t(f,x[e+40>>2]);To(f,c);MA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=Ck(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=Ck(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function zk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;a:{b:{while(1){f=d+8|0;e=c<<2;h=f+e|0;g=1<<c&2147483647;if(g|1){e=KK(c,g?a:22267)}else{e=x[e>>2]}x[h>>2]=e;if((e|0)==-1){break b}c=c+1|0;if((c|0)!=6){continue}break}if(!JK(0)){b=121484;if(!kd(f,121484,24)){break a}b=121508;if(!kd(f,121508,24)){break a}c=0;if(!y[500144]){while(1){i=(c<<2)+500096|0,j=KK(c,22267),x[i>>2]=j;c=c+1|0;if((c|0)!=6){continue}break}v[500144]=1;x[125030]=x[125024]}b=500096;a=d+8|0;if(!kd(a,500096,24)){break a}b=500120;if(!kd(a,500120,24)){break a}b=Fd(24);if(!b){break b}}a=x[d+12>>2];x[b>>2]=x[d+8>>2];x[b+4>>2]=a;a=x[d+28>>2];x[b+16>>2]=x[d+24>>2];x[b+20>>2]=a;a=x[d+20>>2];x[b+8>>2]=x[d+16>>2];x[b+12>>2]=a;break a}b=0}fb=d+32|0;return b}function qS(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Gq(a,E(1));Bk(a,E(3.725290298461914e-9));Fq(a,E(268435456));Eq(a,0);break b;case 1:Gq(a,E(32));Bk(a,E(4.656612873077393e-10));Fq(a,E(2147483648));Eq(a,0);break b;case 2:Gq(a,E(2));Bk(a,E(7.450580596923828e-9));Fq(a,E(134217728));Eq(a,1);break b;default:Gq(a,E(1));Bk(a,E(7.450580596923828e-9));Fq(a,E(134217728));Eq(a,1);GA(a,0);FA(a,1);EA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Gq(a,E(.75));Bk(a,E(7.450580596923828e-9));Fq(a,E(134217728));Eq(a,1);GA(a,0);b=(b|0)==4;FA(a,b?2:3);EA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}GA(a,1);FA(a,0);EA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function pY(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){xg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(kh(x[a>>2])&-2)){break c}cd(a,c+(f<<10)|0);if(!SC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((kh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}cd(a,c+D(f,z[e>>1])|0);h=SC(a,64,1)?h:k}cd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(kh(x[a>>2])|0)){break d}}if(c>>>0>=255){RC(b,254,65534);RC(b,255,65535)}l=h}a=l&65535}else{j=z[_b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function DL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(xq(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,Pe(Pe(zd(b),e),1));c=vb(h+8|0,Df(b));bs(b,x[f>>2],x[c>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}i=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Jb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=v[d|0];d=d+1|0;if(!lc(v[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function nT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!HA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Wq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=Oq(a,b,!(x[b+88>>2]&32768),d);break a}if(Sj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=ed(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Hj(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Ai(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36592:35568)|0;break b}Ai(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35568:36592)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Gc(ova(nva(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Eu(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,Pe(Pe(zd(b),e),1));c=vb(h+8|0,Df(b));bs(b,x[f>>2],x[c>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}i=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Jb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=y[d|0];d=d+1|0;if(!lc(y[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function k3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;b=d+12|0;_k(b,a);x[31725]=0;c=d+24|0;O(104,c|0,b|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{if((a|0)!=1){x[31725]=0;a=P(105,d+36|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}tb(c);tb(b);b=x[x[a>>2]-12>>2];x[31725]=0;f=ca(106)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;e=d+8|0;S(107,e|0,a+b|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(e);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31725]=0;c=P(108,a|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}a=vk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);b=x[d+24>>2];Ff(c);fb=d+176|0;return(a?0:b)|0}c=N()|0;break c}c=N()|0;tb(d+24|0)}tb(d+12|0);break a}c=N()|0;Ff(a)}Q(c|0);p()}function jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=nc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Wg(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=$f(d,c,c>>>2|0,x[a+16>>2]);e=vb(g+4|0,x[a+4>>2]);f=x[vb(g,x[a+8>>2])>>2];d=fb-16|0;fb=d;e=x[e>>2];x[d+12>>2]=e;e=Mn(d,c+8|0,Hv(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];hp(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Je(d+12|0);continue}break}he(e);fb=d+16|0;Ub(a,c);Ub(i,c+4|0);Ub(h,c+8|0);Ub(j,nc(c));_f(c);c=x[a+8>>2]}hp(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function QK(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Vd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Vd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Vd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Vd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Vd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function Kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;x[31725]=0;f=R(1159,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){a:{b:{if(f){x[31725]=0;f=d+56|0;O(1160,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=d- -64|0;Qp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+72|0,b);g=Ef(d+48|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;Rp(a,d+8|0,d);break b}break a}x[31725]=0;f=d+56|0;O(1161,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=d- -64|0;Qp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+40|0,b);g=Ef(d+32|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;Rp(a,d+24|0,d+16|0)}ke(b);ke(f);ke(c);fb=d+80|0;return}}a=N()|0;ke(c);Q(a|0);p()}function Xy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=IL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function XC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;gh(b,y[Rb(f+15|0,f+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[((d|0)==4?a+2|0:a+3|0)|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];h=x[b>>2];e=Sd(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(e|0)){i=yb(h,b);g=(b<<2)+a|0;d=y[g+6|0]|y[g+7|0]<<8;w[i>>1]=d;a:{if(!b){break a}j=d;d=z[yb(h,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[i>>1]=d+1}k=i,l=Yb((y[g+8|0]|y[g+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=f+16|0}function Ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function $la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);i=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;pN(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;h=a+4|0;d=y[Rb(h,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Ki(g,h);if((d|0)==1){break b}Ki(g,a);if(d>>>0<3){break b}Ki(g,a+10|0);j=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|j)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;eC(b,x[Gb(a+4|0,a)>>2]);e=0;while(1){h=Cb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Tm(g,d-h|0)}fb=a+16|0}else{Dj(g,cc(b,e),1);e=e+1|0;continue}break}d=c}gf(i,d);fb=f+16|0}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb+-64|0;fb=d;a=x[a+4>>2];g=d+16|0;lx(g,b);x[31725]=0;b=P(1,d+4|0,18382)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31725]=0;e=d+28|0;S(2,e|0,g|0,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break h}x[31725]=0;f=d+40|0;S(491,f|0,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}x[31725]=0;c=d+52|0;O(1065,c|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}h=x[x[a>>2]+8>>2];x[31725]=0;O(h|0,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}tb(c);tb(f);tb(e);tb(b);tb(g);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function dY(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}PC(c+8|0,b);rd(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function PH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;LA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=RM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=SM(d,x[Zr(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function xx(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wd(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}x[31725]=0;O(117,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=fb-80|0;fb=g;e=Tf(g+52|0);x[31725]=0;d=P(835,b|0,e|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){if(d){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(836,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];f=x[e>>2];x[31725]=0;d=g+12|0;c=$b(c);d:{if(!c){h=-1;if(($b(f)|0)==1112491097){break d}}h=c}c=h;S(187,d|0,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}f=ic(g+32|0,d);hd(e+8|0,f);ub(f);ub(d);e:{d=c&1;if(!d){break e}x[31725]=0;P(185,b|0,2-d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break e}break a}Uk(a,e)}Gd(e);fb=g+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;ld(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Rb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Qk(e,2,b+1|0);Cc(d,e);ze(c+43|0,d);tb(d);d=Xc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}fd(d,16);yg(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;d=fb-16|0;fb=d;h=a;c=ce(a);a:{if(c){f=ec(a);while(1){a=c;c=a+13|0;if(lv(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!lv(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=fb-16|0;fb=c;a=ec(h);g=Ch(d,Ec(20),Mg(c+8|0,a));b=x[g>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=ec(g),j=1,v[i+4|0]=j;fb=c+16|0;$g(h,x[d+12>>2],f,x[d>>2]);b=le(d);a=x[d>>2];x[d>>2]=0;if(a){ec(d);Db(a)}g=1}_g(e+8|0,x[vb(d,b)>>2],g);fb=d+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function UH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=re(a,f+44|0);c=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){oe(f+16|0,x[b>>2],x[b+4>>2]);b=Nd(f+8|0);x[31725]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;b=f+24|0;Ns(e,b,x[f+16>>2],x[f+20>>2],f);e=x[31725];x[31725]=0;if((e|0)==1){break d}x[31725]=0;S(998,a|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}ub(b);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Td(k);of(j);Il(i);wh(h);vh(c);Vc(a);Vc(f+44|0);Q(d|0);p()}Vc(f+44|0);fb=f+48|0;return a}function Fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function _m(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;kg(d,e);a:{b:{if(Ed(y[Lm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(943,c+40|0,d|0,c+8|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){b=gi(c+24|0,-1,-1);b=fo(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Jm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}dk(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Tb()}p()}function rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+38150>>1];o=w[e+38148>>1];p=w[e+38146>>1];e=w[e+38144>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function o_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-176|0;fb=c;d=c+12|0;Wf(d,a);x[31725]=0;b=c+24|0;O(126,b|0,d|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31725]=0;a=P(105,c+36|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}tb(b);tb(d);d=x[x[a>>2]-12>>2];x[31725]=0;f=ca(106)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;e=c+8|0;S(107,e|0,a+d|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}Zb(e);x[31725]=0;x[c+24>>2]=0;x[c+28>>2]=0;b=P(411,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}a=vk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);g=C[c+24>>3];Ff(b);fb=c+176|0;g=a?0:g;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Ff(a)}Q(b|0);p()}return+g}function Qh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=aQ(a);h=a+4208|0;c=E(E(B[yb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=De(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[yb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(De(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-Bq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!$m(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=cg(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function Dqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;e=-1;a:{if(!lh(a,1468)){break a}cm(a,1464);c=b+524|0;tY(a,c);if(!ne(c,25252)){e=0;if(!ne(c,15580)){break a}}cm(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}e=qY(a,b);if(!e){cY(b)}if(e){c=c+1|0;d=WC(b)+d|0;continue}break}e=-1;break a}e=0;if(d>>>0>40){break a}d=b+522|0;c=fb-16|0;fb=c;c:{if(!lh(a,2)){v[c|0]=0;sF(d,c);break c}Ip(c+8|0,d);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}d=Jc(d);c=fb-16|0;fb=c;d:{if(!lh(a,512)){bY(b);break d}xE(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}fb=b+528|0;return e|0}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=re(a,e+44|0);f=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);c=x[31725];x[31725]=0;a:{b:{c:{d:{if((c|0)!=1){c=Nd(e+16|0);x[31725]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;c=e+24|0;S(1121,c|0,b|0,e+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,c|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(c);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Td(j);of(i);Il(h);wh(g);vh(f);Vc(a);Vc(e+44|0);Q(d|0);p()}Vc(e+44|0);fb=e+48|0;return a|0}function Dga(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31725]=0;W(990,b+8|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=wb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=Bg(Jb(c));Td(b+8|0);tb(c);break b}if(!d){x[31725]=0;P(991,c|0,14604)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31725]=0;P(842,c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}il(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Td(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31725]=0;V(989,7040,0,0,0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){T(0)|0;Tb();p()}Q(b|0);p()}function KK(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=Fy(13900);if(y[b|0]?b:0){break a}b=Fy(D(a,12)+95776|0);if(y[b|0]?b:0){break a}b=Fy(14156);if(y[b|0]?b:0){break a}b=14737}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14737;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!ni(e,14737)){break e}if(ni(e,13638)){break d}}if(!a){c=95848;if(y[e+1|0]==46){break c}}return 0}c=x[125023];if(c){while(1){if(!ni(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Fd(36);if(c){x[c+4>>2]=20;x[c>>2]=95744;b=c+8|0;yc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125023];x[125023]=c}c=a|c?c:95848}return c}function vU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;d=js(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){C[x[a+44>>2]>>3]=C[b>>3];x[a+44>>2]=x[a+44>>2]+8;b=b+8|0;continue}break}Qe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){e=fb-16|0;fb=e;b=vb(e+12|0,x[x[a+32>>2]>>2]);i=x[vb(e+8|0,x[x[a+28>>2]>>2])>>2];f=fb-16|0;fb=f;b=x[b>>2];x[f+12>>2]=b;while(1){if(pd(b,i)){c=fb-16|0;fb=c;x[c+12>>2]=b;x[c+12>>2]=x[c+12>>2]-8;fb=c+16|0;b=x[Op(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=a+48|0;x[d+4>>2]=h;hc(d);fb=g+16|0}function Una(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function fI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=re(a,g+44|0);d=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31725]=0;O(997,a|0,e|0);l=x[31725];x[31725]=0;a:{b:{c:{d:{if((l|0)!=1){bc(g+16|0,b,c);b=Nd(g+8|0);x[31725]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;b=g+24|0;Ns(f,b,x[g+16>>2],x[g+20>>2],g);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;S(998,a|0,b|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}ub(b);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Td(k);of(j);Il(i);wh(h);vh(d);Vc(a);Vc(g+44|0);Q(e|0);p()}Vc(g+44|0);fb=g+48|0;return a}function G9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Jb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];mo(b,e,c+e|0,h)}if(f&16){My(b,x[b+20>>2],x[b+28>>2]);Bt(b,c)}m=c;n=d}gi(a,m,n)}function Oo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){No(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Mo(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Yb(c,0,256),x[h+688>>2]=i}function _0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=sw(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=sw(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(IE(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31725]=0;O(741,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{c=Sb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Qd(b);pW(b);fb=e+16|0;return a|0}a=N()|0;pW(e+8|0);Q(a|0);p()}function X2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;c=d+12|0;Wf(c,a);x[31725]=0;b=d+24|0;O(126,b|0,c|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31725]=0;a=P(105,d+36|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}tb(b);tb(c);c=x[x[a>>2]-12>>2];x[31725]=0;f=ca(106)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;e=d+8|0;S(107,e|0,a+c|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}Zb(e);x[31725]=0;x[d+24>>2]=0;b=P(127,a|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}a=vk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);c=x[d+24>>2];Ff(b);fb=d+176|0;a=a?0:c;break a}b=N()|0;break d}b=N()|0;tb(d+24|0)}tb(d+12|0);break b}b=N()|0;Ff(a)}Q(b|0);p()}return a|0}function EN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){e=x[a+32>>2];if((Bo(e)|0)>(b|0)){break e}}a=ac(8);x[31725]=0;b=P(36,f+4|0,10735)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(e+(b<<5)|0)+480280|0;g=c?134218752:0;x[d>>2]=g|x[d>>2]&-134218753;c=(e+D(b,872)|0)+1075080|0;x[c>>2]=x[c>>2]&-134218753|g;c=z[e+480188>>1];e=c>>>0<=256?256:c;b=b+1|0;a=x[a+32>>2];while(1){if((c|0)==(e|0)){break a}d=a+D(c,872)|0;if((b|0)==z[d+1075778>>1]){d=d+1075080|0;x[d>>2]=x[d>>2]&-134218753|g}c=c+1|0;continue}}c=N()|0;jc(a)}Q(c|0)}p()}fb=f+16|0}function Bs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Eh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Tk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31725]=0;O(118,e+8|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Cb(x[a+4>>2],c)}b=Cg(b,g,c+1|0);if(i){Db(g)}if(!h){pf(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function Qi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=42776;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31725]=0;O(947,b|0,0);g=x[31725];x[31725]=0;if((g|0)==1){a=N()|0;uc(f);uc(e);mu(d);mu(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31725]=0;d=R(948,a+92|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((vd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;FQ(b);Q(a|0);p()}return a}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Eh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Tk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31725]=0;O(52,e+8|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Cb(x[a+4>>2],c)}b=Xg(b,g,c+1|0);if(i){Db(g)}if(!h){pf(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function gB(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(nh(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}fb=d- -64|0;return e}function ff(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wd(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}x[31725]=0;O(117,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;ld(b,4);w[b+30>>1]=y[a+12|0]<<2;Gf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Dc(g+4|0,22267);ze(b+43|0,a);tb(a);fb=g+16|0}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(zn(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=yn(x[ad(d+12|0,d+8|0)>>2]);if((zn(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=zn(a);g=Cb(x[a+4>>2],y[a+11|0]);b:{c:{j=kr(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Uj(e+8|0,f);break e}x[31725]=0;O(54,e+8|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);h=Jb(a);c=Cb(x[a+4>>2],c)}b=Yi(b,h,c+1|0);if(i){Db(h)}if(!j){pf(a,f);Yd(a,g);yd(a,b);break b}Me(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{c=Ok(x[b>>2],x[b+4>>2]);if(!c){break b}x[31725]=0;O(462,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31725]=0;uu(a,f,e,c);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}a=N()|0;im(d+8|0);Q(a|0);p()}c=d+8|0;Qd(c);im(c);fb=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[31725]=0;d=P(925,a+24|0,b+24|0)|0;c=x[31725];x[31725]=0;c:{d:{if((c|0)!=1){x[31725]=0;P(72,a+36|0,b+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;uc(d)}Rk(a);Q(b|0);p()}}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38150>>1];o=w[e+38148>>1];p=w[e+38146>>1];e=w[e+38144>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function dR(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{f=fb-48|0;fb=f;d=Fb(f+36|0);x[31725]=0;O(938,b|0,f+24|0);g=x[31725];x[31725]=0;if((g|0)!=1){b:{g=x[f+28>>2];e=x[f+24>>2];tf(d);x[31725]=0;g=!g&e>>>0>=255|g?255:e;O(46,d|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=l0(Jb(d),Cb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break c}break b}e=cc(d,h);x[31725]=0;P(939,b|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){h=h+1|0;continue}break}break b}x[31725]=0;b=f+12|0;S(498,b|0,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Ab(c,b);tb(b);tb(d);fb=f+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Yy(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function FT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=Lo(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[ad(f+4|0,f+108|0)>>2]<<3;e=nva(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}Uv(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[yb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Po(a,b,e+h|0);fb=f+112|0}function Vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function Hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{c:{while(1){c=Jb(d);j=Cb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((f|0)>0|(f|0)>=0|(c|0)==(j|0))){v[c|0]=45;i=SN(i,f);f=hb;c=c+1|0}RN(k,c,j,i,f);if(!x[e+16>>2]){break c}c=qi(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Jb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,h|0,d|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Rh(a,h);tb(h);fb=g+16|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)==1){break c}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;W(1003,c|0);f=x[31725];x[31725]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31725]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;Os(1024,f,d+8|0,g,c,1);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5507,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function eG(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(He(d,e,b)){break b}c:{d:{if(pm(d,e)>>>0<=b>>>0){d=qA(f+12|0,a);x[31725]=0;S(201,a|0,b+1|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}Dk(d);d=x[a>>2]}x[31725]=0;O(202,gj(d,b)|0,c|0);c=x[31725];x[31725]=0;e:{if((c|0)!=1){c=gj(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31725]=0;W(203,gj(c,b)|0);c=x[31725];x[31725]=0;if((c|0)!=1){break e}}b=T(125e3)|0;a=gb;break c}a=gj(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(125e3)|0;a=gb;Dk(d)}if(($(125e3)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function uu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;d=Jr(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){Ov(x[a+44>>2],b);x[a+44>>2]=x[a+44>>2]+6;b=b+6|0;continue}break}Qe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+32>>2]>>2]);i=x[vb(c+8|0,x[x[a+28>>2]>>2])>>2];e=fb-16|0;fb=e;b=x[b>>2];x[e+12>>2]=b;while(1){if(pd(b,i)){f=fb-16|0;fb=f;x[f+12>>2]=b;wR(f+12|0,-1);fb=f+16|0;b=x[nD(e+12|0)>>2];continue}break}fb=e+16|0;fb=c+16|0}fb=a+48|0;x[d+4>>2]=h;hc(d);fb=g+16|0}function jR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Nf(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;mR(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Nf(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Nc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=De(i,E(E(1)/E(b|0)));Kl(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){Dq(a)}else{j=De(i,E(d|0));k=yb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function UO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];c=Yu(x[c+484344>>2],x[c+484348>>2]);x[31725]=0;O(178,g|0,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];d=x[c+484344>>2];if(Yu(d,x[c+484348>>2])>>>0<=a>>>0){break b}x[31725]=0;c=e+8|0;O(1072,c|0,Wb(d,a)|0);d=x[31725];x[31725]=0;if((d|0)!=1){f=x[b+24>>2];x[31725]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;O(180,g|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}a=a+1|0;tb(d);tb(c);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(e+8|0);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function GU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=$u(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);h=e+8|0;Rd(h,x[vb(e+4|0,a)>>2]);x[31725]=0;O(802,a|0,2048);d=x[31725];x[31725]=0;a:{if((d|0)!=1){i=fb-16|0;fb=i;g=js(i+4|0,a,2048);d=x[g+4>>2];k=x[g+8>>2];while(1){if((d|0)==(k|0)){hc(g);fb=i+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[g+4>>2]=d;continue}break}Qd(h);_u(h);fb=e+16|0;break a}a=N()|0;_u(e+8|0);Q(a|0);p()}while(1){b:{c=1;if((f|0)!=1024){if((f|0)==2048){break b}c=+(f-1024|0);l=$u(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=l*Wi(c)/(j*c)}m=Ve(x[a>>2],f),n=c*.011841342921061943,C[m>>3]=n;f=f+1|0;continue}break}}function Rz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[d+4>>2]){break a}a=x[d>>2];h=x[d+4>>2];c=30624;while(1){if((c|0)==31056){c=31056;while(1){f=(c|0)!=31104;if((c|0)==31104){break a}x[b+40>>2]=a;x[b+44>>2]=h;e=qc(b+32|0,x[c+8>>2]);g=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=g;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;c=c+12|0;if(!SR(b+8|0,b)){continue}break}break a}x[b+56>>2]=a;x[b+60>>2]=h;f=qc(b+48|0,x[c+4>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=e;c=c+8|0;if(!SR(b+24|0,b+16|0)){continue}break}f=1}fb=b- -64|0;fb=d+16|0;return f}function kZ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);c=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=c;while(1){if(pd(c,k)){c=xf(c);f=xf(x[d+8>>2]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=c;v[f+1|0]=c>>>8;v[f+2|0]=c>>>16;v[f+3|0]=c>>>24;c=Mi(d+12|0);Mi(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function jv(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;kW(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;kW(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);a:{if(!Tj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);if(!Tj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);if(!Tj(b)){break a}b=x[a+12>>2];b=(y[b|0]|y[b+1|0]<<8)<<16>>16;c=x[d+12>>2];c=xe((y[c|0]|y[c+1|0]<<8)<<16>>16);b=xe(b);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Tj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=iv(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=Cd(b);fb=e+48|0;return a}function aB(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!d|!(e&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Yb(a+c|0,0,256),x[f+692>>2]=g}}function lL(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31725]=0;c=P(1187,d+8|0,a|0)|0;b=x[31725];x[31725]=0;c:{if((b|0)!=1){d:{if(!Ed(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=R(1188,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31725]=0;W(1189,a+b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}b=T(0)|0;jL(c);break c}jL(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Z7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;dK(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=oc(e,x[h+12>>2]);a=Gi(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){jo(12661);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){gL(c+12|0,x[e>>2]);e=e+4|0;continue}break}Ac(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function ho(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Li(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111728|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111728|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function In(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31725]=0;c=P(21,d+8|0,a|0)|0;b=x[31725];x[31725]=0;c:{if((b|0)!=1){d:{if(!Ed(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=R(31,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}b=T(0)|0;nm(c);break c}nm(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function H9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;a:{b:{if(!lc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}k=x[a+44>>2];h=x[a+20>>2];x[31725]=0;g=a+32|0;O(117,g|0,0);e=x[31725];x[31725]=0;if((e|0)==1){break b}e=Mc(g);x[31725]=0;O(46,g|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}c=Jb(g);My(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);Bt(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[ad(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Jb(a+32|0);mo(a,c,c+(j-i|0)|0,d)}c=rL(a,b<<24>>24);break a}c=Ly(b);break a}Y(T(0)|0)|0;Z()}fb=f+16|0;return c|0}function go(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=sy(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111728|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111728|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-160|0;fb=e;b=-1;a:{if(!Cm(a,80)){break a}b:{c:{if(!cm(a,60)){break c}d=e+140|0;if(!fX(a,d)){break c}c=15;if(uv(d,15)){break b}}if(!Cm(a,144)){break a}b=0;if(!cm(a,124)){break a}d=e+140|0;if(!fX(a,d)){break a}c=31;if(!uv(d,31)){break a}}qE(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(dX(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!gd(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;f=e+10|0;TC(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((d|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){KC(f)}if(!a){break a}b=eX(y[e+10|0])}fb=e+160|0;return b|0}function pna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function ws(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;c=b+8|0;Dc(c,15391);x[31725]=0;d=b+20|0;S(125,d|0,1,c|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)!=1){x[31725]=0;O(12,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}Qb(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31725]=0;b=ca(119)|0;c=x[31725];x[31725]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31725]=0;b=ca(120)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31725]=0;b=ca(121)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31725]=0;W(122,a+20|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Tf(e+52|0);x[31725]=0;g=P(839,b|0,d|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(840,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31725]=0;f=e+12|0;S(187,f|0,b|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}h=ic(e+32|0,f);hd(d+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31725]=0;P(185,b|0,2-c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Uk(a,d)}Gd(d);fb=e+80|0;return}a=N()|0;Gd(d);Q(a|0);p()}function asa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Nk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31725]=0;w[d+14>>1]=0;g=U(497,a|0,h|0,255)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}if(!g){break d}x[31725]=0;g=d+14|0;O(486,a|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;S(498,d|0,c|0,h|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;g=P(499,b|0,g|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break e}Ab(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function Csa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Nv(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}sZ(c+16|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}j=c+32|0;i=y[j+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Vb(d,h);sZ(c+8|0,j);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Vb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function oT(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Sj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=xh(a,Ju(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function kG(a){a=a|0;var b=0,c=0,d=0,e=0;b=lF(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31725]=0;c=P(21,d+8|0,a|0)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Ed(y[c|0])){break e}e=wp(d+4|0,a);x[31725]=0;b=P(30,e|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break e}}b=T(0)|0;nm(c);break d}nm(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}return In(a)|0}function eI(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31725]=0;e=P(36,f+8|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=d;d=f+20|0;S(b|0,d|0,g|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}b=Bg(Jb(d));tb(d);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31725]=0;V(989,c|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Hsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=Ir(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=G$(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{nZ(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);d=D$(f+12|0,E$(a,Ir(x[a>>2],e)+c|0),Ir(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){nZ(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}he(b);fb=e+16|0;C$(a,d);B$(d)}fb=f+32|0;return}if(b>>>0<d>>>0){y$(a,c+D(b,40)|0)}}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;pg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31725]=0;w[d+14>>1]=0;g=P(500,a|0,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}if(!g){break d}x[31725]=0;g=d+14|0;O(486,a|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;S(498,d|0,c|0,h|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;g=P(499,b|0,g|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break e}Ab(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31725]=0;O(249,h|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;break a}c=gS(c,e);x[31725]=0;c=P(36,d+8|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}e=Ad(x[d+12>>2],y[d+19|0]);x[31725]=0;g=P(842,f|0,c|0)|0;j=x[31725];x[31725]=0;d:{if((j|0)==1){break d}x[31725]=0;P(991,g|0,22242)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38146>>1])+D(v[h-1|0],w[e+38144>>1])|0)+D(v[h+1|0],w[e+38148>>1])|0)+D(v[h+2|0],w[e+38150>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31725]=0;O(249,h|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31725]=0;e=P(36,c+8|0,hS(e,d)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}d=Ad(x[c+12>>2],y[c+19|0]);x[31725]=0;g=P(842,f|0,e|0)|0;j=x[31725];x[31725]=0;d:{if((j|0)==1){break d}x[31725]=0;P(991,g|0,22242)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function p1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;ld(b,0);e=c+16|0;f=rf(e,1,v[a+1|0]);ze(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Rb(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+16|0,d)|0];g=xb(c+12|0,d),h=e,v[g|0]=h;d=d+1|0;continue}break}d=eg(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function W7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=SJ(b);rl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;ql(a,b);Ab(i,a);tb(a);ji(a,b);Ab(h,a);tb(a);m=d,n=uj(b),v[m|0]=n;m=e,n=vj(b),v[m|0]=n;sh(a,b);Ab(f,a);tb(k+4|0);ki(a,b);Ab(g,a);tb(k+4|0);a=Pk(b);break a}a=k+4|0;b=RJ(b);rl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;ql(a,b);Ab(i,a);tb(a);ji(a,b);Ab(h,a);tb(a);m=d,n=uj(b),v[m|0]=n;m=e,n=vj(b),v[m|0]=n;sh(a,b);Ab(f,a);tb(k+4|0);ki(a,b);Ab(g,a);tb(k+4|0);a=Pk(b)}x[l>>2]=a;fb=k+16|0}function qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(xq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,Pe(zd(b),f));bs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!xq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function P7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=NJ(b);rl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;ql(a,b);ph(i,a);Qb(a);ji(a,b);ph(h,a);Qb(a);m=d,n=uj(b),x[m>>2]=n;m=e,n=vj(b),x[m>>2]=n;sh(a,b);Ab(f,a);tb(a);ki(a,b);ph(g,a);Qb(k+4|0);a=Pk(b);break a}a=k+4|0;b=MJ(b);rl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;ql(a,b);ph(i,a);Qb(a);ji(a,b);ph(h,a);Qb(a);m=d,n=uj(b),x[m>>2]=n;m=e,n=vj(b),x[m>>2]=n;sh(a,b);Ab(f,a);tb(a);ki(a,b);ph(g,a);Qb(k+4|0);a=Pk(b)}x[l>>2]=a;fb=k+16|0}function DC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Sc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=xb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Kb(c,x[a+24>>2],b);Jf(c,0);break b;case 2:i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Jf(c,1);break b;case 4:break c;default:break b}}i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Jf(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(lc(x[f>>2],c)){break a}c=AX(c);if(y[xb(x[c>>2],b)|0]==y[xb(x[a>>2],b)|0]){Kb(g+8|0,x[c+24>>2],b);c=Hb(x[x[g+8>>2]>>2],x[g+12>>2]);Kb(g,x[a+24>>2],b);if((Hb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function H2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Eu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,Pe(zd(b),f));bs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Eu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Tf(e+52|0);x[31725]=0;g=P(915,b|0,d|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(916,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31725]=0;f=e+12|0;S(187,f|0,b|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}h=ic(e+32|0,f);hd(d+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31725]=0;P(185,b|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Uk(a,d)}Gd(d);fb=e+80|0;return}a=N()|0;Gd(d);Q(a|0);p()}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(ni(b,14276)){d=Ss(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31725]=0;b=P(36,c+4|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;a=c+16|0;S(1017,a|0,17801,b|0);e=x[31725];x[31725]=0;d:{e:{if((e|0)!=1){x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}jq(e);if(!Rs(a+8|0,16781,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!Rs(a+9|0,22267,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31725]=0;O(274,a+12|0,22267);a=x[31725];x[31725]=0;if((a|0)==1){break b}ol(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}ol(d);Q(a|0);p()}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-80|0;fb=f;d=Tf(f+52|0);x[31725]=0;c=P(831,b|0,d|0)|0;e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(832,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}e=x[d+4>>2];x[31725]=0;c=f+12|0;e=$b(e);S(187,c|0,b|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break a}g=ic(f+32|0,c);hd(d+8|0,g);ub(g);ub(c);d:{c=e&1;if(!c){break d}x[31725]=0;P(185,b|0,2-c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Uk(a,d)}Gd(d);fb=f+80|0;return}a=N()|0;Gd(d);Q(a|0);p()}function Wqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=ri(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=ed(g),w[m>>1]=n;a=a+1|0;continue}}}_(17362,8983,27,9525);p()}_(17312,8983,28,9525);p()}fb=c+16|0}function QA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=x[a>>2];if(!lc(c,x[a+4>>2])){d=wb(c);x[e+12>>2]=d;c=wb(x[a+4>>2]);while(1){if(Ib(d,c)){Lp(d,4194304,67108864);f=x[d>>2];g=f+g|0;b=g>>>0<f>>>0?b+1|0:b;d=x[Je(e+12|0)>>2];continue}else{f=x[a>>2];c=oc(f,x[a+4>>2]);k=e,l=wb(f),x[k+8>>2]=l;d=c<<24;g=pva(g,b,c,0);c=g;h=((hb&1)<<31|c>>>1)&2147483647;i=wb(x[a+4>>2]);while(1){b=x[e+8>>2];if(Ib(b,i)){f=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+j|0;b=Bc(pva(c,c>>>0<h>>>0?b+1|0:b,g,j),hb);x[f>>2]=b;d=d-b|0;Je(e+8|0);continue}else{b=x[a>>2];if(!oc(b,x[a+4>>2])){Dw();p()}x[b>>2]=x[b>>2]+d}break}}break}}fb=e+16|0}function Kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=BP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=TM(UM(g+8|0,32));break a}e=G(c);e=UM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=TM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=yb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=KP(l,d,NP(d));EP(a,d);bn(d);fb=f- -64|0;d=wz(a+120|0,a,b);v[d+20|0]=1;x[31725]=0;O(1144,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){a=N()|0;yo(d);Q(a|0);p()}return a|0}function aP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480192>>1];x[31725]=0;O(178,g|0,a|0);c=x[31725];x[31725]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=gS(c,d);x[31725]=0;c=P(36,e+8|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){f=x[b+24>>2];x[31725]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;O(180,g|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function Vqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=ri(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=vY(g),v[m|0]=n;a=a+1|0;continue}}}_(17362,8983,27,9525);p()}_(17312,8983,28,9525);p()}fb=c+16|0}function Sw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;gh(b,y[Rb(i,e)|0]);g=y[Rb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Kd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Rb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Kd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Rb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Yb(y[e+6|0]+c<<24>>24,0,64);d=yb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=yb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function GN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bo(a)|0)>(b|0)){break d}}a=ac(8);x[31725]=0;d=P(36,d+4|0,10735)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=ac(8);x[31725]=0;d=P(36,d+4|0,11752)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;jc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=Zi(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function MW(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;d=vb(f+12|0,x[a+4>>2]);c=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=g;x[d+12>>2]=c;while(1){if(pd(c,k)){c=jl(c);g=jl(x[d+8>>2]);x[g+8>>2]=x[c+8>>2];l=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=l;c=sk(d+12|0);sk(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function QO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480190>>1];x[31725]=0;O(178,g|0,a|0);c=x[31725];x[31725]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480190>>1]){break b}x[31725]=0;c=P(36,e+8|0,hS(c,d)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){f=x[b+24>>2];x[31725]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;O(180,g|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=ce(a);a:{if(d){f=ec(a);while(1){a=d;d=a+16|0;if(Tu(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Tu(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=ec(g);b=Ch(c,Ec(40),Mg(a+8|0,b));Fb(_c(x[b>>2]+16|0,x[e+4>>2])+12|0);i=ec(b),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[c+12>>2],f,x[c>>2]);b=le(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[ec(c)+4|0]){gn(a+16|0)}Db(a)}h=1}_g(e+8|0,x[vb(c,b)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+12|0}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(nh(a,x[b+8>>2],f)){Ox(b,c,d,e);return}g=y[b+53|0];i=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;Kx(x[a+16>>2],x[a+20>>2],b,c,d,e,f);j=y[b+52|0];h=(h|j)!=0;k=y[b+53|0];l=(g|k)!=0;g=a+24|0;i=(a+16|0)+(i<<3)|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(j){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Kx(x[g>>2],x[g+4>>2],b,c,d,e,f);k=y[b+53|0];l=(k|l)!=0;j=y[b+52|0];h=(j|h)!=0;g=g+8|0;if(i>>>0>g>>>0){continue}break}}v[b+53|0]=l;v[b+52|0]=h}function WY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Ve(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Mw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function voa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=zd(b),x[i+12>>2]=j;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;xV(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[vb(g+8|0,x[g+12>>2])>>2];c=d-Yc(x[b+4>>2],y[b+11|0])|0;c:{e=Gk(e,zd(b));d=Cb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Mc(b);d:{if(c>>>0<=f-d>>>0){f=Jb(b);if((d|0)==(e|0)){break d}h=e+f|0;Ui(c+h|0,h,d-e|0);break d}VB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}hm(e+f|0,c,48);c=c+d|0;ng(b,c);fd(c+f|0,0)}break c}kn();p()}zd(b)}_c(a,b);fb=g+16|0}function tV(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function eva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;K0(c,a);J0(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Gb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;gh(b,y[Rb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Sd(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=yb(e,0);break b}g=z[yb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Ze(d+12|0,d+8|0);c=yb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);f=d+8|0;lk(f,1,a);c=d+20|0;Cc(c,f);ze(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;gm(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Rb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}function BD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;gh(b,Kd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Sd(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){AD(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=qe(e+14|0,e+12|0);i=yb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Rb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function US(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!je(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31664|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=dl(f);bc(d+8|0,g+D(c,b)|0,b);i=d,j=wb(x[d+8>>2]),x[i+4>>2]=j;f=Xk(x[d+8>>2],x[d+12>>2]);while(1){b=x[d+4>>2];if(Ib(b,f)){v[b|0]=y[b|0]^-1;me(d+4|0);continue}else{Qj(e,a)}break}}fb=d+16|0}function Xsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;c=P(412,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(413,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=$b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=ad(c+12|0,c+8|0);fb=c+16|0;c=x[f>>2]-8|0;x[31725]=0;S(187,d+12|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Uk(a,e)}Gd(e);fb=d+80|0}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=c;e=fb-16|0;fb=e;h=b;d=ce(b);a:{if(d){c=ec(b);while(1){b=d;d=b+16|0;if(PR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!PR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(h);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(h);d=Ch(e,Ec(28),Mg(b+8|0,d));i=x[d>>2];x[31725]=0;O(893,i+16|0,f|0);f=x[31725];x[31725]=0;b:{if((f|0)!=1){j=ec(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;OR(d);Q(a|0);p()}$g(h,x[e+12>>2],c,x[e>>2]);b=le(e);OR(e);i=1}c=g+8|0;_g(c,x[vb(e,b)>>2],i);fb=e+16|0;rV(a,c);fb=g+16|0}function Ska(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Cu(a+484344|0);tf(a+1298308|0);tf(a+1298320|0);tf(a+1298332|0);ew(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=Ck(b);while(1){if((b|0)==(c|0)){break a}s0(b);b=b+160|0;continue}}d=x[b>>2];if(d){Db(Iv(d))}x[b>>2]=0;b=b+4|0;continue}}}else{un(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function FR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;gh(g,y[Rb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Sd(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=yb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[yb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=yb(j,b),p=i,w[o>>1]=p}o=m,p=Kd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;fb=h+16|0}function xt(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:500084;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124231]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+111520>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31600]=25;e=-1}return e}x[g>>2]=d;return-2}function bua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;e=b;b=x[a>>2];b=Gk(e,wb(b))+b|0;e=YD(c,d);a:{if((e|0)<=0){break a}g=x[zb(a)>>2];h=x[a+4>>2];if((e|0)<=(g-h|0)){x[f+12>>2]=d;g=h-b|0;if((g|0)<(e|0)){x[f+12>>2]=c;h$(f+12|0,g);XD(a,x[f+12>>2],d,e-g|0);if((g|0)<=0){break a}}g$(a,b,h,b+e|0);lp(c,x[f+12>>2],b);break a}g=zb(a);h=vn(f+12|0,bm(a,Sc(x[a>>2],h)+e|0),b-x[a>>2]|0,g);e=fb-16|0;fb=e;x[e+12>>2]=c;c=yC(e,h+8|0,YD(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){El(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;me(e+12|0);continue}break}he(c);fb=e+16|0;b=f$(a,h,b);tn(h)}wb(b);fb=f+32|0}function EQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;oh(e+8|0,b);f=fb-16|0;fb=f;mf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;l=h,m=wb(a),x[l+12>>2]=m;a=b;b=fb-16|0;fb=b;i=x[h+12>>2];c=i;d=x[c+8>>2];c=x[c+12>>2];a:{if((c|0)<0){break a}j=x[i+4>>2];k=d>>>0>j>>>0;if(k&!c|c){break a}x[b+8>>2]=j-d;x[b+12>>2]=0-(c+k|0);x[b>>2]=a;x[b+4>>2]=0;c=I0(b+8|0,b);if((Su(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}Wg(g,a+g|0,d+x[i>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function Si(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=c*d;k=b*e;h=j+k;l=b*d;m=c*e;i=l-m;a:{if(!Vi(i)){break a}if(!Vi(h)){break a}f=zf(b);g=zf(c);n=f|g;b:{if((n|0)!=1){break b}b=pi(f?1:0,b);c=pi(g?1:0,c);if(Vi(d)){d=pi(0,d)}if(!Vi(e)){break b}e=pi(0,e)}f=zf(d);g=zf(e);c:{if(f|g){d=pi(f?1:0,d);e=pi(g?1:0,e);if(Vi(b)){b=pi(0,b)}if(!Vi(c)){break c}c=pi(0,c);break c}if(n){break c}d:{if(zf(l)){break d}if(zf(m)){break d}if(zf(k)){break d}if(!zf(j)){break a}}if(Vi(b)){b=pi(0,b)}if(Vi(c)){c=pi(0,c)}if(Vi(d)){d=pi(0,d)}if(!Vi(e)){break c}e=pi(0,e)}h=(b*e+d*c)*Infinity;i=(b*d-e*c)*Infinity}Wl(a,i,h)}function NB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=g;x[c+12>>2]=d;while(1){if(pd(d,k)){d=Pp(d);g=Pp(x[c+8>>2]);l=x[d+4>>2];x[g>>2]=x[d>>2];x[g+4>>2]=l;d=Op(c+12|0);Op(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Hi(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;kg(f,g);a:{b:{if(Ed(y[Lm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;Os(88,e+24|0,f,b,c,d);b=x[31725];x[31725]=0;c:{if((b|0)!=1){b=gi(e+8|0,-1,-1);d=fo(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Jm(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}dk(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Tb()}p()}function rra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(a);while(1){a=c;c=z[a+14>>1];if(ep(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!ep(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Ch(d,Ec(20),Mg(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=le(d);dm(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=ip(x[e+8>>2]);fb=e+16|0;return a+2|0}function m_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(a);while(1){a=c;c=x[a+16>>2];if(pE(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!pE(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Ch(d,Ec(24),Mg(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=le(d);dm(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function ln(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;j=1;i=d&2147483647;l=i;k=(i|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|i>>>0>2147418112){break a}i=h&2147483647;if(!g&(i|0)==2147418112?e|f:(i|0)==2147418112&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(i|l)))){return 0}j=d&h;if((j|0)>0|(j|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}j=(a^e|c^g|(b^f|d^h))!=0}return j}function GL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Sb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((FL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]<0;g=x[a>>2];x[a>>2]=g&-33;b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(X0(a)){break b}}c=FL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(i){break a}}fb=f+208|0;return e}function Qt(a,b,c){var d=0,e=0;d=a,e=Bj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=Bj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function Nga(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Nd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31725]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=d+56|0;S(986,a|0,d+8|0,d|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=d+76|0;e=x[re(d+28|0,c)>>2];x[31725]=0;b=+pa(987,a|0,+b,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}ub(a);Vc(c);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Vc(d+76|0);Q(a|0);p()}function vX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);d=x[b+4>>2];if(d){_r(a,d);sn(c+8|0,x[b>>2]);er(c,x[b>>2],x[b+4>>2]);b=fb-32|0;fb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+tX(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}Ep(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;uX(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);fb=b+32|0}fb=c+16|0;return a|0}function qy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;bd(h,b);x[31725]=0;b=R(1217,x[f+12>>2])|0;g=x[31725];x[31725]=0;a:{if((g|0)==1){break a}x[31725]=0;V(1228,b|0,111728,111760,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=R(1218,x[f+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(1229,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[d>>2]=c;x[31725]=0;c=R(1226,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[e>>2]=c;x[31725]=0;O(1227,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(h);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function u8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;bd(a,x[c+28>>2]);x[31725]=0;b=R(1218,x[f+16>>2])|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){Zb(a);c:{if(e){ki(a,b);break c}ji(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=tl(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];Qb(a);break a}a=x[c>>2];x[31725]=0;P(1232,f+28|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){Je(f+12|0);continue}break}c=N()|0;Qb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function mA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=B[d>>2],B[l>>2]=m;d=Mi(c+12|0);Mi(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function wH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Gb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Vm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Vm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function Upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(z[x[x[a+48>>2]+12>>2]+480188>>1],f?b-c|0:c-b|0);d=wb(x[a+4>>2]);c:{if(f){d=vb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31725]=0;V(664,a|0,d|0,c|0,e+20|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}a=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(a|0)|0;Z();break b}c=vb(e+16|0,MD(d,c));d=x[vb(e+12|0,wb(x[a+4>>2]))>>2];f=x[c>>2];c=x[a>>2];c=D(wu(f,wb(c)),6)+c|0;if(Ib(f,d)){sD(a,uA(c+D(wu(d,f),6)|0,x[a+4>>2],c))}wb(c)}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function vy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;bd(h,b);x[31725]=0;b=R(28,x[f+12>>2])|0;g=x[31725];x[31725]=0;a:{if((g|0)==1){break a}x[31725]=0;V(1215,b|0,111728,111760,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=R(1201,x[f+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(1216,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}v[d|0]=c;x[31725]=0;c=R(1213,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}v[e|0]=c;x[31725]=0;O(1214,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(h);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function Zm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=x[d>>2],x[l>>2]=m;d=Mi(c+12|0);Mi(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=DU(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10073];d=c+32|0;x[d+8>>2]=x[10072];x[d+12>>2]=e;e=x[10071];x[d>>2]=x[10070];x[d+4>>2]=e;PB(d,h*+(b>>>0));yU(c+48|0,C[c+32>>3],C[c+40>>3]);d=Xd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Wl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;zA(f,0,g,c);fb=c- -64|0;return f|0}function E8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;bd(a,x[c+28>>2]);x[31725]=0;b=R(1201,x[f+16>>2])|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){Zb(a);c:{if(e){ki(a,b);break c}ji(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=Df(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];tb(a);break a}a=v[c|0];x[31725]=0;P(30,f+28|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){me(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function $g(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[ec(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Th(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Th(d)){ur(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;tr(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Th(d)){tr(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ur(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=zb(a);x[a>>2]=x[a>>2]+1}function m4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(ni(b,14276)){d=Ss(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31725]=0;b=P(36,c+4|0,b|0)|0;a=x[31725];x[31725]=0;c:{d:{e:{if((a|0)!=1){x[31725]=0;a=c+16|0;S(1017,a|0,17734,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}jq(e);fq(a+8|0,16781,x[d>>2]);fq(a+12|0,22267,x[d>>2]);x[31725]=0;O(274,a+16|0,22267);a=x[31725];x[31725]=0;if((a|0)==1){break b}ol(d)}fb=c+32|0;return}a=N()|0}ol(d);Q(a|0);p()}function gh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=Tg(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{Rw(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Mn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Rw(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;as(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function y3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-32|0;fb=k;m=x[c>>2];l=x[c+8>>2];c=x[c+4>>2];x[k+8>>2]=c;x[k+12>>2]=l;x[k+24>>2]=c;x[k+28>>2]=l;x[k+20>>2]=m;x[k+16>>2]=d;x[31725]=0;c=x[k+20>>2];x[k>>2]=x[k+16>>2];x[k+4>>2]=c;a=Ia(1100,a|0,b|0,k|0)|0;b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,10415,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}b=N()|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){Q(b|0);p()}T(0)|0;Tb();p()}return a|0}function Lm(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;v[a|0]=0;a:{d=x[b>>2];e=x[d-12>>2]+b|0;b:{if(!x[e+16>>2]){e=x[e+72>>2];if(e){In(e);d=x[b>>2]}c:{if(c){break c}c=x[d-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}d=f+12|0;bd(d,x[c+28>>2]);x[31725]=0;e=R(28,x[f+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Zb(d);c=wp(f+8|0,b);d=sc(f+4|0);while(1){d:{if(th(c,d)){break d}g=Bl(x[c>>2]);if(!Kf(x[e+8>>2],1,g)){break d}Km(c);continue}break}if(th(c,d)){dk(x[x[b>>2]-12>>2]+b|0,6)}d=x[b>>2]}v[a|0]=!x[(x[d-12>>2]+b|0)+16>>2];break b}dk(e,4)}fb=f+16|0;return a}a=N()|0;Zb(f+12|0);Q(a|0);p()}function $L(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(hf(a)){fc(a,31);return 0}g=a,h=hf(a),v[g+1375|0]=h;d=Aj(a);b=Aj(a);Aj(a);g=a,h=Aj(a),x[g+1112>>2]=h;Aj(a);c=hf(a);x[a+1116>>2]=c;if(!cz(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function hl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){xo(e,f,CG(f));rd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ac(8);x[31725]=0;b=R(163,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,28848,164);p()}function Jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function pua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[31725]=0;O(323,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=Jr(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);im(b);fb=c+16|0;break a}a=N()|0;im(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)==1){break c}x[31725]=0;W(1003,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}e=x[a+24>>2];b=qc(d+12|0,b);x[31725]=0;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=d+20|0;V(1015,c|0,e|0,d|0,1);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Bg(Jb(c));tb(c);break b}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,5535,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function N$(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function $d(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=gi(a,-1,-1);a:{b:{if(Ed(y[Lm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;Os(88,c+8|0,d,0,0,1);d=x[31725];x[31725]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Jm(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}dk(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Tb()}p()}function hN(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31725]=0;W(857,c|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=vb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;og(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Ug(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;ES(c+1298412|0);YA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);XA(c+1298304|0);WA(c+1298300|0);Pu(c+1298264|0);kB(c+1074376|0);DS(c+906300|0);_B(c+484360|0);vS(c+484344|0);uc(c+480248|0);break a}T(0)|0;Tb();p()}Db(c)}}function S4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a:{g=fb+-64|0;fb=g;h=g+16|0;eo(h,c);x[31725]=0;c=g+28|0;O(93,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=g+40|0;O(93,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;c=g+52|0;O(93,c|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}Tx(g+8|0,h);x[31725]=0;V(94,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}FI(h);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;FI(g+16|0)}Q(a|0);p()}}function Cta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if(Zc(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[_b(e,b)>>1];b:{if(!bj(a,b)){break b}c=x[a+24>>2];d=wb(x[c+484360>>2]);x[g+12>>2]=d;h=wb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=lm(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[_b(x[d>>2],f)>>1]){break c}c=WX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=_b(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[dr(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function w3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}e=x[a+24>>2];b=qc(c+8|0,b);x[31725]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Os(1023,e,c,f,d,1);d=x[31725];x[31725]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31725]=0;V(989,8642,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}return b|0}function dG(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=mr(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function Er(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;PE(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Yna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function OL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[496816]){f=496817,g=Qa()|0,v[f|0]=g;v[496816]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[496817]){break c}d=+Ga();break a}x[31600]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(nva(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function XQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=VQ(d);yc(VQ(x[c+8>>2]),d,2048);d=TQ(c+12|0);TQ(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function bia(a){a=a|0;var b=0,c=0,d=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Gc(ova(nva(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31725]=0;x[c+12>>2]=0;d=b;b=c+12|0;S(953,a+4264|0,d|0,b|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){d:{if(!y[a+4260|0]){break d}d=x[a+4316>>2];x[31725]=0;x[c+12>>2]=0;S(953,a+4276|0,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}b=T(125e3)|0;break c}x[c+12>>2]=0;b=c+12|0;vQ(a+4288|0,b);x[c+12>>2]=0;vQ(a+4300|0,b);break b}b=T(125e3)|0}if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function Hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function C$(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=aw(d);yc(aw(x[c+8>>2]),d,36);d=z$(c+12|0);z$(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function P6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=oc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){_q(a,e);break a}f=iq(a);d=Mf(a,oc(x[a>>2],c)+e|0);g=oc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Kg(b+12|0,f);b:{if(!d){f=0;d=0;break b}iJ(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=nc(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;jA(b,e);Zm(a,b);hQ(b);a=x[b>>2];if(a){by(x[b+16>>2],a,Tz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Ih(a,c+(b<<2)|0)}}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)==1){break c}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}e=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1020,e|0,d|0,(c|0)!=0|0,1);c=x[31725];x[31725]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10005,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(Bu(a)>>>0>=b>>>0){e=x[a>>2];g=pm(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Gb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=zR(e,c)+52|0;continue}break}if(b>>>0>g>>>0){pA(a,b-g|0,c);break a}uR(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Cu(a);d=x[a>>2];Bu(a);Db(d);h=zb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=tR(a,b);d=fb-16|0;fb=d;if(uh(82595524)>>>0<e>>>0){dd();p()}qR(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=zb(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;pA(a,b,c)}fb=f+16|0}function Hga(a){a=a|0;var b=0;b=8016;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22267;break a}b=8049;break a}b=18177;break a;case 0:b=5011;break a;case 9:b=8072;break a;case 10:b=8086;break a;case 11:b=5388;break a;case 12:b=5408;break a;case 19:b=8098;break a;case 20:b=8030;break a;case 21:b=12898;break a;case 22:b=12221;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6019;break a}b=7983}return Bg(b)|0}function Gn(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];pw(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;de(a,0,g+9|0);break a}d=y[g+15|0];e=xi(d);c=y[g+13|0];if(e>>>0>xi(c)>>>0){tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;de(a,d,g+14|0)}fb=g+16|0}function zQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Qi(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44748;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=yb(b,0),g=1056964608,x[f>>2]=g;f=yb(b,1),g=1036831949,x[f>>2]=g;f=yb(b,2),g=1038174126,x[f>>2]=g;f=yb(b,3),g=1065353216,x[f>>2]=g;f=yb(b,4),g=1061158912,x[f>>2]=g;f=yb(b,5),g=1059082943,x[f>>2]=g;f=yb(b,6),g=1061997773,x[f>>2]=g;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;uc(d);uc(c);ag(a);Q(b|0);p()}function Lt(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;k=!f;a:{b:{c:{d:{if((c|0)!=1){i=a;j=1;break d}i=a;j=1;if(d){break d}f=a;break c}while(1){f=i-x[(e<<2)+g>>2]|0;if((ro(f,a,b)|0)<=0){f=i;break c}l=k^-1;k=1;e:{if(!((l|(e|0)<2)&1)){l=x[((e<<2)+g|0)-8>>2];m=i-4|0;if((ro(m,f,b)|0)>=0){break e}if((ro(m-l|0,f,b)|0)>=0){break e}}x[(j<<2)+h>>2]=f;c=ML(c,d);Mt(h+232|0,c);j=j+1|0;e=c+e|0;i=f;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}f=i;break b}if(!k){break a}}LL(h,j);_y(f,b,e,g)}fb=h+240|0}function Gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function x3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31725]=0;W(1003,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}c=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=kI(c,d,1);e=x[31725];x[31725]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31725]=0;V(989,8673,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}gb=a;return b|0}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(lc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=lc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(sr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((zt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function ir(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vs(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function Mra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31725]=0;c=U(152,d|0,c|0,1)|0;d=x[31725];x[31725]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31725]=0;W(518,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(199,a|0)|0;d=x[31725];x[31725]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31725]=0;d=e+15|0;f=P(519,a|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}g=f;f=y[e+15|0];if(g&f>>>0<64){yc(hZ(x[b>>2],f),d,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vs(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function j9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(lc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Sk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=sr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Sk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Sk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Ly(b);break a}d=-1}fb=c+32|0;return d|0}function Y_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function Vp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vs(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function Qv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function wz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{b:{if(c){x[31725]=0;O(1141,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=Tg(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){hc(d);fb=f+16|0}else{x[c>>2]=0;sc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Qd(c);ch(c);fb=e+16|0;break a}a=N()|0;ch(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=tS(b);continue}break}x[f>>2]=c;Io(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function FK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}f=a&255;c=(f>>>0)/3|0;g=x[((D(c,-3)+a&255)<<2)+99048>>2];e=c;c=a>>>8|0;d=x[(((D(g,y[(e+D(y[c+100432|0],86)|0)+100432|0])>>>11>>>0)%6|0)+y[c+103104|0]<<2)+99072>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;i=y[(e<<1)+100032|0];if((i|0)==(f|0)){c=x[(y[(e<<1)+100033|0]<<2)+99072>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}g=e;e=f>>>0<i>>>0;c=e?c:g;d=e?h:d-h|0;if(d){continue}break}}return a}function ss(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b|0){case 0:x[31725]=0;b=P(1,d+4|0,15899)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Ab(a,b);tb(b);break b;case 1:x[31725]=0;b=P(1,d+4|0,15924)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 2:x[31725]=0;b=P(1,d+4|0,15872)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[31725]=0;b=P(1,d+4|0,15846)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Ab(a,b);tb(b)}fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function sV(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;cC(a+48|0);cC(a+68|0);cC(a+88|0);cv(a+492|0);cv(a+524|0);kk(a,0,0);jk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Jv(a,b);b=a+108|0;d=NC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function pga(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(e+8|0,b);x[31725]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1022,d|0,e|0,+c,1);d=x[31725];x[31725]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5926,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Zna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(oo(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Sk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=sr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Sk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Sk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=oo(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function N6(a){a=a|0;if(y[500512]){return x[125127]}if(!y[501616]){v[501616]=1}wd(501328,120492);wd(501340,120524);wd(501352,120560);wd(501364,120584);wd(501376,120608);wd(501388,120624);wd(501400,120644);wd(501412,120664);wd(501424,120692);wd(501436,120732);wd(501448,120764);wd(501460,120800);wd(501472,120836);wd(501484,120852);wd(501496,120868);wd(501508,120884);wd(501520,120608);wd(501532,120900);wd(501544,120916);wd(501556,120932);wd(501568,120948);wd(501580,120964);wd(501592,120980);wd(501604,120996);v[500512]=1;x[125127]=501328;return 501328}function m9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(oo(b)){if(d){break a}b=x[a+48>>2];e=a,f=oo(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(sr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((zt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(712,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Qd(b);KW(b);fb=d+16|0;return a|0}a=N()|0;KW(d+8|0);Q(a|0);p()}function SX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Av(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=Av(a);a=a+34|0;if(b){continue}break}}return d}function wD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(pr(y[a+1|0]),c)|0}return c}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!h){Pc(e,a+32|0,5);c=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;Cq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Gb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;tz(g+8|0,f);f=x[g+12>>2];if(hq(-1,2147483647,c,0)^1){i=hq(c,0,0,-2147483648)^1}else{i=0}if(i){Hi(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}gf(a,d);fb=e+16|0}function ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-48|0;fb=d;c=d+28|0;ak(c,b,1819307379);hd(a+40|0,c);ub(c);ak(c,b,1953721961);hd(a+60|0,c);ub(c);ak(c,b,543520099);hd(a+120|0,c);ub(c);ak(c,b,1414744396);x[31725]=0;e=P(414,c|0,13830)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){b:{if(e){x[31725]=0;e=d+8|0;S(811,e|0,c|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break b}yv(a+140|0,e);ie(e)}x[31725]=0;S(812,d+8|0,b|0,1634890872);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;hd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function ww(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);vw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Rh(a,g);tb(g);fb=f+16|0}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[31725]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1013,d|0,c|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5963,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Wna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)==1){break c}x[31725]=0;W(1003,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1009,c|0,d|0,1)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10036,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;h=z[c>>1];i=c;e=fb-16|0;fb=e;g=b;d=ce(b);a:{if(d){c=ec(b);while(1){b=d;d=z[b+14>>1];if(cl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!cl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(g);d=Ch(e,Ec(16),Mg(b+8|0,d));fj(x[d>>2]+14|0,z[i>>1]);k=ec(d),l=1,v[k+4|0]=l;fb=b+16|0;$g(g,x[e+12>>2],c,x[e>>2]);b=le(e);dm(e);j=1}c=f+8|0;_g(c,x[vb(e,b)>>2],j);fb=e+16|0;rV(a,c);fb=f+16|0}function mF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;tf(a);Bs(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Gb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=As(Ft(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Gb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[cc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=cc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function Xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;yS(a+946304|0);f=a+906300|0;g=Ck(f);d=e+48|0;Sb(d,0,160);d=AS(d);x[31725]=0;S(864,f|0,g|0,d|0);f=x[31725];x[31725]=0;a:{if((f|0)!=1){UA(d);d=Ge(e+28|0,b);x[31725]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(865,a|0,e+8|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;UA(d)}ub(b);Q(a|0);p()}function HT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=-1;a:{if(!(y[b+851|0]&2)){break a}d=!(y[a+480209|0]&32);b:{c:{d:{c=x[b+656>>2];e:{if(c){e=y[c+22|0];if(Cd(e)){g=b,h=Vh(e),v[g+838|0]=h;d=1}e=y[c+21|0];f:{if(Cd(e)){g=b,h=Vh(e),v[g+837|0]=h;break f}if(!d){break d}}d=1;c=y[c+25|0];if((c|0)==255){break e}v[b+845|0]=c;break e}x[b+776>>2]=0;x[b+780>>2]=0}c=b+837|0;if(y[b+837|0]>=127){break c}if(d){break b}break a}if(y[b+837|0]<127){break a}d=0;c=b+837|0}if(!d|!Ob(a+1074312|0,36)){break a}}f=Oq(a,b,1,256);if((f|0)<0){break a}f=y[c|0]>>>1|0}return f}function gz(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];bM(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);bM(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87680>>2];i=B[d+87692>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87688>>2];d=5-a<<2;m=B[d+87680>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function jx(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){ai(a);break a}wm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=wm(b+8|0,x[d>>2],x[d+4>>2]);x[31725]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(168,e+40|0,b|0,c|0,g|0);c=x[31725];x[31725]=0;b:{if((c|0)!=1){ke(d);fb=b+16|0;break b}a=N()|0;ke(d);Q(a|0);p()}b=Nd(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;Rp(a,e+8|0,e)}fb=e+48|0}function dC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!lc(c,x[a+4>>2])){w[c>>1]=0;Qf(c+2|0,b);f=d,g=Lk(wb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=wb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[qe(c,Lk(c,-1))>>1],w[f>>1]=g;Qf(c+2|0,b);AW(d+12|0);continue}else{Qf(a+14|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+13|0,y[a+14|0]);Qf(a+16|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}Qf(a+17|0,Sd(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function Fo(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}f=c>>31;d=f;d=(d^c)-d|0;if(d>>>0<224){break c}Kb(e+8|0,a+1074312|0,3);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,(c|0)!=0|f);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Kb(e+8|0,a+1074312|0,3);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Jq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function Es(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;pH(g,c,72);x[31725]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;RV(b,c,x[e+52>>2]);x[31725]=0;d=e+28|0;V(301,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;f=e+40|0;S(302,f|0,d|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break c}Rh(a,f);tb(f);tb(d);tb(b);tb(c);Hh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function una(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38146>>1])+D(w[f-2>>1],w[e+38144>>1])|0)+D(w[f+2>>1],w[e+38148>>1])|0)+D(w[f+4>>1],w[e+38150>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function tsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Ok(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){tD(a,d,c);break a}b=zb(a);b=zZ(e+12|0,oD(a,Ok(x[a>>2],f)+d|0),Ok(x[a>>2],x[a+4>>2]),b);yZ(b,d,c);c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);f=vb(c+8|0,x[a>>2]);g=vb(c+4|0,x[b+4>>2]);h=b,i=vZ(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0;xZ(b)}fb=e+32|0;return}if(b>>>0<d>>>0){sD(a,e+D(b,6)|0)}}function bq(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;pH(g,c,3);x[31725]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;RV(b,c,x[e+52>>2]);x[31725]=0;d=e+28|0;V(19,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;f=e+40|0;S(20,f|0,d|0,g|0);h=x[31725];x[31725]=0;if((h|0)==1){break c}Rh(a,f);tb(f);tb(d);tb(b);tb(c);Hh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function oS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){XE(a,b,h);break b}c=zb(a);c=$f(f+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=Mn(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Do(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=g+16|0;Zm(a,c);_f(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}QA(a);fb=e+16|0}function n1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;ld(b,0);f=e+8|0;lk(f,1,a+33|0);d=e+20|0;Cc(d,f);ze(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Rb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{g=fb-32|0;fb=g;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];f=x[b>>2];x[31725]=0;e=U(152,f|0,e|0,8)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(e){x[31725]=0;e=g+4|0;S(913,e|0,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;O(914,a|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}Gd(e);f=e;e=Mr(x[a+4>>2]);wi(f,x[e>>2],x[e+4>>2]);if(x[g+4>>2]!=(d|0)){continue}}break}fb=g+32|0;break a}b=N()|0;break b}b=N()|0;Gd(g+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function Dj(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Ed(y[Lm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=U(87,d|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Jm(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}dk(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Tb()}p()}function vZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;b=x[d+24>>2];i=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,i)){b=uZ(b);c=uZ(x[a+8>>2]);f=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;b=nD(a+12|0);nD(a+8|0);b=x[b>>2];continue}break}Ac(h,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(g,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;c=P(651,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(652,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31725]=0;S(187,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Uk(a,e)}Gd(e);fb=d+80|0}function KQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Zz(a);c=Pd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;pu(a);return;case 3:v[a+4240|0]=c>=E(.5);pu(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Rl(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=fk(b+12|0,b+8|0,b+4|0);fb=b+16|0;x[a+4232>>2]=x[d>>2];return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Xz(a)}C[a+4256>>3]=c;break;default:break a}}}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;VT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;hc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=zb(a);h=f+12|0;e=FB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=uh(613566756);if(e>>>0<=d>>>0){e=GB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}dd();p()}c=YT(h,d,FB(x[a>>2],x[a+4>>2]),g);VT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;XT(a,c);WT(c);fb=f+32|0}function M1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=hl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}cs(c+4|0,hl(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}cs(c+4|0,d-e|0);break b}QF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}QF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38146>>1])+D(v[f-1|0],w[e+38144>>1])|0)+D(v[f+1|0],w[e+38148>>1])|0)+D(v[f+2|0],w[e+38150>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function qF(a){var b=0,c=0,d=0,e=0,f=0;a:{b=y[a|0]|y[a+1|0]<<8;b:{if((b|0)!=26217){if((b|0)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}b=a+110|0;c=a+2|0;while(1){if((b|0)==(c|0)){while(1){c=(e|0)==128;if(c){break a}b=a+e|0;d=v[b+113|0];if((d|0)<-2){break a}f=y[b+241|0];if(!f&(d|0)>=0|f>>>0>15){break a}e=e+1|0;if(y[b+369|0]<64){continue}break a}}c:{if((y[c|0]-1&255)>>>0>30){break c}d=d+1|0;if((d&255)>>>0<=40){break c}return 0}c=c+1|0;continue}}return c}function Dra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Tf(d+52|0);x[31725]=0;e=P(523,b|0,c|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(524,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31725]=0;S(187,d+12|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(c);Q(a|0);p()}b=d+12|0;e=ic(d+32|0,b);hd(c+8|0,e);ub(e);ub(b);YY(a,c)}Gd(c);fb=d+80|0}function VW(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=ZW(a+20|0)}return c}function xR(a,b,c,d){var e=0,f=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);while(1){if((b|0)!=(c|0)){Do(x[e+44>>2],x[b>>2]);x[e+44>>2]=x[e+44>>2]+4;b=b+4|0;continue}break}Qe(e+24|0);d=x[e+44>>2];if(!y[e+36|0]){b=fb-16|0;fb=b;a=vb(b+12|0,x[x[e+32>>2]>>2]);f=x[vb(b+8|0,x[x[e+28>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[a>>2];x[c+12>>2]=a;while(1){if(pd(a,f)){rA(a);a=x[Mi(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}fb=e+48|0;return d}function sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=dj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Vh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Jb(a);e=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;g=Eh(x[ad(e,c+12|0)>>2])+1|0}else{g=2147483631}sg(e,g);e=x[c+4>>2];if(d){Cg(e,f,d)}if((d|0)!=10){Db(f)}yd(a,e);pf(a,x[c+8>>2]);fb=c+16|0;break e}qf();p()}c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function L1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=hl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}cs(c+4|0,hl(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}cs(c+4|0,d-e|0);break b}PF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}PF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function pta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,8)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}if(c){x[31725]=0;c=e+4|0;O(409,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(410,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}Gd(c);d=c;c=Mr(x[a+4>>2]);wi(d,x[c>>2],x[c+4>>2]);if(($b(x[e+4>>2])|0)!=1162757187){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Gd(e+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function pP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;g=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){c=x[b+24>>2];if(z[c+480188>>1]<=a>>>0){break a}x[31725]=0;f=d+8|0;O(1058,f|0,(c+(a<<5)|0)+480289|0);c=x[31725];x[31725]=0;if((c|0)!=1){e=x[b+24>>2];x[31725]=0;c=d+20|0;S(1059,c|0,e|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;O(180,g|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}a=a+1|0;tb(c);tb(f);continue}break}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0)}Td(g);Q(a|0);p()}fb=d+32|0}function nua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function Uc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+4>>2]=1211;x[b>>2]=a;x[b+8>>2]=0;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=vb(c+8|0,yf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){yd(a,1);b=x[x[b>>2]>>2];x[31725]=0;W(1212,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;yd(a,0);x[31725]=0;X(86);a=x[31725];x[31725]=0;c:{if((a|0)==1){a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break c}T(0)|0;Tb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function BN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=zq(a);d:{if(!e){if(yq(a)>>>0<=b>>>0){break d}a=ti(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ac(8);x[31725]=0;b=P(36,d+4|0,6e3)|0;c=x[31725];x[31725]=0;e:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;o(+b);g=j(1)|0;c=j(0)|0;d=g&2147483647;f=d+-1048576|0;a:{if((f|0)==2145386495|f>>>0<2145386495){h=c<<28;c=(d&15)<<28|c>>>4;d=(d>>>4|0)+1006632960|0;break a}if((d|0)==2146435072|d>>>0>2146435072){h=c<<28;c=(g&15)<<28|c>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}f=c;c=d?G(d):G(c)+32|0;bg(e,f,d,0,0,c+49|0);i=x[e>>2];h=x[e+4>>2];f=15372-c<<16;c=x[e+8>>2];d=f|x[e+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=e+16|0}function ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);b:{d=Zc(x[b>>2],x[b+4>>2]);if(!d){break b}x[31725]=0;O(642,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31725]=0;$U(a,f,e,d);d=x[31725];x[31725]=0;if((d|0)!=1){break b}}a=N()|0;_j(c+8|0);Q(a|0);p()}d=c+8|0;Qd(d);_j(d);fb=c+16|0;x[31725]=0;P(3,a+12|0,b+12|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;md(a);Q(b|0);p()}}function XW(a,b,c,d,e,f){b=y[(b&15)+25392|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}wc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function Qpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,8)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}if(c){x[31725]=0;c=e+4|0;O(682,c|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(683,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}Gd(c);d=c;c=Mr(x[a+4>>2]);wi(d,x[c>>2],x[c+4>>2]);if(x[e+4>>2]!=1413891155){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Gd(e+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function Oga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Ik(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Ik(E(E(c>>>0)*E(1.1892070770263672)));e=Ik(E(E(d>>>0)*E(1.1892070770263672)));h=Ik(E(E(e>>>0)*E(1.1892070770263672)));f=Ik(E(E(c+e>>>0)*E(.11546666920185089)));g=Ik(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=yb(b,0),j=c-f|0,x[i>>2]=j;i=yb(b,1),j=e-f|0,x[i>>2]=j;i=yb(b,2),j=d-g|0,x[i>>2]=j;i=yb(b,3),j=h-g|0,x[i>>2]=j;i=yb(b,4),j=f,x[i>>2]=j;i=yb(b,5),j=g,x[i>>2]=j;ZP(a);YP(a)}function Fqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-608|0;fb=b;c=fb-16|0;fb=c;d=b+8|0;fY(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){eY(d)}c=-1;a:{if(!e){break a}c=0;if(!gY(d)){break a}c=-1;if(!lh(a,1024)){break a}c=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;PC(d+8|0,e);f=x[d+12>>2];od(d,a,x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((f|0)==(g|0)){gd(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){c=QC(e,0)>>>0<17}fb=e+1024|0}fb=b+608|0;return c|0}function QS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}f=x[a+480208>>2]&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(g){if(e&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));Fe(d+12|0,0,256);x[a>>2]=x[d+12>>2]}fb=d+16|0}function EB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return Pq(a,b)}return Sl(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Sl(Pq(c,a),D(a,-100)+b|0)}return zB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return zB(Pq(c,a),D(a,-1e4)+b|0)}return xB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return xB(Pq(c,a),D(a,-1e6)+b|0)}return Qu(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Qu(Pq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Qu(Sl(c,a),D(a,-1e8)+b|0)}function hua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;ld(b,0);e=c+8|0;lk(e,1,a);d=c+20|0;Cc(d,e);ze(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Rb(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function Gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Tf(c+52|0);x[31725]=0;e=P(689,b|0,d|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(690,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31725]=0;S(187,c+12|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(d);Q(a|0);p()}b=c+12|0;e=ic(c+32|0,b);hd(d+8|0,e);ub(e);ub(b);Uk(a,d)}Gd(d);fb=c+80|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);NN(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=qi(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(305,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function Psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);fC(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=qi(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(47,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function z6(a){a=a|0;if(y[500504]){return x[125125]}if(!y[501312]){v[501312]=1}id(501024,5034);id(501036,5025);id(501048,10875);id(501060,10619);id(501072,5261);id(501084,11652);id(501096,5118);id(501108,5609);id(501120,8886);id(501132,8869);id(501144,8877);id(501156,8896);id(501168,10073);id(501180,13314);id(501192,8959);id(501204,7714);id(501216,5261);id(501228,9762);id(501240,10478);id(501252,10887);id(501264,9249);id(501276,6463);id(501288,5492);id(501300,13232);v[500504]=1;x[125125]=501024;return 501024}function bP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}Ao(b,a);x[31725]=0;c=R(1062,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[b+12>>2]=c;of(b);d=x[a+40>>2];c=x[a+36>>2]}c=(f=a+36|0,g=x[b+12>>2],h=Ib(c,d),h?f:g);a=x[a+8>>2];c:{if((a|0)==-1){f=b,g=wb(x[c>>2]),x[f>>2]=g;a=wb(x[c+4>>2]);while(1){c=x[b>>2];if(!Ib(c,a)){break c}e=e+C[c>>3];fA(b);continue}}e=C[wf(x[c>>2],a)>>3]}Fl(b+12|0);fb=b+16|0;return+e}a=N()|0;of(b);Q(a|0);p()}function w1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;d=b+12|0;a:{if(!eF(a,d)){break a}b:{if(dF(d)){if(gd(a,32)){break b}break a}c=0;if(!cF(b+12|0)){break a}}e=b+7|0;d=bF(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Gb(c+28|0,c+8|0)>>2];if(!lh(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;gk(f,e);g=gc(c+16|0,x[c+8>>2],d);od(c,a,x[g>>2],x[g+4>>2]);gk(f,e);Sb(x[c+8>>2]+d|0,0,5-d|0);gd(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=aF(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function mV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function Q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(nh(a,x[b+8>>2],e)){Nx(b,c,d);return}a:{if(nh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function Pv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;h=fb-16|0;fb=h;c=gc(h+8|0,x[g+8>>2],x[g+12>>2]);f=fb-16|0;fb=f;b=122;x[f+12>>2]=122;d=x[c+4>>2];a:{if(!d){d=x[c>>2];break a}e=32-d|0;x[f+8>>2]=e;b=x[c>>2];i=x[b>>2];j=e;e=x[Gb(f+8|0,f+12|0)>>2];x[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=x[f+12>>2];d=b+4|0;x[c>>2]=d;b=i-e|0}e=d;d=b>>>5|0;IF(e,d);b=b&31;x[f+12>>2]=b;if(b){e=c;c=x[c>>2]+(d<<2)|0;x[e>>2]=c;x[c>>2]=x[c>>2]&(-1>>>32-b^-1)}fb=f+16|0;fb=h+16|0;fb=g+16|0;return a}function uH(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Tf(e+52|0);x[31725]=0;d=P(d|0,b|0,f|0)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31725]=0;S(187,e+12|0,b|0,$b(c)|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(f);Q(a|0);p()}b=e+12|0;c=ic(e+32|0,b);hd(f+8|0,c);ub(c);ub(b);Uk(a,f)}Gd(f);fb=e+80|0}function qqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,26);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function hI(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Ud(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Hd(f,0);break e}x[31725]=0;P(d|0,h|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}f=Hd(x[b>>2],a)}x[31725]=0;i=g+4|0;O(e|0,i|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;P(d|0,h|0,i|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}a=a+1|0;tb(i);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function zK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[31600];x[31600]=0;Od();a=yK(a,e+12|0,d);d=hb;d:{f=x[31600];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[31600]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}fb=e+16|0;return b}function en(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function Xra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);d=x[a+4>>2];x[31725]=0;O(503,d|0,b|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Xp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31725]=0;O(503,e|0,b|0);b=x[31725];x[31725]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;ux(a,c);ys(c);fb=d+32|0;break b}a=N()|0;ys(c);Q(a|0);p()}}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{if((d|0)==1){break a}x[31725]=0;W(1074,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31725]=0;b=Ya(1075,d|0,E(e),b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31725]=0;V(989,10353,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function O4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(ut(a)){break c}}if(m){if(tt(a)){break c}}if(l){if(st(a)){break c}}if(k){if(rt(a)){break c}}if(j){if(qt(a)){break c}}if(i){if(pt(a)){break c}}if(h){if(Nh(a)){break c}}if(g){if(ot(a)){break c}}if(f){if(nt(a)){break c}}if(!e){break b}if(!mt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;ld(b,0);d=e+8|0;ND(d,a+1|0);c=e+20|0;Cc(c,d);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=e+32|0}function fn(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=d<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Zk(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}Dp(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Fh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function Pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=fb-16|0;fb=e;g=x[c+4>>2];h=x[c+8>>2];f=Wj(g,h);a:{if(f>>>0<=dp(d)>>>0){j=h;k=x[d>>2];i=Sc(k,x[d+4>>2]);l=i>>>0>=f>>>0;if(!l){x[e+12>>2]=g;b$(e+12|0,i);j=x[e+12>>2]}i=Wg(g,j,k);if(!l){vv(d,j,h,f-Sc(x[d>>2],x[d+4>>2])|0);break a}or(d,i);break a}Zv(d);al(d,bm(d,f));vv(d,g,h,f)}fb=e+16|0}yc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function oH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);fC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function eH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);NN(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function zH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);fC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Ks(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=rO(a);x[a+8>>2]=0;x[a>>2]=47692;x[31725]=0;i=R(856,104)|0;h=x[31725];x[31725]=0;a:{b:{c:{d:{if((h|0)!=1){x[31725]=0;d=R(1105,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31725]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}x[a+8>>2]=b;Vc(d);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Vc(g+8|0)}Db(i)}Um(a);Q(b|0);p()}function Fga(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Bg(22267);break b}x[31725]=0;c=P(36,b+8|0,a|0)|0;a=x[31725];x[31725]=0;c:{d:{if((a|0)!=1){x[31725]=0;d=b+20|0;O(988,d|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}a=Bg(Jb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31725]=0;V(989,11015,0,0,0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function YF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=f;a:{if(!f){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){d=x[c>>2]}else{x[e+12>>2]=d-16;d=x[ad(c,e+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{c:{if(!WF(d,c)){d=x[b+84>>2];break c}d=x[b+84>>2];if(x[b+80>>2]!=x[c+12>>2]){break c}b=1;if(x[c+16>>2]==(d|0)){break b}}b=0;if(x[c+8>>2]!=(d|0)){break a}}g=a,h=D((x[c>>2]-d|0)+(b?112:48)|0,dl(z[c+34>>1]))+f|0,x[g+4>>2]=h}fb=e+16|0}function Uo(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26192|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function Goa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Nr(g,c);x[31725]=0;c=f+24|0;O(598,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=f+36|0;O(598,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}qx(f+4|0,g);x[31725]=0;V(303,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Zn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Zn(f+12|0)}Q(a|0);p()}}function AN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=zq(a);d:{if(!c){if(yq(a)>>>0<=b>>>0){break d}c=(y[ti(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ac(8);x[31725]=0;b=P(36,d+4|0,6e3)|0;c=x[31725];x[31725]=0;e:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function oP(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);ge(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31725]=0;O(178,e|0,lM(d,b)|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((lM(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31725]=0;b=P(36,c+12|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(180,e|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Td(e);Q(a|0);p()}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;a:{b:{c:{d:{if(g=Ad(x[b+4>>2],y[b+11|0]),h=1,i=x[b+12>>2],i?g:h){Fb(a);break d}c=Cb(x[b+4>>2],y[b+11|0]);e=d+20|0;f=hs(14294);hm(Xg(Xg(Jb(Fz(e,c+f|0)),Jb(b),c)+c|0,14294,f)+f|0,1,0);x[31725]=0;c=d+8|0;O(128,c|0,b+12|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;S(2,a|0,e|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(c);tb(e)}fb=d+32|0;return}b=N()|0;break a}b=N()|0;tb(d+8|0)}tb(d+20|0);Q(b|0);p()}function P2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Vp(g,c);x[31725]=0;c=f+24|0;O(135,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=f+36|0;O(135,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}qx(f+4|0,g);x[31725]=0;V(94,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Zn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Zn(f+12|0)}Q(a|0);p()}}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(ut(a)){break b}}if(m){if(tt(a)){break b}}if(l){if(st(a)){break b}}if(k){if(rt(a)){break b}}if(j){if(qt(a)){break b}}if(i){if(pt(a)){break b}}if(h){if(Nh(a)){break b}}if(g){if(ot(a)){break b}}if(f){if(nt(a)){break b}}if(e){if(mt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Js(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=rO(a);x[a+8>>2]=0;x[a>>2]=47692;x[31725]=0;h=R(856,104)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){x[31725]=0;c=R(1105,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=f+8|0;g=x[re(f+12|0,c)>>2];x[31725]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}x[a+8>>2]=b;Vc(c);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Vc(f+8|0)}Db(h)}Um(a);Q(b|0);p()}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=Hf(a,c);$d(e,x[a+36>>2]);h=a;a:{if(!f){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];ul(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;Kl(b,x[Gb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;Cq(g,d+4|0);a=x[b>>2];i=yb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}gf(h,c);fb=e+16|0}function et(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((tp(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=my(i+4|0,b,f);h=Jb(f);x[31725]=0;h=U(1235,a|0,h|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}Qb(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((tp(a,c,b)|0)!=(b|0)){break b}}qE(e);j=a}fb=i+16|0;return j|0}a=N()|0;Qb(f);Q(a|0);p()}function vN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;d=P(36,d+8|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(D(b,872)+a|0)+1075684|0,f=Zi(C[Yg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function eS(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!je(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){un(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Zk(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}fb=d+32|0;return f>>>0<3999}function lsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;d=c+12|0;f=Nb(d+8|0);x[31725]=0;e=R(204,b|0)|0;g=x[31725];x[31725]=0;a:{b:{if((g|0)==1){break b}x[31725]=0;S(171,d|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}e=x[d>>2];x[31725]=0;P(185,b|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;dc(f);Q(a|0);p()}Sn(c+4|0,d);x[31725]=0;S(477,a|0,x[c+4>>2],x[c+8>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(d);fb=c+32|0;return}a=N()|0;Kc(c+12|0);Q(a|0);p()}function TM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=TA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=TA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function M7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=zn(a);f=Sd(b,c);a:{if(!f){break a}b:{if(!KJ(a,b)){if(d-e>>>0<f>>>0){gy(a,d,(e-d|0)+f|0,e,e,0)}d=Jb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=io(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31725]=0;U(1253,a|0,c|0,Cb(d,e)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Qb(b);break a}a=N()|0;Qb(b);Q(a|0);p()}yd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function nV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(i|0)){break b}while(1)if((b|0)>=(e|0)){b=x[a+8>>2]-1|0;c:{if(!((b|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:b;break c}c=c+d|0}f=D(e,g)+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function bg(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){e=f+-64|0;f=b;d=e&31;if((e&63)>>>0>=32){e=f<<d;d=0}else{e=(1<<d)-1&f>>>32-d|c<<d;d=f<<d}b=0;c=0;break a}if(!f){break a}h=d;g=f&31;if((f&63)>>>0>=32){i=d<<g;h=0}else{i=(1<<g)-1&h>>>32-g|e<<g;h=h<<g}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;d=c>>>d|0}else{e=c>>>d|0;d=((1<<d)-1&c)<<32-d|g>>>d}d=h|d;e=e|i;h=b;g=f&31;if((f&63)>>>0>=32){i=b<<g;b=0}else{i=(1<<g)-1&h>>>32-g|c<<g;b=h<<g}c=i}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;f=e+8|0;aj(f,2,a+2|0);d=e+20|0;Cc(d,f);zc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;FR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);FR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=e+32|0}else{d=y[(a+c|0)+31|0];h=_b(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function MX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);e=x[d>>2];kc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Vb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=Mc(a);f=Wj(b,c);a:{if(!f){break a}b:{if(!Lz(a,b)){if(d-e>>>0<f>>>0){Wm(a,d,(e-d|0)+f|0,e,e,0,0)}d=Jb(a)+e|0;while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=si(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31725]=0;U(1246,a|0,c|0,Cb(d,e)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;lk(e,1,a+33|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Rb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function ox(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){b=fb-16|0;fb=b;a=sG(b+4|0,a);c=x[a+4>>2];x[31725]=0;W(166,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=b+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=zb(a);b=qG(c+12|0,rG(a,is(x[a>>2],x[a+4>>2])+1|0),is(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31725]=0;W(166,d|0);d=x[31725];x[31725]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;oG(a,b);cx(b);fb=c+32|0;break b}a=N()|0;cx(b);Q(a|0);p()}}function kp(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;f=(y[xb(b,0)|0]&15)<<8|y[xb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{h=e<<1;d=z[h+31104>>1];if(f>>>0>=d>>>0){if(!e|(f|0)==(d|0)|(z[h+31102>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=y[xb(b,2)|0];d=y[xb(b,0)|0];v[c+3|0]=0;v[c+1|0]=d&16|e>>>4;c=y[xb(b,2)|0];i=g,j=y[xb(b,3)|0],v[i+15|0]=j;de(a,c&15,g+15|0);fb=g+16|0}function sS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function zA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Xd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;zA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Xd(x[a>>2],c);Si(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;zA(a,b|c,f,e)}fb=e+48|0}function Vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(a);while(1){a=d;d=z[a+16>>1];if(ep(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!ep(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){EZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=le(c);DZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function iR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(a);while(1){a=d;d=z[a+16>>1];if(br(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!br(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){EZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=le(c);DZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];kg(x[x[d>>2]-12>>2]+d|0,0);d=x[b>>2];g=x[d+8>>2];e=x[d+12>>2];if(g|e){h=x[a+36>>2];e=x[a+20>>2]+e|0;d=x[a+16>>2];g=g+d|0;e=gi(f+32|0,g,d>>>0>g>>>0?e+1|0:e);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;_m(h,f)}d=f+16|0;$d(d,x[a+36>>2]);WB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=xl(d,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=f+48|0}function cI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;x[31725]=0;W(1002,a|0);j=x[31725];x[31725]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31725]=0;k=h;h=i+4|0;ga(k|0,h|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Bg(Jb(h));tb(h);break b}}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,g|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Iqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!Cm(a,1084)){break a}cm(a,1080);c=d+60|0;tY(a,c);f=sY(d+40|0);b=0;if(!rY(c,f)){break a}cm(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!qY(a,g)|!c){break b}Dv(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];tg(xb(i,c),xb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=WC(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Zi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=ova(nva(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;QM(a,c);fb=c+16|0}function mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Zi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=ova(nva(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;KM(a,c);fb=c+16|0}function bI(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;x[31725]=0;W(1002,a|0);i=x[31725];x[31725]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31725]=0;j=g;g=h+4|0;ja(j|0,g|0,i|0,b|0,c|0,d|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Bg(Jb(g));tb(g);break b}}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,f|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function RN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-bu(d|1,e)|0,1233)>>>12|0;j=(i<<3)+124032|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=EB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=pva(d,e,1410065408,2);f=nva(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=EB(b,c)}c=pva(d,e,1e8,0);e=hb;b=Sl(b,c);c=nva(c,e,-1e8,0)+d|0;c=Qu(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=zn(a);e=Sd(b,c);if(d>>>0<e>>>0){if(KJ(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);gy(a,g,h,d,0,d)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=io(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31725]=0;S(1358,a|0,c|0,Cb(e,d)|0);c=x[31725];x[31725]=0;if((c|0)!=1){Qb(b);break a}a=N()|0;Qb(b);Q(a|0);p()}yd(d,0);ng(a,e)}fb=f+16|0;return a|0}function ts(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Xg(a,d,b)+b|0,0);break a}e=a;a=Vh(y[a+11|0]);Yq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=dj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Xg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Yq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function sP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=Mc(a);e=Wj(b,c);if(d>>>0<e>>>0){if(Lz(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);Wm(a,g,h,d,0,d,0)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=si(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31725]=0;S(74,a|0,c|0,Cb(e,d)|0);c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e)}fb=f+16|0;return a|0}function ow(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Cg(a,d,b)+b|0,0);break a}e=a;a=Vh(y[a+11|0]);eq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=dj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Cg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];eq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Sc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){d=wb(c);g=wb(x[x[a+20>>2]+8>>2]);Qr(b+8|0,a+4228|0);f=wb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;Id(c+24|0,d,g);xn(c+16|0,x[c+24>>2],x[c+28>>2],f);d=d$(d,x[c+16>>2]);h=c,i=WD(f,x[c+20>>2]),x[h+12>>2]=i;Ac(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}aA(a,a)}ku(a);fb=b+16|0}function wY(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=gi(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;_m(i,g)}e=g+16|0;$d(e,x[a+36>>2]);dR(d,x[a+36>>2],c);c=x[b>>2];b=xl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=g+48|0}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=gi(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;_m(i,g)}e=g+16|0;$d(e,x[a+36>>2]);$Q(c,x[a+36>>2],d);c=x[b>>2];b=xl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=g+48|0}function nw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((tp(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=rf(i+4|0,b,f);g=Jb(f);x[31725]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((tp(a,c,b)|0)!=(b|0)){break b}}qE(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function _7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;dK(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){nL(d+12|0,v[e|0]);e=e+1|0;continue}break}Ac(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function wK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31600];x[31600]=0;Od();a=wy(a,e+12|0,d);d=hb;g=x[31600];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31600]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function Kz(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d=b&255;if(!((d|0)==y[a|0]|c>>>0<4)){d=D(d,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=lg(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31725]=0;U(306,b|0,f-c|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=Bm(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31725]=0;U(48,b|0,f-c|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=42540;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Sb(a+4248|0,0,48);x[31725]=0;X(854);c=x[31725];x[31725]=0;a:{if((c|0)==1){break a}e=a,f=zS(),x[e+4296>>2]=f;pu(a);ou(a);x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break a}return a|0}c=N()|0;dc(b);ag(a);Q(c|0);p()}function uT(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=JA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function mR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){nA(a,c,b);break a}e=zb(a);d=$f(f+12|0,Mf(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=Mn(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){Bk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;mA(a,d);_f(d)}fb=f+32|0;return}if((c|0)!=128){Ih(a,d+512|0)}}function kH(a,b,c,d,e,f){var g=0,h=0;a:{g=fb-48|0;fb=g;h=g+12|0;eo(h,c);x[31725]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=g+36|0;O(93,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}qx(g+4|0,h);x[31725]=0;V(94,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Zn(h);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;Zn(g+12|0)}Q(a|0);p()}}function VR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Ml(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Ml(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Ml(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Ml(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function N5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){yI(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}if(x[a>>2]){Nf(a);by(iq(a),x[a>>2],Ug(a));j=zb(a),k=0,x[j>>2]=k;x[a>>2]=0;x[a+4>>2]=0}AJ(a,Mf(a,e));yI(a,c,b,e)}fb=d+16|0}return a|0}function jL(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(BL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;b=R(1188,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31725]=0;W(1189,a+b|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Tb();p()}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;pn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(734,b|0,d|0,Sc(e,a)>>>5|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;Xi(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;pn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(736,b|0,d|0,Sc(e,a)>>>8|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;sv(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;pn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(737,b|0,d|0,Sc(e,a)>>>4|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;qn(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;ND(e,a+1|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=d+32|0}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;pn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(735,b|0,d|0,Sc(e,a)>>>2|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;uc(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Ec(168);x[31725]=0;g=P(36,f+4|0,22267)|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){x[31725]=0;d=U(37,h|0,g|0,0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;gl(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31725]=0;S(27,a|0,c|0,b|0);a=x[31725];x[31725]=0;if((a|0)!=1){Zb(c);fb=e+16|0;return}a=N()|0;Zb(c);Q(a|0);p()}function nm(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(BL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;b=R(31,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Tb();p()}function Ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);h=wb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[mm(g+12|0)>>2];continue}break}fb=g+16|0;if(lc(d,wb(x[b+4>>2]))){ai(a);return}sp(a,d)}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Wf(f,b);x[31725]=0;b=c+20|0;S(11,b|0,0,f|0);g=x[31725];x[31725]=0;a:{b:{c:{if((g|0)!=1){x[31725]=0;O(968,e|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break c}Qb(b);tb(f);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31725]=0;P(966,a|0,e|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function tK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31600];x[31600]=0;Od();a=wy(a,e+12|0,d);d=hb;d:{g=x[31600];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;a=-1;b=-1;break a}x[31600]=h;if(x[e+12>>2]==(b|0)){break d}break b}b=a;c=(f|0)==45;a=c?0-b|0:b;b=c?0-(d+((b|0)!=0)|0)|0:d;break a}}x[c>>2]=4;a=0;b=0}fb=e+16|0;hb=b;return a}function LT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Zj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=eB(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=ec(a);h=Ch(c,Ec(28),Mg(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=ec(h),k=1,v[j+4|0]=k;fb=e+16|0;$g(a,x[c+12>>2],g,x[c>>2]);b=le(c);dm(c);e=1}_g(d+8|0,x[vb(c,b)>>2],e);fb=c+16|0;a=td(x[d+8>>2]);fb=d+16|0;return a+8|0}function Hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=z[a+30>>1];if(d){b=hA(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!Ad(x[c+4>>2],y[c+11|0])){ts(iR(a,e+14|0),c);break a}b=iA(a,e+14|0);if(!Zg(b,Rf(a))){break a}c=fb-16|0;fb=c;b=x[vb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=ah(vb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=zb(a);x[g>>2]=x[g>>2]-1;qV(x[ec(a)>>2],b);a=x[f>>2];fb=d+16|0;Xj(td(b));Db(b);vb(c+12|0,a);fb=c+16|0}fb=e+16|0}function xI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=yn(x[ad(j,i+12|0)>>2])+1|0}else{c=1073741807}Uj(j,c);c=x[i+4>>2];if(e){Yi(c,k,e)}if(g){Yi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Yi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);yd(c+(a<<2)|0,0);fb=i+16|0;return}qf();p()}function caa(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(OL(1,c+24|0)){It(x[31600],12779);p()}b=we(c+16|0,x[c+24>>2],x[c+28>>2]);f=ZA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=we(e+8|0,nva(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=we(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=we(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Dc(b,x[e>>2]);x[31725]=0;P(1151,b+12|0,c|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}Ac(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,kA(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function ZE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Zc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){QE(a,b);break a}c=zb(a);c=mk(e+12|0,nk(a,Zc(x[a>>2],d)+b|0),Zc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Hp(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Uw(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;Xr(a,c);jj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jn(a,d+(b<<1)|0)}}function Lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[d+16>>2]=b;e=x[a+48>>2];x[d+20>>2]=c-((e|0)!=0);g=x[a+44>>2];x[d+28>>2]=e;x[d+24>>2]=g;a:{b:{if(Yy(cb(x[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=x[d+12>>2];if((e|0)>0){break b}b=e?32:16}x[a>>2]=b|x[a>>2];break a}f=e;g=x[d+20>>2];if(g>>>0>=e>>>0){break a}f=x[a+44>>2];x[a+4>>2]=f;x[a+8>>2]=f+(e-g|0);if(x[a+48>>2]){x[a+4>>2]=f+1;v[(b+c|0)-1|0]=y[f|0]}f=c}fb=d+32|0;return f|0}function Yta(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);f=d+8|0;Rd(f,x[vb(d+4|0,a)>>2]);x[31725]=0;W(346,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){g=fb-16|0;fb=g;b=g+4|0;x[b>>2]=a;e=x[a+4>>2];x[b+4>>2]=e;x[b+8>>2]=e+32768;c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){hc(b);fb=g+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}Qd(f);ch(f);fb=d+16|0;return a|0}a=N()|0;ch(d+8|0);Q(a|0);p()}function Baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=x[b+292>>2];kg(x[x[e>>2]-12>>2]+e|0,0);$d(g+16|0,x[b+292>>2]);f=gi(g,-1,-1);e=x[g+24>>2];h=x[g+28>>2];a:{if(!fo(e,h,x[f+8>>2],x[f+12>>2])){b:{if((c|0)!=(e|0)|h){break b}break a}}Hi(x[b+292>>2],c,0,0)}e=x[d>>2];d=x[d+4>>2];c=0;while(1){if(d){f=x[b+292>>2];h=uh(d);Dj(f,c+e|0,h);f=x[x[b+292>>2]+4>>2];d=d-f|0;c=c+f|0;if((f|0)==(h|0)){continue}}break}bc(a,e,c);fb=g+32|0}function kva(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!lh(a,7)){break b}c=0;if(!OE(a,18431)){break a}if(!lh(a,1)){break b}c=-1;if(!gd(a,Rr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;Qr(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){DE(f)}c=-1;if(!e){break a}c=0;if(!O0(y[d+9|0],y[d+10|0])){break a}c=ve(a,b,N0(f),hb);break a}c=-1}fb=d+16|0;return c|0}function Kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function cH(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31725]=0;a=U(152,f|0,a|0,8)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(!a){break d}x[31725]=0;a=g+4|0;S(e|0,a|0,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;O(d|0,h|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}Gd(a);continue}break}a=N()|0;break b}a=N()|0;Gd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=e+28|0;f=x[re(e+24|0,c)>>2];x[31725]=0;g=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=g;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;ba(996,a+8|0,e+8|0,f|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);d=Cz(a+92|0);f=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[d>>2]=47968;x[f>>2]=48008;Vc(c);fb=e+32|0;return a|0}a=N()|0;Vc(e+28|0);Q(a|0);p()}function j4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=io(f+20|0,b,c);x[31725]=0;e=U(1364,f+8|0,d|0,e|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){c=Jb(g);d=Jb(e);a=x[d>>2];b=x[c>>2];a:{if(!a|!b|(a|0)!=(b|0)){break a}while(1){a=x[d+4>>2];b=x[c+4>>2];if(!a|!b){break a}d=d+4|0;c=c+4|0;if((a|0)==(b|0)){continue}break}}Qb(e);Qb(g);fb=f+32|0;a=(a|0)>(b|0)?-1:(a|0)<(b|0);return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Qb(g);Q(a|0);p()}function aq(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31725]=0;a=U(152,f|0,a|0,e|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(!a){break d}x[31725]=0;a=g+4|0;O(d|0,a|0,b|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;O(c|0,h|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}Gd(a);continue}break}a=N()|0;break b}a=N()|0;Gd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function Yj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Sc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){XX(a,b);break a}c=zb(a);c=vn(e+12|0,bm(a,Sc(x[a>>2],d)+b|0),Sc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=yC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){EX(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;hr(a,c);tn(c)}fb=e+32|0;return}if(b>>>0<c>>>0){or(a,b+d|0)}}function T2(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31725]=0;P(129,a|0,4945)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31725]=0;P(129,a|0,12608)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(Ad(x[a+4>>2],y[a+11|0])){x[31725]=0;P(129,a|0,10067)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31725]=0;P(129,a|0,11127)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function vta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(376,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=_h(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){hc(e);fb=f+16|0}else{hj(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Qd(b);_j(b);fb=d+16|0;return a|0}a=N()|0;_j(d+8|0);Q(a|0);p()}function rc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return rc(a,24)+(rc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Pt(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10077,13258,1632,6865);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function hu(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31594]){b=hu(x[31594])}if(!x[31520]){break a}c=b|c;a=x[31520];continue}break}d=x[a+76>>2]<0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(!d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(d){break a}}}return b|c}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-4096|0;fb=c;pn(a,b);a:while(1){if(Sc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[xb(g,b+h|0)|0]+d|0;i=xb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}ov(c,sC(c),Pe(wb(g),f));e=e+1|0;continue a}else{d=y[xb(x[a>>2],b+f|0)|0]+d|0;i=xb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}fb=c+4096|0}function KR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Gb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Kd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function Wy(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124231]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31600]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function mZ(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){jD(a,b);break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Mn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Hn(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;kZ(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function dU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Zj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=LB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=ec(a);g=Ch(c,Ec(36),Mg(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=ec(g),k=1,v[j+4|0]=k;fb=b+16|0;$g(a,x[c+12>>2],f,x[c>>2]);b=le(c);iU(c);d=1}_g(e+8|0,x[vb(c,b)>>2],d);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+8|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Xc(c+12|0,16,1,1,0);x[c+8>>2]=0;ld(a,0);xc(b);a:{b:{if(Sr(b,13822)){cd(b,12);if(!up(b)){Cp(d,2)}cd(b,24);break b}if(ik(b,13709)){xc(b);x[c+8>>2]=4;e=1;break a}fd(d,8)}e=0}f=a,g=(lf(b)>>>0)/(D(y[d|0],pr(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=fg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Wk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Sb(d,0,x[Gb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function _fa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31725]=0;W(1027,a|0);f=x[31725];x[31725]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31725]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11298,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function a3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;ow(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Jb(c)+Cb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Jb(c);mo(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Cb(x[a+36>>2],y[a+43|0]);e=a,f=b+Jb(c)|0,x[e+44>>2]=f;eC(c,Mc(c));c=Jb(c);My(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Bt(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Bt(a,b)}}function _aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Ec(56),x[h+8>>2]=i;c=ym(x[e+8>>2]);x[c>>2]=77472;g=nc(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=DM(g);x[d>>2]=77636;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Xn(e);Wn(b,nc(a),a);zm(e);fb=f+16|0}function waa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31725]=0;O(1166,x[e+44>>2],b|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+12;b=b+12|0;continue}break}a=N()|0;pM(e+24|0);Q(a|0);p()}a=e+24|0;Qe(a);b=x[e+44>>2];pM(a);fb=e+48|0;return b|0}function ul(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;mi(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;mi(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31725]=0;O(1130,x[e+44>>2],b|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+16;b=b+16|0;continue}break}a=N()|0;mN(e+24|0);Q(a|0);p()}a=e+24|0;Qe(a);b=x[e+44>>2];mN(a);fb=e+48|0;return b|0}function $sa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;p_(h,b);j=g,k=wb(x[g+4>>2]),x[j>>2]=k;h=rg(h);i=z[a+480190>>1];while(1){b=x[g>>2];if(!Ib(b,h)){Sv(g+4|0);break a}b=z[ip(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}ah(g);continue}}fb=g+16|0}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Lg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){ZB(a,d,c);break c}b=zb(a);b=fv(e+12|0,$q(a,Lg(x[a>>2],f)+d|0),Lg(x[a>>2],x[a+4>>2]),b);x[31725]=0;S(788,b|0,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}_U(a,b);YB(b)}fb=e+32|0;break a}a=N()|0;YB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){aV(a,e+(b<<5)|0)}}function Vu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=OB(x[a+24>>2],y[a+32|0]);g=Pj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!bj(i,d&65535)){break c}e=x[a>>2];if(Ud(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Hd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!BC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function bV(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function Hz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-48|0;fb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=gc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=zu(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+20|0,8057)|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+48|0;return a|0}p()}function Of(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=nva(b,c,h,i);h=hb;e=nva(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=nva(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=nva(f,0,b,0);h=hb;i=0;d=nva(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;b=nva(b,m,j,e)+h|0;e=hb;e=b>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=b}function lV(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=_h(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Se(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Re(a+36|0,a+8|0);while(1){if(Ib(b,c)){fj(x[a+56>>2],z[b>>1]);b=Md(a+60|0);x[a+56>>2]=x[a+56>>2]+2;b=x[b>>2];continue}break}b=a+36|0;Qe(b);c=x[a+56>>2];oE(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function KH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-256|0;fb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;gt(h|1,10616,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=qh(d,24,f,h,g)+d|0;h=sj(d,e,x[b+4>>2]);f=g+20|0;bd(f,x[b+28>>2]);x[31725]=0;i=d;d=g+32|0;ga(1233,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31725];x[31725]=0;a:{if((e|0)!=1){Zb(f);a=et(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function w$(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=hl(a,7),v[f|0]=g;d=hl(a,1);e=hl(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;w$(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function _na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function XD(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$l(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Se(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Re(a+36|0,a+8|0);while(1){if(Ib(b,c)){El(x[a+56>>2],y[b|0]);b=me(a+60|0);x[a+56>>2]=x[a+56>>2]+1;b=x[b>>2];continue}break}b=a+36|0;Qe(b);c=x[a+56>>2];c$(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function MH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-112|0;fb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;gt(h|1,10616,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=qh(d,24,f,h,g)+d|0;h=sj(d,e,x[b+4>>2]);f=g+20|0;bd(f,x[b+28>>2]);x[31725]=0;i=d;d=g+32|0;ga(1230,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31725];x[31725]=0;a:{if((e|0)!=1){Zb(f);a=nw(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function gu(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=ce(a);d=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=Tu(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!Tu(b,td(c))){break a}}c=rg(a)}if(!lc(c,rg(a))){b=x[vb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=ah(vb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=zb(a);x[d>>2]=x[d>>2]-1;qV(x[ec(a)>>2],b);fb=c+16|0;gn(td(b));Db(b)}fb=e+16|0}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31725]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11443,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function uK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31600];x[31600]=0;Od();a=wy(a,e+12|0,d);d=hb;g=x[31600];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31600]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function eq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Eh(x[ad(j,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Cg(c,k,e)}if(g){Cg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Cg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}qf();p()}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31725]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11479,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Yq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Eh(x[ad(j,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Xg(c,k,e)}if(g){Xg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Xg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}qf();p()}function Sr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,7);kc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(e,b,7)){break b}Vb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function jc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{d=pl(a);a=d;if(a>>>0<502720&a>>>0>=502208){b=a-4|0;e=x[125550];c=e;while(1){a=c;if(!(!a|(a|0)==502720)){if((sI(a)|0)==(b|0)){w[a+2>>1]=z[d-2>>1]+z[a+2>>1];break a}if((sI(b)|0)==(a|0)){c=d-2|0;w[c>>1]=z[a+2>>1]+z[c>>1];if(!f){x[125550]=b;w[b>>1]=z[a>>1];break a}g=f,h=Px(b),w[g>>1]=h;break a}else{c=Qx(z[a>>1]);f=a;continue}}break}g=b,h=Px(e),w[g>>1]=h;x[125550]=b;break a}Db(d)}}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function zF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8)!=26215|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}d=a+514|0;c=a+2|0;while(1){if((c|0)!=(d|0)){f=zb(c);b=c;while(1){if((b|0)!=(f|0)){g=y[b|0];b=b+1|0;if(g>>>0>31){continue}break a}break}c=c+8|0;continue}break}d=a+772|0;b=a+516|0;c=-1;while(1){e=(b|0)==(d|0);if(e){break a}a=c;c=y[b|0]|y[b+1|0]<<8;a=(a|0)<(c|0);b=b+2|0;if(a){continue}break}}return e}function UW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=cr(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=ym(a);x[e>>2]=76972;d=nc(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=wM(d,xM(b));x[d>>2]=77136;c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function Yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31725]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6695,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31725]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6749,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Jra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Uf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){WE(a,c);break c}b=zb(a);b=QD(d+12|0,RD(a,Uf(x[a>>2],e)+c|0),Uf(x[a>>2],x[a+4>>2]),b);x[31725]=0;O(522,b|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}PD(a,b);Xv(b)}fb=d+32|0;break a}a=N()|0;Xv(b);Q(a|0);p()}return}if(b>>>0<c>>>0){SE(a,d+D(b,20)|0)}}function xg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Nc(41420,d+14|0)>>1];e=x[a>>2];c=Zc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){zp(a,b,f);break b}c=zb(a);c=mk(e+12|0,nk(a,Zc(x[a>>2],g)+b|0),Zc(x[a>>2],x[a+4>>2]),c);rF(c,b,f);Xr(a,c);jj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){Jn(a,e+(b<<1)|0)}}fb=d+16|0}function GV(a,b,c,d){var e=0,f=0,g=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){e=c+1|0;f=11;break b}if((b&254)==16){e=c&15|b<<4|-128;f=14;break b}if((b|0)==18){break b}e=c;f=b;if(b>>>0>18){break a}}Bf(a,f,e&255);b=y[a+3|0];c:{d:{if(!((d|0)!=4|(b|0)!=13)){b=y[a+5|0];if(b&3?(b|0)!=255:0){break d}v[a+5|0]=b+3>>>2;return 1}if((b&255)!=13){break c}}b=46;v[a+3|0]=46}g=1;if((d|0)==4|(b&255)!=17|y[a+5|0]!=32){break a}v[a+3|0]=16}return g}function ve(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=kh(a);a:{b:{if(!b){i=e,j=kh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Zr(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function qu(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function B3(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31725]=0;m=a;a=0;a=jI(1099,m|a,b,c,d,a|e,f);b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,8843,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}return a|0}function $U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=_h(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){fj(x[a+44>>2],z[b>>1]);x[a+44>>2]=x[a+44>>2]+2;b=b+2|0;continue}break}b=a+24|0;Qe(b);c=x[a+44>>2];oE(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$l(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){El(x[a+44>>2],y[b|0]);x[a+44>>2]=x[a+44>>2]+1;b=b+1|0;continue}break}b=a+24|0;Qe(b);c=x[a+44>>2];c$(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;GM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=D(x[a+16>>2],e+h|0);l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b+k<<2)+l|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function XL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function eu(a,b,c,d,e){var f=0,g=0;a:{if(!Rt(b)){break a}f=x[a+484344>>2];if(!He(f,x[a+484348>>2],b&65535)){break a}b=Wb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=jd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Yi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function LO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31725]=0;b=P(36,h+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Jl(a,b,4);c=sz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function DO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31725]=0;b=P(36,h+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Jl(a,b,4);c=uz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function C3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=tc(c+8|0,16781);x[31725]=0;S(100,c+20|0,a|0,b|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Ud(d,x[c+24>>2])>>>0>b>>>0)){Td(c+20|0);fb=c+32|0;return a|0}x[31725]=0;d=R(101,Hd(d,b)|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Td(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function f1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];g=x[Gb(c+4|0,c+12|0)>>2];d=fb+-64|0;fb=d;f=d+44|0;ug(f,a,g);h=x[d+44>>2];a=d+20|0;wg(a,3,$e(f),h);x[31725]=0;e=d+32|0;O(220,e|0,a|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=d+12|0;gc(a,b,11);tm(a,e);tb(e);Kc(f);fb=d- -64|0;e=!g|(h|0)!=0;break a}a=N()|0;Kc(d+44|0);Q(a|0);p()}}fb=c+16|0;return e|0}function Ufa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11678,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Kfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11616,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Ifa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11066,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function s0(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){CQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;fp(a);b=fb-32|0;fb=b;a:{b:{d=dp(a);c=Sc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31725]=0;c=ba(956,b+12|0,c|0,c|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){hr(a,c);tn(c);break c}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Tb();p()}}function pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;MM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=e+h|0;l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=x[(b<<2)+l>>2]+(k<<2)|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function l8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-208|0;fb=a;g=Od();x[a>>2]=e;e=a+176|0;h=qh(e,20,g,9262,a);g=h+e|0;i=sj(e,g,x[c+4>>2]);f=a+12|0;bd(f,x[c+28>>2]);x[31725]=0;j=R(1217,x[a+12>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){Zb(f);f=e;e=a+16|0;mK(j,f,g,e);f=b;b=e+(h<<2)|0;b=et(f,e,(g|0)==(i|0)?b:((i-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Cg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function LH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;gt(g|1,10783,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+123|0;e=qh(d,13,e,g,f)+d|0;h=sj(d,e,x[b+4>>2]);g=f+4|0;bd(g,x[b+28>>2]);x[31725]=0;i=d;d=f+16|0;ga(1233,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31725];x[31725]=0;a:{if((e|0)!=1){Zb(g);a=et(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;d=f+8|0;We(d,2,a+6|0);e=f+20|0;Cc(e,d);zc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;vA(a+180|0,b+48|0,0);vA(a+228|0,b+88|0,2);vA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Sb(d,0,256)}fb=f+32|0}else{e=y[(a+c|0)+38|0];h=_b(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function NH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb+-64|0;fb=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;gt(g|1,10783,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+43|0;e=qh(d,13,e,g,f)+d|0;h=sj(d,e,x[b+4>>2]);g=f+4|0;bd(g,x[b+28>>2]);x[31725]=0;i=d;d=f+16|0;ga(1230,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31725];x[31725]=0;a:{if((e|0)!=1){Zb(g);a=nw(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function p2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Ec(32),x[j+8>>2]=k;e=ym(x[f+8>>2]);x[e>>2]=41432;h=nc(e);e=fb-16|0;fb=e;b=wm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Vn(h);x[b>>2]=41568;wm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;ke(e);fb=e+16|0;b=a;a=Xn(f);Wn(b,nc(a),a);zm(f);fb=g+16|0}function oU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(ev(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=Yo(d+20|0);x[31725]=0;f=P(761,a|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[31725]=0;O(762,e|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}x[e+4>>2]=b;iC(a,e);uf(e)}sn(d+12|0,x[a>>2]);Pw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;uf(e);Q(a|0);p()}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=43620;c=Nb(a+4256|0);b=a+4208|0;e=yb(b,0),f=1056964608,x[e>>2]=f;e=yb(b,1),f=1017370378,x[e>>2]=f;e=yb(b,2),f=1028670828,x[e>>2]=f;e=yb(b,3),f=1059760811,x[e>>2]=f;e=yb(b,4),f=1017370378,x[e>>2]=f;e=yb(b,5),f=1065353216,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;uc(c);ag(a);Q(b|0);p()}function WL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){Dl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Nm(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}_(7566,13258,1793,5750);p()}function JA(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+31872|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return XR(Jo(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30528|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31744|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+31808|0]}function dz(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Ot(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}_(15794,13258,1564,6036);p()}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Qm(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){fh(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Pg(a);Vb(a,b-4|0)}v[f|0]=c}function bB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;f=Nu(a,a+1074376|0,b,c);a:{if(!f){break a}Kb(d+8|0,a+1074312|0,117);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}c=D(b,872)+a|0;e=x[c+1075648>>2];if(!e){break a}g=y[e+33|0];if(!g){break a}h=a;a=c+1074992|0;c=Jq(h,x[a+88>>2],e);if(!c){break a}a=y[a+799|0];if(!(!e|(!a|a>>>0>128))){a=y[xb(e+108|0,a-1|0)|0]}ib[x[x[c>>2]+88>>2]](c,f,a,g<<24>>24,b)}fb=d+16|0}function Opa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=dw(a,127,b+15|0);x[31725]=0;v[b+14|0]=64;d=U(601,a+12|0,127,b+14|0)|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[31725]=0;v[b+13|0]=0;P(681,a+24|0,b+13|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+44>>2]=0;x[a+48>>2]=0;x[a+36>>2]=-1;x[a+40>>2]=108855296;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;dc(d)}dc(a);Q(b|0);p()}function NF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=xf(b);c=xf(x[a+8>>2]);v[c+2|0]=y[b+2|0];w[c>>1]=z[b>>1];b=Mi(a+12|0);Mi(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Jta(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Cb(x[a+4>>2],y[a+11|0]);f=Mc(a);a:{if(f-g>>>0>=b>>>0){f=Jb(a);if((c|0)==(g|0)){break a}i=c+f|0;Ui(i+b|0,i,g-c|0);break a}Wm(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;ng(a,b);fd(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){fd(b,y[d|0]);b=b+1|0;d=x[me(h+12|0)>>2];continue}break}a=Pe(zd(a),c);fb=h+16|0;return a|0}function v8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-96|0;fb=a;g=Od();x[a>>2]=e;e=a- -64|0;h=qh(e,20,g,9262,a);g=h+e|0;i=sj(e,g,x[c+4>>2]);f=a+12|0;bd(f,x[c+28>>2]);x[31725]=0;j=R(28,x[a+12>>2])|0;k=x[31725];x[31725]=0;if((k|0)!=1){Zb(f);f=e;e=a+16|0;rK(j,f,g,e);f=b;b=e+h|0;b=nw(f,e,(g|0)==(i|0)?b:((i-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,12847,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,12330,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11152,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Ffa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,15129,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11308,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Sfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11716,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,9312,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11634,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11697,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Qfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7777,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Ofa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7725,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Jx(a,b,c){var d=0,e=0,f=0,g=0;e=Jb(a);a=Cb(x[a+4>>2],y[a+11|0]);d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=Eu(c,(f-b|0)+1|0,g);if(!c){break c}if(!ZG(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11086,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function DU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(804,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=gv(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Wl(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);sU(b);fb=c+16|0;return a}a=N()|0;sU(c+8|0);Q(a|0);p()}function mB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ek(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function ik(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);kc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Vb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function dea(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Nd(d+16|0);x[31725]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;c=d+24|0;S(1121,c|0,a|0,d|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){a=d+44|0;e=x[re(d+12|0,a)>>2];x[31725]=0;b=+pa(987,c|0,+b,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}ub(c);Vc(a);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Vc(d+44|0);Q(c|0);p()}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31725]=0;b=P(d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6722,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31725]=0;b=P(d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6773,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Sc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Gb(e+28|0,e+24|0)>>2];f=Pe(wb(f),c);c=Pe(Pe(wb(x[b+12>>2]),c),g);b=x[d>>2];lp(f,c,b);bc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;ib[f|0](a,b,c,e+8|0)}fb=e+32|0}function _9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Pf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[ud(e+12|0,e+8|0)>>2];Cg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function UM(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126944;x[a+24>>2]=0;x[a+28>>2]=65536;x[a+8>>2]=b;x[a+32>>2]=0;x[a+36>>2]=65536;c=(b|0)!=0;x[a+12>>2]=c;x[a+16>>2]=c;d=63-b|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+48>>2]=c;x[a+52>>2]=d;d=64-b|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+40>>2]=b?c:0;x[a+44>>2]=b?d:0;return a}function OF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=Nn(b);i=Nn(x[a+8>>2]),j=z[b>>1],w[i>>1]=j;b=ij(a+12|0);ij(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function kf(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=cq(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(pI(a,b)&3){case 0:c=cq(C[b>>3],C[b+8>>3]);break a;case 1:c=-dq(C[b>>3],C[b+8>>3],1);break a;case 2:c=-cq(C[b>>3],C[b+8>>3]);break a;default:break b}}c=dq(C[b>>3],C[b+8>>3],1)}a=c;fb=b+16|0;return a}function hk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}wc(f+12|0,65535);xg(a,z[f+12>>1]);c=wb(x[a>>2]);x[f+4>>2]=c;h=wb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!fh(b,a)){eh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Md(f+4|0)>>2];continue}}fb=f+16|0}function vO(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function joa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=hC(c+4|0,a);Qm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Qm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;kZ(a,c);_f(c);fb=d+32|0}function WW(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=GW(b);i=GW(x[a+8>>2]),j=y[b|0],v[i|0]=j;b=tC(a+12|0);tC(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function av(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(x[c>>2]);x[e+12>>2]=d;f=wb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=uU(b,C[d>>3]),C[g>>3]=h;d=x[Zu(e+12|0)>>2];continue}}}else{uU(b,C[Ve(x[c>>2],0)>>3]);d=d+1|0;continue}break}_l(a,c);fb=e+16|0}function xS(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=wb(x[c>>2]);x[b+12>>2]=d;f=wb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}CQ(a,e);a=x[x[e>>2]+8>>2];x[31725]=0;W(a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){continue}break}T(0)|0;Tb();p()}a=uc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Je(b+12|0)>>2];continue}break}Db(a)}}function lB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ek(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;Cj(d+8|0,d+31|0);Rm(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}BZ(f,b,d)}f=c}gf(a,f);fb=e+16|0}function Zba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Wo(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,yh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function ZH(a,b,c,d,e,f,g,h,i){var j=0;x[31725]=0;W(1002,a|0);j=x[31725];x[31725]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31725]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,h|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function SA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;qS(a+1074332|0,b);a=a+906300|0;f=Ck(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function OE(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,7);od(c+16|0,a,x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(e,b,7)){break b}gd(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d}function zx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;_k(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,yh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31725]=0;S(1098,d|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10321,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function vo(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;_k(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,yh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{b:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function JO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31725]=0;b=P(36,f+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Jl(a,b,2);c=sz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function CO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31725]=0;b=P(36,f+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Jl(a,b,2);c=uz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function gI(a,b,c){a=Fb(a);x[31725]=0;O(c|0,a|0,4);c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,32);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,10);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,13);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,9);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;d=-1;a:{if(!lh(a,1)){break a}e=Rr(a);if((e-5&255)>>>0>=253){while(1){if((f|0)==127){d=1;break a}c=fb-16|0;fb=c;bE(c+8|0,b);g=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=(g|0)==(h|0);if(!c){Kr(b)}if(!c){break a}f=f+1|0;if(HV(b,e)){continue}break}}d=0}fb=b+16|0;return d|0}function bqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!lh(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);od(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){gd(a,8)}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!pk(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function lN(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Wf(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(95,a|0,yh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{b:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[cc(c+4|0,b)|0];x[31725]=0;O(97,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function b_(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31725]=0;e=+oa(1094,d|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5350,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function soa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Gf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(On(a)>>>0>=c>>>0){g=x[a>>2];f=Zc(g,x[a+4>>2]);x[d+8>>2]=f;Gv(g,x[Gb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){zp(a,c-f|0,e);break a}Jn(a,x[a>>2]+(c<<1)|0);break a}kV(a);GC(a,nk(a,c));zp(a,c,e)}fb=d+16|0;fb=b+16|0}
function Tfa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11734,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function DN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bo(a)|0)>(b|0)){break d}}b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=N()|0;jc(b)}Q(a|0)}p()}function A3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31725]=0;a=Ha(1101,a|0,b|0,c|0,d|0)|0;b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,11192,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}return a|0}function XY(a){var b=0;a:{if(kd(a,14260,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function Rfa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7794,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Pfa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7742,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Gla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);e=c+8|0;Rd(e,x[vb(c+4|0,a)>>2]);x[31725]=0;W(809,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){f=fb-16|0;fb=f;d=_h(f+4|0,a,2304);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{Uw(b);b=b+2|0;x[d+4>>2]=b;continue}break}Qd(e);_j(e);fb=c+16|0;return a|0}a=N()|0;_j(c+8|0);Q(a|0);p()}function Wi(a){var b=0,c=0;b=fb-16|0;fb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=dq(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(pI(a,b)&3){case 0:a=dq(C[b>>3],C[b+8>>3],1);break a;case 1:a=cq(C[b>>3],C[b+8>>3]);break a;case 2:a=-dq(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-cq(C[b>>3],C[b+8>>3])}fb=b+16|0;return a}function cua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{f=Zd(a);b:{if(f>>>0>1){break b}c:{if(f){x[31725]=0;d=e+4|0;S(336,d|0,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){En(b,d);dc(d);break c}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break a}Y(a|0)|0;Z();d=0;break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}tw(a,b,c)}d=Sc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=e+16|0;return d|0}Q(a|0);p()}function Y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=lf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Yj(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(lc(c,a)){break a}oe(d+8|0,c,a);kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function Rv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Gc(ova(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Gc(ova(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=Zi(qL(8192/+x[Ze(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return((a|0)>0?a:0)&255}function oz(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=zM(b,4096);yM(a,b-c|0);c=x[a+16>>2];b=gc(d+16|0,xb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function FN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bo(a)|0)>(b|0)){break d}}b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;jc(b)}Q(a|0)}p()}function uE(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(X0(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}yc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function Wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Kk(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[31725]=0;O(1127,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[31725]=0;V(1128,a|0,b|0,e|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}}a=N()|0;oN(c+8|0);Q(a|0);p()}a=c+8|0;Qd(a);oN(a);fb=c+16|0}function YH(a,b,c,d,e,f,g){var h=0;x[31725]=0;W(1002,a|0);h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31725]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,f|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Jb(c);c=Cb(x[c+4>>2],y[c+11|0]);a:{d=Cb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Mc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Jb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Ui(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Ui(h,f,c);b=c+d|0;ng(a,b);fd(b+e|0,0);break a}Yq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}kn();p()}return a|0}function sK(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();d=fb-16|0;fb=d;By(d,a,e+12|0,0);f=TG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31600];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function cY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function bsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{f=b+c|0;c=Wj(b,f);if(c){x[31725]=0;O(347,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}e=fb-16|0;fb=e;a=$l(e+4|0,a,c);g=a,h=Br(b,f,x[a+4>>2]),x[g+4>>2]=h;hc(a);fb=e+16|0}a=d+8|0;Qd(a);cj(a);fb=d+16|0;break a}a=N()|0;cj(d+8|0);Q(a|0);p()}}function UV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Pta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,15);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function Eea(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31725]=0;O(1093,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10900,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Lra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,14);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function s4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Kf(x[d+8>>2],64,e)){break b}f=4;g=sl(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Kf(x[d+8>>2],64,e)){break a}f=f-1|0;g=sl(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function qj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(th(a,f+12|0)){break b}h=Bl(x[a>>2]);g=4;if(!Kf(x[d+8>>2],64,h)){break b}b=sl(d,h);while(1){c:{b=b-48|0;h=Km(a);if(th(h,f+12|0)|(e|0)<2){break c}g=Bl(x[h>>2]);if(!Kf(x[d+8>>2],64,g)){break a}e=e-1|0;b=sl(d,g)+D(b,10)|0;continue}break}g=2;if(!th(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function MO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,e+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Jl(a,b,1);c=sz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function EO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,e+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Jl(a,b,1);c=uz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function gja(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31725]=0;O(289,b+4|0,8);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(b|0)|0;fp(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function dga(a){a=a|0;var b=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31725]=0;V(989,5051,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=jh(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(802,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;vU(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;_u(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);_u(b);fb=c+16|0;return a|0}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=oc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(227,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;vu(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;ch(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}function Ipa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=zC(a,b);x[31725]=0;c=P(685,a+12|0,b+12|0)|0;d=x[31725];x[31725]=0;b:{c:{if((d|0)!=1){x[31725]=0;P(686,a+24|0,b+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;dc(c)}dc(a);Q(b|0);p()}}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=44240;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;uc(b);ag(a);Q(c|0);p()}function zC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Sc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(324,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;vv(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;cj(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);cj(b);fb=c+16|0;return a|0}function tN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;d=P(36,d+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=qC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function $n(a,b,c,d,e,f){var g=0;x[31725]=0;W(1002,a|0);g=x[31725];x[31725]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31725]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,e|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function wO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;c=gc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=zu(a,b,0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+12|0,8057)|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+32|0;return a|0}p()}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;PM(a,c);fb=c+16|0}function pK(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();d=fb-16|0;fb=d;By(d,a,e+12|0,1);f=vx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31600];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;LM(a,c);fb=c+16|0}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;JM(a,c);fb=c+16|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;FM(a,c);fb=c+16|0}function nY(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,5);kc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(kd(e,b,5)){break b}Vb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d}function bL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Dc(d+8|0,c);x[31725]=0;c=d+20|0;S(1191,c|0,b|0,e|0);f=x[31725];x[31725]=0;a:{b:{if((f|0)!=1){x[31725]=0;a=P(1192,a|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}tb(c);tb(e);x[a>>2]=124272;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[ud(f+12|0,f+8|0)>>2];Yi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function rka(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Ec(2500);c=fb-2496|0;fb=c;MQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=yf(e+12|0,b);fb=e+16|0;return x[a>>2]}function eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}w[d>>1]=z[a+480190>>1];w[d+14>>1]=c-1;c=z[Nc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(BC(x[b>>2],c)){break b}if(eS(a,c&65535)){e=Dc(d,22267);zc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[a+480190>>1];if((e|0)!=(c|0)){break b}w[a+480190>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function Aea(a,b){a=a|0;b=+b;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31725]=0;b=+Wa(1095,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7606,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function j1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=-1;a:{if(!lh(a,7)){break a}c=0;if(!OE(a,11774)){break a}c=fb-16|0;fb=c;f=e+5|0;Gw(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){LE(f)}c=-1;if(!d){break a}c=0;if(!NE(y[e+6|0])){break a}c=ve(a,b,ME(f),hb)}fb=e+16|0;return c|0}function Gx(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47652;i=Ec(80);x[31725]=0;d=R(1105,d|0)|0;h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31725]=0;b=ha(f|0,i|0,b|0,c-b|0,h|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+4>>2]=b;Vc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Vc(g+8|0)}Db(i);Q(a|0);p()}function Tia(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function daa(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(OL(0,b+24|0)){It(x[31600],12742);p()}a=we(b+16|0,x[b+24>>2],x[b+28>>2]);d=ZA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=Du(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=we(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=we(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function afa(a){a=a|0;var b=0,c=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31725]=0;b=R(1070,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7278,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function O6(a){a=a|0;if(y[500496]){return x[125123]}if(!y[501016]){v[501016]=1}wd(500848,120152);wd(500860,120180);wd(500872,120208);wd(500884,120240);wd(500896,120280);wd(500908,120316);wd(500920,120344);wd(500932,120380);wd(500944,120396);wd(500956,120412);wd(500968,120428);wd(500980,120444);wd(500992,120460);wd(501004,120476);v[500496]=1;x[125123]=500848;return 500848}function Hs(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47652;i=Ec(80);x[31725]=0;d=R(1105,d|0)|0;h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31725]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+4>>2]=b;Vc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Vc(g+8|0)}Db(i);Q(a|0);p()}function __(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;wi(b,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){sp(b,a);x[31725]=0;O(362,e|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}ub(b)}a=x[mm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function x_(a){var b=0,c=0;a:{if(kd(a,15227,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Bb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Bb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Bb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Bb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Bb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function kfa(a){a=a|0;var b=0,c=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31725]=0;c=+ia(1061,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7678,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function iQ(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function hB(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31725]=0;O(53,f|0,Yc(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[cc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31725]=0;O(35,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Qb(f);Q(a|0);p()}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Ec(64);x[31725]=0;e=R(879,c|0)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){c=yf(d+8|0,e);e=x[c>>2];x[31725]=0;a=U(945,e|0,a|0,b|0)|0;b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}sc(d+12|0);break b}a=N()|0;og(c);break a}re(d+12|0,c)}og(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function F5(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jb(b);b=fb-32|0;fb=b;a=xd(a,0);x[a>>2]=113264;d=zk(c);x[a+8>>2]=d;if(!d){a=Dc(b+8|0,c);x[31725]=0;c=b+20|0;S(1017,c|0,17527,a|0);d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){x[31725]=0;W(1345,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=119640;return a|0}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!yj(d,64,e)){break b}g=wk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!yj(d,64,e)){break a}f=f-1|0;g=wk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function Aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((Ak(y[a+140|0])|0)!=1){break b}if((cN(a)|0)!=(b|0)){break b}d=a+120|0;_t(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[18383];x[a+8>>2]=x[18382];x[a+12>>2]=e;e=x[18381];x[a>>2]=x[18380];x[a+4>>2]=e;ib[x[uq(a,Ak(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}bN(a,1,b)}fb=c+16|0}function zV(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=zd(b);x[c+12>>2]=a;b=Df(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31725]=0;O(117,d|0,((a|0)==13?10:a)<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[me(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function Vz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Rl(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=qQ(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function pj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(li(a,f+12|0)){break b}g=4;h=Al(x[a>>2]);if(!yj(d,64,h)){break b}b=wk(d,h);while(1){c:{b=b-48|0;h=no(a);if(li(h,f+12|0)|(e|0)<2){break c}g=Al(x[h>>2]);if(!yj(d,64,g)){break a}e=e-1|0;b=wk(d,g)+D(b,10)|0;continue}break}g=2;if(!li(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function XH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,f+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Jl(a,b,e);c=PH(a,c,e,d,76144,76916);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function WH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,f+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Jl(a,b,e);c=PH(a,c,e,d,75316,76088);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function MN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31725]=0;c=P(36,c+4|0,7854)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=_e(65536/b),x[e+480244>>2]=f;Hq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function KN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31725]=0;c=P(36,c+4|0,7875)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=_e(b*65536),x[e+480240>>2]=f;Hq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function gy(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(1073741807-b>>>0>=c>>>0){i=Jb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=yn(x[ad(h,g+12|0)>>2])+1|0}else{c=1073741807}Uj(h,c);c=x[g+4>>2];if(e){Yi(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Yi(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}yd(a,c);pf(a,x[g+8>>2]);fb=g+16|0;return}qf();p()}function XO(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}Ao(b,a);x[31725]=0;c=R(1062,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[b+12>>2]=c;of(b);d=x[a+40>>2];c=x[a+36>>2]}c:{if(Ib(c,d)){a=a+36|0;break c}a=x[b+12>>2];c=x[a>>2]}a=oj(c,x[a+4>>2]);Fl(b+12|0);fb=b+16|0;return a|0}a=N()|0;of(b);Q(a|0);p()}function Om(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+89120|0]}if(a>>>0<=511){return v[(a>>>5|0)+89120|0]+5|0}return v[(a>>>10|0)+89120|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+89120|0]+15|0}return v[(a>>>20|0)+89120|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+89120|0]+25|0}a=v[(a>>>30|0)+89120|0]+30|0}else{a=0}return a}function Gs(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47652;h=Ec(80);x[31725]=0;c=R(1105,c|0)|0;g=x[31725];x[31725]=0;a:{b:{if((g|0)!=1){x[f+8>>2]=c;c=f+8|0;g=x[re(f+12|0,c)>>2];x[31725]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}x[a+4>>2]=b;Vc(c);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Vc(f+8|0)}Db(h);Q(a|0);p()}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ym(a);x[d>>2]=77892;a=wM(nc(d),tM(b));x[a>>2]=78224;x[31725]=0;P(343,a+24|0,65536)|0;c=x[31725];x[31725]=0;a:{if((c|0)!=1){c=a+36|0;Sb(c,0,192);e=a+228|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Sb(e,0,64);break a}b=N()|0;St(a);Q(b|0);p()}x[a+292>>2]=b;x[a>>2]=78036;return d|0}function yN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function uua(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;W$(c,a,b);Bf(b,y[d+14|0],y[Jc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function rta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;v_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){u_(f)}c=-1;a:{if(!e){break a}c=0;if(!x_(f)){break a}c=ve(a,b,w_(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function lg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Tk(d)){Me(a,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Eh(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Cg(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function kq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(kr(d)){Me(a,d);break c}if(d>>>0>=1073741808){break b}Uj(e+8|0,yn(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Yi(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function ft(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function f0(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=ac(16);b=fb-16|0;fb=b;if(!y[496960]){v[496960]=1}gc(b+8|0,1,126084);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31725]=0;a=Ca(1193,c|0,8943,a|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){da(a|0,94572,1194);p()}a=N()|0;jc(c);Q(a|0);p()}}function Wm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(2147483631-b>>>0>=c>>>0){j=Jb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Eh(x[ad(i,h+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[h+4>>2];if(e){Cg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){Cg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}yd(a,c);pf(a,x[h+8>>2]);fb=h+16|0;return}qf();p()}function Bm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Tk(d)){Me(a,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Eh(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Xg(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function uN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;jc(b)}Q(a|0)}p()}function EC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;wi(b,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){sp(b,a);x[31725]=0;O(362,e|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}ub(b)}a=x[mm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function sN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;jc(b)}Q(a|0)}p()}function hsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31725]=0;ba(471,b|0,h|0,e|0,d|0)|0;b=x[31725];x[31725]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}gf(a,e);fb=f+16|0}function d1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Wf(a,c);break e}e=d+8|0;Wf(e,c);x[31725]=0;c=d+20|0;S(125,c|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(246,a|0,4,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function bR(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Nk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Kl(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;Cq(a,c+8|0);g=yb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function _R(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=Oe(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=Oe(a+902204|0,c&127)}vT(a,e,b,f,d,c&255)}}function Q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+112112>>2];break b}e=(ut(a)|0)!=0;e=tt(a)?e|2:e;e=st(a)?e|4:e;e=rt(a)?e|8:e;e=qt(a)?e|16:e;e=pt(a)?e|32:e;e=Nh(a)?e|64:e;e=ot(a)?e|128:e;e=nt(a)?e|256:e;x[d>>2]=e;if(!mt(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function sX(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=cl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function pX(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;e=d+12|0;QX(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!SX(e)){break a}c=ve(a,b,RX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function No(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(!c){break a}x[31725]=0;O(1163,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;V(1164,a|0,b|0,Hd(b,c)|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;qM(d+8|0);Q(a|0);p()}b=d+8|0;Qd(b);qM(b);fb=d+16|0;return a|0}function yR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){vu(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}vr(a);rm(a,Mf(a,e));vu(a,c,b,e)}fb=d+16|0}return a}function Oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=43860;b=a+4208|0;e=yb(b,0),f=1060320051,x[e>>2]=f;e=yb(b,1),f=1041865114,x[e>>2]=f;e=yb(b,2),f=1065353216,x[e>>2]=f;e=yb(b,3),f=1049951732,x[e>>2]=f;e=yb(b,4),f=1049951732,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function lv(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;lW(d,a,a+1|0,a+2|0,a+3|0);lW(c,b,b+1|0,b+2|0,b+3|0);a=kv(y[x[d>>2]],y[x[c>>2]]);a:{if(!Tj(a)){break a}a=y[x[d+4>>2]];b=y[x[c+4>>2]];a=(a|0)!=(b|0)?a<<24>>24<b<<24>>24?-1:1:0;if(!Tj(a)){break a}a=kv(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Tj(a)){break a}a=kv(y[x[d+12>>2]],y[x[c+12>>2]])}a=Cd(a);fb=c+32|0;return a}function tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31725]=0;O(49,d|0,Yc(e,c)|0);c=x[31725];x[31725]=0;if((c|0)!=1){a:{b:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[cc(b,a)|0];x[31725]=0;O(50,d|0,Pf(Pf(c))|0);c=x[31725];x[31725]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function nga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(Aq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31725]=0;V(989,5078,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function xK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();a=yK(a,e+12|0,d);d=hb;f=x[31600];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Ec(223888);x[31725]=0;b=P(846,d|0,b+1074376|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){b=yf(c+12|0,b);fb=c+16|0;b=x[b>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31725]=0;W(608,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;Ae(b);jT(a+4|0);Q(c|0);p()}function Rg(a,b){var c=0,d=0,e=0,f=0,g=0;e=Jb(a);d=Cb(x[a+4>>2],y[a+11|0]);c=Cf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=xq(a,(f-c|0)+1|0,g);if(!a){break c}if(!oy(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function lq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;bd(f,b);x[31725]=0;b=R(1218,x[d+12>>2])|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;e=R(1226,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[c>>2]=e;x[31725]=0;O(1227,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(f);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function nq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;bd(f,b);x[31725]=0;b=R(1201,x[d+12>>2])|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;e=R(1213,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}v[c|0]=e;x[31725]=0;O(1214,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(f);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function jga(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31725]=0;V(989,5660,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function cB(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;cn(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!Dd(a)){break a}Mj(a,b,0)}}function bs(a,b,c){var d=0,e=0,f=0,g=0;a:{d=Gk(b,zd(a));b=Gk(c,b);if(Cb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){pU(a,d);break a}c=a;e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Cb(x[a+4>>2],y[a+11|0]);g=Jb(a);b=f-d|0;x[e+8>>2]=b;a=x[Gb(e+12|0,e+8|0)>>2];b:{if((b|0)==(a|0)){a=b;break b}d=d+g|0;Ui(d,a+d|0,b-a|0)}Xu(c,g,f-a|0)}fb=e+16|0;break a}kn();p()}}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){yc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){yc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function SH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,d+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function ON(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ac(8);x[31725]=0;c=P(36,c+4|0,9363)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Aha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=zQ(a,b,c,d,e^1);x[b>>2]=44472;a=b+4208|0;f=yb(a,0),g=1056964608,x[f>>2]=g;f=yb(a,1),g=1065353216,x[f>>2]=g;f=yb(a,2),g=1020054733,x[f>>2]=g;f=yb(a,3),g=1065353216,x[f>>2]=g;f=yb(a,4),g=1056964608,x[f>>2]=g;f=yb(a,5),g=1048406533,x[f>>2]=g;f=yb(a,6),g=1056964608,x[f>>2]=g;return b|0}function Wsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;$Z(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){_Z(d)}c=-1;a:{if(!e){break a}c=0;if(!b_(d)){break a}c=ve(a,b,a_(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function VB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(2147483631-b>>>0>=c>>>0){h=Jb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Eh(x[ad(i,g+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[g+4>>2];if(e){Xg(c,h,e)}if((d|0)!=(e|0)){Xg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}yd(a,c);pf(a,x[g+8>>2]);fb=g+16|0;return}qf();p()}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=YD(b,c);a:{if(e>>>0<=dp(a)>>>0){x[d+12>>2]=c;g=x[a>>2];f=Sc(g,x[a+4>>2]);h=f>>>0>=e>>>0;if(h){f=c}else{x[d+12>>2]=b;h$(d+12|0,f);f=x[d+12>>2]}b=lp(b,f,g);if(!h){XD(a,x[d+12>>2],c,e-Sc(x[a>>2],x[a+4>>2])|0);break a}or(a,b);break a}Zv(a);al(a,bm(a,e));XD(a,b,c,e)}fb=d+16|0}function A6(a){a=a|0;if(y[500488]){return x[125121]}if(!y[500840]){v[500840]=1}id(500672,5240);id(500684,5247);id(500696,5213);id(500708,5221);id(500720,5204);id(500732,5254);id(500744,5231);id(500756,9758);id(500768,9964);id(500780,11294);id(500792,12930);id(500804,5503);id(500816,10797);id(500828,6622);v[500488]=1;x[125121]=500672;return 500672}function Zsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;a=Tg(d+4|0,a,1);h_(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=zb(a);d=$f(e+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),d);h_(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;as(a,d);_f(d);fb=e+32|0}function ER(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function D_(a){var b=0,c=0;a:{if(kd(a,13907,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Bb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Bb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Bb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Bb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Bb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function Bua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=zd(b),x[f+12>>2]=g;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;xV(e+12|0)}if(c>>>0>=d>>>0){break a}JE(b,x[vb(e+8|0,x[e+12>>2])>>2],d-Yc(x[b+4>>2],y[b+11|0])|0,48)}_c(a,b);fb=e+16|0}function Mo(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function PN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ac(8);x[31725]=0;c=P(36,c+4|0,5848)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Ox(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function GE(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function xM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}d=x[a+8>>2];if(!d){break b}c=x[a+12>>2];if(!c){break b}a=ib[c|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[d|0](b,0,0,0)|0)<0){break a}if((ib[d|0](b,0,0,2)|0)<0){break a}f=ib[c|0](b)|0;c=hb;ib[d|0](b,a,e,0)|0;if((c|0)<0){break b}g=Su(f,c)}return g}ib[d|0](b,a,e,0)|0;return 0}function mga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31725]=0;V(989,8916,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ll(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;_t(y[h+20|0]);g=fb-16|0;fb=g;x[g+12>>2]=f+8;e=fb-16|0;fb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[uq(e,Ak(y[h+20|0]))>>2]](g+12|0,h);fb=e+16|0;fb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=f+16|0}function Xf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Cb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}it(b,c);e=c-4|0;c=Jb(a);g=c+Cb(x[a+4>>2],y[a+11|0])|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function TH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{b:{c:{if(b<g|b>f){a=ac(8);x[31725]=0;d=P(36,h+4|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(d);break b}i=x[a+32>>2]+d|0,j=_e(b*c),x[i>>2]=j;fb=h+16|0;return}e=N()|0;jc(a)}Q(e|0)}p()}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(nh(a,b,0)){break a}e=0;if(!b){break a}b=gB(b,124608,124656);e=0;if(!b){break a}Sb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function BF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){hj(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){fh(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d&65535}function h1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;EE(f,c);c=y[d|0];x[31725]=0;O(245,e+20|0,c|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(e,f);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function XI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=wJ(a,c);x[a>>2]=113144;c=zk(Jb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31725]=0;c=d+4|0;S(1008,c|0,17988,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;W(1345,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(c);break b}fb=d+16|0;return a|0}b=N()|0}Ys(a);Q(b|0)}p()}function Gka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Fb(a+40|0);f=qg(a+52|0);Nf(c);w[a+28>>1]=65472;x[31725]=0;x[b+12>>2]=1065353216;O(883,c|0,b+12|0);g=x[31725];x[31725]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Nf(d);fb=b+16|0;return a|0}a=N()|0;GZ(f);tb(e);uc(d);uc(c);Q(a|0);p()}function kga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Bg(a)|0}Y(T(0)|0)|0;x[31725]=0;V(989,12243,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();return 0}return Bg(22267)|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Ec(24),x[h+8>>2]=i;b=ym(x[e+8>>2]);x[b>>2]=78552;DG(nc(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Xn(e);Wn(c,nc(b),b);zm(e);fb=g+16|0;Ef(a,c);ke(c);fb=f+16|0;fb=d+16|0}function rk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function mv(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);nva(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31725]=0;b=R(783,a|0)|0;c=x[31725];x[31725]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Tb();p()}if(!b){break a}d=Sb(b,0,a)- -64|0}return d}function Xea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31725]=0;W(1002,a|0);f=x[31725];x[31725]=0;if((f|0)!=1){return eu(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31725]=0;V(989,12486,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=x[b+1298404>>2];b=fb-32|0;fb=b;e=b+8|0;Wf(e,c);x[31725]=0;c=b+20|0;S(504,c|0,d|0,e|0);d=x[31725];x[31725]=0;b:{c:{if((d|0)!=1){x[31725]=0;S(246,a|0,0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function OG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function NT(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];de(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function Gta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;T_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){S_(f)}c=-1;a:{if(!e){break a}c=0;if(!V_(f)){break a}c=ve(a,b,U_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=yb(b,c);d=fb-16|0;fb=d;e=Sd(b,c);a:{if(e>>>0<=Ug(a)>>>0){f=c;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;$C(d+12|0,h);f=x[d+12>>2]}b=Wg(b,f,g);if(!i){KY(a,f,c,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,b);break a}vr(a);rm(a,Mf(a,e));KY(a,b,c,e)}fb=d+16|0}function w7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=Mh(g+12|0,x[a+8>>2]);i=xt(0,c,d-c|0,b?b:500204);Lh(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function jf(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31725]=0;O(53,e|0,Yc(f,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[cc(b,a)|0]<<2)+c>>2];x[31725]=0;O(35,e|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Qb(e);Q(a|0);p()}function QB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function j2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;bc(e+24|0,x[d>>2],x[Gb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function Xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];oz(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Gb(e+12|0,e+8|0)>>2];Dr(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];lp(Pe(wb(x[b+4>>2]),c),Pe(Pe(wb(x[b+4>>2]),c),i),h);Dr(a,d,g,0,f)}fb=e+16|0}function VK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Sk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=hu(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function TJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1238;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=Ev(e?0:h,f);if(g){if(!e){le(a)}x[d+4>>2]=1205;e=Be(d+8|0,g,d+4|0);a=QJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}zy();p()}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;oF(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){nF(f)}c=-1;a:{if(!e){break a}c=0;if(!qF(f)){break a}c=ve(a,b,pF(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function oka(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;d=b+16|0;c=gc(b,d,15);kc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(kd(d,8525,15)){break a}Vb(a,15);c=1}fb=b+32|0;return c|0}function jua(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!$D(a,d)){break a}c=0;if(!v$(d)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!gd(a,4)){break a}}c=-1;if(!pk(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}fb=b+32|0;return c|0}function jra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Nr(f,c);x[31725]=0;O(598,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(e,f);x[31725]=0;V(303,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function eT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function CF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Qm(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){fh(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d}function u9(a){a=a|0;a:{x[31725]=0;R(1196,499224)|0;a=x[31725];x[31725]=0;b:{if((a|0)==1){break b}x[31725]=0;R(1196,499560)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}x[31725]=0;R(1197,499308)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}x[31725]=0;R(1197,499644)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}break a}T(0)|0;Tb();p()}}function era(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31725]=0;O(591,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(592,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;yY(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);yY(b);fb=c+16|0;return a|0}function s1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31725]=0;O(228,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(229,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;VE(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);VE(b);fb=c+16|0;return a|0}function kta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;d_(f,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(e,f);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Pr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);g=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;wi(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[mm(e+12|0)>>2];continue}break}fb=e+16|0;if(lc(d,wb(x[b+4>>2]))){ai(a);return}sp(a,d)}function HP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;a=Nb(a);x[31725]=0;c=b+4|0;W(992,c|0);d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){d=wb(x[b+4>>2]);e=wb(x[b+8>>2]);f=x[vb(b,a)>>2];x[31725]=0;S(993,d|0,e|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}uc(c);fb=b+16|0;return}c=N()|0;break a}c=N()|0;uc(b+4|0)}Td(a);Q(c|0);p()}
function V4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;eo(f,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(e,f);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31725]=0;O(924,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;he(d);Q(a|0);p()}he(d);fb=e+16|0}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}if(b>>>0>=4925422){$j();p()}c=Ec(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function CE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;ww(f,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(e,f);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function $c(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;gl(b);e=a+8|0;f=yf(d+12|0,b);a:{b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;O(1292,e|0,c+1|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}b=x[e>>2]}a=yb(b,c);b=x[a>>2];if(b){Am(b);a=yb(x[e>>2],c)}g=a,h=le(f),x[g>>2]=h;jJ(f);fb=d+16|0;return}a=N()|0;jJ(f);Q(a|0);p()}function uA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);b=fb-16|0;fb=b;f=x[d+28>>2];g=x[d+24>>2];h=f-g|0;i=b,j=ml(c,g,h)+D((h|0)/6|0,6)|0,x[i+12>>2]=j;Ac(d+16|0,f,b+12|0);fb=b+16|0;a=BR(a,x[d+16>>2]);i=d,j=tA(c,x[d+20>>2]),x[i+12>>2]=j;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function ld(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;un(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Dc(c+4|0,22267);ze(a+43|0,b);tb(b);qW(a);fb=c+16|0}function nia(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;Qr(b+8|0,a+4228|0);c=x[a+20>>2];d=wb(x[b+8>>2]);e=Xk(x[b+8>>2],x[b+12>>2]);x[31725]=0;S(971,c+4|0,d|0,e|0);c=x[31725];x[31725]=0;a:{if((c|0)==1){c=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(c|0)|0;fp(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function _sa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Ug(a)){d=x[a>>2];e=oc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Gb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){k_(a,1-e|0,b);break a}Ih(a,x[a>>2]+4|0);break a}vr(a);rm(a,Mf(a,1));k_(a,1,b)}fb=c+16|0}function Uua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,10);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=43360;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){ku(a);return a|0}b=N()|0;uc(c);ag(a);Q(b|0);p()}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Qv(e,c);x[31725]=0;O(476,d+20|0,41676);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(d,e);x[31725]=0;V(94,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;Ag(d+8|0)}Q(a|0);p()}}function Tq(a){var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;b=wb(x[a>>2]);f=wb(x[a+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){if(Ib(b,f)){c=c+C[b>>3];b=x[Zu(e+12|0)>>2];continue}break}fb=e+16|0;b=wb(x[a>>2]);x[d+12>>2]=b;c=-c;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){c=c+C[b>>3];C[b>>3]=c;b=x[Zu(d+12|0)>>2];continue}else{fb=d+16|0}break}}function Ls(a,b,c,d,e,f){var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=g+12|0;h=x[re(g+8|0,d)>>2];x[31725]=0;ha(f|0,a+8|0,b|0,c|0,h|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);c=Cz(a+92|0);e=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[c>>2]=47968;x[e>>2]=48008;Vc(d);fb=g+16|0;return a}a=N()|0;Vc(g+12|0);Q(a|0);p()}function U7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1238;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=Ev(e?0:h,f);if(g){if(!e){le(a)}x[d+4>>2]=1205;e=Be(d+8|0,g,d+4|0);a=QJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}zy();p()}function Jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Tn(b,f)){Hn(f)}w[c>>1]=x[d+8>>2];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function mQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Gc(b,b>>31);x[a+4272>>2]=b;x[31725]=0;x[c+12>>2]=0;S(953,a+4256|0,b<<1,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function RR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Gb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Qq(v[xb(a,f)|0]);h=Qq(v[xb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(lc(b,-1)){mo(a,g,f-1|0,e);return Ly(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!lc(c,v[f-1|0])){break a}}mo(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function wja(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);Bk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Bk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;mA(a,c);_f(c);fb=d+32|0}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=Hf(a,c);d=e+8|0;$d(d,x[a+36>>2]);f=a;a:{if(!c){Pc(d,a+32|0,5);d=0;if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;ZE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){YU(d,_b(x[b>>2],a));a=a+1|0;continue}break}d=c}gf(f,d);fb=e+32|0}function Jka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!Dd(x[a+1298300>>2])){b=x[a+24620>>2];d=fb-16|0;fb=d;e=Ec(536);x[31725]=0;f=P(878,e|0,b|0)|0;b=x[31725];x[31725]=0;a:{if((b|0)!=1){b=yf(d+12|0,f);fb=d+16|0;b=x[b>>2];break a}a=N()|0;Db(e);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;wS(b,le(a));WA(a)}fb=c+16|0}function JE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Gk(b,zd(a));a:{f=Cb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Jb(a);if((b|0)==(f|0)){break b}g=b+e|0;Ui(g+c|0,g,f-b|0);break b}Wm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}hm(b+e|0,c,d);b=c+f|0;ng(a,b);fd(b+e|0,0)}break a}kn();p()}zd(a)}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;nX(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){mX(d)}c=-1;a:{if(!e){break a}c=0;if(!pX(d)){break a}c=ve(a,b,oX(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function ysa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Sc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[zb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Gp(a,b,c);break a}d=zb(a);d=vn(e+12|0,bm(a,Sc(x[a>>2],f)+b|0),Sc(x[a>>2],x[a+4>>2]),d);tZ(d,b,c);hr(a,d);tn(d)}fb=e+32|0;return}if(b>>>0<d>>>0){or(a,b+e|0)}}function L0(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=_h(c+4|0,a,1);fj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=mk(d+12|0,nk(a,Zc(x[a>>2],x[a+4>>2])+1|0),Zc(x[a>>2],x[a+4>>2]),c);fj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Xr(a,c);jj(c);fb=d+32|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31725]=0;V(989,13107,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-784|0;fb=e;c=fb-16|0;fb=c;f=e+12|0;xF(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){wF(f)}c=-1;a:{if(!d){break a}c=0;if(!zF(f)){break a}c=ve(a,b,yF(y[e+527|0]),0)}fb=e+784|0;return c|0}function io(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Sd(b,c);if(f>>>0<1073741808){b:{if(kr(f)){Me(d,f);break b}Uj(e+8|0,yn(f)+1|0);g=x[e+8>>2];yd(d,g);pf(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){yd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}yd(d,0);fb=e+16|0;break a}qf();p()}return a|0}function y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=fb-16|0;fb=c;f=e+10|0;hF(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){gF(f)}c=-1;a:{if(!d){break a}c=0;if(!jF(f)){break a}c=ve(a,b,iF(y[e+45|0]),hb)}fb=e+48|0;return c|0}function si(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Wj(b,c);if(f>>>0<2147483632){b:{if(Tk(f)){Me(d,f);break b}sg(e+8|0,Eh(f)+1|0);g=x[e+8>>2];yd(d,g);pf(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){fd(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}fd(d,0);fb=e+16|0;break a}qf();p()}return a|0}function i0(a,b,c,d){var e=0,f=0,g=0,h=0;e=Cb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Mc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Jb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Ui(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Ui(h,c,d);b=d+e|0;ng(a,b);fd(b+f|0,0);return a}eq(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}kn();p()}function f3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;bd(a,x[b+28>>2]);x[31725]=0;d=e+12|0;S(110,d|0,b|0,c|0);f=x[31725];x[31725]=0;a:{if((f|0)==1){break a}Zb(d);b=x[b+24>>2];if(b){x[31725]=0;d=e+8|0;S(111,d|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}Zb(d)}fb=e+16|0;return}b=N()|0;Zb(a);Q(b|0);p()}function a0(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(ci(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+28;fb=b+16|0;Gd(kE(x[b+12>>2]));a=x[mm(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function Pj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(lc(x[a>>2],b)){a=0}else{b=_i(b);e=_i(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Zg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=ij(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[ij(c+12|0)>>2];continue}break}fb=c+16|0;a=mE(wb(x[a>>2]),b)}return a&65535}function Is(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=f+12|0;g=x[re(f+8|0,c)>>2];x[31725]=0;ba(e|0,a+8|0,b|0,g|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);d=Cz(a+92|0);e=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[d>>2]=47968;x[e>>2]=48008;Vc(c);fb=f+16|0;return a}a=N()|0;Vc(f+12|0);Q(a|0);p()}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wo(e,c);x[31725]=0;c=d+20|0;O(14,c|0,e|0);f=x[31725];x[31725]=0;b:{c:{if((f|0)!=1){x[31725]=0;S(845,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wo(e,c);x[31725]=0;c=d+20|0;S(504,c|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;S(246,a|0,0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){_q(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);Zm(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function _F(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31725]=0;W(230,b|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;he(c);Q(a|0);p()}he(c);fb=d+16|0}function X3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(Dd(e)){f=d+4|0;if(!Ad(x[c+4>>2],y[c+11|0])){GP(c,18382);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31725]=0;P(842,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}tb(f)}_c(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;hD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);hD(e,b);Sb(x[d+8>>2]+c|0,0,33-c|0);Vb(a,x[d+28>>2]);fb=d+32|0;return c|0}function $X(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function sra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Fp(e,b,c);x[31725]=0;b=d+20|0;S(125,b|0,28,e|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){x[31725]=0;O(12,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Eta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;e=d+6|0;K_(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!M_(e)){break a}c=ve(a,b,L_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function Bra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;c=fb-16|0;fb=c;e=f+12|0;VY(c+8|0,e);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){UY(e)}c=-1;a:{if(!d){break a}c=0;if(!XY(e)){break a}c=ve(a,b,WY(e),hb)}fb=f- -64|0;return c|0}function AA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=$u(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Wi(g)*$u(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=qC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function Zua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;D0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){C0(f)}c=-1;a:{if(!d){break a}c=0;if(!F0(f)){break a}c=ve(a,b,1024,0)}fb=e+1968|0;return c|0}function QU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Mj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Uh(a+8|0,18,b+15|0);Gv(a+26|0,18,27562);v[b+14|0]=255;Uh(a+62|0,256,b+14|0);zh(x[a>>2],x[a+4>>2],65535,261,1);zh(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function L3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(nh(a,x[b+8>>2],e)){Nx(b,c,d);return}a:{if(!nh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function Gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wo(e,c);x[31725]=0;c=d+20|0;S(125,c|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function AM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){yM(a,65536);c=gc(b+16|0,xb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function zta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-208|0;fb=f;c=fb-16|0;fb=c;e=f+2|0;B_(c+8|0,e);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){A_(e)}c=-1;a:{if(!d){break a}c=0;if(!D_(e)){break a}c=ve(a,b,C_(e),hb)}fb=f+208|0;return c|0}function _y(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((ro(a,f,b)|0)>=0){if((ro(a,e,b)|0)>=0){break a}}j=f;f=(ro(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}LL(g,h);fb=g+240|0}function _Q(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=cA(a);b=ok(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31725]=0;b=ba(951,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){XQ(a,b);WQ(b);break b}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Tb();p()}function ZQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Ug(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31725]=0;b=ba(952,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zm(a,b);_f(b);break b}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Tb();p()}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=45740;b=a+4208|0;e=yb(b,0),f=1065353216,x[e>>2]=f;e=yb(b,1),f=1065353216,x[e>>2]=f;e=yb(b,2),f=1051372203,x[e>>2]=f;e=yb(b,3),f=0,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function JZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31725]=0;c=d+20|0;S(504,c|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function $ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45504;b=a+4208|0;e=yb(b,0),f=1056880300,x[e>>2]=f;e=yb(b,1),f=1050733080,x[e>>2]=f;e=yb(b,2),f=1056964608,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function mS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;kS(d,b+80|0);x[31725]=0;b=c+20|0;S(125,b|0,0,d|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;O(12,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Zpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=yw(c+4|0,a,1);LX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);LX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Xv(c);fb=d+32|0}function zfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(nP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6229,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function yfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(mP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,9377,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function wfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(lP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6272,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function vfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(kP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6174,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ufa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(jP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6130,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=lg(d+8|0,b);x[31725]=0;e=d+20|0;S(841,e|0,b|0,c|0);f=x[31725];x[31725]=0;a:{b:{if((f|0)!=1){x[31725]=0;S(73,a|0,e|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function iE(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=G$(c+4|0,a,1);F$(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=D$(d+12|0,E$(a,Ir(x[a>>2],x[a+4>>2])+1|0),Ir(x[a>>2],x[a+4>>2]),c);F$(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;C$(a,c);B$(c);fb=d+32|0}function bma(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=jC(c+4|0,a,1);XB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=fv(d+12|0,$q(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);XB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;_U(a,c);YB(c);fb=d+32|0}function Kta(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=yw(c+4|0,a,1);SD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);SD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Xv(c);fb=d+32|0}function EM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;b=(b|0)>0|(b|0)>=0}ib[d|0](c,a,f,0)|0}return b|0}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:983;return}Y(T(0)|0)|0;x[31725]=0;V(989,13137,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;_X(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){ZX(f)}c=-1;a:{if(!d){break a}c=0;if(!$X(f)){break a}c=ve(a,b,256,0)}fb=e+128|0;return c|0}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);uC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Xp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);uC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;MW(a,c);LW(c);fb=d+32|0}function ME(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=nva(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31725]=0;b=c+20|0;O(964,b|0,d|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;S(965,a|0,0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function iA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=ce(a);e=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=br(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!br(z[b>>1],z[td(c)>>1])){break a}}c=rg(a)}a=vb(d+12|0,c);fb=d+16|0;return x[a>>2]}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;kD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);kD(e,b);Sb(x[d+8>>2]+c|0,0,4896-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=Bm(d+8|0,b);x[31725]=0;e=d+20|0;S(150,e|0,b|0,c|0);f=x[31725];x[31725]=0;a:{b:{if((f|0)!=1){x[31725]=0;S(4,a|0,e|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function tH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;Vp(g,c);x[31725]=0;O(e|0,f+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(f,g);x[31725]=0;V(94,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function mH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;Y_(g,c);x[31725]=0;O(e|0,f+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tk(f,g);x[31725]=0;V(94,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wo(d,b);x[31725]=0;b=c+20|0;O(14,b|0,d|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;S(246,a|0,0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function eua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;Q0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){FE(f)}c=-1;a:{if(!d){break a}c=0;if(!m$(f)){break a}c=ve(a,b,72,0)}fb=e+32|0;return c|0}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;_k(d,b);x[31725]=0;b=c+20|0;O(14,b|0,d|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;S(246,a|0,0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function T1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31725]=0;b=c+20|0;S(125,b|0,22,d|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;O(12,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function S1(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=sG(c+4|0,a);ax(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=qG(d+12|0,rG(a,is(x[a>>2],x[a+4>>2])+1|0),is(x[a>>2],x[a+4>>2]),c);ax(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;oG(a,c);cx(c);fb=d+32|0}function Oua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);e=c,f=Bb(z[d+10>>1]),w[e>>1]=f;c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;IV(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);IV(e,b);Sb(x[d+8>>2]+c|0,0,263-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;l_(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);l_(e,b);Sb(x[d+8>>2]+c|0,0,102-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function Y2(a){a=a|0;var b=0,c=0,d=0,e=0;a:{b=fb-32|0;fb=b;c=b+8|0;Dc(c,13576);x[31725]=0;d=b+20|0;S(125,d|0,1,c|0);e=x[31725];x[31725]=0;b:{c:{if((e|0)!=1){x[31725]=0;O(12,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function TX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=nva(y[a+30|0],0,37,0);d=hb;b=nva(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function pA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31725]=0;O(924,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;hc(d);Q(a|0);p()}hc(d);fb=e+16|0}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;Yv(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Yv(e,b);Sb(x[d+8>>2]+c|0,0,22-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;aD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);aD(e,b);Sb(x[d+8>>2]+c|0,0,40-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function e8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=x[27991];x[g+24>>2]=x[27990];x[g+28>>2]=h;h=x[27989];x[g+16>>2]=x[27988];x[g+20>>2]=h;h=x[27987];x[g+8>>2]=x[27986];x[g+12>>2]=h;h=x[27985];x[g>>2]=x[27984];x[g+4>>2]=h;h=a;a=g+32|0;b=xk(h,b,c,d,e,f,g,a);fb=a;return b|0}function yea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){yO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31725]=0;V(989,5784,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function o1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;xw(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);xw(e,b);Sb(x[d+8>>2]+c|0,0,65-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function fQ(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=ri(E(B[Mv(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function Yea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return TO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31725]=0;V(989,6659,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function R4(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(ut(c)|0)!=0}if(b&2){a=(tt(c)|0)!=0|a}if(b&4){a=(st(c)|0)!=0|a}if(b&8){a=(rt(c)|0)!=0|a}if(b&16){a=(qt(c)|0)!=0|a}if(b&32){a=(pt(c)|0)!=0|a}if(b&64){a=(Nh(c)|0)!=0|a}if(b&128){a=(ot(c)|0)!=0|a}if(b&256){a=(nt(c)|0)!=0|a}if(b&512){a=(mt(c)|0)!=0|a}return a|0}function Kl(a,b){var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){_q(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);mA(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;gk(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);gk(e,b);Sb(x[d+8>>2]+c|0,0,5-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function aR(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;pg(a,c+14|0);e=z[c+14>>1];Kl(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;Cq(a,c+8|0);f=yb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function y7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;g=fb-16|0;fb=g;x[e>>2]=c;b=g+12|0;a=ey(b,0,x[a+8>>2]);f=2;a:{if(a+1>>>0<2){break a}c=a-1|0;f=1;if(c>>>0>d-x[e>>2]>>>0){break a}while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}f=0}a=f;fb=g+16|0;return a|0}function vm(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=$S(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return _S(a,b,c,e);case 1:break b;default:break a}}f=_S(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=$S(x[a+720>>2],x[a+1272>>2],e)}return f}function pu(a){var b=0,c=0,d=0;b=Ci(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=rq(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ci(d+c)*.5}else{b=0}C[a+4248>>3]=b}ou(a)}function fV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=OF(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Br(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function f$(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=WW(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Br(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function YQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){$j();p()}d=Ec(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function Osa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;mw(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){VZ(d)}c=-1;a:{if(!e){break a}c=0;if(!XZ(d)){break a}c=ve(a,b,WZ(d),hb)}fb=d+192|0;return c|0}function Qn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-qd((qd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-qd(e+(qd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Sb(a,0,b<<3)}}function OQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<1,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;qZ(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){mD(d)}c=-1;a:{if(!e){break a}c=0;if(!MV(d)){break a}c=ve(a,b,LV(d),hb)}fb=d+80|0;return c|0}function gt(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}c=Ec(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function b2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c+8|0;_k(d,b);x[31725]=0;b=c+20|0;O(14,b|0,d|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){x[31725]=0;O(15,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Qb(b);tb(d);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Qb(c+20|0)}tb(c+8|0);Q(b|0);p()}function yU(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=wt(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Wl(e,b,+n());return}a:{if(!zf(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Wl(a,b,zf(c)?NaN:c);return}b=wt(b);g=Wi(c);Wl(a,b*kf(c),g*b)}function rv(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124213]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Jy(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Jy(a)}le(b)}return a}function Yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Ki(f,b);break c;default:break d}}BZ(f,b,e)}f=c}gf(a,f);fb=d+16|0}function SI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;Qb(b+520|0);Qb(b+508|0);Qb(b+496|0);d=b+460|0;c=Qb(b+484|0);while(1){c=Qb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=Qb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=Qb(c-12|0);if((d|0)!=(c|0)){continue}break}Ws(b);return a|0}function HI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;tb(b+520|0);tb(b+508|0);tb(b+496|0);d=b+460|0;c=tb(b+484|0);while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=tb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}Ws(b);return a|0}function rH(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Cc(f,c);x[31725]=0;c=e+20|0;S(d|0,c|0,b|0,f|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c);tb(f);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Qb(e+20|0)}tb(e+8|0);Q(a|0);p()}}function my(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(kr(b)){Me(d,b);break b}Uj(f+8|0,yn(b)+1|0);e=x[f+8>>2];yd(d,e);pf(d,x[f+12>>2]);Yd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;JF(d,b,e+12|0);fb=e+16|0;yd((b<<2)+d|0,0);fb=f+16|0;break a}qf();p()}return a|0}function FV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){yp(e);break a}dE(b+8|0,Yb(Zi(rq(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];de(e,d,b+7|0)}fb=b+16|0;b=c+4|0;VD(b,a+36|0,a+37|0);UD(b,e);fb=c+16|0}function vt(a,b,c,d){var e=0,f=0,g=0;e=fb-160|0;fb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Sb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1200;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31600]=61;break a}v[f|0]=0;a=GL(e,c,d,1176,1177)}fb=e+160|0;return a}function yha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-1|0){case 0:c=ri(c);if(c==B[yb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(ri(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function xH(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Dc(e,b);x[31725]=0;b=d+20|0;S(125,b|0,c|0,e|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){x[31725]=0;O(12,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function nfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return eP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,12865,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function fia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-3|0){case 0:c=ri(c);if(c==B[yb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(ri(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function _ea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return VO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31725]=0;V(989,9801,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Qua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Oj(x[a>>2],x[a+4>>2])>>>0<=49){b=$B(c,x[a+12>>2]);x[31725]=0;O(293,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}Hk(b);ck(a,Oj(x[a>>2],x[a+4>>2])-1&255);b=Oj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Hk(b);Q(a|0);p()}function Maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+28>>2]){c=x[d>>2];break a}e=ib[x[b+32>>2]](x[b+24>>2],c,0,0)|0;c=x[d>>2];if((e|0)<0){break a}d=x[d+4>>2];e=c;while(1){if(!d){break a}f=ib[x[b+28>>2]](x[b+24>>2],e,d)|0;if(!f){break a}g=f+g|0;d=d-f|0;e=e+f|0;continue}}bc(a,c,g)}function I_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function yG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=c+8|0;Qw(e,b);x[31725]=0;d=c+20|0;S(11,d|0,1,e|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){x[31725]=0;O(12,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){b=N()|0;Qb(d);break a}Qb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function sfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return iP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,8796,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function pfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return gP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7165,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ofa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return fP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,5319,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function mfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return dP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,9330,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ffa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return Bo(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7133,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function efa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return zq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,6822,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function dfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return ZO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,6940,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function cfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return YO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7008,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function bfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return yq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7480,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Uea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return RO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,5816,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function tm(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Jb(b);e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;Wg(d,d+x[Gb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Vm(d+x[Gb(c+12|0,c+8|0)>>2]|0,a+d|0,78784);fb=c+16|0}function tfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+PA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31725]=0;V(989,10149,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function rr(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;gC(c,CV(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;gC(a,sC(a),b);fb=b+32|0}function lfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+cP(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31725]=0;V(989,15148,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(nh(a,x[b+8>>2],0)){Mx(b,c,d);return}f=x[a+12>>2];rI(x[a+16>>2],x[a+20>>2],b,c,d);e=a+24|0;a=(a+16|0)+(f<<3)|0;a:{if(e>>>0>=a>>>0){break a}while(1){rI(x[e>>2],x[e+4>>2],b,c,d);if(y[b+54|0]){break a}e=e+8|0;if(a>>>0>e>>>0){continue}break}}}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);Lq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=zC(c+223848|0,b+223848|0);x[31725]=0;P(847,c+223860|0,b+223860|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){return c|0}b=N()|0;dc(a);Q(b|0);p()}function GQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function gE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=lf(b),x[g+28>>2]=h;c=f+8|0;ug(c,b,x[Gb(c,f+28|0)>>2]);b=$e(c);x[31725]=0;aa(238,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(c);fb=f+32|0;return}a=N()|0;Kc(f+8|0);Q(a|0);p()}function $K(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=Jt(a);x[a+32>>2]=b;x[a>>2]=94860;e=d+12|0;bd(e,x[a+4>>2]);x[31725]=0;b=R(1198,x[d+12>>2])|0;f=x[31725];x[31725]=0;if((f|0)!=1){Zb(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=ko(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;Zb(d+12|0);lo(a);Q(b|0);p()}function mq(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;bd(d,a);x[31725]=0;a=R(1217,x[c+12>>2])|0;e=x[31725];x[31725]=0;a:{b:{if((e|0)==1){break b}x[31725]=0;V(1228,a|0,111728,111754,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Zb(d);fb=c+16|0;break a}a=N()|0;Zb(c+12|0);Q(a|0);p()}return b}function H0(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31725]=0;c=d+20|0;S(125,c|0,b|0,e|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){x[31725]=0;O(12,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Qb(c);tb(e);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Qb(d+20|0)}tb(d+8|0);Q(c|0);p()}function Cf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[b|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function mh(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);bg(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function c$(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(pd(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;b$(b+12|0,-1);fb=b+16|0;a=x[tC(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function ZK(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=mL(a);x[a+32>>2]=b;x[a>>2]=95228;e=d+12|0;bd(e,x[a+4>>2]);x[31725]=0;b=R(38,x[d+12>>2])|0;f=x[31725];x[31725]=0;if((f|0)!=1){Zb(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=ko(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;Zb(d+12|0);Dt(a);Q(b|0);p()}function TW(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Bb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Bb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Bb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function Wea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31725]=0;V(989,7642,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function Sea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31725]=0;V(989,10930,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function J0(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;mw(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);mw(e,b);Sb(x[d+8>>2]+c|0,0,192-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function sW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=Ar(f*+A[Gb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=Ar(f*+A[Gb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;wn(a,h,Gb(b,g));fb=e+16|0}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=42300;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];q0(a+4260|0,80,150,80,255);x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;uc(b);ag(a);Q(c|0);p()}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function px(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function By(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Ii(f,0,0);PK(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function $_(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function qfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return hP(x[a+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,9766,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function nB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ek(a,b,b+700|0,c<<2,0)}}function jO(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47652;a=ac(8);x[31725]=0;b=P(36,b+4|0,12133)|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0)}p()}function fja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Sc(b,x[c+8>>2])|0)!=8){break b}d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((d|0)!=1869112133){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=d;x[a+4264>>2]=c;break a}aA(a,a)}qu(a)}function ZF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-qd((qd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-qd((qd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;tf(b);x[d+12>>2]=0;a:{if(!Nk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(mi(a,d+11|0)){Yp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function p_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=qg(a);b=b+236|0;e=zr(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31725]=0;S(403,c+4|0,a|0,c+14|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Sv(a);Q(b|0);p()}function gQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<2,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function oB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ek(a,b,b+700|0,c,0)}}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Ed(y[b+24|0])){a=qg(a);c=_i(x[b>>2]);d=Rf(b);x[31725]=0;S(850,a|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;P(849,a+12|0,b+12|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;hT(a);Q(b|0);p()}function wC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!je(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}un(b);b=ap(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Fh(b)){break a}if(x[a>>2]!=(d|0)){fs(b+68|0)}yc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function pH(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31725]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){a=d+20|0;Rh(a,b);Ab(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Hh(a);Q(b|0);p()}function cN(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;_t(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;e=x[18379];x[a+8>>2]=x[18378];x[a+12>>2]=e;e=x[18377];x[a>>2]=x[18376];x[a+4>>2]=e;b=ib[x[uq(a,Ak(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function qk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function hR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Ug(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;gR(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){nA(a,b-e|0,c);break a}Ih(a,x[a>>2]+(b<<2)|0);break a}vr(a);rm(a,Mf(a,b));nA(a,b,c)}fb=d+16|0}function Mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;Ao(c,a);if(x[b>>2]){CZ(b);a=x[b>>2];$s(b);Db(a);e=zb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=zb(c);e=zb(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;of(c);fb=d+16|0}function lga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31725]=0;V(989,5690,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function ai(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Ec(16),x[g+8>>2]=h;b=ym(x[c+8>>2]);x[b>>2]=41192;g=Vn(nc(b)),h=41324,x[g>>2]=h;b=d+8|0;f=Xn(c);Wn(b,nc(f),f);zm(c);fb=e+16|0;Ef(a,b);ke(b);fb=d+16|0;x[a+8>>2]=0;Nd(a+12|0);return a}function Efa(a){a=a|0;var b=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;V(989,11974,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Tb();p()}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(642,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}zp(a,b,c)}b=d+8|0;Qd(b);_j(b);fb=d+16|0;return a|0}a=N()|0;_j(d+8|0);Q(a|0);p()}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(1217,x[g+8>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(b);gK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function b8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(1217,x[g+8>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(b);fK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function _D(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=lf(b),x[f+28>>2]=g;c=e+8|0;ug(c,b,x[Gb(c,e+28|0)>>2]);b=$e(c);x[31725]=0;V(345,a|0,b|0,x[e+8>>2],d|0);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(c);fb=e+32|0;return}a=N()|0;Kc(e+8|0);Q(a|0);p()}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(227,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}XE(a,b,c)}b=d+8|0;Qd(b);ch(b);fb=d+16|0;return a|0}a=N()|0;ch(d+8|0);Q(a|0);p()}function WP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;UP(a+60|0);UP(a+52|0);Iq(a+49956|0);Iq(a+58148|0);Iq(a+66340|0);Iq(a+74532|0);Sb(a+228|0,0,32768);Sb(a+32996|0,0,512);Sb(a+33508|0,0,16384)}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(462,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}tD(a,b,c)}b=d+8|0;Qd(b);im(b);fb=d+16|0;return a|0}a=N()|0;im(d+8|0);Q(a|0);p()}function rj(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=Mh(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=vt(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Fd(d);x[h>>2]=a;if(!a){break a}f=vt(a,d,c,x[b+12>>2])}fb=b+16|0;Lh(g);fb=e+16|0;return f}function q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31725]=0;d=e+8|0;V(169,d|0,b|0,e+28|0,e+24|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=e+16|0;Qp(c,x[e+8>>2],x[e+12>>2]);Ef(a,c);ke(c);ke(d);ke(b);fb=e+32|0;return}a=N()|0;ke(b);Q(a|0);p()}function i8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(28,x[g+8>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(b);jK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function h8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(28,x[g+8>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(b);iK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function _p(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){$j();p()}d=Ec(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=nc(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function Yra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Dd(b)){break a}x[31725]=0;d=a;a=c+12|0;O(502,d|0,a|0);e=x[31725];x[31725]=0;d=b;if((e|0)!=1){break a}b=N()|0;og(a);Q(b|0);p()}og(c+12|0);fb=c+16|0;return d|0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Nk(f,b);break c}pN(f,b,e)}f=c}gf(a,f);fb=d+16|0}function Ju(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=Hj(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=xh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(dp(a)>>>0>=b>>>0){f=x[a>>2];e=Sc(f,x[a+4>>2]);x[d+8>>2]=e;Uh(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Gp(a,b-e|0,c);break a}or(a,x[a>>2]+b|0);break a}Zv(a);al(a,bm(a,b));Gp(a,b,c)}fb=d+16|0}function ri(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function g3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Nt(c);x[a>>2]=94320;x[d>>2]=94340;x[a+60>>2]=94380;x[a>>2]=94360;x[a+4>>2]=0;e=c;c=a+8|0;so(e,c);x[a>>2]=94320;x[d>>2]=94340;x[31725]=0;P(109,c|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Cl(d);Q(a|0);p()}function Rs(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!fq(e+12|0,b,c)){break a}f=x[e+12>>2];b=Sx(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function PZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;e=c+44|0;ug(e,a,32);a=x[c+44>>2];d=c+20|0;wg(d,2,$e(e),a);x[31725]=0;a=c+32|0;O(220,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=c+12|0;Ln(d,b);tm(d,a);tb(a);Kc(e);fb=c- -64|0;break a}a=N()|0;Kc(c+44|0);Q(a|0);p()}}function QF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=_d(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function EP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;MQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function OY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=_e(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=D(y[x[e+12>>2]+25168|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=_e(733.8401379310345/f*1e4);break a}a=_e(f/.264*1e4)}fb=e+16|0;return a}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31725]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;d=a;a=c+4|0;S(81,d|0,b|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){Hh(a);fb=c+32|0;return}a=N()|0;Hh(c+4|0);Q(a|0);p()}function n0(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=xb(a,31),f=0,v[e|0]=f;d=Li(a,Xo(a),0);v[c+15|0]=0;d=Wj(a,d);Vm(d+a|0,Xo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[xb(a,b)|0]>=32){if(y[xb(a,b)|0]!=127){break a}}e=xb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}fb=c+16|0}function a8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(1217,x[a+8>>2])|0;g=x[31725];x[31725]=0;if((g|0)!=1){Zb(b);eK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function Xe(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function XZ(a){var b=0,c=0;b=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{b:{if((b|0)!=1297108297){if((b|0)!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}c=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return c}function cn(a,b,c,d){var e=0,f=0,g=0;a:{f=D(b,872)+a|0;e=x[f+1075648>>2];if(!e){break a}if(!Rj(y[e+31|0])){break a}g=y[e+34|0]-1|0;if((g&255)>>>0>249){break a}a=x[vd(a+906300|0,g)>>2];if(!a){break a}ib[x[x[a>>2]+96>>2]](a,e,c,d,b);if(c>>>0>250){break a}w[f+1075834>>1]=65535}}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=ac(16);if(!y[502193]){v[502193]=1}a=gc(c+8|0,a,126384);x[31725]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1178,d|0,c|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){da(a|0,124308,1179);p()}a=N()|0;jc(d);Q(a|0);p()}function g8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;bd(b,x[d+28>>2]);x[31725]=0;d=R(28,x[a+8>>2])|0;g=x[31725];x[31725]=0;if((g|0)!=1){Zb(b);hK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function BH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;wc(c,f);wc(c,65535);h=z[g+12>>1];xg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Vr(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function d0(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=rE(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=VV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31725]=0;O(786,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;he(a);Q(b|0);p()}he(a);fb=d+16|0}function Fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;rX(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){qX(d)}if(a){e=sX(d)}fb=b+160|0;return e|0}
function Foa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=dj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Vh(c);if((c|0)!=1){break b}}gy(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=(c<<2)+d|0;yd(a,b);yd(a+4|0,0)}function E$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=A$(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function yua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;_$(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){Z$(d)}if(a){e=$$(d)}fb=b+624|0;return e|0}function u0(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function rd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];mf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function rM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;mf(e+24|0,b,c);b=Ef(e+16|0,d);x[31725]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;jg(165,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31725];x[31725]=0;if((a|0)!=1){ke(d);fb=e+32|0;return}a=N()|0;ke(d);Q(a|0);p()}function moa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(227,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}_q(a,b)}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}a=N()|0;ch(c+8|0);Q(a|0);p()}function hra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(590,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}jD(a,b)}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}a=N()|0;ch(c+8|0);Q(a|0);p()}function GY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!je(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}wc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Fh(a)){break a}yc(x[a+20>>2],x[b+20>>2],Wk(x[a>>2],z[a+34>>1]))}}function AQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,D(b,254)|0,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function po(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=pva(a,b,10,0);e=hb;a=nva(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+4|0;SW(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){RW(d)}if(a){e=TW(d)}fb=b+208|0;return e|0}function c9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Yp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=dj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Vh(c);if((c|0)!=10){break b}}Wm(a,d,1,d,d,0,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function PF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+_d(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function Nqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=CJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31725]=0;W(599,b|0);e=x[31725];x[31725]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Cr(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);a=fb-16|0;fb=a;e=c;b=x[d+28>>2];c=x[d+24>>2];g=b-c|0;e=e-g|0;x[a+12>>2]=e;ml(e,c,g);Ac(d+16|0,b,a+12|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,a,d+12|0);fb=d+32|0;fb=f+16|0}function Bta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+3|0;H_(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){G_(d)}if(a){e=I_(d)}fb=b+160|0;return e|0}function WE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=yw(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31725]=0;W(230,b|0);e=x[31725];x[31725]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Vta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+10|0;Yv(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){$_(d)}if(a){e=a$(d)}fb=b+32|0;return e|0}function Rra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+11|0;gk(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){iZ(d)}if(a){e=jZ(d)}fb=b+16|0;return e|0}function P_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;wc(c,256);wc(c,65535);f=z[d+12>>1];xg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Vr(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Mla(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=dj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Vh(c);if((c|0)!=10){break b}}VB(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function Ee(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Dx(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;ug(g,a,e);a=x[f+44>>2];e=f+20|0;wg(e,d,$e(g),a);x[31725]=0;a=f+32|0;O(220,a|0,e|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=f+12|0;gc(d,b,c);tm(d,a);tb(a);Kc(g);fb=f- -64|0;break a}a=N()|0;Kc(f+44|0);Q(a|0);p()}}function lF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;bd(d,a);x[31725]=0;a=R(28,x[c+12>>2])|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;a=P(29,a|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}Zb(d);fb=c+16|0;return a}a=N()|0;Zb(c+12|0);Q(a|0);p()}function ku(a){var b=0,c=0,d=E(0);c=y[a+4232|0];if(c>>>0>=5){v[a+4232|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-De(E(2),E(-E((b+1&255)>>>0))));break a}d=De(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function YW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=wb(x[a>>2]);x[c+12>>2]=b;e=wb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Md(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function Eia(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6053,9014,88,7400);p()}fb=b+16|0;return a|0}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;tf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function ak(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wb(x[b>>2]);f=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(H$(c,x[d>>2],x[d+4>>2])){break a}d=x[mm(e+12|0)>>2];continue}break}fb=e+16|0;if(lc(d,wb(x[b+4>>2]))){ai(a);return}sp(a,d)}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}bc(a,x[c>>2],g)}function LF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}Ep(d+8|0,a,e);Pw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function tM(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+32|0,a);a=Hi(a,0,0,2);$d(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];_m(a,b);a=Su(d,c);fb=b+48|0;return a}function m$(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Pf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Sk(b,1,c,x[a+32>>2])}return c|0}function dq(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function O$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[ef(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[ef(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function DJ(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;e=sc(a+8|0),f=0,v[e+128|0]=f;c=b+8|0;Rd(c,x[vb(b+4|0,a)>>2]);x[31725]=0;O(1291,a|0,30);d=x[31725];x[31725]=0;if((d|0)!=1){_q(a,30);Qd(c);zJ(c);fb=b+16|0;return a}a=N()|0;zJ(b+8|0);Q(a|0);p()}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=e|(d|y[b|0]);x[a+4232>>2]=c;ku(a)}}function Zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=e|(d|y[b|0]);x[a+4264>>2]=c;qu(a)}}function Uq(a,b,c,d){var e=0,f=0,g=0;a:{e=Xl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Nj(g)){break a}f=Hd(a+318|0,e);e=OU(e);if(v[xb(f,10)|0]&1|d){zh(g,x[a+4>>2],b,e- -64&65535,NU(c,y[xb(f,2)|0]))}if(d){break a}zh(x[a>>2],x[a+4>>2],b,e+67&65535,NU(c,y[xb(f,3)|0]))}}function uv(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function ZB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=jC(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31725]=0;O(786,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=d+16|0}function Xh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function P0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;tf(b);f=d+28|0;ug(f,a,c);a=x[d+28>>2];e=d+4|0;wg(e,3,$e(f),a);x[31725]=0;g=d+16|0;O(220,g|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){Ab(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function J9(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){mo(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Pf(v[a|0])}return d|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){ze(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Kh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31725]=0;x[g+4>>2]=x[g+4>>2]&e|d;d=a;a=g+4|0;S(c|0,d|0,b|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){Hh(a);fb=g+32|0;return}a=N()|0;Hh(g+4|0);Q(a|0);p()}function Fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){om(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function zt(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]<0;b:{c=x[b+4>>2];c:{if(!c){Vy(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function vP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126908;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function X$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){zc(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=lu(a+8|0,d);x[31725]=0;P(967,a+20|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function Dl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=Pt(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Bx(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31725]=0;x[f+4>>2]=x[f+4>>2]&e|d;d=a;a=f+4|0;S(c|0,d|0,b|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){Hh(a);fb=f+32|0;return}a=N()|0;Hh(f+4|0);Q(a|0);p()}function An(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=IC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(kr(c)){Me(d,c);break b}Uj(e+8|0,yn(c)+1|0);f=x[e+8>>2];yd(d,f);pf(d,x[e+12>>2]);Yd(d,c);d=f}yd(Yi(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}qf();p()}return a|0}function yH(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31725]=0;O(d|0,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}Gp(a,b,c)}b=e+8|0;Qd(b);cj(b);fb=e+16|0;return a}a=N()|0;cj(e+8|0);Q(a|0);p()}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;e=c+28|0;ug(e,a,32);a=x[c+28>>2];d=c+4|0;wg(d,1,$e(e),a);x[31725]=0;a=c+16|0;O(220,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){zc(b,a);tb(a);Kc(e);fb=c+48|0;break a}a=N()|0;Kc(c+28|0);Q(a|0);p()}}function i4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=io(e+4|0,c,d);c=GK(0,Jb(b),0);x[31725]=0;a=U(1365,a|0,c|0,0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){GK(Jb(a),Jb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);Qb(b);fb=e+16|0;return}a=N()|0;Qb(b);Q(a|0);p()}function _n(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);bg(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function WZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function SC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;PC(d+8|0,e);f=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=QC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function f4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=si(e+4|0,c,d);c=IK(0,Jb(b),0);x[31725]=0;a=U(543,a|0,c|0,0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){IK(Jb(a),Jb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function R1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-48|0;fb=c;d=-1;e=a;a=c+12|0;a:{if(!$F(e,a)){break a}d=0;if(!_F(a)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function LB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Vl(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Vl(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function iH(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;tf(b);g=f+28|0;ug(g,a,d);a=x[f+28>>2];d=f+4|0;wg(d,e,$e(g),a);x[31725]=0;a=f+16|0;S(600,a|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(g);fb=f+48|0;break a}a=N()|0;Kc(f+28|0);Q(a|0);p()}}function eB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Go(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Go(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function S0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;f=d+28|0;ug(f,a,c);a=x[d+28>>2];e=d+4|0;wg(e,3,$e(f),a);x[31725]=0;g=d+16|0;O(220,g|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){zc(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function WI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=vJ(a,c);x[a>>2]=113196;c=zk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Sm(a,17927,b);x[31725]=0;W(1345,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function Ura(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;tf(b);v[c+15|0]=0;a:{if(!mi(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(mi(a,c+14|0)){Yp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function M5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=yJ(a,c);x[a>>2]=111996;c=zk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Sm(a,17865,b);x[31725]=0;W(1345,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=xJ(a,c);x[a>>2]=112028;c=zk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Sm(a,18046,b);x[31725]=0;W(1345,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function nH(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(c|0,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}XX(a,b)}b=d+8|0;Qd(b);cj(b);fb=d+16|0;return a}a=N()|0;cj(d+8|0);Q(a|0);p()}function hP(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Pj(Xb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return xp(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function $8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function _la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=1;g=b}gf(a,g);fb=d+16|0;return f|0}function Vy(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function OH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Ec(d),x[g+8>>2]=h;d=x[e+8>>2];x[31725]=0;P(c|0,d|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){b=a;a=Xn(e);Wn(b,nc(a),a);zm(e);fb=f+16|0;break a}a=N()|0;zm(e);Q(a|0);p()}}function Q$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[ef(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=44976;b=a+4208|0;e=yb(b,0),f=1017370378,x[e>>2]=f;e=yb(b,1),f=0,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function rf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Tk(b)){Me(d,b);break b}sg(e+8|0,Eh(b)+1|0);f=x[e+8>>2];yd(d,f);pf(d,x[e+12>>2]);Yd(d,b);d=f}fd(hm(d,b,c)+b|0,0);fb=e+16|0;break a}qf();p()}return a|0}function pM(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Eb(Wp(a));a=x[sk(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function mN(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Xj(Az(a));a=x[ar(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function g4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=si(a+20|0,b,c);x[31725]=0;c=U(1366,a+8|0,d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=ni(Jb(b),Jb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function dD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;TY(a,b);cd(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);SY(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!cd(a,b)){break a}fD(a,c);return}Sb(c,0,80)}function WG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14771);a:{if(!Yc(x[a+4>>2],y[a+11|0])){break a}c=1;if((Rg(a,14629)|0)!=-1){break a}if((Rg(a,16809)|0)!=-1){break a}if((Rg(a,13773)|0)!=-1){break a}c=(Rg(a,13816)|0)!=-1}tb(a);fb=b+16|0;return c|0}function Oaa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(!y[a+8|0]){Yj(a+12|0,x[a+4>>2]);oe(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;ib[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}fb=b+32|0;return x[a+12>>2]}function $f(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Uj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=sJ(a,0);x[a>>2]=118104;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31725]=0;O(1348,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=rJ(a,0);x[a>>2]=118208;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31725]=0;O(1349,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=qJ(a,0);x[a>>2]=118312;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31725]=0;O(1350,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Qb(f);Qb(e);Qb(d);tb(c);Q(a|0);p()}function p5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=pJ(a,0);x[a>>2]=118416;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31725]=0;O(1351,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Qb(f);Qb(e);Qb(d);tb(c);Q(a|0);p()}function BK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;mi(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;mi(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function oE(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){nE(a);a=x[ij(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function qT(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Xq(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function gO(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d,g=qO(c),x[f+8>>2]=g;c=d+8|0;e=x[re(d+12|0,c)>>2];x[31725]=0;b=+pa(1120,a|0,+b,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){Vc(c);fb=d+16|0;return+b}a=N()|0;Vc(d+8|0);Q(a|0);p()}function HL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=HL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function qH(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;ug(f,a,d);a=x[e+28>>2];d=e+4|0;wg(d,c,$e(f),a);x[31725]=0;a=e+16|0;O(220,a|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){ze(b,a);tb(a);Kc(f);fb=e+48|0;break a}a=N()|0;Kc(e+28|0);Q(a|0);p()}}function _ra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;Bm(f,x[yb(c,d)>>2]+40|0);c=nr(f,b);tb(f);if(!c){break a}g=x[yb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function o0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;tf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function Sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}gf(a,g);fb=e+16|0}function Sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;zx(e,c);c=d+16|0;x[c>>2]=b;_c(c+4|0,e);x[31725]=0;O(1131,a+4|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){Xj(c);tb(e);fb=d+32|0;return}a=N()|0;Xj(d+16|0);tb(d+4|0);Q(a|0);p()}function jW(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=d+16|0}else{gW(Sb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function RC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=wb(x[a>>2]);c=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Md(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function xda(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22267}c=Fd(Cf(b)+1|0);x[a+4>>2]=c;if(!c){break a}yc(c,b,Cf(b)+1|0)}return a|0}function hr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=WW(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function ex(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function as(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=NF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Xr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=OF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Gl(a,b,c){var d=0,e=0,f=0,g=0,h=0;while(1){a:{if((a|0)!=(b|0)){e=x[c>>2];g=x[c+4>>2];d=fb-16|0;fb=d;f=qc(d+8|0,x[a>>2]);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;e=Ic(e,g,d);fb=d+16|0;if(!e){break a}}else{a=b}return a}a=a+8|0;continue}}function cq(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Tb(){var a=0;a=x[31597];x[31725]=0;X(a|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){x[31725]=0;X(1367);a=x[31725];x[31725]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[31725]=0;X(1367);a=x[31725];x[31725]=0;if((a|0)!=1){break a}T(0)|0;Tb()}p()}function Ksa(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=b+28|0;d=gc(b+8|0,c,3);kc(b+20|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(kd(c,14733,3)){break a}Vb(a,3);e=1}fb=b+32|0;return e|0}function Joa(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=b+24|0;d=gc(b+8|0,c,6);kc(b+16|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(kd(c,3856,6)){break a}Vb(a,6);e=1}fb=b+32|0;return e|0}function vn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}sg(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function HS(a,b){a=CS(a);CS(a+368680|0);if(b){BS(a,1);return}if(!y[495776]){HS(127072,1);v[495776]=1}Mk(258184,323720,a+131112|0);Mk(323720,389256,a+196648|0);Mk(389256,454792,a+262184|0);Mk(127096,258184,a+24|0);yc(a+327720|0,454792,40960)}function ET(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Gb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=tv(e+4|0,a,d);f=x[d+4>>2];x[31725]=0;a=ba(1165,zb(a)|0,b|0,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function rh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Cb(x[a+4>>2],d);a:{if((c|0)!=(Cb(x[b+4>>2],y[b+11|0])|0)){break a}a=Jb(a);b=Jb(b);if(!Cd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!oy(a,b,c)}return e}function nQ(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=gv(e+4|0,a,d);f=x[d+4>>2];x[31725]=0;a=ba(1129,zb(a)|0,b|0,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function ue(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function sH(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=z[e+12>>1];xg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Vr(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function rD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[31725]=0;d=R(204,b|0)|0;e=x[31725];x[31725]=0;b:{if((e|0)==1){break b}x[31725]=0;S(171,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}break a}a=N()|0;dc(c);Q(a|0);p()}}function VT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function U0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,3,$e(e),a);x[31725]=0;a=d+16|0;O(220,a|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){om(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function $W(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=ZW(a+20|0)}return c}function xy(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;mi(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;mi(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function hx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;mf(e+8|0,b,c);x[31725]=0;Ma(167,a|0,x[e+8>>2],x[e+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){x[a+8>>2]=0;Ef(a+12|0,d);ke(d);fb=e+16|0;return a|0}a=N()|0;ke(d);Q(a|0);p()}function VC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];mf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function zU(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=x[a>>2];e=Kk(b,x[a+4>>2]);b=wb(b);x[c+12>>2]=b;d=+(e>>>0);a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){C[b>>3]=C[b>>3]/d;C[b+8>>3]=C[b+8>>3]/d;b=x[_o(c+12|0)>>2];continue}else{fb=c+16|0}break}}function sA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function mT(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function N0(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=b}gf(a,f);fb=d+16|0}function sqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;ir(e,c);Cj(d+12|0,e);x[31725]=0;V(303,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function qua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;_w(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function nv(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Bb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Bb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Bb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function Iua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Nr(e,c);Cj(d+12|0,e);x[31725]=0;V(303,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Ii(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function DT(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function vsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Qv(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Vp(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;d_(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function j$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;EE(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function gV(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=_h(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Cr(b,f,h);fb=e+16|0}else{fj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function _E(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;ww(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function RG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;eo(e,c);Cj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function BV(a){var b=0,c=0,d=0;d=Xo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31725]=0;S(171,a|0,b|0,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){a=x[a>>2];x[31725]=0;P(185,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}a=N()|0;dc(d);Q(a|0);p()}}function MT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function Gsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;kD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Sb(b,0,4896)}return a|0}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Sk(b,4,c,x[a+32>>2])}return c|0}function oZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=zn(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Yi(d+(e<<2)|0,b,c);b=c+e|0;ng(a,b);yd(d+(b<<2)|0,0);return a|0}xI(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function g$(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=$l(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Cr(b,f,h);fb=e+16|0}else{El(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function Zf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31725]=0;V(1150,17408,9110,435,6381);a=x[31725];x[31725]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Tb();p()}function nC(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=vW(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function fS(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=nC(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}yc(b+112|0,a,538);b=b+872|0;continue}}fb=c+544|0}function fB(a,b,c){var d=0,e=0;d=ce(a);a:{if(d){e=ec(a);while(1){a=d;d=y[a+16|0];if(Ho(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Ho(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(a);e=a}x[b>>2]=a;return e}function Fra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;hD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Sb(b,0,33)}return a|0}function xba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function u1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;xw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Sb(b,0,65)}return a|0}function fva(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){eh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,120);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=-1;e=a;a=c+8|0;a:{if(!PG(e,a)){break a}d=0;if(!ER(a)|(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]?b:0)){break a}d=1}fb=c+32|0;return d|0}function vR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22296|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function Sta(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){yp((a<<1)+b|0);a=a+1|0;continue}break}break a}gw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ri(a){var b=0,c=0,d=0,e=0;b=Zd(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Zd(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function Eg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[yb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function w2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[d>>2];g=x[b+8>>2];if(g>>>0>c>>>0){x[e+12>>2]=g-c;x[e+8>>2]=x[d+4>>2];b=x[b+4>>2]+c|0;h=x[Gb(e+12|0,e+8|0)>>2];Wg(b,b+h|0,f)}bc(a,f,h);fb=e+16|0}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=pm(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=gj(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Ng(a,d&65535,b)?d:-1)&65535}function TR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Gc(ova(nva(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Rr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Yr(b+8|0,c+15|0);d=x[b+12>>2];od(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){gd(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function QD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}RE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function Dm(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}$G(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function ova(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=pva(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!$D(a,d)){break a}c=0;if(!FX(d)){break a}c=-1;if(!pk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}c=!(x[b+12>>2]&-2139062144)}fb=b+32|0;return c|0}function Sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;IU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){QB(b)}return a|0}function Oqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(178956970)>>>0<b>>>0){dd();p()}d=Ec(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function KT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[ad(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=xC(c&255),x[e+44>>2]=f}fb=d+16|0}function Hoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(119304647)>>>0<b>>>0){dd();p()}d=Ec(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function zv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;GX(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){HX(b)}return a|0}function zZ(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}wZ(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function uw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Gw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LE(b)}return a|0}function sj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function mk(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Tw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function ls(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}tG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function fv(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}WV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function _V(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}ZV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function Sq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[Pp(b)>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-Ee(f*C[Ve(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=yb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Ec(40),x[f+8>>2]=g;d=ym(x[c+8>>2]);x[d>>2]=78280;d=DM(nc(d));x[d+24>>2]=b;x[d>>2]=78428;b=a;a=Xn(c);Wn(b,nc(a),a);zm(c);fb=e+16|0}function yZ(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Ov(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}he(d);fb=e+16|0}function v$(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function lua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(715827882)>>>0<b>>>0){dd();p()}d=Ec(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function kla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){a=0;while(1){if((a|0)!=16){eh(a+b|0);a=a+1|0;continue}break}break a}bE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function ae(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Msa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;xr(c,yr(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Au(a+8|0,yr(a));fb=c+16|0}
function Au(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42284;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42136;break a;case 2:c=42132;break a;case 1:break b;case 0:break c}}c=42128;break a}c=42124}x[a>>2]=x[c>>2]}function sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(2147483647)>>>0<b>>>0){dd();p()}d=Ec(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function nr(a,b){var c=0,d=0;c=fb-32|0;fb=c;ee(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=x[c+24>>2];b=x[c+28>>2];d=x[c+12>>2];if((b|0)==(d|0)){a=FZ(a,b,x[c+8>>2],d)}else{a=1}fb=c+32|0;return!a}function RV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=zd(b);x[d+12>>2]=c;f=Df(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[me(d+12|0)>>2];continue}}_c(a,b);fb=d+16|0}function C_(a){var b=0,c=0,d=0;c=y[a+3|0];b=nva(c>>>0<3?48:64,0,Bb(y[a+196|0]|y[a+197|0]<<8),0);d=b;b=nva(nva(Bb(y[a+198|0]|y[a+199|0]<<8),0,c>>>0<4?4:5,0),hb,Bb(y[a+200|0]|y[a+201|0]<<8),0);a=d+b|0;a=a+512|0;hb=0;return a}function kqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){eh(a+b|0);a=a+1|0;continue}break}break a}TD(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ft(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Cg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a|0}eq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function AH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=I0(f+24|0,f+8|0);b=f+16|0;a=hq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function yv(a,b){var c=0,d=0,e=0;if(x[a>>2]){m0(a);c=x[a>>2];rE(a);Db(c);d=zb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function Zt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=sc(c+12|0);f=yb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function fT(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=zb(a);c=ec(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=ec(b);x[b>>2]=c;x[c>>2]=0;e=zb(b),f=0,x[e>>2]=f}return a}function cia(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Vz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function bX(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+31054>>1]-z[(c<<1)+31054>>1]|0)/5;a=y[Rb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function MA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}yc(a+24604|0,b,40);aS(a,c)}function Ix(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=Ef(f+8|0,d);x[31725]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=jg(e,a,b,c,f);b=x[31725];x[31725]=0;if((b|0)!=1){ke(d);fb=f+16|0;return a}a=N()|0;ke(d);Q(a|0);p()}function oea(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(Ad(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(Ld(b,47360)){break a}c=a+88|0;if(Ld(b,47372)){break a}c=a+92|0;if(Ld(b,47384)){break a}c=Ld(b,47397)?a+96|0:0}}return c|0}function eZ(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function di(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Sb(b,0,c)}return a}function a$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Bb(y[a+8|0]|y[a+9|0]<<8)}return b}function Wta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(uh(1073741823)>>>0<=8191){dd();p()}c=Ec(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function Sra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!pk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Kn(8978)|0)&e>>>0>255&e>>>0<260)){break a}c=ve(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function Pt(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!dz(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=hf(a)}return b}_(15751,13258,1578,5429);p()}function CX(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;gr(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];zX(a);Db(b)}fb=c+16|0}function vB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42208|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;em(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function TU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function EF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;fh(a,c+15|0);d=v[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11235,9079,324,14199);p()}return a}function wr(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Tc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[_b(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function nva(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function bz(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Ot(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function Qba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;lN(e,c);a=x[a+1298472>>2];x[31725]=0;S(387,a|0,b|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function LL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;yc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;yc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function uU(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function WB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:YU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;nz(d+16|0,a,d+26|0,x[Gb(d+28|0,d+12|0)>>2]);hj(b,z[d+26>>1]);fb=d+32|0}function vV(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function qo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function UI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=zk(Jb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Sm(a,17609,b);x[31725]=0;W(1345,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return}p()}function Lq(a,b){a=yc(a,b,88);x[a+88>>2]=x[b+88>>2];yc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];yc(a+672|0,b+672|0,52);jB(a+724|0,b+724|0);jB(a+732|0,b+732|0);jB(a+740|0,b+740|0);yc(a+748|0,b+748|0,123);return a}function gsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}LZ(x[a+36>>2],b,d,0);f=c}gf(a,f);fb=e+16|0}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Ug(a)>>>0<b>>>0){if(uh(1073741823)>>>0<b>>>0){break a}d=zb(a);e=a;a=$f(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);Zm(e,a);_f(a)}fb=c+32|0;return}dd();p()}function ZT(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-7|0;continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];GB(a);Db(b)}fb=c+16|0}function TI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=zk(Jb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Sm(a,17650,b);x[31725]=0;W(1345,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return a}p()}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(kl(a)>>>0<b>>>0){if(uh(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Dm(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);ux(e,a);ys(a)}fb=c+32|0;return}dd();p()}function ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(kl(a)>>>0<b>>>0){if(uh(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Dm(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);MW(e,a);LW(a)}fb=c+32|0;return}dd();p()}function fG(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Tk(c)){Me(a,c);break a}sg(d+8|0,Eh(c)+1|0);e=x[d+8>>2];yd(a,e);pf(a,x[d+12>>2]);Yd(a,c);a=e}fd(Xg(a,b,c)+c|0,0);fb=d+16|0;return}qf();p()}function an(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[yb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function TY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;VY(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){UY(b)}return a}function PY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(On(a)>>>0<b>>>0){if(uh(2147483647)>>>0<b>>>0){break a}d=zb(a);e=a;a=mk(c+12|0,b,Zc(x[a>>2],x[a+4>>2]),d);Xr(e,a);jj(a)}fb=c+32|0;return}dd();p()}function OD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;N_(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){O_(b)}return a}function Kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Yn(a)>>>0<b>>>0){if(uh(536870911)>>>0<b>>>0){break a}d=zb(a);e=a;a=ls(c+12|0,b,jh(x[a>>2],x[a+4>>2]),d);NB(e,a);ks(a)}fb=c+32|0;return}dd();p()}function Gu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Tk(c)){Me(a,c);break a}sg(d+8|0,Eh(c)+1|0);e=x[d+8>>2];yd(a,e);pf(a,x[d+12>>2]);Yd(a,c);a=e}fd(Cg(a,b,c)+c|0,0);fb=d+16|0;return}qf();p()}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}dR(d,x[a+36>>2],b);f=c}gf(a,f);fb=e+16|0}function Ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(GB(a)>>>0<b>>>0){if(uh(613566756)>>>0<b>>>0){break a}d=zb(a);e=a;a=YT(c+12|0,b,FB(x[a>>2],x[a+4>>2]),d);XT(e,a);WT(a)}fb=c+32|0;return}dd();p()}function $k(a){wc(a+16|0,x[a>>2]);wc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function gL(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!oo(b)){break a}x[a>>2]=0}return a|0}function VM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;tz(f,b);while(1){if(d){b=x[f+4>>2];h=uh(d);Dj(b,c+g|0,h);b=x[x[f+4>>2]+4>>2];d=d-b|0;g=b+g|0;if((b|0)==(h|0)){continue}}break}bc(a,c,g);fb=e+16|0}function Oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Ej(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function KA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;$R(a+24648|0);fS(a)}function Gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=x[c>>2];c=x[c+4>>2];while(1){if(c){d=x[b+24>>2];g=uh(c);Dj(d,e+f|0,g);d=x[x[b+24>>2]+4>>2];c=c-d|0;e=e+d|0;if((d|0)==(g|0)){continue}}break}bc(a,f,e)}function lp(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);xn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=d$(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Mx(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function IJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);xn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=kA(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function HA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Iw(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[WR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=lc(x[d>>2],x[d+4>>2])^1}return a}
function vW(a){a=a*4294967296;if(F(a)<0x8000000000000000){hb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}hb=-2147483648;return 0}function _S(a,b,c,d){var e=0,f=0;b=D(c,872)+b|0;e=x[b+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[b+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function Uga(a){a=a|0;var b=0;b=fb-16|0;fb=b;a:{if(!Ld(a,10265)){b=b+4|0;Sm(b,18196,a);a=Jb(b);x[31725]=0;O(68,44,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(b);Q(a|0);p()}fb=b+16|0;return}p()}function QC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=CG(a);a:while(1){if((a|0)!=(e|0)){f=td(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[xb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function ov(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);xn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=WD(c,x[d+20>>2]),x[f+12>>2]=g;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function bpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;pn(a,b);b=wb(x[a>>2]);x[c+12>>2]=b;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[me(c+12|0)>>2];continue}else{fb=c+16|0}break}}function XS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function FE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function zqa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Vb(a,2);d=1}fb=b+32|0;return d|0}function uea(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;lN(d,b);a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function od(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];mf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function Lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=qg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31725]=0;O(805,a|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;mU(d);rU(a);Q(b|0);p()}function Jd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;fh(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11235,9079,324,14199);p()}return d}function Di(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Sb(b,0,c)}}function vua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){eh(a+b|0);a=a+1|0;continue}break}break a}gw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function VU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Uo(d);UU(x[c>>2])}b=b+1|0;continue}break}}function VO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Pj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function Rla(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){eh(a+b|0);a=a+1|0;continue}break}break a}IU(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function lha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Gc(ova(nva(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;eQ(a,e);b=x[a+12>>2];x[f+12>>2]=0;hR(a,b,f+12|0);fb=f+16|0}function iG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Yf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Sb(f,b&255,c?d:256);if(!c){while(1){Lf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Lf(a,f,d)}fb=f+256|0}function U3(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=pl(a);if(uI(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31725]=0;R(b|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}}jc(a)}return}T(0)|0;Tb();p()}function Bw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){eh(a+b|0);a=a+1|0;continue}break}break a}PE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function xoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=ev(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[ad(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}dd();p()}function wo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(dp(a)>>>0<b>>>0){if(uh(-1)>>>0<b>>>0){break a}d=zb(a);e=a;a=vn(c+12|0,b,Sc(x[a>>2],x[a+4>>2]),d);hr(e,a);tn(a)}fb=c+32|0;return}dd();p()}function te(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Fd(b)}return c}function ZY(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;TD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Y9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}si(a,x[b+24>>2],d);break a}if(c&8){si(a,x[b+12>>2],x[b+20>>2]);break a}Fb(a)}}function UN(a,b){a=a|0;b=b|0;var c=0;a=Lj(a);x[a+4>>2]=0;x[a>>2]=47632;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22267}c=Fd(Cf(b)+1|0);x[a+4>>2]=c;if(c){yc(c,b,Cf(b)+1|0)}return a|0}function Pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{if(!c){Pc(d,a+32|0,5);e=0;if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break a}}QZ(x[a+36>>2],b,a);e=c}gf(a,e);fb=d+16|0}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=lg(d+4|0,b);x[31725]=0;V(1018,a|0,b|0,c|0,1);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function $h(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;el(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function t0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){eh(a+b|0);a=a+1|0;continue}break}break a}el(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function qi(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Gb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Gb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function dK(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){tg(g+13|0,g+14|0)}h=c,i=(fa(b|0,Sc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function wia(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Ug(a)>>>0<=12){if(uh(1073741823)>>>0<=12){break a}c=zb(a);d=a;a=$f(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);Zm(d,a);_f(a)}fb=b+32|0;return}dd();p()}function d3(a,b){a=a|0;b=b|0;var c=0;a=Jt(a);x[a>>2]=93640;c=Fb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[31725]=0;O(114,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);lo(a);Q(b|0);p()}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=lg(d+4|0,c);x[31725]=0;S(1004,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function WX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!He(d,x[a+4>>2],b)){break a}d=eE(a,x[gj(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=gj(c,b);zR(gj(c,d),a);c=d}return c|0}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function GS(a,b,c){var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Xg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a}Yq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a}function Cl(a){a=a|0;var b=0;x[a>>2]=94836;x[31725]=0;O(115,a|0,0);b=x[31725];x[31725]=0;if((b|0)!=1){Zb(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Tb();p()}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){dd();p()}iJ(c+8|0,iq(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function sx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){kn();p()}b=Jb(b);x[e+8>>2]=d-c;Gu(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function p$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=443372356|y[a+4|0]!=32|(!y[a+46|0]|(y[a+45|0]-17&255)>>>0<240)){break a}if(!y[a+47|0]){break a}b=y[a+49|0]<101}return b}function j3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){kn();p()}b=Jb(b);x[e+8>>2]=d-c;fG(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function B0(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Hn((a<<2)+b|0);a=a+1|0;continue}break}break a}xE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Cw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){eh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,256);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function xU(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function k_(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{hp(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function be(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function M_(a){var b=0,c=0,d=0;a:{if(kd(a,22256,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Mz(e,d,f,c,1);fb=d+16|0}function Bj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function As(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b){d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);if(d-e>>>0<b>>>0){Wm(a,d,(b-d|0)+e|0,e,e,0,0)}d=Jb(a);hm(d+e|0,b,c);b=b+e|0;ng(a,b);fd(b+d|0,0)}return a|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(357913941)>>>0<b>>>0){dd();p()}$G(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function q$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;gw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){$v(b)}return a}function pk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;el(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fl(b)}return a}function oY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Tn(b,a)|!c){break a}oh(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];tg(xb(b,a),xb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function mP(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function kka(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!pk(a,b+8|0)){break a}c=0;if(!IR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!eF(a,b+4|0)){break a}c=HR(x[b+4>>2])}fb=b+16|0;return c|0}function iS(a){var b=0,c=0;a=a+906300|0;c=Ck(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function fX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;dx(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){ex(b)}return a}function aX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;N_(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){O_(b)}return a}function V$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;fw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){jE(b)}return a}function Pqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){dd();p()}KF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function PG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;NG(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){px(b)}return a}function Kr(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function KX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;GX(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){HX(b)}return a}function $F(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;es(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fs(b)}return a}function $D(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Gr(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){u$(b)}return a}function rm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){dd();p()}Uj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function l1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(214748364)>>>0<b>>>0){dd();p()}RE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function dja(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;PT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function cE(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Ze(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=ef(c+7|0,c+6|0);fb=c+16|0;return y[a|0]|b<<4&240}function GC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(2147483647)>>>0<b>>>0){dd();p()}Tw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function Ela(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(uh(2147483647)>>>0<=2303){dd();p()}Tw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function AE(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function wU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(536870911)>>>0<b>>>0){dd();p()}tG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function tU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(268435455)>>>0<b>>>0){dd();p()}ZV(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function fq(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=dy(d+4|0,b,Cf(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function fM(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function ZS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=js(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{YS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;pg(a,d+14|0);e=z[d+14>>1];oS(b,e);c=0;while(1){if((c|0)==(e|0)){QA(b);fb=d+16|0}else{Nk(a,yb(x[b>>2],c));c=c+1|0;continue}break}}function NZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(715827882)>>>0<b>>>0){dd();p()}wZ(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function EL(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Nh(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function YI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=111976;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[yb(b,c)>>2];if(b){Am(b)}c=c+1|0;continue}break}tb(a+152|0);cy(d);return a|0}function NA(a,b){var c=0;a=CW(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function Eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=jR(a,b,c,d+12|0);fb=d+16|0;return a|0}function nk(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(2147483647);if(d>>>0<=b>>>0){a=On(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function kc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;mf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);mf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function Mj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Xl(a,b);if((d|0)==255){break a}Fk(a,b);Uq(a,b,0,0);if(!c){break a}e=_b(a+26|0,d),f=65535,w[e>>1]=f;a=xb(a+62|0,b);v[a|0]=y[a|0]|128}}function Mf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(1073741823);if(d>>>0<=b>>>0){a=Ug(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function rG(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(119304647);if(d>>>0<=b>>>0){a=bx(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function oD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(715827882);if(d>>>0<=b>>>0){a=bw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function ms(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(536870911);if(d>>>0<=b>>>0){a=Yn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function jN(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Ec(1298480);x[31725]=0;c=R(1133,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){b=yf(a+12|0,c);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function Xp(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(357913941);if(d>>>0<=b>>>0){a=kl(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function RD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(214748364);if(d>>>0<=b>>>0){a=TE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function OJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(178956970);if(d>>>0<=b>>>0){a=$s(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function GD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(rq(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;QT(c+8|0,127);a=fm(C[c+8>>3]);fb=c+16|0;return a}function $q(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(134217727);if(d>>>0<=b>>>0){a=bp(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function $V(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(268435455);if(d>>>0<=b>>>0){a=hv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function zE(a,b){var c=0,d=0;c=fb-16|0;fb=c;gk(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function yu(a){var b=0;x[31725]=0;a=R(856,a|0)|0;b=x[31725];x[31725]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Tb();p()}function yE(a,b){var c=0,d=0;c=fb-16|0;fb=c;Qr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function x$(a,b){var c=0,d=0;c=fb-16|0;fb=c;fw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function tR(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(82595524);if(d>>>0<=b>>>0){a=Bu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function s$(a,b){var c=0,d=0;c=fb-16|0;fb=c;gw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function rZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;qZ(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function r$(a,b){var c=0,d=0;c=fb-16|0;fb=c;Gr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function oA(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Do(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Zm(a,c);_f(c);fb=d+32|0}function kX(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function jG(a,b){var c=0,d=0;c=fb-16|0;fb=c;NG(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function hY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Dv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function fx(a,b){var c=0,d=0;c=fb-16|0;fb=c;dx(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function fh(a,b){var c=0,d=0;c=fb-16|0;fb=c;Yr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function aG(a,b){var c=0,d=0;c=fb-16|0;fb=c;es(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function X0(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function Tn(a,b){var c=0,d=0;c=fb-16|0;fb=c;oh(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function R0(a,b){var c=0,d=0;c=fb-16|0;fb=c;Q0(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function OX(a,b){var c=0,d=0;c=fb-16|0;fb=c;aD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function OC(a,b){var c=0,d=0;c=fb-16|0;fb=c;TC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function NK(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function M$(a,b){var c=0,d=0;c=fb-16|0;fb=c;bE(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function LV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Jp(a,b){var c=0,d=0;c=fb-16|0;fb=c;Ip(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function HB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+123776>>2]<=d>>>0)|0)){break a}}c=EB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function Cx(a,b,c){var d=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);b=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Vb(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function qz(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Sg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function eV(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=$B(b,x[a+12>>2]);x[31725]=0;O(785,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){Hk(c);fb=b+32|0;return}a=N()|0;Hk(c);Q(a|0);p()}function eM(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=vn(d+12|0,bm(a,Sc(x[a>>2],x[a+4>>2])+1|0),Sc(x[a>>2],x[a+4>>2]),c);El(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;hr(a,c);tn(c);fb=d+32|0}function Vf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=qA(c+12|0,a);x[31725]=0;S(201,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){Dk(d);fb=c- -64|0;return}a=N()|0;Dk(d);Q(a|0);p()}function EV(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function ni(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Kz(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;yc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Re(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;fb=c+16|0}function FZ(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=ZG(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function E_(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=oy(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function Bga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=DP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function yo(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!aN(y[a+20|0])){x[31725]=0;O(1140,b+15|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Tb();p()}function k8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=yk(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function Fk(a,b){var c=0,d=0,e=0;a:{c=Xl(a,b);if((c|0)==255){break a}if(Nj(x[a>>2])){break a}e=a+8|0;d=xb(e,c);v[d|0]=y[d|0]&223;d=bv(c);c=xb(e,c);zh(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function Dba(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=x[18387];x[c+8>>2]=x[18386];x[c+12>>2]=d;d=x[18385];x[c>>2]=x[18384];x[c+4>>2]=d;ib[x[uq(c,Ak(y[b+20|0]))>>2]](a,b);fb=c+16|0}function aH(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Xp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);zs(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;ux(a,c);ys(c);fb=d+32|0}function Wt(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Nw(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Nw(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function Dsa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Uh(b,12,c);break a}Gr(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function zp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=_h(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{fj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function nA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Bk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function d8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return xk(g,h,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function bm(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(-1);if(d>>>0<=b>>>0){a=dp(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function XE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Do(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Wh(a,b){var c=0;b=Uc(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[yb(c,b)>>2]!=0}else{a=0}if(!a){a=Lj(ac(4));x[a>>2]=125456;da(a|0,125592,1190);p()}return x[yb(c,b)>>2]}function TP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=Ci(b-+(a|0))}else{b=0}return b}function Rl(a){var b=0;a=ri(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function _r(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){dd();p()}KF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=zb(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function QP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=PP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function Pm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Sb(a- -64|0,0,48);return a}function Isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;mZ(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){lZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;k$(b,4,c);break a}oh(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Gp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=$l(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{El(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function s2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function al(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(-1)>>>0<b>>>0){dd();p()}sg(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function Xt(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=Io(a);continue}break}return a}function MB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Th(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Fu(a,b){var c=0;a=LS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Loa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;BW(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];bc(d+8|0,c,Sh(c,x[b+4>>2])<<8);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function GT(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function C2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Sc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Yj(c,a)}return!d|0}function g6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+112112>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function epa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;d=b+8|0;c=-1;a:{if(!pk(a,d)){break a}c=0;if(!DW(d)){break a}c=-1;if(!lh(a,4)){break a}c=dX(a)>>>31|0}fb=b+16|0;return c|0}function Xz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Io(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function XR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=Io(a);continue}break}return a}function Ov(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function Jh(a,b,c){a:{if(b>>>0<=c>>>0){a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24440,164);p()}function usa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;PZ(b,c);OZ(a,c);fb=c+32|0}function j8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return yk(g,h,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0)|0}function fU(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Vl(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=vb(e+12|0,d);fb=e+16|0;return x[a>>2]}function eha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Pd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(ri(E(c*E(3)))/E(3));b=12}e=yb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function _l(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Sc(a,b)>>>0){a=xl(e+4|0,xb(a,f),z[c+20>>1]);g=Ey(d,a);Eb(a)}fb=e+16|0;return g|0}function tD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Jr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Ov(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Nz(a,e,c,d,1);fb=e+16|0}function jp(a){var b=0,c=0;b=x[31480];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[31480]=a;return b}x[31600]=48;return-1}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;oz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function uY(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];$s(a);Db(b)}}function u3(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=wP(a,c,1);fb=c+16|0;gb=hb;return a|0}function nN(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Xj(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];hv(a);Db(b)}}function Rta(a,b){a=a|0;b=b|0;if(!r$(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function QH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];kl(a);Db(b)}}function Aq(a){var b=0;b=x[a+24>>2];x[31725]=0;W(857,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){Td(a+68|0);of(a+36|0);Il(a+32|0);wh(a+24|0);vh(a+4|0);return Vc(a)}T(0)|0;Tb();p()}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];BA(a,d+8|0);b=x[Je(d+12|0)>>2];continue}else{fb=d+16|0}break}}function pc(a,b){a=a|0;b=b|0;var c=0;a=Lj(a);x[a+4>>2]=0;x[a>>2]=47632;c=Fd(Yc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){yc(c,Jb(b),Yc(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function G4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=Sx(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function tw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Yj(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];bc(d+8|0,c,Sc(c,x[b+4>>2]));rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function qY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Dv(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function jD(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Hn(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function _q(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{JV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function XX(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{EX(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function Tca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=xP(a,c,1);fb=c+16|0;return+e}function QE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=_h(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Uw(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function Og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Jh(x[d>>2],x[d+4>>2],a);return((Jh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Jh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function Fz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Tk(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;Me(a,b);return a}c=Eh(b)+1|0;d=Ec(c);pf(a,c);yd(a,d);Yd(a,b);return a}qf();p()}function $E(a,b){var c=0,d=0;c=fb-16|0;fb=c;oh(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function mi(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;Cj(c+8|0,c+31|0);Rm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+112112>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function b4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];c=lc(x[d+12>>2],x[c+4>>2]);fb=d+16|0;return(a|0)==(b|0)&c}function YG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&255)!=0}return b}function V_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(kd(a+44|0,18439,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function tda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=yP(a,c,1);fb=c+16|0;return a|0}function sf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=l0(b,c),x[e+12>>2]=f;c=b;b=sE(d+4|0);Wg(c,c+b|0,a);e=xb(a,b),f=0,v[e|0]=f;n0(a);fb=d+16|0}function rua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;el(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Vb(a,x[c+12>>2])}fb=c+16|0}function rF(a,b,c){var d=0;d=fb-16|0;fb=d;a=Hp(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){fj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function hH(a,b){var c=0,d=0,e=0;c=x[a>>2];if(x[c>>2]){e=x[c>>2];d=x[c+4>>2];while(1){if((d|0)!=(e|0)){d=d-b|0;continue}break}x[c+4>>2]=e;a=x[a>>2];b=x[a>>2];zb(a);Db(b)}}function Tka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Ec(1);x[31725]=0;X(59);c=x[31725];x[31725]=0;if((c|0)!=1){b=yf(a+12|0,b);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function tZ(a,b,c){var d=0;d=fb-16|0;fb=d;a=yC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){El(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function oW(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-36|0;continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];bx(a);Db(b)}}function jta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}rS(d,9153,10891,171,42);MG(d,b,c)}fb=d+16|0}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+112112>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function Hx(a,b,c,d,e){var f=0;a:{f=yu(4332);if(f){x[31725]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function yT(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function kT(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mc(a);d=Cb(x[a+4>>2],y[a+11|0]);if((c|0)==(d|0)){VB(a,c,1,c,c,0)}c=Jb(a);hm(c+d|0,1,b);b=d+1|0;ng(a,b);fd(b+c|0,0);return a|0}function _ka(a,b){a=a|0;b=b|0;var c=0;a=qg(a);c=_i(x[b>>2]);b=Rf(b);x[31725]=0;S(851,a|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;iT(a);Q(b|0);p()}function Mm(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function KV(a,b,c,d){a=gc(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function BA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);Do(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}oA(a,b)}function z5(a,b,c){a=a|0;b=b|0;c=c|0;a=uJ(a,c);x[a>>2]=113436;b=Jb(b);x[31725]=0;O(1346,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;_x(a);Q(b|0);p()}function x5(a,b,c){a=a|0;b=b|0;c=c|0;a=tJ(a,c);x[a>>2]=113476;b=Jb(b);x[31725]=0;O(1347,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;$x(a);Q(b|0);p()}function wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;uP(a,b,d,1);fb=d+16|0}function qr(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){lD(b);break a}oh(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function gM(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Pz(a,d,c,1);fb=d+16|0}function Cka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(a+4|0,10265);x[31725]=0;W(63,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Av(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function rpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!aX(a,c)){break a}d=0;if(!$W(c)){break a}d=ve(a,b,_W(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function oqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function kd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function dI(a,b,c){var d=0;a:{if(!a){a=ac(8);x[31725]=0;c=R(c|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return}da(c|0,b|0,1006);p()}function ZM(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function Uda(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Oz(a,d,c,1);fb=d+16|0}function gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Yy(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function eD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;mZ(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){lZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cb(x[b+4>>2],y[b+11|0]);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Xg(Jb(Fz(e,d+a|0)),Jb(b),d)+d|0;hm(Xg(b,Jb(c),a)+a|0,1,0)}function cX(a,b){var c=0;c=fb-32|0;fb=c;NX(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function bi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hs(b);d=Mc(a);if(c>>>0<=d>>>0){Xu(a,Ui(Jb(a),b,c),c);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);Yq(e,d,c-d|0,a,0,a,c,b)}}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;oz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function u2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function ota(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;c_(a,6,c);break a}Gr(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function jV(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);xn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=iV(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function FX(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function EZ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=ec(b);a=Ch(a,Ec(32),Mg(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=ec(a),f=1,v[e+4|0]=f;fb=d+16|0}function AV(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function rL(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Pf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Pf(b)}function RT(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=tv(c+4|0,a,1);zs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}aH(a,b)}function Ld(a,b){var c=0;c=fb-32|0;fb=c;ee(c+24|0,a);a=qc(c+16|0,b);b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function II(a,b,c){var d=0,e=0;d=zn(a);if(d>>>0>=c>>>0){e=b;b=c<<2;d=ml(Jb(a),e,b);ng(a,c);yd(b+d|0,0);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);xI(e,d,c-d|0,a,0,a,c,b)}function $pa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;c_(a,4,c);break a}el(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function gW(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;nC(a+112|0,48e3);x[a+668>>2]=0;mC(a+724|0);mC(a+732|0);mC(a+740|0);bh(a+788|0);return a}function Tpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Uh(a,5,c);break a}gk(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Pd(a,b){var c=0,d=0,e=0,f=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;e=c,f=cg(a),B[e+4>>2]=f;d=Mv(c+4|0,c+12|0,c+8|0);fb=c+16|0;return B[d>>2]}function yM(a,b){var c=0,d=0;c=Sc(x[a+4>>2],x[a+8>>2]);b=x[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=qi(c);if(b>>>0<=a>>>0){break a}}a=zM(b,65536)}Yj(d,a)}}function x9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=bL(a,e,b);x[a>>2]=94516;fb=e+16|0;return a|0}function sm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Uh(a,4,c);break a}oh(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function sE(a){var b=0,c=0;a:{c=yb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=pE(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-80|0;fb=d;e=d+14|0;c=-1;a:{if(!V$(a,e)){break a}c=0;if(!UX(e)){break a}c=ve(a,b,TX(e),hb)}fb=d+80|0;return c|0}function i3(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);zs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}aH(a,b)}function eea(a,b){a=a|0;b=b|0;var c=0;a=ac(8);x[31725]=0;b=P(1057,a|0,12097)|0;c=x[31725];x[31725]=0;if((c|0)!=1){da(b|0,125360,164);p()}b=N()|0;jc(a);Q(b|0);p()}function Zq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function Z_(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Uh(a,6,c);break a}TD(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function I4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=JI(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function I3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=uh(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[fk(c+12|0,c+8|0,42288)>>2],x[d+36>>2]=e;Dq(a);fb=c+16|0}function ur(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){Cn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Th(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;Cn(a,b)}function tr(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){Cn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Th(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;Cn(a,b)}function tS(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){sS(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=sS(a);return a}function jA(a,b){var c=0;c=fb-16|0;fb=c;a=Mn(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){JV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}he(a);fb=c+16|0}function a1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=S0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function Sia(a){a=a|0;var b=0;b=fb-16|0;fb=b;JQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;IQ(a+4|0,wb(x[b+8>>2]),Xk(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function KE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=P0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function ID(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Gf(b+14|0,4095);a=z[b+14>>1];c=HD(Ci(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function Ec(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Fd(a);if(b){break a}b=x[125549];if(b){ib[b|0]();continue}break}da(Xm(ac(4))|0,125e3,34);p()}return b|0}function ml(a,b,c){var d=0;if(a>>>0<b>>>0){return yc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function _H(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function Vla(a,b){a=a|0;b=b|0;a=sc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31725]=0;O(791,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;Gj(a);Q(b|0);p()}function Ot(a){var b=0;a:{if((hf(a)|0)!=79){break a}if((hf(a)|0)!=103){break a}if((hf(a)|0)!=103){break a}b=(hf(a)|0)==83}if(!b){fc(a,30);return 0}return $L(a)}function NS(a,b){var c=0;c=fb-32|0;fb=c;a=we(c+8|0,a,b);a=Du(c+16|0,x[a>>2],x[a+4>>2]);a=we(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function Hw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;sF(a,c);break a}Ip(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function DW(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function kN(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function hG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31725]=0;S(171,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;dc(d);Q(a|0);p()}}function Nk(a,b){var c=0;c=fb-32|0;fb=c;x[c+28>>2]=0;Tx(c+8|0,c+28|0);Rm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Qm(b,x[c+28>>2]);fb=c+32|0;return(a|0)==4}function Bn(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function zS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=TA(126944);continue}break}x[b>>2]=d;Io(b);fb=a+16|0;return x[b>>2]}function vja(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){ny(a)}a=vb(b+12|0,wb(x[a+52>>2]));fb=b+16|0;return x[a>>2]}function uja(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){ny(a)}a=vb(b+12|0,wb(x[a+56>>2]));fb=b+16|0;return x[a>>2]}function qC(a){var b=0;a=Ee(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function p9(a,b){a=a|0;b=b|0;var c=0,d=0;b=FD(x[b>>2]);x[a+36>>2]=b;c=a,d=kh(b),x[c+44>>2]=d;c=a,d=ko(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){jo(5563);p()}}function i9(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ky(x[b>>2]);x[a+36>>2]=b;c=a,d=kh(b),x[c+44>>2]=d;c=a,d=ko(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){jo(5563);p()}}function _P(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function M6(a){a=a|0;if(y[500528]){return x[125131]}if(!y[501688]){v[501688]=1}wd(501664,121012);wd(501676,121024);v[500528]=1;x[125131]=501664;return 501664}function LC(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Ib(a,b)|(c|0)==z[a>>1])){a=x[Md(d+12|0)>>2];continue}break}fb=d+16|0;return a}function cR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];BA(a,d+12|0);b=b+4|0;continue}break}}function a9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Vb(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Te(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[ec(a)>>2];x[31725]=0;W(a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Tb();p()}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!aX(a,d)){break a}c=0;if(!TV(d)){break a}c=ve(a,b,SV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function $H(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function y6(a){a=a|0;if(y[500520]){return x[125129]}if(!y[501656]){v[501656]=1}id(501632,13897);id(501644,13876);v[500520]=1;x[125129]=501632;return 501632}function hma(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31725]=0;W(784,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;_B(a);Q(b|0);p()}function Hu(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Mv(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function r0(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function nj(a,b,c,d,e){a:{e=yu(e);if(e){x[31725]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function hz(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+82240>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function h2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function fr(a,b){var c=0,d=0;a:{if(!a){break a}c=nva(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Fd(c);if(!(!a|!(y[a-4|0]&3))){Sb(a,0,c)}return a}function a_(a,b){var c=0;c=nva(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function Fj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function Fi(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function v2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function c3(a,b,c){a=a|0;b=b|0;c=c|0;a=Cs(a,x[b+28>>2]);bH(b+28|0,c);x[31725]=0;O(115,b|0,1);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;Zb(a);Q(b|0);p()}}function Wga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=BB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;$P(a);_P(a)}function AY(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);xn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function to(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Fd(b)}return c}function lX(a){var b=0;return(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16?b:((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}function ah(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Th(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=g_(c)}x[a>>2]=b;return a}function JX(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!q$(a,d)){break a}c=0;if(!VW(d)){break a}c=ve(a,b,UW(d),hb)}fb=d- -64|0;return c|0}function pN(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;nz(d+16|0,a,d+24|0,x[Gb(d+28|0,d+12|0)>>2]);Qm(b,x[d+24>>2]);fb=d+32|0}function Z5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function En(a,b){var c=0,d=0,e=0;Zv(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function CW(a,b){var c=0,d=0,e=0;vr(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function so(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Sb(a+32|0,0,40);wL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function hX(a,b,c,d){var e=0;e=c&4;a:{if((b&255)!=4){b=e?16:8;break a}b=16;if(e){break a}b=8;if(c&2){break a}Xc(a,8,1,0,10);return}Xc(a,b,c&2|1,0,d^1)}function gua(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!q$(a,d)){break a}c=0;if(!p$(d)){break a}c=ve(a,b,o$(d),0)}fb=d- -64|0;return c|0}function cd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function OO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;mM(i,b,c,d,e,f,g);_c(a,h+20|0);gn(i);fb=h+32|0}function Jq(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Jj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[vd(a+906300|0,b-1|0)>>2]}return d}function BZ(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;nz(d+16|0,a,d+27|0,x[Gb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function vu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=xR(zb(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function naa(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=lg(a,b);x[31725]=0;P(72,a+12|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function n$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[c|0]=0;Uh(a,8,c);break a}el(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function BJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function AT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Lo(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function $w(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Uh(a,3,c);break a}_w(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ypa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!KX(a,d)){break a}c=0;if(!lX(d)){break a}c=ve(a,b,kX(d),hb)}fb=d+96|0;return c|0}function ph(a,b){var c=0;if(Cd(y[a+11|0])){c=x[a>>2];dj(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);yd(b,0)}function eR(a){var b=0,c=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;c=Mv(b+12|0,b+8|0,b+4|0);fb=b+16|0;return B[c>>2]}function Xpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!KX(a,d)){break a}c=0;if(!JX(d)){break a}c=ve(a,b,IX(d),hb)}fb=d+96|0;return c|0}function XG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14771);if(Yc(x[a+4>>2],y[a+11|0])){c=(Rg(a,13898)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function Vw(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Q5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function JI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Mh(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124231]>>2]?-1:a&57343}Lh(d);fb=c+16|0;return b}function ys(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){xs(a);Db(c)}}function yX(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;gr(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function pR(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Dk(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function cx(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Np(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function b0(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Gd(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function YB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Hk(b);continue}break}c=x[a>>2];if(c){xs(a);Db(c)}}function Xv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function Xq(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function R3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(nh(a,x[b+8>>2],f)){Ox(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function PA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function JS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=we(c+8|0,nva(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function GK(a,b,c){var d=0,e=0,f=0,g=0;d=IC(b);if(d>>>0<c>>>0){HK(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=HK(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function w9(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function u$(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function qha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Pd(c,E(0));if((b|0)==1){d=1;c=ri(c)}e=yb(a+4208|0,d),f=c,B[e>>2]=f;fQ(a)}}function nI(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function gf(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function aY(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function TB(a,b,c){var d=0,e=0,f=0;d=Xl(a,b);if((d|0)!=255){e=_b(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=xb(a,b),f=255,v[e|0]=f;e=xb(a,c),f=d,v[e|0]=f}}function OP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=du(Ec(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47532;a=yf(d+12|0,c);fb=d+16|0;return x[a>>2]}function MU(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function L_(a,b){var c=0;c=nva(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function IX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;b=b+e|0;a=(b<<2)+d|0;a=a-96|0;hb=0;return a}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;Ip(c+20|0,b);d=x[c+20>>2];Ip(c+12|0,b);xl(a,d,x[c+16>>2]);fb=c+32|0}function Fs(a,b,c,d){var e=0;e=ac(8);x[31725]=0;a=P(d|0,e|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;jc(e);Q(a|0);p()}function ut(a){var b=0,c=0,d=0;if(!a){return 0}d=98960;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function rP(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;mM(i,b,c,d,e,f,g);_c(a,i);gn(i);fb=h+32|0}function lG(a){a=a|0;var b=0;a=Fb(a);x[31725]=0;R(170,a+12|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){sc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function bj(a,b){var c=0;c=x[a>>2];if(Zc(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=He(x[a+484344>>2],x[a+484348>>2],z[_b(c,b)>>1])}else{a=0}return a}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Yr(c+20|0,b);d=x[c+20>>2];Yr(c+12|0,b);xl(a,d,x[c+16>>2]);fb=c+32|0}function LE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function KB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){ah(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function CQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}if(c){x[c+8>>2]=x[b+8>>2]}a=x[b+8>>2];if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function tq(a,b){var c=0;a:{if(!gM(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function SP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=kf(31415.926535897932/b);c=Zi(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function Mua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];o0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Jy(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Vy(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function tT(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function g1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];U0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Sk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=uE(a,e,d);break a}a=uE(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Gz(a,0,0,0,0,0,0,c,d);return}Gz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function rqa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Pg(b);Pg(b);break a}a=hh(b);hh(b)}while(1){if(a){if(a&1){Vb(b,260)}a=a>>>1|0;continue}break}}function pg(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;w[c+30>>1]=0;tk(c+8|0,c+30|0);Rm(c+20|0,a,x[c+8>>2],x[c+12>>2]);hj(b,z[c+30>>1]);fb=c+32|0}function aF(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Sm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cf(b);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Cg(Jb(Fz(e,d+a|0)),b,d)+d|0;hm(Cg(b,Jb(c),a)+a|0,1,0)}function QL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function IY(a){var b=0;if(!(kd(a,15015,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Em(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){nc(a);Db(b)}}function ag(a){a=a|0;var b=0;x[a>>2]=42776;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;FQ(a+44|0);return a|0}function Yu(a,b){var c=0,d=0;d=ek(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!He(a,b,d&65535)){continue}}break}return c&65535}function XV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){xs(a);Db(b)}}function W$(a,b,c){var d=0;d=fb-16|0;fb=d;sm(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);kp(a,d+8|0,c);fb=d+16|0}function Tu(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=E_(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function Rn(a,b){var c=0;a=Vn(a);x[a>>2]=78688;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function PR(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=FZ(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function LW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){xs(a);Db(b)}}function Ei(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function hE(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=lm(a,b),w[d+12>>1]=e;a=qe(c+14|0,c+12|0);fb=c+16|0;return z[a>>1]-1&65535}function NO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;nM(h,b,c,d,e,f);_c(a,g+20|0);gn(h);fb=g+32|0}function w_(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=$b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=ad(b+12|0,b+8|0);fb=b+16|0;hb=0;return x[a>>2]-216|0}function of(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=vb(d+12|0,a);c=x[b>>2];if(x[c>>2]){CZ(c);b=x[b>>2];c=x[b>>2];$s(b);Db(c)}fb=d+16|0;return a}function Ne(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=122){Vq(12210);p()}e=d+8|0;Kb(e,a,b);Jf(e,c);fb=d+16|0;return a|0}function Jw(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=BF(a,1);break a}c=hh(a);Vb(a,b-2|0)}return c}function Bp(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=CF(a,b);break a}c=Pg(a);Vb(a,b-4|0)}return c}function Ab(a,b){var c=0;if(Cd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);fd(b,0);return a}function wL(a){var b=0,c=0;x[31725]=0;c=ca(1180)|0;b=x[31725];x[31725]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;gl(a);return}T(0)|0;Tb();p()}function rI(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Lx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function i6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function Sx(a,b){var c=0;c=fb-16|0;fb=c;b=Mh(c+12|0,b);a=a>>>0>=128?(a&-128)!=57216?-1:x[x[124231]>>2]?-1:a&255:a;Lh(b);fb=c+16|0;return a}function Pl(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=ad(a+20|0,b+12|0);fb=b+16|0;return D(x[a>>2],c+d|0)}function KO(a,b,c){var d=0,e=0;d=Mc(a);if(d>>>0>=c>>>0){Xu(a,Ui(Jb(a),b,c),c);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);eq(e,d,c-d|0,a,0,a,c,b)}function xC(a){a=50-(D(y[(a>>>4|0)+29904|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Gc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function wla(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function kk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Rb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function jk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Rb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function i$(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;$w(b,a);a=y[xb(b,0)|0];d=y[xb(b,1)|0];b=y[xb(b,2)|0];fb=c+16|0;return d<<8|a|b<<16}function ed(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=Ze(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return w[a>>1]}function TO(a,b){var c=0,d=0;a:{if(!Rt(b)){break a}c=x[a+484344>>2];if(!He(c,x[a+484348>>2],b&65535)){break a}d=x[Wb(c,b)+12>>2]}return d}function Ria(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];oe(b,x[c+4>>2],x[c+8>>2]);HQ(a,gc(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function AC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=zb(b),d=0,x[c>>2]=d;return a}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=vx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function M4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Cy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Dy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function JH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function sY(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function qP(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;nM(h,b,c,d,e,f);_c(a,h);gn(h);fb=g+32|0}function gd(a,b){var c=0,d=0,e=0;c=lh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function WC(a){var b=0;b=Bb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Bb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function RS(a,b,c,d){var e=0;e=a+1074376|0;pB(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=Iu(x[a+480180>>2])}Fo(a,b,e,c)}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=zl(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function u4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=yt(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function tn(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function lva(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){In(b)}v[a|0]=1}return a|0}function cp(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){bZ(a,x[a>>2]);a=x[b>>2];b=x[a>>2];cZ(a);Db(b)}fb=c+16|0}function ala(a,b){a=a|0;b=b|0;a=iB(a);x[31725]=0;O(848,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;Mq(a);Q(b|0);p()}return a|0}function OW(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){IW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];kl(a);Db(b)}fb=c+16|0}function Jia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Tc(c&255))){KQ(a,8,E(0))}a=Ej(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Du(a,b,c){var d=0;d=fb-16|0;fb=d;b=we(d+8|0,nva(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=eu(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42192|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=eu(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42144|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function yda(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function tt(a){return a>>>0<=254?(a+1&127)>>>0>32:(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}function M9(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){lL(b)}v[a|0]=1}return a|0}function zla(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function wi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function vY(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=Ze(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return v[a|0]}function IH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function Fha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Pd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=ri(c)}B[d>>2]=c;iQ(a)}}function oi(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Oc(c,d,(b>>31&a)+b|0)>>2]}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=122){Vq(12175);p()}d=c+8|0;Kb(d,a,b);Jf(d,0);fb=c+16|0;return a|0}function SS(a,b,c,d){var e=0;e=a+1074376|0;qB(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=Iu(x[a+480180>>2])}Fo(a,b,e,c)}function Qy(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Pf(v[b|0])|0}function Kt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function Ej(a){var b=0,c=0;b=um(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[vd(x[a+16>>2]+906300|0,b)>>2]}return c}function pi(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;o(+b);e=j(1)|0;j(0)|0;l(0,d|0);l(1,c&2147483647|e&-2147483648);return+n()}function ela(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Vq(12210);p()}d=c+8|0;Kb(d,a,b);gp(d);fb=c+16|0;return a|0}function Mt(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function $9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Pf(v[a|0])}else{a=-1}return a|0}function dZ(a,b){var c=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);hp(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function PL(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14218,13258,1180,5734);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Dh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=Ze(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return y[a|0]}function zT(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Lo(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function ke(a){var b=0;a=x[a+4>>2];if(a){if(Am(a)){a:{b=a+8|0;if(x[b>>2]){if((gx(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function jH(a,b,c,d){a=Nb(a);x[31725]=0;S(d|0,a|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a}b=N()|0;uc(a);Q(b|0);p()}function iK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=lt(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function fK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=ht(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function cz(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}yc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function OB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Oj(c,x[a+484364>>2])>>>0<=b>>>0){return Xb(c,y[a+484376|0])}return Vj(c,b)}function O9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function CH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Zr(d+8|0,d);fb=d+16|0;return x[a>>2]}function BC(a,b){var c=0;c=fb-16|0;fb=c;a=gc(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Hb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function $5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function vS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Cu(b);a=x[a>>2];b=x[a>>2];Bu(a);Db(b)}fb=c+16|0}function vC(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){NW(b);a=x[a>>2];b=x[a>>2];kl(a);Db(b)}fb=c+16|0}function sv(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){YV(b);a=x[a>>2];b=x[a>>2];lC(a);Db(b)}fb=c+16|0}function rU(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){lU(b);a=x[a>>2];b=x[a>>2];kl(a);Db(b)}fb=c+16|0}function pS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Sp(b);a=x[a>>2];b=x[a>>2];bx(a);Db(b)}fb=c+16|0}function ou(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function mu(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){dA(b);a=x[a>>2];b=x[a>>2];cA(a);Db(b)}fb=c+16|0}function ie(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){m0(b);a=x[a>>2];b=x[a>>2];rE(a);Db(b)}fb=c+16|0}function gG(a,b){var c=0;c=x[b+4>>2];if(c){bc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!lc(c,b)){oe(a,c,b);return}Nd(a)}function fH(a,b,c){a=ri(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function _B(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){dV(b);a=x[a>>2];b=x[a>>2];bp(a);Db(b)}fb=c+16|0}function Xi(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){jY(b);a=x[a>>2];b=x[a>>2];bp(a);Db(b)}fb=c+16|0}function XU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Yd(b,a)}if(c){Yd(c,a)}if(d){Yd(d,a)}if(e){Yd(e,a)}}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function ES(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){ew(b);a=x[a>>2];b=x[a>>2];A$(a);Db(b)}fb=c+16|0}function Ar(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function yI(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=xR(iq(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function xn(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=ml(d,f,b)+b|0,x[g+12>>2]=h;Ac(a,c,e+12|0);fb=e+16|0}function sw(a,b){return mr(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function qO(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=du(Ec(8));x[c+4>>2]=a;x[c>>2]=48480;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function iN(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=WM(Ec(8));x[c+4>>2]=a;x[c>>2]=73560;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function SG(a){a=a|0;var b=0;a=Fb(a);x[31725]=0;O(132,a|0,13724);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function Rx(a,b){var c=0,d=0,e=0,f=0;c=Cf(b);d=Ec(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=yc(nc(d),b,c+1|0),x[e>>2]=f}function P3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(nh(a,x[b+8>>2],0)){Mx(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function jK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=lt(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function gK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=ht(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function cm(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Rc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function QY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((lm(x[a>>2],x[a+4>>2])|0)!=65535){L0(a,c+14|0)}fb=c+16|0}function OT(a){tB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=qg(a);qg(a+12|0);v[a+24|0]=1}function Ll(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;yA(a,c,d)}function Fg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return So(a,d)}function sr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function pia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Ah(E(Pd(c,E(0))*E(127))),v[d|0]=e;ku(a)}}function ija(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Ah(E(Pd(c,E(0))*E(255))),v[d|0]=e;qu(a)}}function dQ(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=uc(b-24|0);if((c|0)!=(b|0)){continue}break}return ag(a)|0}function qp(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function dH(a,b){x[a>>2]=b;wL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function RK(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|(e&2147418112)>>>16)<<16}function NR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function FC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Eu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(lc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function pt(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+103616|0]<<5)+103616|0]>>>(a&7)&1}else{a=a>>>0<196606}return a}function ne(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function Lp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function Fe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function tY(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!lh(a,4)){lD(b);break a}oh(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function qh(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=Mh(f+8|0,c);a=vt(a,b,d,x[f+12>>2]);Lh(c);fb=f+16|0;return a}function qW(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function pV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){mV(a,1);mV(a,0)}}function pF(a,b){var c=0;c=nva(b&255,0,1536,0);b=hb;a=nva(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function oV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){nV(a,1);nV(a,0)}}function hL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function ZW(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function KY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a=Tg(e+4|0,a,d);f=a,g=Br(b,c,x[a+4>>2]),x[f+4>>2]=g;hc(a);fb=e+16|0}function pT(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function n3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function hf(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function dF(a){var b=0;b=0;a:{if(kd(a,14188,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function cu(a){a=a|0;var b=0;x[a>>2]=47692;Yd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Um(a)|0}function c_(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function UX(a){var b=0;if(!(kd(a,13865,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function Li(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function Hla(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=yf(b+12|0,Sb(Ec(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Cga(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=qc(b+8|0,a);a=Rz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function $u(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function xi(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42224|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function s9(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=FD(x[b>>2]);x[a+36>>2]=b;c=a,d=ko(b),v[c+44|0]=d}function nK(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=Mh(d+8|0,b);a=MK(a,9262,x[d+12>>2]);Lh(b);fb=d+16|0;return a}function lH(a,b,c){a=Ee(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function l9(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Ky(x[b>>2]);x[a+36>>2]=b;c=a,d=ko(b),v[c+44|0]=d}function Zga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;$P(a)}}function Uha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;oQ(a)}}function Rga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;ZP(a)}}function Mha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;kQ(a)}}function wV(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function m0(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Gd(b);continue}break}x[a+4>>2]=c}function Xl(a,b){a=a+62|0;if(v[xb(a,b)|0]<0){return 255}if(y[xb(a,b)|0]!=255){a=y[xb(a,b)|0]&127}else{a=255}return a}function W8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function Sp(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Np(b);continue}break}x[a+4>>2]=c}function HK(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function Fh(a){var b=0;un(a);b=mv(x[a>>2],dl(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Wk(x[a>>2],z[a+34>>1])}function vr(a){var b=0,c=0,d=0;if(x[a>>2]){Nf(a);b=x[a>>2];Ug(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function uh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function tua(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-80|0;fb=b;c=-1;d=a;a=b+14|0;if(V$(d,a)){c=U$(a)}fb=b+80|0;return c|0}function kV(a){var b=0,c=0,d=0;if(x[a>>2]){kj(a);b=x[a>>2];On(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function hU(a){var b=0,c=0,d=0;if(x[a>>2]){IG(a);b=x[a>>2];Yn(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function AR(a){var b=0,c=0,d=0;if(x[a>>2]){K$(a);b=x[a>>2];bw(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function yc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function q0(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function pra(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(pk(d,a)){c=IY(a)}fb=b+16|0;return c|0}function kM(a,b){var c=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,1);El(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;hc(a);fb=c+16|0}function Xua(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(pk(d,a)){c=y0(a)}fb=b+16|0;return c|0}function NL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function Bqa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+4|0;if($D(d,a)){c=aY(a)}fb=b+16|0;return c|0}function xT(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=Bg(a?a:22267),x[d>>2]=e}}function nL(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!lc(rL(c,b),-1)){break a}x[a>>2]=0}return a|0}function lS(a,b){var c=0;c=fb-16|0;fb=c;a=hC(c+4|0,a);Do(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function jQ(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function it(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Ub(a,b);a=a+4|0;continue}}}function SR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=RR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Ol(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Hm(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}tg(a,b);a=a+1|0;continue}}}function hQ(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function sy(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function eN(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(!Ld(c,x[a>>2])){break a}}else{a=b}return a}a=a+8|0;continue}}function _A(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,ova(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Ql(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function KJ(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=(Cb(x[a+4>>2],y[a+11|0])<<2)+c>>>0>=b>>>0}else{a=0}return a}function nh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!ni(x[a+4>>2],x[b+4>>2])}function lR(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=Gb(b+12|0,b+8|0);fb=b+16|0;return w[a>>1]}function km(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=Gb(b+12|0,b+8|0);fb=b+16|0;return z[a>>1]}function cw(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Fe(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function NW(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;continue}break}x[a+4>>2]=c}function Kn(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Jf(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function DH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=yb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function e4(){if(y[500396]){return x[125098]}Cs(500388,x[vH()>>2]);v[500396]=1;x[125098]=500388;return 500388}function _v(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=Nc(b+14|0,b+12|0);fb=b+16|0;return y[a|0]}function _1(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(pk(d,a)){c=iG(a)}fb=b+16|0;return c|0}function WR(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Tl(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;gc(a,b,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Lk(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function LS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function Kx(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Lx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function G2(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;c=-1;d=a;a=b+8|0;if(PG(d,a)){c=OG(a)}fb=b+32|0;return c|0}function Cq(a,b){var c=0;c=fb-32|0;fb=c;oh(c+16|0,b);Rm(c+24|0,a,x[c+16>>2],x[c+20>>2]);oh(c+8|0,b);fb=c+32|0}function tL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return Pf(v[b|0])}function hK(a,b,c,d,e){b=qj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function eK(a,b,c,d,e){b=pj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function UU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27424|0]>>>z[a+68>>1]}function yra(a,b){a=a|0;b=b|0;if(!ZY(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function yi(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=Gb(b+12|0,b+8|0);fb=b+16|0;return y[a|0]}function yV(a,b){a=a|0;b=b|0;var c=0;c=Cb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){As(a,b-c|0,0);return}pU(a,b)}function tx(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+12;fb=b+16|0;return Wp(x[b+12>>2])}function qA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function lY(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function ega(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){It(x[31600],12710);p()}fb=a+16|0;return x[a+12>>2]}function bM(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Vl(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Tj(a)){a=gU(b,d)}return Cd(a)}function Nea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ZH(a,b,c,d,e,f,g,12977,1084)|0}function Gea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ZH(a,b,c,d,e,f,g,13045,1091)|0}function _W(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function Ou(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Io(a);continue}break}return a}function Lz(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=Cb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function Iw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function mI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return Hz(g|a,b,c,d,a|e,f)|0}function gva(a){a=a|0;var b=0;b=x[a+76>>2];if(lc(-1,b)){b=lF(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function ZI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function VN(a,b){a=a|0;b=b|0;a=Lj(a);x[a+4>>2]=0;x[a>>2]=47632;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function U$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function Qs(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Lx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function Ob(a,b){var c=0;c=fb-16|0;fb=c;XF(c+8|0,a,b);a=Hb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function Al(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function uS(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Dk(c);continue}break}x[a+4>>2]=b}function p0(a,b){a=wm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];wm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function nl(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function kz(a,b,c){b=(D(D(iz(a),jz(a,b)),125)>>>0)/(jM(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function kU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;uf(c);continue}break}x[a+4>>2]=b}function cV(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Hk(c);continue}break}x[a+4>>2]=b}function bea(a){a=a|0;var b=0;b=fb-16|0;fb=b;ee(b+8|0,a);a=Rz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function SE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function Pb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function PT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function Lda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return LO(x[a+4>>2],b,c,d,e,f,g)|0}function IW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;vC(c);continue}break}x[a+4>>2]=b}function Hda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return DO(x[a+4>>2],b,c,d,e,f,g)|0}function wj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function dv(a,b){b=nva(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Gc(ova(b,a,1e6,0),hb)}function QT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function EJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=Mh(b+12|0,a);c=x[x[124231]>>2];Lh(a);fb=b+16|0;return c?4:1}function up(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Tn(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c|0}function Vk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Jp(a,b+14|0)){c=Bb(z[b+14>>1])}fb=b+16|0;return c|0}function qaa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;T0(c+8|0,b);Fp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function d_(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Bb(b&65535),w[d+14>>1]=e;Qv(a,c+14|0);fb=c+16|0}function Zv(a){var b=0,c=0;if(x[a>>2]){fp(a);Db(x[a>>2]);b=zb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function ZD(a,b){if(b>>>0<=126){Xe(((b<<5)+a|0)+480280|0);Vo((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function Uv(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Vm(b,b+22|0,78784);x[a+20>>2]=0;ld(a,0);return a|0}function Sb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function MV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=kd(a,18296,17)}else{a=1}return!a}function FS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Fc(a+60|0,0);x[a+64>>2]=0;return a}function uf(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,a)>>2];c=x[a>>2];if(c){zb(a);Db(c)}fb=b+16|0}function fl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function bra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Jp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function VH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Dc(d+4|0,c);a=pc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function OV(a){ie(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function Lia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Ej(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function K1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Ln(c+8|0,b);Fp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function J1(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);_r(a,127);LF(a,127,y[b|0]);return a|0}function Hg(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function HZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){GZ(c+52|0);tb(c+40|0);uc(c+16|0);uc(c+4|0);Db(c)}}function DE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function CS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function pea(a,b){a=a|0;b=b|0;var c=0;b=Jb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}iu(b,a)}function nU(a,b,c){var d=0;d=fb-16|0;fb=d;a=vb(d+12|0,fU(b,c,ce(a),ec(a)));fb=d+16|0;return x[a>>2]}function iJ(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=HY(c)}x[a+4>>2]=c;x[a>>2]=b}function gS(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22267}else{a=22267}return a}function ei(a,b,c){var d=0;d=x[a+4>>2];while(1){if((b|0)!=(d|0)){d=d-c|0;continue}break}x[a+4>>2]=b}function dy(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Mh(f+12|0,e);a=xt(a,b,c,d);Lh(e);fb=f+16|0;return a}function _c(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];QG(b);return a}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;a=Ej(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function HF(a,b,c,d,e,f,g){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f);vb(a+20|0,g)}function Gi(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Mh(f+12|0,e);a=DK(a,b,c,d);Lh(e);fb=f+16|0;return a}function Kw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=fh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function rR(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function kw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Dc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=tc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function bt(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function ZJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function UJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Tra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Tn(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function Qea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cI(a,b,c,d,e,f,10648,1081)|0}function Od(){var a=0;if(y[500372]){return x[125092]}a=zk(14276);v[500372]=1;x[125092]=a;return a}function Dfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cI(a,b,c,d,e,f,10693,1054)|0}function nz(a,b,c,d){var e=0;e=fb-16|0;fb=e;bc(e+8|0,c,d);VM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function dva(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function Yz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function X9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function W9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function V9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function U9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function T9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Rm(a,b,c,d){var e=0;e=fb-16|0;fb=e;mf(e+8|0,c,d);VM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function MD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=J_(c+12|0,0-b|0);fb=c+16|0;return x[a>>2]}function vka(a,b){a=a|0;b=b|0;Ri(a);Ri(a);a:{if(b>>>0>=60){Vb(a,4);break a}Ri(a)}return Ri(a)|0}function Ww(a,b){a=bG(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];bG(a+12|0,x[b+12>>2],x[b+16>>2])}function VX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function Rca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;rP(a,x[b+4>>2],c,d,e,f,g)}function R2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;VI(d,b);Rh(a,d);tb(d);fb=c+16|0}function Mca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;OO(a,x[b+4>>2],c,d,e,f,g)}function K0(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(nh(a,x[b+8>>2],f)){Ox(b,c,d,e)}}function Eba(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,_l(Ec(12),a));fb=b+16|0;return x[a>>2]}function E9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function dX(a){var b=0,c=0;b=fb-16|0;fb=b;if($E(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c}function Zd(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=fh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function RL(a){var b=0;b=+((a&2097151)>>>0);return E(rk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function P$(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function JD(a){var b=0,c=0;b=fb-16|0;fb=b;if(Jp(a,b+14|0)){c=xe(w[b+14>>1])}fb=b+16|0;return c}function Ica(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;qP(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Hca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;NO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Ex(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function EK(a){var b=0;b=x[124231];if(a){x[124231]=(a|0)==-1?500180:a}return(b|0)==500180?-1:b}function $$(a){var b=0;if(!(kd(a,24692,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function ot(a){return y[(a>>>3&31|y[(a>>>8|0)+107520|0]<<5)+107520|0]>>>(a&7)&1&a>>>0<=131071}function jZ(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function Ys(a){a=a|0;var b=0;x[a>>2]=112060;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function Vm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Um(a){a=a|0;var b=0;x[a>>2]=47652;b=x[a+4>>2];if(b){Db(Aq(b))}x[a+4>>2]=0;return a|0}function Lqa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=ai(b+12|0);FY(c,a,0,0);ub(a);fb=b+32|0}function Lca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return eu(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function Ic(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=E_(a,b,x[c>>2],d)}else{a=1}return!a}function FW(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function rA(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;JY(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function nE(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;h0(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function iV(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=hV(c+12|0,b);fb=c+16|0;return x[a>>2]}function Q9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function Pe(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=SU(c+12|0,b);fb=c+16|0;return x[a>>2]}function IC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function y0(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function wJ(a,b){a=xd(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=112060;x[a+8>>2]=112112;return a}function sB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function lqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=$h(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function i5(a,b){a=a|0;b=b|0;a=xd(a,0);UI(a+8|0,b);x[a>>2]=117092;x[a>>2]=117376;return a|0}function hh(a){var b=0;b=fb-16|0;fb=b;a=Jp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function gg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){ZD(a,c);b=b+1|0;continue}break}}function g5(a,b){a=a|0;b=b|0;a=xd(a,0);UI(a+8|0,b);x[a>>2]=117248;x[a>>2]=117492;return a|0}function ey(a,b,c){var d=0;d=fb-16|0;fb=d;c=Mh(d+12|0,c);a=Wy(a,b);Lh(c);fb=d+16|0;return a}function UE(a){var b=0;b=x[a>>2];if(x[b>>2]){SE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];TE(a);Db(b)}}function NN(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=CN(d);b=b+1|0}PU(a,b,c,d,e)}function Mga(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Gz(a,b,c,d,e,0,0,f,g)}function LD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;Au(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function GF(a,b){if((a&4088)>>>0>=520){b=Nw(0-qva(b^1230262859,25)|0,4)^1247037516}return b}function sL(a){var b=0;b=x[a>>2];if(b){if(!lc(tL(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function lx(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22276>>2]}else{b=9742}tc(a,b)}function eQ(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function bG(a,b,c){var d=0;d=fb-16|0;fb=d;b=wm(d+8|0,b,c);FG(b,a);ke(b);fb=d+16|0;return a}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function Fm(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[yb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Eh(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function wq(a){a=a|0;var b=0;x[a>>2]=47632;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function qva(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function nx(){var a=0,b=0;a=fb-16|0;fb=a;b=yf(a+12|0,Nb(Ec(12)));fb=a+16|0;return x[b>>2]}function lA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function iF(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function hs(a){var b=0;while(1){if(!lc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function b3(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);Cs(a,x[b+4>>2]);bH(b+4|0,c)}function Ml(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function JU(a,b,c){while(1){if((b|0)!=(c|0)){HU(a,y[b|0]);b=b+1|0;continue}break}return a}function H$(a,b,c){var d=0;d=fb-16|0;fb=d;wi(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function Gy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=vt(a,b,c,d);fb=e+16|0;return a}function yn(a){var b=0;if(a>>>0>=2){b=NY(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function tJ(a,b){a=xd(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=113352;Fb(a+16|0);return a}function oJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121044;x[a>>2]=116028;x[b>>2]=116076;return a}function nn(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,(b<<1)+a|0);fb=c+16|0;return x[a>>2]}function nJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121080;x[a>>2]=116292;x[b>>2]=116340;return a}function hw(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,D(b,6)+a|0);fb=c+16|0;return x[a>>2]}function dT(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function _t(a){if(aN(a)){a=ac(4);x[a>>2]=0;a=Lj(a);x[a>>2]=124524;da(a|0,124560,34);p()}}function XB(a,b){a=_l(a,b);_c(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function Pia(a,b){a=a|0;b=b|0;a=Ej(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function NX(a,b){var c=0;c=fb-16|0;fb=c;Ln(c+8|0,b);AZ(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function DS(a){var b=0;b=a+4e4|0;while(1){b=UA(b-160|0);if((b|0)!=(a|0)){continue}break}}function zD(a){var b=0;b=DV(a);while(1){if((a|0)!=(b|0)){n0(a);a=a+32|0;continue}break}}function yC(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function vs(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=CN(d);b=b+1|0}HB(a,b,c,d)}function l2(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function iL(a){var b=0;b=x[a>>2];if(b){if(!oo(Al(b))){return!x[a>>2]}x[a>>2]=0}return 1}function hm(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Uh(a,b,d+15|0);fb=d+16|0;return a}function bh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Pea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bI(a,b,c,d,e,12433,1082)|0}function Mv(a,b,c){var d=E(0);d=B[a>>2];if(!Lv(d,B[b>>2])){b=Lv(B[c>>2],d)?c:a}return b}function LK(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=MK(a,11188,b);fb=c+16|0;return a}function Kq(a,b,c){a=Pl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function Cfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bI(a,b,c,d,e,12533,1055)|0}function Am(a){var b=0;b=gx(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function zc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Ln(d,a);tm(d,b);fb=c+16|0;return a}function z0(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24640|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function kaa(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function jaa(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function iu(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;FP(18447,b);hu(125936);fb=b+16|0}function W5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function SV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function Q2(){var a=0;a:{if(YG(19989505)){break a}if(XG()){break a}a=WG()^1}return a|0}function NU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Mea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,9626,1085)|0}function GG(a,b){var c=0;c=fb-16|0;fb=c;b=Ef(c+8|0,b);FG(b,a);ke(b);fb=c+16|0;return a}function Fea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,9698,1092)|0}function EE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;ww(a,c+15|0);fb=c+16|0}function z8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return MH(b,c,d,e,f,0)|0}function wv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function r8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return KH(b,c,d,e,f,1)|0}function p8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return KH(b,c,d,e,f,0)|0}function p6(a){a=a|0;a=501656;while(1){a=tb(a-12|0);if((a|0)!=501632){continue}break}}function o6(a){a=a|0;a=501312;while(1){a=tb(a-12|0);if((a|0)!=501024){continue}break}}function n6(a){a=a|0;a=500840;while(1){a=tb(a-12|0);if((a|0)!=500672){continue}break}}function kJ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];by(iq(a),x[a>>2],Ug(a))}}function X5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+97936>>2]}return b<<24>>24}function Wg(a,b,c){var d=0;d=fb-16|0;fb=d;AY(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function U5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96400>>2]}return b<<24>>24}function QJ(a,b){var c=0,d=0;Te(a,le(b));b=ec(b);c=ec(a),d=x[b>>2],x[c>>2]=d;return a}function Mu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){IA(a,b,0);IA(a,b,1);IA(a,b,2)}}function Jv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;Gv(a+236|0,128,c+14|0);fb=c+16|0}function JK(a){return(a|0)!=0&(a|0)!=121484&(a|0)!=121508&(a|0)!=500096&(a|0)!=500120}function D6(a){a=a|0;a=501688;while(1){a=Qb(a-12|0);if((a|0)!=501664){continue}break}}function C6(a){a=a|0;a=501616;while(1){a=Qb(a-12|0);if((a|0)!=501328){continue}break}}function B8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return MH(b,c,d,e,f,1)|0}function B6(a){a=a|0;a=501016;while(1){a=Qb(a-12|0);if((a|0)!=500848){continue}break}}function yga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return CP(a,b,c,d,0,0,0,0,e)|0}function uC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function oia(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function lf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function kW(a,b,c,d,e,f){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f)}function hja(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function fy(a){a=a|0;x[a>>2]=113264;if(x[a+8>>2]!=(Od()|0)){wl(x[a+8>>2])}return a|0}function fk(a,b,c){var d=0;d=x[a>>2];if(!cr(d,x[b>>2])){b=cr(x[c>>2],d)?c:a}return b}function Yg(a,b,c){var d=0;d=C[a>>3];if(!NV(d,C[b>>3])){b=NV(C[c>>3],d)?c:a}return b}function Pg(a){var b=0;b=fb-16|0;fb=b;a=Tn(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function Mda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JO(x[a+4>>2],b,c,d,e)|0}function Jda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return CO(x[a+4>>2],b,c,d,e)|0}function Io(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function He(a,b,c){if(xp(a,b,c)){a=gj(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function H4(a,b,c){a=a|0;b=b|0;c=c|0;a=Sx(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function yW(a){var b=0;b=x[a>>2];if(x[b>>2]){bW(b);a=x[a>>2];b=x[a>>2];hv(a);Db(b)}}function x7(a){a=a|0;jq(x[a+8>>2]);a=x[a+8>>2];if(!a){return 1}return(EJ(a)|0)==1|0}function oq(a){a=a|0;x[a+56>>2]=94176;x[a>>2]=94156;Ct(a+4|0);Cl(a+56|0);return a|0}function jz(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+81137|0]<<1}function j0(a,b,c){a=a|0;b=b|0;c=c|0;return i0(a,b,Jb(c),Cb(x[c+4>>2],y[c+11|0]))|0}function iU(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){jU(b+16|0)}Db(b)}}function gm(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=_e(Ci(b)*+(c>>>0)),x[d+24>>2]=e}function ge(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48616;Ac(a,48512,b+12|0);fb=b+16|0}function fR(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];b=x[a>>2];Ug(a);Db(b)}}function Xk(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a+b|0);fb=c+16|0;return x[a>>2]}function TF(a){var b=0;b=x[a>>2];if(x[b>>2]){kj(b);a=x[a>>2];b=x[a>>2];On(a);Db(b)}}function TA(a){var b=0;b=fb-16|0;fb=b;vb(b+12|0,a+116|0);a=tS(a);fb=b+16|0;return a}function OR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Eb(b+16|0)}Db(b)}}function L$(a){var b=0;b=x[a>>2];if(x[b>>2]){K$(b);a=x[a>>2];b=x[a>>2];bw(a);Db(b)}}function JG(a){var b=0;b=x[a>>2];if(x[b>>2]){IG(b);a=x[a>>2];b=x[a>>2];Yn(a);Db(b)}}function Ff(a){a=a|0;x[a+60>>2]=94340;x[a>>2]=94320;Ct(a+8|0);Cl(a+60|0);return a|0}function Ef(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function DZ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Xj(b+16|0)}Db(b)}}function Cha(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];iQ(a);gQ(a)}function $ia(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];qu(a);OQ(a)}function wT(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function p7(){var a=0,b=0,c=0;a=xd(501744,1);x[a>>2]=113264;b=a,c=Od(),x[b+8>>2]=c}function iv(a,b){a=Bb(a&65535);b=Bb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Zp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function VL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function Eda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fI(a,b,c,d,e,1122)|0}
function $p(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function wM(a,b){a=Vn(a);v[a+8|0]=0;x[a+4>>2]=b;x[a>>2]=77372;Nb(a+12|0);return a}function rg(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,ec(a));fb=b+16|0;return x[a>>2]}function nea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1107)|0}function lea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1109)|0}function kea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1111)|0}function gR(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function ap(a,b){a=yc(a,b,34);w[a+34>>1]=z[b+34>>1];yc(a+36|0,b+36|0,68);return a}function _i(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,wb(a));fb=b+16|0;return x[a>>2]}function TV(a){if((y[a+14|0]-53&255)>>>0>=252){a=kd(a,15612,14)}else{a=1}return!a}function Rf(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,rg(a));fb=b+16|0;return x[a>>2]}function Ms(a,b,c,d){if(b>>>0>=d>>>0){$j();p()}c=Ec(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function JF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Gv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function FP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;GL(125936,a,b,0,0);fb=c+16|0}function sO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1106)|0}function pO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1108)|0}function oO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1110)|0}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function nO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1026)|0}function h6(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+112112>>2]&b)!=0&c>>>0<=127}function fga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1e3)|0}function fO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gx(a,b,c,d,e,1107)|0}function eO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hs(a,b,c,d,e,1107)|0}function dO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gx(a,b,c,d,e,1109)|0}function cO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hs(a,b,c,d,e,1109)|0}function bY(a){var b=0;while(1){if((b|0)!=512){eh(a+b|0);b=b+1|0;continue}break}}function bO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gx(a,b,c,d,e,1111)|0}function aO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hs(a,b,c,d,e,1111)|0}function Uk(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;ic(a+8|0,b+8|0)}function DM(a){a=Vn(a);x[a>>2]=77836;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function AP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fI(a,b,c,d,e,1001)|0}function zi(a){return(ok(x[a>>2],x[a+4>>2])|0)!=(0-ok(x[a+12>>2],x[a+16>>2])|0)}function r3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function qg(a){var b=0,c=0;sc(a+4|0);Fc(a+8|0,0);b=a,c=ec(a),x[b>>2]=c;return a}function lca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return zN(a-88|0,b,c,d,e)|0}function kS(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;HC(d,1,b);Cc(a,d);fb=c+16|0}function k$(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function eg(a){var b=0;b=xb(a,2);return y[xb(a,1)|0]<<8|y[b|0]<<16|y[xb(a,0)|0]}function Qb(a){var b=0;if(Cd(y[a+11|0])){b=x[a>>2];dj(x[a+8>>2]);Db(b)}return a}function PJ(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function Lsa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,oZ(b,Jb(c),Cb(x[c+4>>2],y[c+11|0])))}function L6(a){a=a|0;if(!y[500624]){An(500612,113580);v[500624]=1}return 500612}function J6(a){a=a|0;if(!y[500656]){An(500644,113664);v[500656]=1}return 500644}function Id(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;wn(a,b,d+12|0);fb=d+16|0}function Haa(a){a=a|0;a=x[a+24>>2];return uM(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function HU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27564>>2]}function H6(a){a=a|0;if(!y[500560]){An(500548,113508);v[500560]=1}return 500548}function Fx(a,b,c,d){if(b>>>0>=d>>>0){$j();p()}c=Ec(b<<c);x[a+4>>2]=b;x[a>>2]=c}function FH(a,b){x[a>>2]=b;Qb(a+52|0);Qb(a+40|0);Qb(a+28|0);tb(a+16|0);return a}function F6(a){a=a|0;if(!y[500592]){An(500580,113544);v[500592]=1}return 500580}function EH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function Ax(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function $N(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hs(a,b,c,d,e,1e3)|0}function x6(a){a=a|0;if(!y[500608]){Dc(500596,13617);v[500608]=1}return 500596}function r6(a){a=a|0;if(!y[500576]){Dc(500564,13766);v[500576]=1}return 500564}function lda(a,b){a=a|0;b=b|0;a=x[a+4>>2];return SO(x[a+24>>2],B[a+48>>2],b)|0}function lD(a){var b=0;while(1){if((b|0)!=4){eh(a+b|0);b=b+1|0;continue}break}}function l3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function e$(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){kM(a,b);return}eM(a,b)}function Y4(a,b){a=a|0;b=b|0;a=Lj(a);x[a>>2]=125052;Rx(a+4|0,Jb(b));return a|0}function Y3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[502192]){v[502192]=1}gc(a,c,126380)}function Tw(a,b){var c=0;if((b|0)<0){$j();p()}c=Ec(b<<1);x[a+4>>2]=b;x[a>>2]=c}function IE(a,b){return _e(Ci((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function DA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){lS(a,b);return}oA(a,b)}function $o(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function zj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function ze(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Ow(d,a);tm(d,b);fb=c+16|0}function zB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Sl(Sl(c,a),D(a,-100)+b|0)}function yB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function xB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return zB(Sl(c,a),D(a,-1e4)+b|0)}function wb(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,a);fb=b+16|0;return x[a>>2]}function v6(a){a=a|0;if(!y[500640]){Dc(500628,9253);v[500640]=1}return 500628}function uJ(a,b){a=xd(a,b);w[a+8>>1]=11310;x[a>>2]=113312;Fb(a+12|0);return a}function tf(a){if(Cd(y[a+11|0])){fd(x[a>>2],0);Yd(a,0);return}fd(a,0);Me(a,0)}function t6(a){a=a|0;if(!y[500544]){Dc(500532,5265);v[500544]=1}return 500532}function om(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;T0(d,a);tm(d,b);fb=c+16|0}function nS(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[zb(a)>>2]){lS(a,b);return}oA(a,b)}function hA(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function gA(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function aU(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Zj(a){var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,a);fb=b+16|0;return x[a>>2]}function Xba(a,b){a=a|0;b=b|0;In(x[a+4>>2]);kG(pG(x[a+4>>2],b));In(x[a+4>>2])}function Qu(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return xB(Sl(c,a),D(a,-1e6)+b|0)}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(nh(a,x[b+8>>2],0)){Mx(b,c,d)}}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,12934,1086)|0}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,13008,1088)|0}function Hj(a){if(Ob(a+1074312|0,7)){a=Dn(x[a+480180>>2])^1}else{a=0}return a}function Eha(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function rK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function mK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function fe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Vb(b,c);jx(a,b,d,c)}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,9420,1083)|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,9581,1087)|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,9659,1089)|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $n(a,b,c,d,9451,1090)|0}function $e(a){var b=0;b=fb-16|0;fb=b;Sn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function $S(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function yQ(a){a=a|0;x[a>>2]=44748;uc(a+4276|0);uc(a+4264|0);return ag(a)|0}function y9(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){cL(a,c);return}Dc(a,7920)}function t8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LH(b,c,d,e,1)|0}function rC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function q8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LH(b,c,d,e,0)|0}function jM(a,b){a=a^-1;return x[(b&12)+81140>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function g_(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function fL(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function d6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+97936>>2]}return b|0}function b6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96400>>2]}return b|0}function Gh(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function EU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);xU(a,b,0,0,b+-1,0)}function D8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return NH(b,c,d,e,1)|0}function A8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return NH(b,c,d,e,0)|0}function $l(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function gi(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return IO(x[a+4>>2],b,c,d)|0}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return GO(x[a+4>>2],b,c,d)|0}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HO(x[a+4>>2],b,c,d)|0}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return FO(x[a+4>>2],b,c,d)|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return MO(x[a+4>>2],b,c,d)|0}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return EO(x[a+4>>2],b,c,d)|0}function Jk(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(PV(a)?b:a)&65535}function Bia(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function AG(a,b){a=a|0;b=b|0;a=Lj(a);x[a>>2]=125052;Rx(a+4|0,b);return a|0}function $3(a,b,c){a=a|0;b=b|0;c=c|0;return lc(a,x[b+4>>2])&x[b>>2]==(c|0)}function zG(a,b){a=Ef(a,b);x[a+8>>2]=x[b+8>>2];Ef(a+12|0,b+12|0);return a}function yj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function uc(a){var b=0;b=fb-16|0;fb=b;fR(vb(b+12|0,a));fb=b+16|0;return a}function tz(a,b){var c=0,d=0;c=vb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function tp(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function pG(a,b){a=a|0;b=b|0;return AF(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))|0}function nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Bp(a,b),x[d>>2]=e}function msa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Jw(a,b),w[d>>1]=e}function mY(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function hd(a,b){a=GG(a,b);x[a+8>>2]=x[b+8>>2];GG(a+12|0,b+12|0);return a}function dc(a){var b=0;b=fb-16|0;fb=b;MZ(vb(b+12|0,a));fb=b+16|0;return a}function Xc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function Jb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Cd(y[a+11|0]),d?b:c}function IF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function zL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gi(a,-1,-1)}function Qm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Iy(a,b){var c=0;c=Nt(a+4|0);x[a>>2]=94968;x[c>>2]=94988;so(c,b)}function Hy(a,b){var c=0;c=WK(a+4|0);x[a>>2]=95336;x[c>>2]=95356;so(c,b)}function vpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kH(a,b,c,d,e,135)}function tQ(a){a=a|0;return E(E(E(B[yb(a+4208|0,5)>>2]*E(198))+E(-99)))}function qc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Cf(b),x[c+4>>2]=d;return a}function jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1113)|0}function iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1115)|0}function gq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1117)|0}function fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1119)|0}function dE(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function WU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function Tua(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function OU(a){if(a>>>0<=8){return y[a+27552|0]}return y[a+27543|0]|256}function Mc(a){if(Cd(y[a+11|0])){a=dj(x[a+8>>2])-1|0}else{a=10}return a}function JN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function IK(a,b,c){var d=0;d=c;c=Cf(b);if(d>>>0>c>>>0){vO(a,b)}return c}function I$(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function H3(a){a=a|0;if(!a){return 0}return(gB(a,124608,124752)|0)!=0|0}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1001)|0}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1122)|0}function $y(a){return((Oh(a)+(Oh(a)<<8)|0)+(Oh(a)<<16)|0)+(Oh(a)<<24)|0}function zn(a){if(Cd(y[a+11|0])){a=dj(x[a+8>>2])-1|0}else{a=1}return a}function st(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function qD(a,b){if(b){qD(a,x[b>>2]);qD(a,x[b+4>>2]);Xj(b+16|0);Db(b)}}function pD(a,b){if(b){pD(a,x[b>>2]);pD(a,x[b+4>>2]);Xj(b+16|0);Db(b)}}function mra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ix(a,b,c,d,587)|0}function mO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1112)|0}function lO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1114)|0}function kv(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function kO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1116)|0}function jB(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function iO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1118)|0}function hi(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function gs(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function _N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Gs(a,b,c,d,1113)|0}function ZN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Gs(a,b,c,d,1115)|0}function YN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Gs(a,b,c,d,1117)|0}function XN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Gs(a,b,c,d,1119)|0}function Ssa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kH(a,b,c,d,e,93)}function Rq(a,b){if(b){Rq(a,x[b>>2]);Rq(a,x[b+4>>2]);jU(b+16|0);Db(b)}}function Nx(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function DB(a,b){if(b){DB(a,x[b>>2]);DB(a,x[b+4>>2]);gn(b+16|0);Db(b)}}function CA(a,b){if(b){CA(a,x[b>>2]);CA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function $j(){var a=0;a=Xm(ac(4));x[a>>2]=124936;da(a|0,125012,34);p()}function $B(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function rS(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function qU(a,b,c){if(He(a,b,c)){a=x[Wb(a,c)+12>>2]}else{a=1}return a}function p3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function lW(a,b,c,d,e){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e)}function l$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ix(a,b,c,d,341)|0}function kx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ix(a,b,c,d,165)|0}function gN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){yo(c+120|0);Db(c)}}function ay(a){a=a|0;if(x[a+8>>2]!=(Od()|0)){wl(x[a+8>>2])}return a|0}function MZ(a){var b=0;b=x[a>>2];if(x[b>>2]){fp(b);Db(x[x[a>>2]>>2])}}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function YY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];ic(a+8|0,b+8|0)}function X8(a){a=a|0;var b=0;b=x[125100]+1|0;x[125100]=b;x[a+4>>2]=b}function D7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lg(a,f)}function C7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kq(a,f)}function jI(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function iZ(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function cT(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function Zr(a,b){return Mw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Vr(a,b,c){if(Zc(a,b)>>>0<=c>>>0){Dw();p()}return(c<<1)+a|0}function Oc(a,b,c){if(oc(a,b)>>>0<=c>>>0){Dw();p()}return(c<<2)+a|0}function Mk(a,b,c){var d=0;d=fb-16|0;fb=d;AY(d+8|0,a,b,c);fb=d+16|0}function Im(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function IO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,4)|0}function I0(a,b){return hq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function HO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,2)|0}function GO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return WH(a,b,c,d,4)|0}function FO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return WH(a,b,c,d,2)|0}function C4(a,b){a=a|0;b=b|0;a=XI(a,b,1);x[a>>2]=121116;return a|0}
function sg(a,b){a=a|0;b=b|0;var c=0;c=Ec(b);x[a+4>>2]=b;x[a>>2]=c}function rV(a,b){var c=0,d=0;c=vb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function nd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function by(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function _5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function Yca(a,b){a=a|0;b=b|0;if(!x[31725]){x[31725]=a;x[31726]=b}}function X4(a,b){a=a|0;b=b|0;a=WI(a,b,1);x[a>>2]=121212;return a|0}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,981,86224)|0}function Uj(a,b){a=a|0;b=b|0;var c=0;c=HY(b);x[a+4>>2]=b;x[a>>2]=c}function wp(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function wk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function uo(a,b){if(A[a+4>>2]<A[zb(a)>>2]){kM(a,b);return}eM(a,b)}function tha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,977,4228)|0}function ria(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,970,4236)|0}function nja(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,946,4268)|0}function m2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function lI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return wO(a,b,c,d)|0}function kha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,978,5048)|0}function fma(a,b){a=a|0;b=b|0;a=Wv(a,b);x[a>>2]=125260;return a|0}function ck(a,b){if(Lg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function aha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,980,4276)|0}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,973,4280)|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,954,4304)|0}function Us(a){a=a|0;x[a>>2]=113144;wl(x[a+16>>2]);return Ys(a)|0}function Rp(a,b,c){a=Ef(a,b);x[a+8>>2]=0;Ef(a+12|0,c);ke(c);ke(b)}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,974,4276)|0}function ML(a,b){a=KL(a-1|0);if(!a){a=KL(b);a=a?a+32|0:0}return a}function Ita(a,b){a=a|0;b=b|0;a=Wv(a,b);x[a>>2]=125208;return a|0}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,975,4268)|0}function HN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function FY(a,b,c,d){a=Ge(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function Cm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function Ch(a,b,c){a=vb(a,b);i_(a+4|0,x[c>>2],x[c+4>>2]);return a}function zW(a){var b=0;b=fb-16|0;fb=b;oW(vb(b+12|0,a));fb=b+16|0}function vz(a){var b=0;b=fb-16|0;fb=b;nN(vb(b+12|0,a));fb=b+16|0}function uW(a){var b=0;b=fb-16|0;fb=b;hW(vb(b+12|0,a));fb=b+16|0}function t_(a,b){a=a|0;b=b|0;a=Wv(a,b);x[a>>2]=125072;return a|0}function qn(a){var b=0;b=fb-16|0;fb=b;yW(vb(b+12|0,a));fb=b+16|0}function n2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function md(a){var b=0;b=fb-16|0;fb=b;TF(vb(b+12|0,a));fb=b+16|0}function jr(a,b,c){a=Bb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function jq(a){var b=0;b=fb-16|0;fb=b;Lh(Mh(b+12|0,a));fb=b+16|0}function hq(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function cy(a){var b=0;b=fb-16|0;fb=b;kJ(vb(b+12|0,a));fb=b+16|0}function aQ(a){return E(E(B[yb(a+4208|0,11)>>2]*E(19980))+E(20))}function YA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function Td(a){var b=0;b=fb-16|0;fb=b;QH(vb(b+12|0,a));fb=b+16|0}function Rk(a){var b=0;b=fb-16|0;fb=b;L$(vb(b+12|0,a));fb=b+16|0}function Qca(a,b){a=a|0;b=b|0;return E(nP(x[x[a+4>>2]+24>>2],b))}function Qc(a){var b=0;b=fb-16|0;fb=b;UE(vb(b+12|0,a));fb=b+16|0}function Pca(a,b){a=a|0;b=b|0;return E(mP(x[x[a+4>>2]+24>>2],b))}function PW(a){var b=0;b=fb-16|0;fb=b;JW(vb(b+12|0,a));fb=b+16|0}function Oca(a,b){a=a|0;b=b|0;return E(jP(x[x[a+4>>2]+24>>2],b))}function Kga(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Kca(a,b){a=a|0;b=b|0;return E(lP(x[x[a+4>>2]+24>>2],b))}function Jca(a,b){a=a|0;b=b|0;return E(kP(x[x[a+4>>2]+24>>2],b))}function DG(a,b,c){a=Vn(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78688}function BY(a){var b=0;b=fb-16|0;fb=b;uY(vb(b+12|0,a));fb=b+16|0}function Ae(a){var b=0;b=fb-16|0;fb=b;JG(vb(b+12|0,a));fb=b+16|0}function yy(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function yx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function v7(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return EJ(a)|0}function qm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function ita(a,b){a=a|0;b=b|0;a=f_(a,b);if(!a){e_(b)}return a|0}function bu(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function bQ(a){return E(E(B[yb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Wca(a,b){a=a|0;b=b|0;return TO(x[x[a+4>>2]+24>>2],b)|0}function Vc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ru(b)}return a}function Se(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Ps(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function Mw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Go(a,b,c,d){a=kv(a,c);if(Tj(a)){a=gU(b,d)}return Cd(a)}function Bla(a,b){a=a|0;b=b|0;a=fZ(a,b);if(!a){eZ(b)}return a|0}function Bg(a){var b=0;b=fr(Cf(a)+1|0,1);if(b){vO(b,a)}return b}function At(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function yD(a,b){a=a|0;b=b|0;a=rZ(a,b);if(!a){mD(b)}return a|0}function uha(a,b,c){a=a|0;b=b|0;c=c|0;return Hx(a,b,c,1,976)|0}function tl(a){return wb(Jb(a)+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)}function rs(a,b){a=a|0;b=b|0;a=jG(a,b);if(!a){px(b)}return a|0}function rQ(a){a=a|0;return Ik(E(B[yb(a+4208|0,4)>>2]*E(4)))|0}function np(a,b){a=a|0;b=b|0;a=r$(a,b);if(!a){u$(b)}return a|0}function lh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function l0(a,b){if(!b){return-1}b=xq(a,b,0);return b?b-a|0:-1}function iX(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function hia(a,b,c){a=a|0;b=b|0;c=c|0;return Hx(a,b,c,0,972)|0}function hS(a,b){return b>>>0>=4e3?22267:((b<<5)+a|0)+946304|0}function cs(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function cS(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function ax(a,b){a=_c(a,b);ic(a+12|0,b+12|0);re(a+32|0,b+32|0)}function Zw(a,b){a=a|0;b=b|0;a=aG(a,b);if(!a){fs(b)}return a|0}function V7(a,b){a=a|0;b=b|0;aT(a,Qy(x[b>>2])<<24>>24,x[b>>2])}function Tr(a,b){a=a|0;b=b|0;a=Tn(a,b);if(!a){Hn(b)}return a|0}function Tp(a,b){a=a|0;b=b|0;a=fx(a,b);if(!a){ex(b)}return a|0}function ST(a,b){a=a|0;b=b|0;a=M$(a,b);if(!a){Kr(b)}return a|0}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;return+AO(x[a+4>>2],b,c)}function M0(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){DE(b)}return a|0}function IS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function Fr(a,b){a=a|0;b=b|0;a=s$(a,b);if(!a){$v(b)}return a|0}function Bi(a,b){a=a|0;b=b|0;a=$h(a,b);if(!a){fl(b)}return a|0}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;return Hx(a,b,c,0,976)|0}function zsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mH(a,b,c,d,476)}function zM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function wua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tH(a,b,c,d,135)}function wm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){gl(c)}return a}function wS(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Gj(c))}}function uI(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function o$(a){return(y[a+47|0]+y[a+45|0]|0)+(y[a+46|0]<<5)|0}function dm(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ec(a);Db(b)}}function _ha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(20)))}function Tba(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];lg(a+4|0,b+4|0)}function Rka(a){a=a|0;a=Wv(a,22267);x[a>>2]=125152;return a|0}function Lta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mH(a,b,c,d,365)}function LG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(dc(c))}}function Kf(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function Iia(a){a=a|0;a=Ej(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function HY(a){if(a>>>0>=1073741824){$j();p()}return Ec(a<<2)}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function zI(a){a=a|0;x[a>>2]=111996;wl(x[a+8>>2]);return a|0}function ym(a){a=EG(a,0);x[a+8>>2]=0;x[a>>2]=121352;return a}function vha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(4)))}function tj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function sQ(a){a=a|0;return E(E(B[yb(a+4208|0,2)>>2]*E(10)))}function sM(a){a=a|0;x[a>>2]=78224;dc(a+24|0);return St(a)|0}function ih(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function e2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bc(a,x[d>>2],0)}function Zz(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Xs(a){a=a|0;x[a>>2]=113196;wl(x[a+8>>2]);return a|0}function Wv(a,b){a=Lj(a);x[a>>2]=125032;Rx(a+4|0,b);return a}function Ub(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function UR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function LN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function KL(a){var b=0,c=0,d=0;return b=mva(a),c=0,d=a,d?b:c}function DY(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function Ct(a){a=a|0;x[a>>2]=93640;tb(a+32|0);return lo(a)|0}function Bsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tH(a,b,c,d,93)}function AS(a){x[a>>2]=0;Nb(a+4|0);Sb(a+16|0,0,144);return a}function AI(a){a=a|0;x[a>>2]=112028;wl(x[a+8>>2]);return a|0}function yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iH(a,b,c,d,2)}function yka(a,b,c){a=a|0;b=b|0;c=c|0;return jH(a,b,c,64)|0}function xq(a,b,c){if(!b){return 0}return fu(a,c<<24>>24,b)}function uz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,73620,74416)}function sz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,74496,75260)}function qN(a,b){a=a|0;b=+b;TH(a,b,1e4,1074420,9363,512,32)}function q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function pC(a,b){if(b){pC(a,x[b>>2]);pC(a,x[b+4>>2]);Db(b)}}function oC(a,b){if(b){oC(a,x[b>>2]);oC(a,x[b+4>>2]);Db(b)}}function jT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(kB(b))}}function gx(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function dw(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,324)|0}function cF(a){return!kd(a,14184,3)&(y[a+3|0]-10&255)>>>0<5}function c6(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,97936)|0}function bD(a,b){if(b){bD(a,x[b>>2]);bD(a,x[b+4>>2]);Db(b)}}function a6(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,96400)|0}function _ba(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,i0(c,0,b,Cf(b)))}function YM(a,b){a=a|0;b=b|0;return Wj(x[b>>2],x[b+4>>2])|0}function Xw(a,b){return GS(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function XM(a,b){a=a|0;b=b|0;return Sd(x[b>>2],x[b+4>>2])|0}function V5(a,b,c){a=a|0;b=b|0;c=c|0;return IH(b,c,97936)|0}function Uqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iH(a,b,c,d,3)}function T5(a,b,c){a=a|0;b=b|0;c=c|0;return IH(b,c,96400)|0}function Sy(a,b){return Ft(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function Ss(a,b){var c=0,d=0;c=a,d=zk(b),x[c>>2]=d;return a}function Oba(a){a=a|0;Iz(a,2,100);ck(x[a+24>>2]+484360|0,0)}function O1(a){a=a|0;a=BG(a,13422);x[a>>2]=24460;return a|0}function Mh(a,b){var c=0,d=0;c=a,d=EK(b),x[c>>2]=d;return a}function Lu(a,b){if(b){Lu(a,x[b>>2]);Lu(a,x[b+4>>2]);Db(b)}}function Ku(a,b){if(b){Ku(a,x[b>>2]);Ku(a,x[b+4>>2]);Db(b)}}function Hr(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function G0(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,264)|0}function Fl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(of(b))}}function ED(a,b){if(b){ED(a,x[b>>2]);ED(a,x[b+4>>2]);Db(b)}}function DD(a,b){if(b){DD(a,x[b>>2]);DD(a,x[b+4>>2]);Db(b)}}function Co(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function yA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function xz(a){return(Jb(a)+Cb(x[a+4>>2],y[a+11|0])|0)-1|0}function v9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function mo(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function kI(a,b,c){b=La(1011,a|0,b|0,c|0)|0;hb=gb;return b}function gp(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function a4(a){a=a|0;a=t_(a,7956);x[a>>2]=40264;return a|0}function ZO(a){return Pj(Xb(x[a+484360>>2],y[a+484376|0]))}function R5(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Fp(a,b,c){a=a|0;b=b|0;c=c|0;si(a,b,Li(b,b+c|0,0))}function A2(a){a=a|0;a=BG(a,8704);x[a>>2]=28868;return a|0}function qK(a,b,c){a=a|0;b=b|0;c=c|0;Gu(a,b,c);return a|0}function ng(a,b){if(Cd(y[a+11|0])){Yd(a,b);return}Me(a,b)}function maa(a,b,c){a=a|0;b=b|0;c=c|0;return Fd(D(b,c))|0}function ksa(a,b,c){a=a|0;b=b|0;c=c|0;si(a,b,Sc(b,c)+b|0)}function jfa(a,b){a=a|0;b=b|0;return ao(a,b,11782,1063)|0}function jd(a,b,c,d){return Wc(a,D(z[b+480188>>1],c)+d|0)}function ifa(a,b){a=a|0;b=b|0;return eI(a,b,13394,1064)|0}function g0(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function fN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){ru(c)}}function ez(a,b){return x[((a>>>24^b)<<2)+495792>>2]^a<<8}function _x(a){a=a|0;x[a>>2]=113312;tb(a+12|0);return a|0}function _f(a){var b=0;hQ(a);b=x[a>>2];if(b){Tz(a);Db(b)}}function _L(a){while(1){if((Pt(a)|0)!=-1){continue}break}}function Zea(a,b){a=a|0;b=b|0;return ao(a,b,11847,1073)|0}function Yo(a){x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);return a}function Tea(a,b){a=a|0;b=b|0;return ao(a,b,11943,1076)|0}function Rea(a,b){a=a|0;b=b|0;return ao(a,b,11911,1077)|0}function Qq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function OA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function My(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function KF(a,b){var c=0;c=Ec(b<<2);x[a+4>>2]=b;x[a>>2]=c}function IN(a,b){a=a|0;b=+b;TH(a,b,256,1074456,11752,1,0)}function Gc(a,b){return AH(a,b,2147483647,-2147483648,-1)}function Df(a){return wb(Jb(a)+Cb(x[a+4>>2],y[a+11|0])|0)}function Bfa(a,b){a=a|0;b=b|0;return ao(a,b,11879,1056)|0}function $x(a){a=a|0;x[a>>2]=113352;tb(a+16|0);return a|0}function $ea(a,b){a=a|0;b=b|0;return ao(a,b,11817,1071)|0}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gi(a,-1,-1)}function xha(a){a=a|0;return B[yb(a+4208|0,1)>>2]<E(1)|0}function xga(a,b){a=a|0;b=b|0;return eI(a,b,6432,1004)|0}function tg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function nha(a){a=a|0;fQ(a);v[a+4202|0]=1;x[a+4224>>2]=0}function ix(a){a=a|0;x[a>>2]=125052;qI(a+4|0);return a|0}function iC(a,b){Ub(a,b);Ub(a+4|0,b+4|0);Ub(zb(a),zb(b))}function gT(a,b){a=fT(a,b);fT(a+12|0,b+12|0);v[a+24|0]=1}function bH(a,b){gl(x[b>>2]);Am(x[a>>2]);x[a>>2]=x[b>>2]}function aia(a){a=a|0;return B[yb(a+4208|0,3)>>2]<E(1)|0}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function UD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function St(a){a=a|0;x[a>>2]=77372;dc(a+12|0);return a|0}function R_(a){a=a|0;x[a>>2]=125032;qI(a+4|0);return a|0}function Ph(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function PB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function Iv(a){uc(a+88|0);uc(a+68|0);uc(a+48|0);return a}function Hn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function B2(a,b,c){a=a|0;b=b|0;c=c|0;jx(a,b,x[b+8>>2],c)}function Aj(a){return hf(a)|hf(a)<<8|hf(a)<<16|hf(a)<<24}function xG(a){a=a|0;x[a>>2]=41568;ke(a+4|0);return a|0}function wn(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function vda(a,b,c){a=a|0;b=b|0;c=c|0;$O(a,x[b+4>>2],c)}function ula(a,b,c){a=a|0;b=b|0;c=c|0;cH(a,b,c,838,837)}function qI(a){a=jl(x[a>>2]);if((gx(a+8|0)|0)<0){Db(a)}}function pL(a){a=a|0;return Et(x[x[a>>2]-12>>2]+a|0)|0}
function ola(a,b,c){a=a|0;b=b|0;c=c|0;hI(a,b,c,842,843)}function lo(a){a=a|0;x[a>>2]=93512;Zb(a+4|0);return a|0}function jg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function jJ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Am(b)}}function iM(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function hka(a,b,c){a=a|0;b=b|0;c=c|0;cH(a,b,c,914,913)}function Yt(a){a=a|0;x[a>>2]=48700;vz(a+4|0);return a|0}function YO(a){return Yu(x[a+484344>>2],x[a+484348>>2])}function Xn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;Iz(x[a+4>>2],b,c)}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);return a}function Kd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function KD(a){a=a&255;return Tc(a)^1|(a-49&255)>>>0<36}function HR(a){return(a|0)==1179012417|(a|0)==538987841}function Dt(a){a=a|0;x[a>>2]=93576;Zb(a+4|0);return a|0}function CM(a){a=a|0;x[a>>2]=77836;dc(a+4|0);return a|0}function AK(a,b,c){a=vb(a,b);vb(a+4|0,x[c>>2]);return a}function $T(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function xd(a,b){a=EG(a,b-1|0);x[a>>2]=113720;return a}function vL(a){a=a|0;return Gt(x[x[a>>2]-12>>2]+a|0)|0}function sq(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function sh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function koa(a,b){a=a|0;b=b|0;if(!OX(a,b)){Sb(b,0,40)}}function ki(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function jsa(a,b){a=a|0;b=b|0;return Dc(a,b?b:22267)|0}function jia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function ji(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function iz(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function hva(a,b){a=a|0;b=b|0;Kh(a,b,262,1025,-1284,2)}function gU(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function dda(a,b){a=a|0;b=b|0;return VO(x[a+4>>2],b)|0}function cba(a,b){a=a|0;b=b|0;RT(x[a>>2],b);return a|0}function boa(a,b){a=a|0;b=b|0;Kh(a,b,588,1058,-1332,3)}function b9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;si(a,c,d)}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;io(a,c,d)}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Wda(a,b){a=a|0;b=b|0;yO(x[x[a+4>>2]+24>>2],b)}function V6(){xd(501976,1);hJ(501984);x[125494]=117092}function Uka(a){a=a|0;Gj(126932);Gj(126924);tb(126912)}function Rsa(a,b){a=a|0;b=b|0;Kh(a,b,417,1042,-1332,2)}function Oh(a){var b=0;b=Pt(a);x[a+1396>>2]=0;return b}function O7(a,b){a=a|0;b=b|0;gc(a,hL(x[b>>2]),x[b>>2])}function LR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function Jua(a,b){a=a|0;b=b|0;Kh(a,b,297,1058,-1332,2)}function Jm(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function D9(a){a=a|0;return oq(x[x[a>>2]-12>>2]+a|0)|0}function B9(a){a=a|0;return Ff(x[x[a>>2]-12>>2]+a|0)|0}function Apa(a,b){a=a|0;b=b|0;Kh(a,b,262,1042,-1332,2)}function yK(a,b,c){a=CK(a,b,c,0,-2147483648);return a}function x4(a,b){a=a|0;b=b|0;return zl(b&255)<<24>>24}function wea(a,b){a=a|0;b=b|0;Kh(a,b,81,1025,-1284,4)}function vj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function v4(a,b){a=a|0;b=b|0;return yt(b&255)<<24>>24}function uj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function uda(a){a=a|0;return ZO(x[x[a+4>>2]+24>>2])|0}function tc(a,b){a=a|0;b=b|0;fG(a,b,hs(b));return a|0}function tb(a){if(Cd(y[a+11|0])){Db(x[a>>2])}return a}function sl(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function sda(a){a=a|0;return fP(x[x[a+4>>2]+24>>2])|0}function rsa(a,b){a=a|0;b=b|0;Kh(a,b,81,1042,-1332,2)}function qra(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,j0(c,0,b))}function qda(a){a=a|0;return yq(x[x[a+4>>2]+24>>2])|0}function ps(a,b){a=ic(a,b);Sb(a+20|0,0,1040);return a}function oda(a){a=a|0;return Bo(x[x[a+4>>2]+24>>2])|0}function nda(a){a=a|0;return YO(x[x[a+4>>2]+24>>2])|0}function mea(a,b){a=a|0;b=b|0;Kh(a,b,13,1025,-1284,2)}function kh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function kda(a){a=a|0;return RO(x[x[a+4>>2]+24>>2])|0}function kB(a){Mq(a+223860|0);dc(a+223848|0);return a}function hg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function hea(a,b){a=a|0;b=b|0;Kh(a,b,81,1025,-1284,2)}function hda(a){a=a|0;return iP(x[x[a+4>>2]+24>>2])|0}function gda(a){a=a|0;return eP(x[x[a+4>>2]+24>>2])|0}function fda(a){a=a|0;return dP(x[x[a+4>>2]+24>>2])|0}function df(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function cf(a,b,c,d){bc(a,jd(b,c,d,0),z[c+480188>>1])}function aE(a,b){a=Ge(a,b);Sb(a+20|0,0,1040);return a}function _ca(a){a=a|0;return zq(x[x[a+4>>2]+24>>2])|0}function _C(a,b){a=a|0;b=b|0;Kh(a,b,588,1058,-1332,2)}function Tda(a,b){a=a|0;b=b|0;Kh(a,b,82,1025,-1284,2)}function T6(){xd(501992,1);hJ(502e3);x[125498]=117248}function SN(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function Qp(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){gl(c)}}function Nca(a){a=a|0;return gP(x[x[a+4>>2]+24>>2])|0}function L2(a,b,c){a=a|0;b=b|0;c=c|0;hI(a,b,c,76,149)}function J4(a,b){a=a|0;b=b|0;return JI(b,x[a+8>>2])|0}function Gia(a){a=a|0;v[a+4202|0]=1;ou(a);Xz(a);GQ(a)}function Fv(a,b){a=a|0;b=b|0;Kh(a,b,589,1058,-1332,2)}function FQ(a){uc(a+36|0);uc(a+24|0);mu(a+12|0);mu(a)}function Dc(a,b){a=a|0;b=b|0;Gu(a,b,Cf(b));return a|0}function DR(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function CT(a,b,c,d){return ed(Lo(a,b,c,d,0)-32768|0)}function CR(a,b){return(b>>>0>46?63:v[a+b|0])<<24>>24}function xu(a){a=a|0;a=ai(a);x[a+20>>2]=0;return a|0}function wha(a){a=a|0;return E(B[yb(a+4208|0,3)>>2])}function rw(a,b,c){if(b){sP(a+36|0,b,Li(b,b+c|0,0))}}function qG(a,b,c,d){return _p(a,b,c,d,36,119304648)}function pca(a,b,c){a=a|0;b=b|0;c=c|0;EN(a-88|0,b,c)}function paa(a,b,c){a=a|0;b=b|0;c=c|0;Es(a,b,c,1168)}function nca(a,b,c){a=a|0;b=b|0;c=c|0;BN(a-88|0,b,c)}function mva(a){if(a){return 31-G(a-1^a)|0}return 32}function jm(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function fo(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function ee(a,b){gc(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function de(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function cC(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function c0(a,b,c,d){return _p(a,b,c,d,28,153391690)}function aea(a){a=a|0;return Rz(x[a>>2],x[a+4>>2])|0}function Yw(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function WF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function RX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function PQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Os(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function LJ(a,b,c,d){return _p(a,b,c,d,24,178956971)}function EG(a,b){x[a+4>>2]=b;x[a>>2]=124504;return a}function Dr(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function D$(a,b,c,d){return _p(a,b,c,d,40,107374183)}function $ha(a){a=a|0;return E(B[yb(a+4208|0,1)>>2])}function $4(a,b){a=a|0;b=b|0;Kh(a,b,13,1058,-1332,2)}function xta(a,b,c){a=a|0;b=b|0;c=c|0;y_(a,c,b,0,0)}function xo(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function xm(a){a=a|0;a=nc(a);ib[x[x[a>>2]>>2]](a)|0}function ura(a,b,c){a=a|0;b=b|0;c=c|0;sH(a,b,c,256)}function uQ(a){a=a|0;return E(B[yb(a+4208|0,0)>>2])}function s3(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function rx(a,b){a=a|0;b=b|0;return GS(a,b,hs(b))|0}function rca(a,b,c){a=a|0;b=b|0;c=+c;GN(a-88|0,b,c)}function oy(a,b,c){if(!c){return 0}return kK(a,b,c)}function oca(a,b){a=a|0;b=b|0;return DN(a-88|0,b)|0}function mqa(a,b){a=a|0;b=b|0;return di(a,b,1030)|0}function mca(a,b){a=a|0;b=b|0;return AN(a-88|0,b)|0}function mC(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function le(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function fca(a,b,c){a=a|0;b=b|0;c=+c;vN(a-92|0,b,c)}function dqa(a,b){a=a|0;b=b|0;return Cx(a,b,1100)|0}function dca(a,b,c){a=a|0;b=b|0;c=+c;tN(a-92|0,b,c)}function cG(a){return JL(a,E(15845632502852868e13))}function c2(a,b){a=a|0;b=b|0;return AF(a,b,Cf(b))|0}function ava(a,b,c){a=a|0;b=b|0;c=c|0;bq(a,b,c,263)}function ada(a){a=a|0;return+cP(x[x[a+4>>2]+24>>2])}function ZA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function Ysa(a,b){a=a|0;b=b|0;return Ds(a,b,1186)|0}function YT(a,b,c,d){return _p(a,b,c,d,7,613566757)}function XF(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function Vda(a,b){a=a|0;b=+b;return+zO(x[a+4>>2],b)}function Sua(a,b){a=a|0;b=b|0;Bx(a,b,262,274,-1332)}function Sj(a){if(!a){return 0}return x[a+44>>2]!=0}function Sca(a){a=a|0;return+PA(x[x[a+4>>2]+24>>2])}function Rqa(a,b,c){a=a|0;b=b|0;c=c|0;Es(a,b,c,596)}function Qsa(a,b,c){a=a|0;b=b|0;c=c|0;bq(a,b,c,418)}function Qqa(a,b,c){a=a|0;b=b|0;c=c|0;Es(a,b,c,597)}function QN(a){a=a|0;a=x[a+4>>2];return(a?a:5011)|0}function Mqa(a,b,c){a=a|0;b=b|0;c=c|0;rH(a,b,c,504)}function MF(a){return JL(a,E(2524354896707238e-44))}function Kqa(a,b,c){a=a|0;b=b|0;c=c|0;zH(a,b,c,305)}function Jqa(a,b,c){a=a|0;b=b|0;c=c|0;eH(a,b,c,305)}function Jj(a){if(!a){return 0}return Rj(y[a+31|0])}function Hpa(a,b){a=a|0;b=b|0;return Ds(a,b,1182)|0}function Fua(a,b,c){a=a|0;b=b|0;c=c|0;Es(a,b,c,300)}function Ep(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function Cua(a,b,c){a=a|0;b=b|0;c=c|0;oH(a,b,c,305)}function Cba(a,b){a=a|0;b=b|0;return Ds(a,b,1185)|0}function CU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function Aoa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,rx(b,c))}function zda(a,b,c){a=a|0;b=b|0;c=c|0;bq(a,b,c,84)}function yJ(a,b){a=xd(a,b);x[a>>2]=115076;return a}function xJ(a,b){a=xd(a,b);x[a>>2]=115108;return a}function vJ(a,b){a=xd(a,b);x[a>>2]=113776;return a}function sJ(a,b){a=xd(a,b);x[a>>2]=117608;return a}function rJ(a,b){a=xd(a,b);x[a>>2]=117756;return a}function qJ(a,b){a=xd(a,b);x[a>>2]=117872;return a}function pJ(a,b){a=xd(a,b);x[a>>2]=117988;return a}function mJ(a,b){a=xd(a,b);x[a>>2]=119176;return a}function lra(a,b){a=a|0;b=b|0;return di(a,b,422)|0}function lJ(a,b){a=xd(a,b);x[a>>2]=119296;return a}function gta(a,b){a=a|0;b=b|0;return di(a,b,308)|0}function gra(a,b){a=a|0;b=b|0;return di(a,b,826)|0}function eka(a,b){a=a|0;b=b|0;return di(a,b,225)|0}function e3(a,b){a=a|0;b=b|0;return Ds(a,b,1184)|0}function dn(a){Ij(a+724|0);Ij(a+732|0);Ij(a+740|0)}function dha(a,b){a=a|0;b=b|0;return E(Fm(a,b,12))}function cl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function bka(a,b){a=a|0;b=b|0;return di(a,b,326)|0}function Yy(a){if(!a){return 0}x[31600]=a;return-1}function Yba(a){a=a|0;x[a>>2]=48480;return du(a)|0}function Xta(a,b){a=a|0;b=b|0;return nH(a,b,347)|0}function MY(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,Sy(b,c))}function Lr(a,b,c){a=a|0;b=b|0;c=c|0;rH(a,b,c,125)}function KG(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,Xw(b,c))}function Ida(a,b,c){a=a|0;b=b|0;c=c|0;bq(a,b,c,83)}function Eca(a,b,c){a=a|0;b=b|0;c=c|0;eH(a,b,c,47)}function Doa(a,b,c){a=a|0;b=b|0;c=c|0;oH(a,b,c,47)}function BG(a,b){a=AG(a,b);x[a>>2]=125312;return a}function $ua(a,b,c){a=a|0;b=b|0;c=c|0;zH(a,b,c,47)}function zX(a){return(x[zb(a)>>2]-x[a>>2]|0)/56|0}function we(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function vqa(a,b){a=a|0;b=b|0;if(!yE(a,b)){DE(b)}}function th(a,b){a=a|0;b=b|0;return sL(a)^sL(b)^1}function rO(a){x[a+4>>2]=0;x[a>>2]=47652;return a}function rE(a){return(x[zb(a)>>2]-x[a>>2]|0)/28|0}function qca(a,b){a=a|0;b=b|0;return+FN(a-88|0,b)}function pha(a,b){a=a|0;b=b|0;return E(Fm(a,b,1))}function oI(a){return(a<<1)+16777216>>>0<16777217}function nta(a,b){a=a|0;b=b|0;if(!f_(a,b)){e_(b)}}function nt(a){return a-48>>>0<10|(a|32)-97>>>0<6}function nka(a,b){a=a|0;b=b|0;if(!jG(a,b)){px(b)}}function mta(a,b){a=a|0;b=b|0;return di(a,b,78)|0}function li(a,b){a=a|0;b=b|0;return iL(a)^iL(b)^1}function kl(a){return(x[zb(a)>>2]-x[a>>2]|0)/12|0}function k5(a,b){a=a|0;b=b|0;Bx(a,b,13,290,-1332)}function jn(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function jF(a){return!kd(a,24544,25)&y[a+34|0]<65}function i2(a,b){a=a|0;b=b|0;Bx(a,b,13,257,-1284)}function gka(a,b){a=a|0;b=b|0;return di(a,b,73)|0}function gc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function eia(a,b){a=a|0;b=b|0;return E(Fm(a,b,6))}function eca(a,b){a=a|0;b=b|0;return+uN(a-92|0,b)}function dra(a,b){a=a|0;b=b|0;return di(a,b,41)|0}function cca(a,b){a=a|0;b=b|0;return+sN(a-92|0,b)}function cZ(a){return(x[zb(a)>>2]-x[a>>2]|0)/33|0}function bx(a){return(x[zb(a)>>2]-x[a>>2]|0)/36|0}function ZZ(a){if(!(a&255)){return 1}return Tc(a)}function Yga(a,b){a=a|0;b=b|0;return E(Fm(a,b,2))}function Wl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function Vpa(a,b){a=a|0;b=b|0;return di(a,b,71)|0}function UZ(a,b){a=a|0;b=b|0;return nH(a,b,324)|0}function Tha(a,b){a=a|0;b=b|0;return E(Fm(a,b,5))}function TE(a){return(x[zb(a)>>2]-x[a>>2]|0)/20|0}function SK(a){return(Nh(a)|0)!=0|(a|32)-97>>>0<6}function Qga(a,b){a=a|0;b=b|0;return E(Fm(a,b,3))}function Nra(a,b){a=a|0;b=b|0;return di(a,b,91)|0}function Nq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Lha(a,b){a=a|0;b=b|0;return E(Fm(a,b,4))}function Ira(a,b){a=a|0;b=b|0;if(!fZ(a,b)){eZ(b)}}function IR(a,b){return(a|0)==1179011410&b>>>0>80}function G1(a,b,c){a=a|0;b=b|0;c=c|0;bq(a,b,c,18)}function Bu(a){return(x[zb(a)>>2]-x[a>>2]|0)/52|0}function A$(a){return(x[zb(a)>>2]-x[a>>2]|0)/40|0}function $s(a){return(x[zb(a)>>2]-x[a>>2]|0)/24|0}function $ja(a,b){a=a|0;b=b|0;return di(a,b,60)|0}function zz(a,b){x[a>>2]=x[b>>2];_c(a+4|0,b+4|0)}function t$(a,b){a=a|0;b=b|0;if(!s$(a,b)){$v(b)}}function su(a){a=a|0;uc(a+4208|0);return ag(a)|0}function sea(a){a=a|0;return VH(a,47592,12589)|0}function pp(a,b){a=a|0;b=b|0;if(!$h(a,b)){fl(b)}}function pQ(a){a=a|0;uc(a+4256|0);return ag(a)|0}function n_(a,b){a=a|0;b=b|0;if(!aG(a,b)){fs(b)}}function hV(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function fi(a,b,c){return Fa(1016,a|0,b|0,c|0)|0}function fE(a,b){a=a|0;b=b|0;if(!M$(a,b)){Kr(b)}}function fD(a,b){a=a|0;b=b|0;if(!rZ(a,b)){mD(b)}}function em(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function eF(a,b){a=$E(a,b);if(!a){Hn(b)}return a}function bw(a){return(x[zb(a)>>2]-x[a>>2]|0)/6|0}function aT(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function Wn(a,b,c){a=Nd(a);x[a+4>>2]=c;x[a>>2]=b}function UB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function T$(a,b){a=x$(a,b);if(!a){jE(b)}return a}function QM(a,b){a=a|0;b=b|0;ll(a,b,74456,74464)}function QG(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function PM(a,b){a=a|0;b=b|0;ll(a,b,74472,74480)}function MM(a,b){a=a|0;b=b|0;ll(a,b,75276,75284)}function LQ(a){a=a|0;dc(a+4208|0);return ag(a)|0}function LM(a,b){a=a|0;b=b|0;ll(a,b,75292,75300)}function KM(a,b){a=a|0;b=b|0;ll(a,b,76104,76112)}function J_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function JM(a,b){a=a|0;b=b|0;ll(a,b,76120,76128)}function HE(a,b){a=a|0;b=b|0;if(!Jp(a,b)){yp(b)}}function GM(a,b){a=a|0;b=b|0;ll(a,b,76932,76940)}function GB(a){return(x[zb(a)>>2]-x[a>>2]|0)/7|0}function FM(a,b){a=a|0;b=b|0;ll(a,b,76948,76956)}function Aw(a,b){a=a|0;b=b|0;if(!fx(a,b)){ex(b)}}function $0(a,b){a=a|0;b=b|0;if(!R0(a,b)){FE(b)}}function zY(a){var b=0;b=x[a>>2];me(a);return b}function y5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500468))}function w5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500476))}function ud(a,b){return cr(x[b>>2],x[a>>2])?b:a}function u5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500288))}function tB(a){if(y[a+24|0]){lT(a);v[a+24|0]=0}}function s5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500296))}function qea(a){a=a|0;return VH(a,47612,8191)|0}function qe(a,b){return cl(z[a>>1],z[b>>1])?b:a}function q5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500304))}function o5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500312))}function m5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500256))}function ko(a){return ib[x[x[a>>2]+28>>2]](a)|0}function j5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500264))}function hJ(a){var b=0,c=0;b=a,c=Od(),x[b>>2]=c}function h5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500272))}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;KO(a,b,c)}function fqa(a,b){a=a|0;b=b|0;aq(a,b,650,649,8)}function f5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500280))}function e5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500352))}function d5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500360))}function bva(a,b,c){a=a|0;b=b|0;c=c|0;H0(a,b,c)}function bha(a){a=a|0;cQ(a);Sz(a);v[a+4202|0]=1}function ad(a,b){return mr(x[a>>2],x[b>>2])?b:a}function Ze(a,b){return cr(x[a>>2],x[b>>2])?b:a}function Ym(a,b){return Lv(B[b>>2],B[a>>2])?b:a}function Wz(a,b){return Lv(B[a>>2],B[b>>2])?b:a}function Vua(a,b){a=a|0;b=b|0;aq(a,b,299,298,8)}function Vca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function Tta(a,b){a=a|0;b=b|0;aq(a,b,364,363,8)}function Sl(a,b){return hn((b<<1)+123824|0,2,a)}function Rha(a){a=a|0;v[a+4202|0]=1;mQ(a);oQ(a)}function Qla(a,b,c){a=a|0;b=b|0;c=c|0;fe(a,b,c)}function Pra(a,b){a=a|0;b=b|0;aq(a,b,521,520,6)}function Ppa(a,b){a=a|0;b=b|0;aq(a,b,683,682,8)}function Pk(a){return ib[x[x[a>>2]+36>>2]](a)|0}function O0(a,b){return(b&255)==2&(a&255)>>>0<3}function Nv(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function Nc(a,b){return cl(z[b>>1],z[a>>1])?b:a}function L5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500208))}function Jha(a){a=a|0;v[a+4202|0]=1;kQ(a);jQ(a)}function Jba(a,b){a=a|0;b=b|0;_c(a,uO(b,18256))}function J5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500216))}function I5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500412))}function H5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500404))}function Gb(a,b){return mr(x[b>>2],x[a>>2])?b:a}function G5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500420))}function F1(a,b){a=a|0;b=b|0;Yp(a,b);return a|0}function E5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500428))}function D5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500436))}function CL(a,b){if(!a){return 0}return Wy(a,b)}function C5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500452))}function B5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500444))}function AL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function A5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500460))}function wE(a,b,c){a=a|0;b=b|0;c=c|0;o0(a,b,c)}function um(a){return(a>>>0<=127?-1:a^128)&255}function ti(a,b){return(D(b,104)+a|0)+484380|0}function rea(a,b){a=a|0;b=b|0;return Xw(a,b)|0}function nla(a,b){a=a|0;b=b|0;return Sy(a,b)|0}function nf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function hfa(a){a=a|0;return aI(a,6626,1068)|0}function eqa(a,b){a=a|0;b=b|0;return OX(a,b)|0}function c4(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function bv(a){return(a>>>0<9?a:a-9|256)&65535}function bo(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function Xm(a){a=Lj(a);x[a>>2]=124916;return a}function Vv(a,b){return y[a+b|0]!=63&b>>>0<=15}function Uca(a){a=a|0;return x[x[a+4>>2]+8>>2]}function Tt(a,b){return(a&255)>>>0<(b&255)>>>0}function Saa(a){a=a|0;x[a>>2]=77472;return a|0}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;P0(a,b,c)}function S$(a,b,c){a=a|0;b=b|0;c=c|0;S0(a,b,c)}function Oja(a,b){a=a|0;b=b|0;QA(yR(a+24|0,b))}function Ns(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function Mg(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Lf(a,b,c){if(!(y[a|0]&32)){uE(b,c,a)}}function Laa(a){a=a|0;x[a>>2]=76972;return a|0}function KU(a){QB(a);Sb(a+27|0,0,255);return a}function Jaa(a,b){a=a|0;b=b|0;OH(a,b,1162,308)}function Gg(a,b,c){a=ova(a,b,c,c>>31);return a}function Faa(a){a=a|0;x[a>>2]=78280;return a|0}function F4(a,b,c){a=a|0;b=b|0;c=c|0;II(a,b,c)}function BP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function Afa(a){a=a|0;return aI(a,7109,1060)|0}function Aaa(a){a=a|0;x[a>>2]=77892;return a|0}function $i(a,b){return y[a+b|0]!=63&b>>>0<=46}function zua(a,b){a=a|0;b=b|0;uH(a,b,308,307)}function wy(a,b,c){a=CK(a,b,c,-1,-1);return a}function wc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function uL(a){a=a|0;Ry(x[x[a>>2]-12>>2]+a|0)}function rn(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function r2(a){a=a|0;x[a>>2]=78552;return a|0}function pda(a,b){a=a|0;b=b|0;WO(a,x[b+4>>2])}function oX(a){a=nva(a&65535,0,80,0);return a}function oL(a){a=a|0;Py(x[x[a>>2]-12>>2]+a|0)}function lu(a,b){a=a|0;b=b|0;return lg(a,b)|0}function jda(a,b){a=a|0;b=b|0;QO(a,x[b+4>>2])}function ida(a,b){a=a|0;b=b|0;pP(a,x[b+4>>2])}function iaa(a){a=a|0;return Ba(x[a+60>>2])|0}function f2(a){a=a|0;x[a>>2]=41432;return a|0}function ef(a,b){return Tt(y[a|0],y[b|0])?b:a}function du(a){a=a|0;x[a>>2]=48460;return a|0}function dta(a,b){a=a|0;b=b|0;Dx(a,b,17,3,16)}function d2(a){a=a|0;x[a>>2]=41192;return a|0}function cda(a,b){a=a|0;b=b|0;UO(a,x[b+4>>2])}function cA(a){return x[zb(a)>>2]-x[a>>2]>>11}function bda(a,b){a=a|0;b=b|0;PO(a,x[b+4>>2])}function Zda(a,b){a=a|0;b=b|0;Jz(x[a+4>>2],b)}function Yaa(a){a=a|0;AM(a);return x[a+16>>2]}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Xca(a,b){a=a|0;b=b|0;aP(a,x[b+4>>2])}function WK(a){a=SL(a);x[a>>2]=95200;return a}function U_(a){a=(a&65535)-98|0;hb=0;return a}function S2(a,b){a=a|0;b=b|0;return rx(a,b)|0}function Rua(a,b){a=a|0;b=b|0;Dx(a,b,44,2,44)}function Rb(a,b){return Tt(y[b|0],y[a|0])?b:a}function R$(a){v[a+12|0]=y[a+12|0]|2;return a}function QW(a){return _e(443250/+(a>>>0)*1e4)}function Nt(a){a=SL(a);x[a>>2]=94808;return a}function Nd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Hta(a,b){a=a|0;b=b|0;uH(a,b,368,367)}function HJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Gf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function GP(a,b){a=a|0;b=b|0;return uO(a,b)|0}function C9(a){a=a|0;eL(x[x[a>>2]-12>>2]+a|0)}function Ai(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function A9(a){a=a|0;dL(x[x[a>>2]-12>>2]+a|0)}function $aa(a,b){a=a|0;b=b|0;OH(a,b,1158,52)}function vI(a,b,c){a=a|0;b=b|0;c=c|0;cL(a,c)}function u7(a){a=a|0;$c(a,501696,Uc(500208))}function tA(a,b){return D((b-a|0)/6|0,6)+a|0}function t7(a){a=a|0;$c(a,501704,Uc(500216))}function s7(a){a=a|0;$c(a,501712,Uc(500412))}function r7(a){a=a|0;$c(a,501728,Uc(500404))}function q7(a){a=a|0;$c(a,501736,Uc(500420))}function o7(a){a=a|0;$c(a,501744,Uc(500428))}function n7(a){a=a|0;$c(a,501760,Uc(500436))}function mda(a){a=a|0;return XO(x[a+4>>2])|0}function m7(a){a=a|0;$c(a,501768,Uc(500452))}function lC(a){return x[zb(a)>>2]-x[a>>2]>>8}function l7(a){a=a|0;$c(a,501776,Uc(500444))}function k7(a){a=a|0;$c(a,501784,Uc(500460))}function j7(a){a=a|0;$c(a,501792,Uc(500468))}function iB(a){v[a+24|0]=0;v[a|0]=0;return a}function i7(a){a=a|0;$c(a,501816,Uc(500476))}function hv(a){return x[zb(a)>>2]-x[a>>2]>>4}function h7(a){a=a|0;$c(a,501848,Uc(500224))}function g7(a){a=a|0;$c(a,501856,Uc(500232))}function f7(a){a=a|0;$c(a,501864,Uc(500240))}function e7(a){a=a|0;$c(a,501872,Uc(500248))}function d7(a){a=a|0;$c(a,501880,Uc(500288))}function c7(a){a=a|0;$c(a,501888,Uc(500296))}function bp(a){return x[zb(a)>>2]-x[a>>2]>>5}function b7(a){a=a|0;$c(a,501896,Uc(500304))}function a7(a){a=a|0;$c(a,501904,Uc(500312))}function _z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function _6(a){a=a|0;$c(a,501920,Uc(500328))}function Zaa(a){a=a|0;AM(a);return x[a+4>>2]}function Z6(a){a=a|0;$c(a,501928,Uc(500336))}function Yn(a){return x[zb(a)>>2]-x[a>>2]>>3}function Y6(a){a=a|0;$c(a,501936,Uc(500344))}function X6(a){a=a|0;$c(a,501944,Uc(500256))}function W6(a){a=a|0;$c(a,501960,Uc(500264))}function Uz(a){return E(E(a*E(7900))+E(100))}function Ug(a){return x[zb(a)>>2]-x[a>>2]>>2}function U6(a){a=a|0;$c(a,501976,Uc(500272))}function Tz(a){return x[nc(a)>>2]-x[a>>2]>>2}function Th(a){return x[x[a+8>>2]>>2]==(a|0)}function TQ(a){x[a>>2]=x[a>>2]-2048;return a}function S6(a){a=a|0;$c(a,501992,Uc(500280))}function R6(a){a=a|0;$c(a,502008,Uc(500352))}function Q6(a){a=a|0;$c(a,502016,Uc(500360))}function On(a){return x[zb(a)>>2]-x[a>>2]>>1}function Mp(a,b,c,d){a=ova(a,b,c,d);return a}function LY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function Ik(a){return fH(a,E(4294967296),-1)}function Cb(a,b){if(!Cd(b)){a=Vh(b)}return a}function Ak(a){a=a&255;return(a|0)==255?-1:a}function AZ(a,b,c){gc(a,b,Li(b,b+c|0,0)-b|0)}function $ca(a){a=a|0;return hP(x[a+4>>2])|0}function $6(a){a=a|0;$c(a,501912,Uc(500320))}function xp(a,b,c){return ek(a,b)>>>0>c>>>0}function ru(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function no(a){a=a|0;hL(x[a>>2]);return a|0}function hp(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function dp(a){return x[zb(a)>>2]-x[a>>2]|0}function dW(a){x[a>>2]=x[a>>2]-256;return a}function dP(a){return A[a+1074420>>2]/1e4|0}function cja(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function br(a,b){return a<<16>>16<b<<16>>16}function Yl(a,b){return br(z[a>>1],z[b>>1])}function SU(a,b){x[a>>2]=x[a>>2]+b;return a}function Qw(a,b){if(b){Dc(a,b);return}Fb(a)}function Qf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Oi(a,b){a=a|0;b=b|0;return E(E(0))}function N4(a,b){a=a|0;b=b|0;return Cy(b)|0}function L4(a,b){a=a|0;b=b|0;return Dy(b)|0}function Km(a){a=a|0;Qy(x[a>>2]);return a|0}function CB(a){v[a+4|0]=0;v[a|0]=0;return a}function Aia(a,b,c){a=a|0;b=b|0;c=c|0;Nd(a)}function zy(){da(Xm(ac(4))|0,125e3,34);p()}function zw(a){a=a|0;return Wh(a,500412)|0}function zca(a,b){a=a|0;b=b|0;PN(a-88|0,b)}function z$(a){x[a>>2]=x[a>>2]-40;return a}function yca(a,b){a=a|0;b=b|0;ON(a-88|0,b)}function xX(a){x[a>>2]=x[a>>2]-56;return a}function xW(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function x2(a){a=a|0;return x[a+4>>2]!=0|0}function vf(a,b,c){a=nva(c,0,a,b);return a}function un(a){aC(x[a+20>>2]);x[a+20>>2]=0}function ty(a){a=a|0;return Wh(a,500476)|0}function sk(a){x[a>>2]=x[a>>2]-12;return a}function saa(a,b){a=a|0;b=b|0;Bm(a,b+12|0)}function rl(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function ql(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function oR(a){x[a>>2]=x[a>>2]-52;return a}function nG(a){x[a>>2]=x[a>>2]-36;return a}function mm(a){x[a>>2]=x[a>>2]+28;return a}function kpa(a,b){a=a|0;b=b|0;qH(a,b,2,31)}function kca(a,b){a=a|0;b=b|0;yN(a-88|0,b)}function jw(a){x[a>>2]=x[a>>2]-28;return a}function jo(a){a=a|0;Fs(a,164,125360,1057)}function il(a){x[a>>2]=x[a>>2]+12;return a}function id(a,b){a=a|0;b=b|0;KO(a,b,Cf(b))}function hca(a,b){a=a|0;b=b|0;xN(a-92|0,b)}function gr(a){uf(a+24|0);dc(a+12|0);dc(a)}function gca(a,b){a=a|0;b=b|0;wN(a-92|0,b)}function dr(a){x[a>>2]=x[a>>2]+32;return a}function bT(a,b){return CH(a,b,2147483647)}function at(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function ar(a){x[a>>2]=x[a>>2]-16;return a}function am(a){x[a>>2]=x[a>>2]+52;return a}function _s(a){x[a>>2]=x[a>>2]-24;return a}function _o(a){x[a>>2]=x[a>>2]+16;return a}function Zo(a){x[a>>2]=x[a>>2]-32;return a}function Zca(a){a=a|0;return+bP(x[a+4>>2])}function Z9(a){a=a|0;return Wh(a,500224)|0}function Z4(a){a=a|0;Fs(a,164,125360,1192)}function X_(a){x[a>>2]=x[a>>2]-20;return a}function XP(a){return E(E(a*E(96))+E(-96))}function Sf(a){x[a>>2]=x[a>>2]+20;return a}function Rt(a){return(a|0)<=65535&(a|0)>=0}function R9(a){a=a|0;return Wh(a,500240)|0}function Ny(a){a=a|0;return Wh(a,500404)|0}function Np(a){qs(a+32|0);ub(a+12|0);tb(a)}function Lua(a,b){a=a|0;b=b|0;ow(a+36|0,b)}function Ky(a){a=a|0;return Wh(a,500420)|0}function Jg(a){return E(F(a))==E(Infinity)}function JL(a,b){return E(yx(a?E(-b):b)*b)}function Fka(a,b){a=a|0;b=b|0;ts(a+40|0,b)}function FD(a){a=a|0;return Wh(a,500428)|0}function EI(a){a=a|0;return FH(a,118416)|0}function Dk(a){tb(a+36|0);uc(a+24|0);Rk(a)}function DI(a){a=a|0;return FH(a,118312)|0}function CI(a){a=a|0;return EH(a,118208)|0}function BI(a){a=a|0;return EH(a,118104)|0}function Ay(a){a=a|0;return Wh(a,500468)|0}function $Y(a){x[a>>2]=x[a>>2]-33;return a}function xe(a){return Bb(a&65535)<<16>>16}function xca(a,b){a=a|0;b=+b;MN(a-88|0,b)}function xN(a,b){a=a|0;b=b|0;SH(a,b,2048)}function wN(a,b){a=a|0;b=b|0;SH(a,b,4096)}function vq(a){a=a|0;Aq(a+8|0);return a|0}function vg(a){x[a>>2]=x[a>>2]+6;return a}function vca(a,b){a=a|0;b=+b;KN(a-88|0,b)}function uqa(a,b){a=a|0;b=b|0;Di(a,b,274)}function tca(a,b){a=a|0;b=+b;IN(a-88|0,b)}function tC(a){x[a>>2]=x[a>>2]-1;return a}function pqa(a,b){a=a|0;b=b|0;Di(a,b,106)}function nD(a){x[a>>2]=x[a>>2]-6;return a}function mz(a,b,c){gc(a,(c<<12)+b|0,4096)}function mua(a,b){a=a|0;b=b|0;qH(a,b,3,8)}function me(a){x[a>>2]=x[a>>2]+1;return a}function m6(a,b){a=a|0;b=b|0;An(a,113384)}function lz(a,b){a=a|0;b=b|0;lg(a,b+36|0)}function l6(a,b){a=a|0;b=b|0;An(a,113404)}function kia(a){a=a|0;v[a+4202|0]=1;AQ(a)}function jy(a,b){a=a|0;b=b|0;lg(a,b+12|0)}function jca(a){a=a|0;return vq(a-92|0)|0}function ij(a){x[a>>2]=x[a>>2]-2;return a}function iI(a){a=Da(a|0)|0;hb=gb;return a}function hy(a,b){a=a|0;b=b|0;lg(a,b+16|0)}function gha(a){a=a|0;return x[a+4260>>2]}function cv(a){Vm(a,Xo(a),78784);return a}function cP(a){return+A[a+1074420>>2]/1e4}function bta(a,b){a=a|0;b=b|0;Di(a,b,282)}function bca(a){a=a|0;return vq(a-96|0)|0}function aK(a,b){a=a|0;b=b|0;lg(a,b+24|0)}function Zu(a){x[a>>2]=x[a>>2]+8;return a}function YP(a){a=a|0;Sb(a+4296|0,0,81928)}function YJ(a,b){a=a|0;b=b|0;kq(a,b+28|0)}function Xg(a,b,c){Mk(b,b+c|0,a);return a}function XJ(a,b){a=a|0;b=b|0;kq(a,b+40|0)}function WJ(a,b){a=a|0;b=b|0;kq(a,b+52|0)}function Tf(a){a=a|0;ai(a+8|0);return a|0}function TT(a){x[a>>2]=x[a>>2]-7;return a}function Pq(a,b){v[a|0]=b+48;return a+1|0}function Op(a){x[a>>2]=x[a>>2]-8;return a}function Mi(a){x[a>>2]=x[a>>2]-4;return a}function Md(a){x[a>>2]=x[a>>2]+2;return a}function Je(a){x[a>>2]=x[a>>2]+4;return a}function Hua(a,b){a=a|0;b=b|0;Di(a,b,136)}function Gt(a){a=a|0;Cl(a+8|0);return a|0}function Et(a){a=a|0;Cl(a+4|0);return a|0}function Cs(a,b){x[a>>2]=b;gl(b);return a}function Cg(a,b,c){Wg(b,b+c|0,a);return a}function Bl(a){a=a|0;return tL(a)<<24>>24}function Bca(a){a=a|0;return vq(a-88|0)|0}function AB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function $m(a){return E(F(a))<E(Infinity)}function $ba(a,b){a=a|0;b=+b;qN(a-96|0,b)}function $J(a,b){a=a|0;b=b|0;lg(a,b+48|0)}function zl(a){return a-97>>>0<26?a&95:a}function yt(a){return a-65>>>0<26?a|32:a}function yl(a){return(a|0)==32|a-9>>>0<5}function tra(a,b){a=a|0;b=b|0;Di(a,b,42)}function ro(a,b,c){return ib[c|0](a,b)|0}function pf(a,b){x[a+8>>2]=b|-2147483648}function nqa(a,b){a=a|0;b=b|0;Di(a,b,72)}function mg(a,b){a=ova(0,a,b,0);return a}function k6(a,b){a=a|0;b=b|0;Dc(a,11280)}function je(a,b){return(b|0)!=0&(a|0)!=0}function j6(a,b){a=a|0;b=b|0;Dc(a,11397)}function i_(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function hj(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function hc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function dl(a){return D(Pn(a),_d(a))&255}function cta(a,b){a=a|0;b=b|0;rw(a,b,17)}function bja(a){a=a|0;return y[a+4201|0]}function aja(a){a=a|0;return y[a+4202|0]}function Ur(a,b,c,d,e){BH(a,b,c,d,e,256)}function SY(a,b){a=a|0;b=b|0;Di(a,b,284)}function Px(a){return a-502208>>>2&65535}function Pua(a,b){a=a|0;b=b|0;xH(a,b,28)}function Nta(a,b){a=a|0;b=b|0;Di(a,b,34)}function Ij(a){w[a+4>>1]=65535;x[a>>2]=0}function Iga(a){a=a|0;return(a|0)==277|0}function FG(a,b){Ub(a,b);Ub(a+4|0,b+4|0)}function Ew(a,b,c,d,e){BH(a,b,c,d,e,128)}function Bt(a,b){x[a+24>>2]=x[a+24>>2]+b}function zm(a){a=x[a+8>>2];if(a){Db(a)}}function wca(a){a=a|0;return+LN(a-88|0)}function wR(a,b){x[a>>2]=x[a>>2]+D(b,6)}function w0(a,b){a=a|0;b=b|0;Di(a,b,50)}function ui(a){return(a&65535)>>>0<3999}function uca(a){a=a|0;return+JN(a-88|0)}function tX(a,b,c,d){return rn(c,d,a,b)}function sca(a){a=a|0;return+HN(a-88|0)}function sI(a){return(z[a+2>>1]<<2)+a|0}function r1(a,b){a=a|0;b=b|0;Di(a,b,59)}function nP(a,b){return $H(a,b,1075834)}function mt(a){return(a|0)==32|(a|0)==9}function lP(a,b){return _H(a,b,1075834)}function kY(a,b){a=a|0;b=b|0;return b|0}function kP(a,b){return _H(a,b,1075835)}function jP(a,b){return $H(a,b,1075835)}function hn(a,b,c){return Wg(a,a+b|0,c)}function h0(a,b){x[a>>2]=x[a>>2]+(b<<1)}function e1(a,b){a=a|0;b=b|0;rw(a,b,11)}function cK(a,b){a=a|0;b=b|0;rf(a,1,45)}function bK(a,b){a=a|0;b=b|0;my(a,1,45)}function _g(a,b,c){v[a+4|0]=c;x[a>>2]=b}function Zy(a){return(q(a),j(2))>>>20|0}function XK(a){x[a+4>>2]=x[a+4>>2]|8192}function WS(a,b){return(Xl(a,b)|0)!=255}function V3(a){a=a|0;if(a){uI(pl(a),1)}}function Tv(a,b,c){return a<b?b:a>c?c:a}function Sga(a){a=a|0;return-2013527448}function RI(a){a=a|0;return td(a-8|0)|0}function QI(a){a=a|0;return Zx(a-8|0)|0}function PI(a){a=a|0;return Yx(a-8|0)|0}function OZ(a,b){a=a|0;b=b|0;rw(a,b,32)}function OI(a){a=a|0;return Xx(a-8|0)|0}function NI(a){a=a|0;return Wx(a-8|0)|0}function MI(a){a=a|0;return Vx(a-8|0)|0}function LI(a){a=a|0;return Ux(a-8|0)|0}function Kj(a,b){return rB(a&255,b&255)}function KS(a,b,c,d){return hq(a,b,c,d)}function JY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function Hra(a,b){a=a|0;b=b|0;U0(a,b,8)}function HD(a){return lH(a,65535,65535)}function E0(a,b){return(a&255)==(b&255)}function Bb(a){return(a<<8|a>>>8)&65535}function BB(a,b,c){return a<b?b:a>c?c:a}function zha(a){a=a|0;return-271958638}function yw(a,b,c){return Zp(a,b,c,20)}function tv(a,b,c){return Zp(a,b,c,12)}function tk(a,b){x[a+4>>2]=2;x[a>>2]=b}function rha(a){a=a|0;return-620920304}function qx(a,b){x[a+4>>2]=3;x[a>>2]=b}function oe(a,b,c){xo(a,b,Sc(b,c)+b|0)}function k2(a){a=a|0;return x[a+16>>2]}function iy(a){a=a|0;return x[a+12>>2]}function hha(a){a=a|0;return-275227023}function he(a){x[x[a+8>>2]>>2]=x[a>>2]}function h_(a,b,c){em(a,b&65535,c&255)}function gia(a){a=a|0;return-270114148}function dN(a){return a?(a|0)==2?3:2:1}function ct(a){a=a|0;return 2147483647}function c5(a,b){a=a|0;b=b|0;HH(a,b,0)}function b5(a,b){a=a|0;b=b|0;HH(a,b,1)}function aoa(a){a=a|0;jX(a);return a|0}function a5(a,b){a=a|0;b=b|0;GH(a,b,0)}function _ga(a){a=a|0;return 302837129}function _J(a){a=a|0;return x[a+60>>2]}function _4(a,b){a=a|0;b=b|0;GH(a,b,1)}function _2(a,b){a=a|0;b=b|0;As(a,1,b)}function Xu(a,b,c){ng(a,c);fd(b+c|0,0)}function Wha(a){a=a|0;return-285139079}function Wd(a,b){return Jb(a)+(b<<2)|0}function Via(a){a=a|0;return 542066252}function VJ(a){a=a|0;return x[a+64>>2]}function Uaa(a){a=a|0;return y[a+40|0]}function Tx(a,b){x[a+4>>2]=4;x[a>>2]=b}function Su(a,b){return AH(a,b,-1,0,0)}function RQ(a){a=a|0;return 1869112133}function PX(a,b){a=a|0;b=b|0;xH(a,b,4)}function Nha(a){a=a|0;return-284078960}function Lj(a){x[a>>2]=125612;return a}function Lga(a,b){a=a|0;b=b|0;return 3}function KP(a,b,c){return jH(a,b,c,69)}function Jga(a,b){a=a|0;b=b|0;return 2}function Gha(a){a=a|0;return-281111764}function G$(a,b,c){return Zp(a,b,c,40)}function Cj(a,b){x[a+4>>2]=1;x[a>>2]=b}function CJ(a,b,c){return Zp(a,b,c,24)}function Ah(a){return fH(a,E(255),255)}function zP(a){a=a|0;dI(a,47456,1005)}function xia(a,b){a=a|0;b=b|0;uF(a,b)}function wI(a){a=E(a-a);return E(a/a)}function vaa(a,b){a=a|0;b=b|0;lu(a,b)}function vG(a,b,c){bc(a,b,jh(b,c)<<3)}function uO(a,b){return Ft(a,b,Cf(b))}function rt(a){return(Dy(a)|0)!=(a|0)}function qt(a){return(Cy(a)|0)!=(a|0)}function os(a){a=a|0;return x[a+4>>2]}function op(a,b){w[a+8>>1]=b;return a}function ol(a){a=x[a>>2];if(a){wl(a)}}function o9(a){a=a|0;return UK(a,0)|0}function ns(a){a=a|0;return x[a+8>>2]}function n9(a){a=a|0;return UK(a,1)|0}function mla(a,b){a=a|0;b=b|0;Nr(a,b)}function lZ(a,b,c){bc(a,b,oc(b,c)<<2)}function js(a,b,c){return $p(a,b,c,3)}function jC(a,b,c){return $p(a,b,c,5)}function iP(a){return z[a+1074448>>1]}function iD(a,b,c){Mk(a,(b<<2)+a|0,c)}function h9(a){a=a|0;return TK(a,0)|0}function gv(a,b,c){return $p(a,b,c,4)}function gX(a){return(a|0)>=120?120:a}function g9(a){a=a|0;return TK(a,1)|0}function fP(a){return x[a+1074424>>2]}function ek(a,b){return pm(a,b)&65535}function eP(a){return x[a+1074416>>2]}function dla(a,b){a=a|0;b=b|0;FU(a,b)}function cla(a,b){a=a|0;b=b|0;kT(a,b)}function _h(a,b,c){return $p(a,b,c,1)}function Zl(a,b){return v[a|0]<v[b|0]}function Yi(a,b,c){iD(b,c,a);return a}function Ye(a,b){x[a+4>>2]=b;return a}function WM(a){x[a>>2]=48780;return a}function Vn(a){x[a>>2]=77424;return a}function VV(a,b,c){return Ex(a,b,c,5)}function Tla(a,b){a=a|0;b=b|0;Vb(a,b)}function Tg(a,b,c){return $p(a,b,c,2)}function SL(a){x[a>>2]=94836;return a}function Rj(a){return(a-1&255)>>>0<17}function RP(a){return Zi(TP(a)*32768)}function RM(a){x[a>>2]=74440;return a}function RE(a,b){Ms(a,b,20,214748365)}function Qz(a){a=a|0;dI(a,47512,1007)}function Paa(a){a=a|0;return y[a+8|0]}function PV(a){return(a&65535)==65534}function Mn(a,b,c){return Ex(a,b,c,2)}function MP(a,b){a=a|0;b=b|0;return 0}function Lh(a){a=x[a>>2];if(a){EK(a)}}function Jr(a,b,c){return Zp(a,b,c,6)}function Ji(a,b,c){_c(_c(a,b)+12|0,c)}function JT(a,b){return(0-b|0)!=(a|0)}function Ht(a,b){a=a|0;b=b|0;return-1}function Hp(a,b,c){return Ex(a,b,c,1)}function GR(a,b){Xc(a,b&4?16:8,1,0,0)}function Ez(a){x[a>>2]=48296;return a}function Dz(a){x[a>>2]=48320;return a}function Dua(a,b){a=a|0;b=b|0;Sy(a,b)}function Dn(a){return(a&740327453)!=0}function Cz(a){x[a>>2]=48400;return a}function CY(a){fz(a);Ie(x[a+80>>2],a)}function Bz(a){x[a>>2]=48440;return a}function $z(a,b){a=a|0;b=b|0;return 1}function $G(a,b){Ms(a,b,12,357913942)}function zq(a){return z[a+480192>>1]}function zka(a){a=a|0;return Ri(a)|0}function zf(a){return F(a)==Infinity}function yq(a){return z[a+480190>>1]}function wta(a){a=a|0;return JD(a)|0}function wZ(a,b){Ms(a,b,6,715827883)}function wW(a,b){return D(b,872)+a|0}function vd(a,b){return D(b,160)+a|0}function uF(a,b){a=a|0;b=b|0;F_(a,b)}function tG(a,b){Fx(a,b,3,536870912)}function rT(a){return(a+5&255)>>>0<2}function qR(a,b){Ms(a,b,52,82595525)}function o4(a,b){a=a|0;b=b|0;Xw(a,b)}function mha(a){a=a|0;x[a+4224>>2]=0}function ly(a){a=a|0;return v[a+8|0]}function ky(a){a=a|0;return v[a+9|0]}function kR(a,b){return Lk(a,b-a>>2)}function jla(a){a=a|0;return kh(a)|0}function h3(a,b){a=a|0;b=b|0;zx(a,b)}function gl(a){x[a+4>>2]=x[a+4>>2]+1}function gP(a){return z[a+480214>>1]}function fC(a,b,c,d,e){PU(a,b,c,d,e)}function ev(a){return x[zb(a)>>2]<<5}function eo(a,b){a=a|0;b=b|0;_k(a,b)}function eX(a){return(a&255)>>>0<129}function eC(a,b){a=a|0;b=b|0;yV(a,b)}function dk(a,b){a=a|0;b=b|0;k0(a,b)}function az(a){return!kd(a,125928,6)}function aua(a){a=a|0;return i$(a)|0}function _k(a,b){a=a|0;b=b|0;Bm(a,b)}function ZV(a,b){Fx(a,b,4,268435456)}function Wr(a,b){a=a|0;b=b|0;$w(a,b)}function Wf(a,b){a=a|0;b=b|0;lg(a,b)}function WV(a,b){Fx(a,b,5,134217728)}function VD(a,b,c){vb(vb(a,b)+4|0,c)}function UP(a){x[a>>2]=0;x[a+4>>2]=0}function U2(a,b){a=a|0;b=b|0;Vp(a,b)}function RO(a){return x[a+480272>>2]}function Qx(a){return(a<<2)+502208|0}function QQ(a,b,c){a=a|0;b=b|0;c=c|0}function Ota(a){a=a|0;return Ec(a)|0}function Nr(a,b){a=a|0;b=b|0;Wf(a,b)}function MC(a,b){if(!hY(a,b)){cY(b)}}function I2(a,b){a=a|0;b=b|0;eo(a,b)}function Bo(a){return z[a+480188>>1]}function Bh(a){of(a+52|0);dc(a+40|0)}function $2(a,b){a=a|0;b=b|0;Bs(a,b)}function zJ(a){if(!y[a+4|0]){kJ(a)}}function yY(a){if(!y[a+4|0]){uY(a)}}function xv(a,b){return(b-a|0)/56|0}function xl(a,b,c){return qK(a,b,c)}function xA(a,b){return D(b,28)+a|0}function x0(a){a=a|0;return Yw(a)|0}function wf(a,b){return D(b,24)+a|0}function vb(a,b){x[a>>2]=b;return a}function sU(a){if(!y[a+4|0]){yW(a)}}function re(a,b){return Fc(a,le(b))}function qM(a){if(!y[a+4|0]){QH(a)}}function pv(a,b){return D(b,36)+a|0}function pr(a){return(a&255)==1?1:2}function pm(a,b){return(b-a|0)/52|0}function pla(a){a=a|0;gI(a,117,116)}function pd(a,b){return(a|0)!=(b|0)}function pW(a){if(!y[a+4|0]){oW(a)}}function oj(a,b){return(b-a|0)/24|0}function oN(a){if(!y[a+4|0]){nN(a)}}function mr(a,b){return a>>>0<b>>>0}function lm(a,b){return km(Zc(a,b))}function lc(a,b){return(a|0)==(b|0)}function laa(a,b){a=a|0;b=b|0;Db(b)}function kL(a){a=a|0;return Cl(a)|0}function kK(a,b,c){return kd(a,b,c)}function k0(a,b){f0(a,x[a+16>>2]|b)}function is(a,b){return(b-a|0)/36|0}function im(a){if(!y[a+4|0]){L$(a)}}function iW(a){if(!y[a+4|0]){hW(a)}}function hZ(a,b){return D(b,33)+a|0}function gj(a,b){return D(b,52)+a|0}function fu(a,b,c){return Kz(a,b,c)}function fm(a){return lH(a,255,255)}function eda(a,b){a=a|0;b=b|0;_O(a)}function dh(a,b){return D(b,20)+a|0}function cj(a){if(!y[a+4|0]){MZ(a)}}function ch(a){if(!y[a+4|0]){fR(a)}}function aL(a){a=a|0;return ix(a)|0}function a2(a){a=a|0;lG(Sb(a,0,36))}function _u(a){if(!y[a+4|0]){JG(a)}}function _j(a){if(!y[a+4|0]){TF(a)}}function Zx(a){a=a|0;return a+184|0}function ZG(a,b,c){return kK(a,b,c)}function Yx(a){a=a|0;return a+472|0}function YC(a,b){return Pe(a,0-b|0)}function Xx(a){a=a|0;return a+496|0}function Xb(a,b){return Oe(a,b&255)}function Wx(a){a=a|0;return a+508|0}function WD(a,b){return Pe(a,b-a|0)}function Vx(a){a=a|0;return a+520|0}function VE(a){if(!y[a+4|0]){UE(a)}}function Ux(a){a=a|0;return a+532|0}function Ui(a,b,c){return ml(a,b,c)}function Uf(a,b){return(b-a|0)/20|0}function Ud(a,b){return(b-a|0)/12|0}function Rw(a){v[a+2|0]=0;w[a>>1]=0}function RF(a){a=a|0;return hh(a)|0}function Or(a,b){return(b-a|0)/28|0}function Oj(a,b){return Lg(a,b)&255}function Nl(a){return I$(a,251,255)}function Mq(a){if(y[a+24|0]){lT(a)}}function Kv(a,b){return(b-a|0)/33|0}function KW(a){if(!y[a+4|0]){JW(a)}}function K9(a){a=a|0;return Al(a)|0}function Jja(a){a=a|0;rw(a,22267,1)}function Iu(a){return!(a&204473357)}function Ir(a,b){return(b-a|0)/40|0}function Hd(a,b){return D(b,12)+a|0}function Fw(a,b){w[a>>1]=b;return a}function Fca(a,b){a=a|0;b=b|0;oP(a)}function E2(a){a=a|0;return Pg(a)|0}function DF(a){a=a|0;return Zd(a)|0}function CC(a,b){return D(b,56)+a|0}function Br(a,b,c){return Wg(a,b,c)}function Be(a,b,c){return AK(a,b,c)}function B7(a){a=a|0;return fy(a)|0}function $1(a){a=a|0;return ai(a)|0}function zo(a,b){x[a+1298472>>2]=b}function yp(a){v[a|0]=0;v[a+1|0]=0}function yF(a){return(a&255)+704|0}function wx(a,b){return $l(a,b,12)}function wu(a,b){return(a-b|0)/6|0}function vl(a){return(a&255)>>>0>1}function td(a){a=a|0;return a+16|0}function sT(a){Ae(a+8|0);jT(a+4|0)}function sG(a,b){return $l(a,b,36)}function ry(a,b){return!(b>>>31|0)}function qq(a,b){v[a|0]=b;return a}function ii(a,b){a=a|0;b=b|0;Fb(a)}function gJ(a){C[(fb-16|0)+8>>3]=a}function f_(a,b){return Cx(a,b,56)}function fZ(a,b){return Cx(a,b,18)}function e0(a,b){return $l(a,b,28)}function ds(a,b){return(b<<11)+a|0}function dj(a){return a&2147483647}function cr(a,b){return(a|0)<(b|0)}function b$(a,b){x[a>>2]=x[a>>2]+b}function aN(a){return(Ak(a)|0)==-1}function _M(a,b){a=a|0;b=b|0;bn(b)}function Wk(a,b){return D(dl(b),a)}function Wc(a,b){return D(b,6)+a|0}function So(a,b){return(b<<13)+a|0}function SJ(a){return Wh(a,500296)}function RJ(a){return Wh(a,500288)}function Ok(a,b){return(b-a|0)/6|0}function Ni(a){a=a|0;v[a+4202|0]=0}function NJ(a){return Wh(a,500312)}function MJ(a){return Wh(a,500304)}function Ly(a){return lc(a,-1)?0:a}function Hl(a,b){return(a+b|0)-1|0}function FB(a,b){return(b-a|0)/7|0}function Cd(a){return(a&128)>>>7|0}function Bc(a,b){return CH(a,b,-1)}function $M(a,b){a=a|0;b=b|0;dc(b)}function z9(a){a=a|0;return 10406}function yz(a,b){return NR(a,b)^1}function yb(a,b){return(b<<2)+a|0}function yO(a,b){x[a+480272>>2]=b}function sc(a){x[a>>2]=0;return a}function on(a,b){return(b<<8)+a|0}function oM(a){return a+1298412|0}function mL(a){return dH(a,93576)}function jt(a,b){return AK(a,0,b)}function hC(a,b){return $l(a,b,4)}function fA(a){x[a>>2]=x[a>>2]+24}function cg(a){return a!=a?E(0):a}function ce(a){return x[ec(a)>>2]}function cc(a,b){return Jb(a)+b|0}function cU(a,b){return $l(a,b,8)}function bl(a){w[a>>1]=0;return a}function bF(a){return a>>>0>8?5:4}function aC(a){if(a){Db(a+-64|0)}}function _b(a,b){return(b<<1)+a|0}function _3(a){a=a|0;return 13206}function Zta(a){a=a|0;ig(a,3872)}
function Z3(a){a=a|0;return 10286}function Yh(a){x[a>>2]=1;return a}function Y$(a){Fs(a,17,125240,33)}function Xd(a,b){return(b<<4)+a|0}function Vq(a){Fs(a,17,125292,51)}function Ve(a,b){return(b<<3)+a|0}function UF(a){return(a&16)>>>4|0}function UA(a){dc(a+4|0);return a}function Tc(a){return I$(a,1,120)}function Sqa(a){a=a|0;ig(a,16829)}function Oe(a,b){return(b<<5)+a|0}function Npa(a){a=a|0;QY(a,65535)}function Nka(a){a=a|0;xg(a,Pj(a))}function Nh(a){return a-48>>>0<10}function Lx(a,b){return x[a+b>>2]}function Jt(a){return dH(a,93512)}function Jo(a){return a+1074328|0}function Ib(a,b){return lc(a,b)^1}function Fn(a){x[a>>2]=2;return a}function F3(a){a=a|0;return 13092}function E3(a){a=a|0;return 10809}function Asa(a){a=a|0;ig(a,16226)}function wsa(a){a=a|0;ig(a,4484)}function wpa(a){a=a|0;ig(a,4165)}function wg(a,b,c,d){df(a,c,d,b)}function vw(a,b,c,d){HB(a,b,c,d)}function vF(a,b,c,d){jx(a,b,c,d)}function ssa(a){a=a|0;ig(a,4378)}function qv(a){v[a|0]=0;return a}function mf(a,b,c){xo(a,b,b+c|0)}function kra(a){a=a|0;kw(a,3863)}function kF(a){Vm(a,Up(a),78784)}function iw(a,b,c){sH(a,b,c,128)}function iva(a){a=a|0;ig(a,4358)}function ira(a){a=a|0;kw(a,4887)}function ica(a){a=a|0;au(a-92|0)}function hO(a){a=a|0;cu(a);Db(a)}function d4(a){a=a|0;return 6920}function aca(a){a=a|0;au(a-96|0)}function _K(a){x[a+72>>2]=499224}function YK(a){x[a+72>>2]=499308}function WN(a){a=a|0;Um(a);Db(a)}function W3(a){a=a|0;return 6901}function VF(a){return(a&2)>>>1|0}function Tqa(a){a=a|0;ig(a,3985)}function TN(a){a=a|0;wq(a);Db(a)}function RY(a,b){yc(a,b+4|0,256)}function Nw(a,b){return qva(a,b)}function M2(a){a=a|0;ig(a,16856)}function Kg(a,b){vb(sc(a)+4|0,b)}function K2(a){a=a|0;gI(a,50,49)}function G3(a){a=a|0;return 9845}function DQ(a){return(a&8)>>>3|0}function D3(a){a=a|0;return 5720}function Aca(a){a=a|0;au(a-88|0)}function zg(a){tb(a+20|0);tb(a)}function zd(a){return wb(Jb(a))}function yh(a,b){return Yc(a,b)}function yf(a,b){return Fc(a,b)}function yba(a){a=a|0;Db(Yt(a))}function xj(a,b){return a>>>b&1}function wl(a){if(JK(a)){Db(a)}}function w6(a){a=a|0;tb(500596)}function vi(a,b,c){df(a,c,20,b)}function vE(a,b,c){df(a,c,30,b)}function uq(a,b){return yb(a,b)}function ub(a){ke(a+12|0);ke(a)}function u6(a){a=a|0;tb(500628)}function s_(a,b,c){df(a,c,24,b)}function s6(a){a=a|0;tb(500532)}function q6(a){a=a|0;tb(500564)}function pE(a,b){return mr(a,b)}function ok(a,b){return b-a>>11}function mE(a,b){return rp(b,a)}function lk(a,b,c){df(a,c,13,b)}function lT(a){iT(a+12|0);hT(a)}function lM(a,b){return jh(a,b)}function kt(a,b){return Ud(a,b)}function kA(a,b){return kR(a,b)}function iq(a){return zb(a+8|0)}function iha(a){a=a|0;Db(dQ(a))}function ic(a,b){return zG(a,b)}function gn(a){tb(a+12|0);tb(a)}function fha(a){a=a|0;return 13}function ep(a,b){return cl(a,b)}function dt(a){a=a|0;return 127}function d$(a,b){return WD(a,b)}function ci(a,b){return pd(a,b)}function aj(a,b,c){df(a,c,28,b)}function _e(a){return Ar(Ee(a))}function _G(a,b){return _c(a,b)}function Zi(a){return Bn(Ee(a))}function Zh(a,b){return Iw(a,b)}function Zg(a,b){return Ib(a,b)}function Yk(a,b,c){df(a,c,22,b)}function Yc(a,b){return Cb(a,b)}function YR(a,b){return WR(a,b)}function YD(a,b){return Gk(b,a)}function Xha(a){a=a|0;Db(pQ(a))}function Wj(a,b){return Sc(a,b)}function Wia(a){a=a|0;Db(LQ(a))}function We(a,b,c){df(a,c,32,b)}function Wb(a,b){return gj(a,b)}function Vj(a,b){return Oe(a,b)}function Vg(a){return rT(a&255)}function Ti(a,b){return(a|b)!=0}function Sd(a,b){return oc(a,b)}function Qk(a,b,c){df(a,c,12,b)}function Qaa(a){a=a|0;Db(St(a))}function Pu(a){mU(a+12|0);rU(a)}function Pc(a,b,c){gc(a,b,1<<c)}function NE(a){return(a&255)==1}function N2(a){a=a|0;ig(a,4532)}function Lw(a,b){return CF(a,b)}function Le(a){a=a|0;return a|0}function LA(a){w[a+480214>>1]=0}function K6(a){a=a|0;Qb(500612)}function Ig(a){return Vi(a)?0:a}function IB(a,b){return Zc(a,b)}function I6(a){a=a|0;Qb(500644)}function Ho(a,b){return Tt(a,b)}function Hk(a){tb(a+12|0);md(a)}function Hc(a,b){return ds(a,b)}function Hb(a,b){return(a&b)!=0}function HC(a,b,c){df(a,c,64,b)}function Gj(a){OA(a,0);return a}function Ge(a,b){return p0(a,b)}function G6(a){a=a|0;Qb(500548)}function Fc(a,b){return vb(a,b)}function FF(a,b){return BF(a,b)}function Ey(a,b){return rh(a,b)}function Ed(a){return(a&255)!=0}function E6(a){a=a|0;Qb(500580)}function Daa(a){a=a|0;Db(sM(a))}function BR(a,b){return tA(a,b)}function Af(a,b){return fh(a,b)}function Ad(a,b){return!Cb(a,b)}function z4(a){a=a|0;Db(HI(a))}function xQ(a){a=a|0;Db(yQ(a))}function wd(a,b){II(a,b,IC(b))}function wX(a){return nl(a,56)}function tO(a){a=a|0;Db(wq(a))}function sZ(a,b){xo(a,b,td(b))}function sC(a){return a+4096|0}function rp(a,b){return a-b>>1}function rN(a,b){gH(a,b,13602)}function rB(a,b){return a<<8|b}function r4(a){a=a|0;Db(EI(a))}function q4(a){a=a|0;Db(DI(a))}function pU(a,b){Xu(a,Jb(a),b)}function p4(a){a=a|0;Db(CI(a))}function oo(a){return(a|0)==-1}function oc(a,b){return b-a>>2}function o2(a){a=a|0;Db(xG(a))}function nu(a){return a>>>27^a}function nR(a){return nl(a,52)}function n4(a){a=a|0;Db(BI(a))}function mG(a){return nl(a,36)}function kE(a){return nl(a,28)}function k4(a){a=a|0;Db(AI(a))}function ju(a){a=a|0;Db(ag(a))}function jh(a,b){return b-a>>3}function h4(a){a=a|0;Db(zI(a))}function fc(a,b){x[a+100>>2]=b}function fJ(a){a=a|0;Db($x(a))}function eL(a){a=a|0;Db(oq(a))}function eJ(a){a=a|0;Db(_x(a))}function dL(a){a=a|0;Db(Ff(a))}function co(a){a=a|0;Db(R_(a))}function bA(a){a=a|0;Db(su(a))}function au(a){a=a|0;Db(vq(a))}function _d(a){return a&64?2:1}function Zs(a){a=a|0;Db(ay(a))}function Zc(a,b){return b-a>>1}function ZU(a){return nl(a,32)}function Y5(a){a=a|0;Db(Ys(a))}function Wp(a){return nl(a,12)}function W_(a){return nl(a,20)}function Vha(a){a=a|0;return 6}function VQ(a){return a-2048|0}function Uy(a){a=a|0;Db(Cl(a))}function Un(a){a=a|0;Db(ix(a))}function Uia(a){a=a|0;return 9}function U4(a){a=a|0;Db(SI(a))}function Ty(a){a=a|0;Db(lo(a))}function Tk(a){return a>>>0<11}function Sh(a,b){return b-a>>8}function Ry(a){a=a|0;Db(Gt(a))}function Py(a){a=a|0;Db(Et(a))}function P5(a){a=a|0;Db(YI(a))}function Oy(a){a=a|0;Db(Dt(a))}function Lg(a,b){return b-a>>5}function Kk(a,b){return b-a>>4}function KI(a){a=a|0;Db(Xs(a))}function Ie(a,b){if(!a){Db(b)}}function Hv(a,b){return a-b>>2}function GJ(a){a=a|0;Db(fy(a))}function GI(a){a=a|0;Db(Us(a))}function F9(a){a=a|0;Db(Ct(a))}function DV(a){return a+4896|0}function CG(a){return a+1024|0}function BX(a,b){Dx(a,b,5,3,4)}function BO(a,b){gH(a,b,22267)}function BM(a){a=a|0;Db(CM(a))}function BL(){return(db()|0)>0}function Az(a){return nl(a,16)}function zr(a){return a+256|0}function xb(a,b){return a+b|0}function xL(a){a=a|0;return-1}function wQ(a){a=a|0;return 7}function vp(a,b){Ab(a+12|0,b)}function vk(a){return(a&5)!=0}function uM(a){return vk(a)^1}function nZ(a){qp(Sb(a,0,40))}function mc(a){a=a|0;return 0}function lQ(a){a=a|0;return 5}function kr(a){return a>>>0<2}function kD(a,b){bc(a,b,4896)}function eW(a){return a-256|0}function bf(a,b){w[a+28>>1]=b}function To(a,b){x[a+36>>2]=b}function Tj(a){return!(a&255)}function Sc(a,b){return b-a|0}function SQ(a,b){ei(a,b,2048)}function Q_(a,b){df(a,b,40,2)}function QX(a,b){bc(a,b,1108)}function Pn(a){return a&1?2:1}function PC(a,b){bc(a,b,1024)}function Nj(a){return Dd(a)^1}function NC(a){return a+128|0}function MR(a,b,c){Wl(a,b,-c)}function LP(){return 19989505}function Ke(a){a=a|0;return 2}function Gk(a,b){return a-b|0}function Fb(a){QG(a);return a}function Eo(a){a=a|0;return 4}function Dy(a){return FK(a,0)}function Dd(a){return(a|0)!=0}function DX(a,b){df(a,b,33,1)}function D0(a,b){bc(a,b,1954)}function Cy(a){return FK(a,1)}function Ck(a){return a+4e4|0}function Ce(a){a=a|0;return 1}function CV(a){return a+512|0}function BQ(a){a=a|0;return 3}function Ap(a){return a>>>0<5}function A0(a,b){df(a,b,13,1)}function $t(a,b){x[a+32>>2]=b}function $r(a,b){df(a,b,26,3)}function xF(a,b){bc(a,b,772)}function xE(a,b){bc(a,b,512)}function wA(a,b){OA(a,le(b))}function v_(a,b){bc(a,b,236)}function vD(a,b,c){de(a,b,c)}function tW(a,b){yc(a,b,128)}function tF(a,b){df(a,b,8,3)}function sp(a,b){Ge(a,b+8|0)}function rX(a,b){bc(a,b,146)}function qd(a,b){return a>>b}function q_(a){return a+10|0}function pl(a){return a-24|0}function pZ(a,b){bc(a,b,128)}function oF(a,b){bc(a,b,497)}function nc(a){return a+12|0}function nX(a,b){bc(a,b,608)}function mx(a,b){LG(a,le(b))}function mw(a,b){bc(a,b,192)}function mn(a){return a-32|0}function lr(a,b){return a<<b}function lj(a){return a-36|0}function l_(a,b){bc(a,b,102)}function lU(a){kU(a,x[a>>2])}function kj(a){SF(a,x[a>>2])}function kC(a){return a-16|0}function jl(a){return a-12|0}function jY(a){iY(a,x[a>>2])}function ip(a){return a+14|0}function fp(a){KZ(a,x[a>>2])}function fY(a,b){bc(a,b,600)}function fW(a,b){ei(a,b,256)}function ew(a){y$(a,x[a>>2])}function er(a,b,c){Ep(a,b,c)}function dV(a){cV(a,x[a>>2])}function dA(a){SQ(a,x[a>>2])}function bc(a,b,c){gc(a,b,c)}function bW(a){aW(a,x[a>>2])}function bU(a,b,c){we(a,b,c)}function bS(a){return a+24|0}function aw(a){return a-40|0}function aZ(a){return a-33|0}function _X(a,b){bc(a,b,126)}function _$(a,b){bc(a,b,610)}function Yd(a,b){x[a+4>>2]=b}function YZ(a,b){bc(a,b,674)}function YV(a){fW(a,x[a>>2])}function YS(a,b,c){i_(a,b,c)}function Xo(a){return a+32|0}function V0(a,b,c){ff(a,c,b)}function Up(a){return a+20|0}function Uh(a,b,c){k$(a,b,c)}function Ue(a,b){a=a|0;b=b|0}function UG(a,b,c){jf(a,c,b)}function TC(a,b){bc(a,b,130)}function SW(a,b){bc(a,b,204)}function RZ(a){return a+36|0}function Nf(a){UQ(a,x[a>>2])}function NY(a){return a+3&-4}function NP(a){return a+48|0}function ND(a,b){df(a,b,8,2)}function Mr(a){return a-28|0}function Me(a,b){v[a+11|0]=b}function L9(a){a=a|0;k0(a,1)}function Kb(a,b,c){XF(a,b,c)}function K_(a,b){bc(a,b,218)}function K$(a){J$(a,x[a>>2])}function JB(a){v[a+6152|0]=0}function IV(a,b){bc(a,b,263)}function IG(a){HG(a,x[a>>2])}function H_(a,b){bc(a,b,157)}function Gq(a,b){B[a+8>>2]=b}function GA(a,b){v[a+34|0]=b}function Fq(a,b){B[a+4>>2]=b}function FA(a,b){v[a+32|0]=b}function Eq(a,b){v[a+33|0]=b}function EA(a,b){v[a+35|0]=b}function Cu(a){uS(a,x[a>>2])}function Cn(a,b){x[a+8>>2]=b}function CZ(a){FJ(a,x[a>>2])}function B_(a,b){bc(a,b,206)}function Ac(a,b,c){wn(a,b,c)}function AX(a){return a-56|0}function $Z(a,b){bc(a,b,576)}function zb(a){return a+8|0}function yg(a,b){v[a+3|0]=b}function y$(a,b){ei(a,b,40)}function xw(a,b){bc(a,b,65)}function xf(a){return a-4|0}function uZ(a){return a-6|0}function tu(a){Sb(a,0,2048)}function tE(a,b){wH(a,b,32)}function r_(a){return a+6|0}function qf(){Y$(11034);p()}function qZ(a,b){bc(a,b,80)}function qE(a){x[a+12>>2]=0}function lw(a,b){wH(a,b,64)}function kn(){Vq(11034);p()}function iY(a,b){ei(a,b,32)}function hF(a,b){bc(a,b,38)}function hD(a,b){bc(a,b,33)}function gw(a,b){bc(a,b,64)}function fw(a,b){bc(a,b,66)}function fF(a,b){Di(a,b,37)}function es(a,b){bc(a,b,36)}function ej(a){return a+3|0}function ec(a){return a+4|0}function dx(a,b){bc(a,b,20)}function bZ(a,b){ei(a,b,33)}function bE(a,b){bc(a,b,16)}function af(a){return a+2|0}function aW(a,b){ei(a,b,16)}function aD(a,b){bc(a,b,40)}function Yv(a,b){bc(a,b,22)}function Vh(a){return a&127}function VY(a,b){bc(a,b,52)}function VA(a){Sb(a,0,4096)}function UT(a){return a-7|0}function T_(a,b){bc(a,b,98)}function T0(a,b){gc(a,b,20)}function Q0(a,b){bc(a,b,17)}function Pp(a){return a-8|0}function Pf(a){return a&255}function PE(a,b){bc(a,b,32)}function Ow(a,b){gc(a,b,22)}function Nn(a){return a-2|0}function N_(a,b){bc(a,b,48)}function NV(a,b){return a<b}function NG(a,b){bc(a,b,24)}function Lv(a,b){return a<b}function Ln(a,b){gc(a,b,32)}function Jc(a){return a+1|0}function JP(){return 458756}function Iq(a){Sb(a,0,8192)}function IU(a,b){bc(a,b,27)}function Gw(a,b){bc(a,b,11)}function Gr(a,b){bc(a,b,12)}function GX(a,b){bc(a,b,96)}function GW(a){return a-1|0}function FJ(a,b){ei(a,b,24)}function F$(a,b){yc(a,b,40)}function Dv(a,b){bc(a,b,30)}function Cp(a,b){v[a+1|0]=b}function CN(a){return 0-a|0}function C0(a){Sb(a,0,1954)}function $da(a){a=a|0;HP(a)}function yd(a,b){x[a>>2]=b}function xc(a){x[a+8>>2]=0}function wF(a){Sb(a,0,772)}function vc(a){a=a|0;Db(a)}function vQ(a,b){gR(a,3,b)}function us(a){a=a|0;ws(a)}function u_(a){Sb(a,0,236)}function sn(a,b){Ep(a,b,0)}function sF(a,b){Uh(a,2,b)}function rfa(a){a=a|0;fb=a}function qX(a){Sb(a,0,146)}function oh(a,b){bc(a,b,4)}function nW(a){oC(a,ce(a))}function nF(a){Sb(a,0,497)}function mX(a){Sb(a,0,608)}function mW(a){pC(a,ce(a))}function mU(a){Rq(a,ce(a))}function k1(a){a=a|0;ai(a)}function j_(a){ED(a,ce(a))}function iT(a){Ku(a,ce(a))}function hT(a){Lu(a,ce(a))}function gk(a,b){bc(a,b,5)}function el(a,b){bc(a,b,8)}function eY(a){Sb(a,0,600)}function dd(){Y$(7718);p()}function cW(a){Sb(a,0,256)}function cD(a){bD(a,ce(a))}function _w(a,b){bc(a,b,3)}function _Z(a){Sb(a,0,576)}function Zb(a){Am(x[a>>2])}function ZX(a){Sb(a,0,126)}function Z$(a){Sb(a,0,610)}function Yr(a,b){bc(a,b,1)}function Ws(a){wl(x[a>>2])}function Vi(a){return a!=a}function VZ(a){Sb(a,0,192)}function Ul(a){DB(a,ce(a))}function UQ(a,b){ei(a,b,4)}function TD(a,b){bc(a,b,6)}function Sv(a){DD(a,ce(a))}function SF(a,b){ei(a,b,2)}function RW(a){Sb(a,0,204)}function Qr(a,b){bc(a,b,7)}function Qha(a){a=a|0;gb=a}function Qe(a){v[a+12|0]=1}function QR(a){CA(a,ce(a))}function KZ(a,b){ei(a,b,1)}function KC(a){Sb(a,0,130)}function J$(a,b){ei(a,b,6)}function Ip(a,b){bc(a,b,2)}function IZ(a){pD(a,ce(a))}function HG(a,b){ei(a,b,8)}function Gga(){return fb|0}function G_(a){Sb(a,0,157)}function GZ(a){qD(a,ce(a))}function Dw(){Vq(7718);p()}function Bk(a,b){B[a>>2]=b}function A_(a){Sb(a,0,206)}function xO(){return 2048}function mD(a){Sb(a,0,80)}function jE(a){Sb(a,0,66)}function gF(a){Sb(a,0,38)}function fs(a){Sb(a,0,36)}function fd(a,b){v[a|0]=b}function e_(a){Sb(a,0,56)}function _Y(a){Sb(a,0,33)}function WQ(a){Em(a,2048)}function UY(a){Sb(a,0,52)}function S_(a){Sb(a,0,98)}function Qd(a){v[a+4|0]=1}function O_(a){Sb(a,0,48)}function Kp(a){return a&1}function Hh(a){tb(a+16|0)}function HX(a){Sb(a,0,96)}function $v(a){Sb(a,0,64)}function zs(a,b){_G(a,b)}function uR(a,b){uS(a,b)}function uG(a,b){HG(a,b)}function sD(a,b){J$(a,b)}function or(a,b){KZ(a,b)}function lE(a,b){Uk(a,b)}function kg(a,b){f0(a,b)}function jU(a){Ae(a+8|0)}function hW(a){hH(a,872)}function h$(a,b){SU(a,b)}function gD(a,b){YY(a,b)}function fj(a,b){Fw(a,b)}function eA(a,b){re(a,b)}function bd(a,b){Cs(a,b)}function aV(a,b){cV(a,b)}function _T(a,b){h0(a,b)}function YU(a,b){pg(a,b)}function Xj(a){tb(a+4|0)}function Wo(a,b){_c(a,b)}function Uu(a,b){eS(a,b)}function Sn(a,b){gG(a,b)}function SD(a,b){ic(a,b)}function Rh(a,b){Wo(a,b)}function Rd(a,b){Mg(a,b)}function Qg(a){a=a|0;p()}function LX(a,b){Ge(a,b)}function LU(a,b){Gh(a,b)}function Ki(a,b){mi(a,b)}function Kc(a){dc(a+8|0)}function Jn(a,b){SF(a,b)}function Ih(a,b){UQ(a,b)}function Gd(a){ub(a+8|0)}function El(a,b){qq(a,b)}function EW(a,b){_l(a,b)}function Do(a,b){vb(a,b)}function $C(a,b){JY(a,b)}function mp(a){DH(a,16)}function eh(a){v[a|0]=0}function Zn(a){Ax(a,36)}function Mka(){ua();p()}function JJ(a){Em(a,24)}function FI(a){Ax(a,48)}function Dp(a){DH(a,11)}function B$(a){Em(a,40)}function Ag(a){Ax(a,24)}function xZ(a){Em(a,6)}function wh(a){hN(a,0)}function vh(a){fN(a,0)}function tI(){va();p()}function qs(a){LG(a,0)}function og(a){HZ(a,0)}function ks(a){Em(a,8)}function jj(a){Em(a,2)}function XA(a){xS(a,0)}function WT(a){Em(a,7)}function WA(a){wS(a,0)}function T3(){tI();p()}function Lc(a){Te(a,0)}function JW(a){hH(a,9)}function Il(a){gN(a,0)}function $R(a){BS(a,0)}function xs(a){nc(a)}function xV(a){me(a)}function eU(a){Yo(a)}function bn(a){uc(a)}function Uw(a){bl(a)}function JV(a){sc(a)}function JC(a){vg(a)}function If(a){a=a|0}function HW(a){Nb(a)}function Eb(a){tb(a)}function EX(a){qv(a)}function AW(a){Je(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,tc,KG,Bm,y2,yG,i2,c2,b2,pG,kG,pe,I1,G1,uF,B1,t_,R_,Doa,voa,roa,lva,gva,nw,dk,Tua,Z,xta,zw,qm,nL,kh,tp,Ita,Le,Foa,Dc,O5,FD,Yj,sr,An,Lsa,y_,si,yV,eC,tna,Qma,FU,Mla,fma,sg,Xka,Uj,Uka,Tka,Mka,Ika,Cka,BA,yka,rka,Uga,Fja,cR,daa,caa,It,cR,ega,sP,lg,xfa,gfa,wea,rea,mea,hea,cea,Tda,Ida,zda,Eca,rda,Qy,ua,Mb,W5,k5,$4,V4,S4,eo,A4,dla,o4,cla,a4,da,z3,k3,j3,i3,h3,g3,vH,f3,e3,d3,c3,b3,$2,_2,a3,w9,Bs,Yp,sg,Z2,XG,WG,Y2,sx,X2,VG,Wf,W2,U2,S2,us,ts,bi,ig,P2,Vp,R2,Q2,O2,V2,N2,RG,M2,RG,T2,SG,L2,K2,J2,I2,H2,cd,Mb,E2,Tp,D2,kh,C2,rd,B2,hl,rd,kx,A2,ix,hx,a2,z2,q2,p2,$1,Y1,V1,U1,Yw,lG,T1,S1,wka,xka,RT,uka,vka,DA,xu,Vb,zka,fe,hG,P1,O1,RF,M1,L1,RF,DF,Kw,F1,Ng,DF,Hw,Kja,Uja,Jja,lf,kla,N1,ug,_ua,jla,kua,_E,ZE,u1,t1,YE,s1,fg,r1,q1,Cc,Aw,p1,o1,n1,Vf,m1,rm,l1,WE,k1,h1,KE,g1,f1,e1,tw,d1,mF,JE,c1,b1,a1,$0,_0,EE,W0,M0,Bd,ow,iva,hva,CE,BE,fva,eva,dva,Aw,cva,L0,bva,uw,ava,$ua,al,Vua,Pr,Uua,Lb,dg,ig,Sua,wE,Rua,id,Vk,Qua,Pua,Oua,x0,w0,ld,Nua,up,Mua,Lua,Kua,t0,s0,Yj,kw,Jua,Iua,bma,Hua,gh,Gua,Fua,zua,bk,Cua,Bua,Aua,Eua,Dua,Wf,j0,$h,Tf,wua,vua,uua,rua,bk,ak,qua,pua,oua,gE,S$,fE,nua,mua,lua,al,w$,t$,hua,cua,l$,wo,bua,xg,X$,aua,tw,$ta,_ta,_D,Zta,j$,hx,Yta,Xta,e$,z_,Wta,al,Tta,Pr,hk,Sta,Rta,w0,Qta,Pta,Nta,__,Z_,sm,Mta,Lta,Kta,Hta,bk,Y_,Jta,$h,Tf,eE,Cta,Lr,j$,vta,uta,tta,sta,pta,Pr,ota,nta,pp,__,mta,lta,ig,kta,jta,ita,hta,gta,p_,fta,eta,qK,o_,dta,cta,K0,n_,bta,ata,$sa,ima,_sa,m_,Zsa,m_,wta,Xsa,bk,Ysa,$h,Tf,ik,Ssa,Rsa,Qsa,Psa,Msa,Ksa,Jsa,Isa,Hsa,pp,Gsa,Fsa,Esa,yD,H1,Dsa,Csa,Bsa,Asa,zsa,UZ,ysa,E1,xsa,wsa,vsa,usa,TZ,tsa,Tsa,ssa,rsa,ig,qsa,iE,psa,Usa,osa,nsa,msa,uD,uD,SZ,lsa,ksa,QZ,uD,NZ,jsa,t9,isa,hsa,gsa,fsa,esa,dsa,csa,LZ,rd,qr,Tra,Qv,bsa,vja,uja,tja,sja,rja,qja,asa,$ra,pg,_ra,Zra,Yra,Xra,KG,ama,_la,Hja,Sja,Tja,Wra,JZ,Vra,Ura,Hka,oja,_k,VG,Yla,dma,Xla,Wla,Pra,Ora,Nra,Mra,Lra,Kra,Jra,Ira,Hra,Gra,Fra,Dra,Cra,Era,ZY,Tf,SY,fD,zra,eD,yra,xra,wra,vra,dD,ura,Kw,YE,tra,QY,PY,sra,Tr,rra,rf,qra,MY,pp,HE,pp,n_,Wr,ig,_E,pp,wo,nra,mra,lra,kra,_C,Fv,jra,ira,hra,gra,fra,era,dra,cra,bra,ara,$qa,_qa,Zqa,Yqa,Xqa,rD,Wqa,Vqa,Uqa,ig,PZ,OZ,AD,Tqa,Sqa,CE,hx,Rqa,Qqa,Pqa,Oqa,Nqa,Hla,Gla,Fla,Jqa,Kqa,Nr,Lqa,Mqa,dw,oY,Gqa,ila,Lla,Wu,hla,gla,LT,Ru,FT,fla,vT,QU,ela,RB,Mj,Bi,zqa,yqa,Fr,Hqa,Nv,vqa,G0,uqa,tqa,WX,qr,sqa,rqa,Bw,qqa,JZ,pqa,oqa,Er,nqa,mqa,lqa,kqa,GC,fqa,EC,eqa,dqa,PX,Fp,cqa,bk,$h,Tf,Bi,$pa,_pa,Zpa,Ypa,eD,Vpa,Upa,Er,Tpa,rm,Vja,Qpa,Ppa,ak,MX,EC,uw,Opa,PX,Npa,Mpa,Lpa,zv,Kpa,zv,Jpa,Cm,J1,Gpa,bk,Ipa,zC,vX,vv,Hpa,$h,Tf,Fr,Dpa,Apa,fD,zpa,wpa,vpa,jX,Bw,yD,upa,CE,ig,lpa,kpa,Aw,jpa,ipa,hpa,gpa,Uv,fpa,up,cpa,bpa,apa,$oa,_oa,Zoa,pn,BW,Yoa,Xoa,Woa,Voa,Uoa,Toa,Soa,Roa,Qoa,Poa,Ooa,Noa,Moa,eD,Loa,Koa,Joa,Nv,Ioa,Hoa,Goa,Pr,wla,Tp,x0,Dla,Cla,Pr,Bla,Bi,Tp,Ala,zla,yla,Eoa,jW,Aoa,zoa,yoa,xoa,woa,_r,soa,qoa,poa,ooa,noa,moa,loa,koa,joa,ioa,hoa,C3,VI,goa,ig,foa,eoa,Ila,jma,Ota,eV,gma,ema,$U,cma,$la,Zla,RU,Sla,Ula,Tla,Rla,Zd,Qla,GU,Pla,Ola,Nla,wU,vU,tU,Ro,oU,Kla,Jla,Ela,np,ula,ak,ST,rs,tka,ska,qka,lla,pka,K1,oka,Zw,rs,M0,nka,ST,sla,mka,xla,bk,$h,Tf,vla,bk,$h,Tf,tla,bk,$h,Tf,qla,nla,mla,Le,W0,bla,ala,$ka,_ka,Zka,Yka,hma,aoa,VP,Wka,Ec,Ska,Nja,Rka,G2,_1,R1,X1,Pka,Oka,Q1,Z1,F2,W1,oS,Nka,Lka,Kka,nS,mS,SA,Jka,Vla,Gka,Fka,Eka,Dka,mR,Eja,Wja,rx,kT,yG,MG,DA,nS,Aka,_k,As,Sr,pla,rla,ika,hka,ak,gka,EC,fka,eka,dka,Fr,cka,Bi,bka,aka,$ja,_ja,Zja,bk,$h,Tf,jka,Rja,Qja,Pja,Oja,mi,Tm,Mja,Lja,uu,vu,Ija,Cja,Bja,Aja,zja,yja,jR,Gja,Dq,iR,ul,mi,pg,wja,pja,S9,xja,Dja,mja,lja,Eia,kja,jja,YQ,$f,hR,Xia,Fia,vn,zia,lka,yia,wia,via,uia,DA,xia,se,lu,lu,tia,sia,qia,IQ,zQ,Yha,Oha,Hha,Aha,sha,jha,lha,$ga,Tga,OP,iu,Nga,Mga,aba,bba,IP,Ega,HP,GP,Bka,dba,Aga,OP,zga,Lba,zba,Oba,AP,rM,zP,Qz,wga,sea,wq,qea,Sm,yP,Iba,wP,Hba,xP,Gba,uP,qK,_ba,rga,Jba,Pz,MY,Oz,Nz,Mz,hga,fga,zP,Qz,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Nfa,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,rP,qP,pP,AG,qaa,Pba,oP,bP,Eba,aP,$O,Zba,taa,uaa,_O,zaa,XO,WO,lz,UO,Qz,SO,QO,PO,Ao,saa,raa,OO,NO,MO,LO,JO,IO,HO,GO,FO,EO,DO,CO,Jz,AO,zO,jS,Cv,Iz,Hz,xea,wO,vea,uea,tea,qO,nea,AP,lea,Fda,kea,Eda,jea,Dda,iea,Cda,gea,Bda,fea,Ada,dea,Kaa,rM,ir,ola,zx,ss,tU,Vba,Uba,Tba,Rba,Nba,Vka,Kba,Cba,Fba,Y9,R9,Q9,Dba,rm,al,al,Aba,Qka,Mba,Wba,Qba,lx,_,cba,jN,iN,Hz,EM,$aa,_aa,Raa,vM,Jaa,Iaa,Eaa,yaa,xaa,waa,vaa,paa,oaa,naa,dS,boa,maa,laa,kaa,jaa,faa,eaa,bL,aL,e4,Z9,X9,W9,V9,U9,T9,M9,kh,L9,Le,X3,Y4,x9,aL,u9,In,lL,Ky,e9,d9,Ay,ki,ji,lt,Db,zy,th,Bl,yy,Km,X8,W8,vj,sh,rK,uj,Ny,ty,ki,ji,ht,li,K9,qm,no,vj,sh,mK,uj,C8,x8,gL,s8,At,tp,n8,et,If,X7,jo,W7,V7,U7,TJ,S7,Ft,Q7,P7,yj,O7,TJ,M7,oZ,K7,J7,G7,F7,u7,t7,s7,r7,q7,p7,o7,n7,m7,l7,k7,j7,i7,h7,g7,f7,e7,d7,c7,b7,a7,$6,_6,Z6,Y6,X6,W6,V6,U6,T6,S6,R6,Q6,AJ,P6,B6,C6,D6,K6,I6,G6,E6,n6,o6,p6,w6,u6,s6,q6,N5,M5,L5,K5,J5,XI,I5,WI,H5,G5,F5,E5,D5,C5,B5,A5,z5,y5,x5,w5,v5,u5,t5,s5,r5,q5,p5,o5,n5,m5,l5,j5,i5,h5,g5,f5,e5,d5,Z4,l4,m4,c5,b5,a5,_4,Gm,kq,C4,B4,X4,W4,F4,E4,D4,wk,t4,s4,io,my,si,tI,Un,os,$na,_na,Zna,Yna,Xna,Wna,Vna,Una,Tna,Sna,Rna,Qna,Pna,Ona,Nna,Mna,Lna,Kna,Jna,Ina,Hna,Gna,Fna,Ena,Dna,Cna,Bna,Ana,zna,yna,xna,wna,vna,una,sna,rna,qna,pna,ona,nna,mna,lna,kna,jna,ina,hna,gna,fna,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Uma,Tma,Sma,Rma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,uma,tma,sma,rma,qma,pma,oma,nma,mma,lma,kma,Un,uoa,toa,Osa,Nsa,ypa,xpa,rpa,qpa,Bra,Ara,jqa,iqa,Rra,Qra,Xua,Wua,Gta,Fta,j1,i1,kva,jva,bqa,aqa,Cpa,Bpa,Coa,Boa,tua,sua,jua,iua,y1,x1,w1,v1,Spa,Rpa,Fpa,Epa,xqa,wqa,Sra,Y0,Bta,Ata,Wsa,Vsa,yua,xua,Vta,Uta,Xpa,Wpa,kka,Yja,Xja,rta,qta,zta,yta,Bqa,Aqa,epa,dpa,hqa,gqa,Eta,Dta,tpa,spa,npa,mpa,eua,dua,ppa,opa,Iqa,Dqa,Cqa,A1,z1,D1,C1,Zua,Yua,pra,ora,gua,fua,Fqa,Eqa,doa,coa,co,os,d2,vc,xm,MP,vc,Le,vc,mc,Ce,Ce,mc,mc,e2,t2,s2,f2,vc,xm,vc,xG,o2,n2,Ce,m2,l2,k2,j2,h2,g2,su,bA,ru,RQ,mc,If,mc,mc,mc,Ue,Eo,ija,hja,gja,fja,eja,Oi,$z,$z,_z,QQ,_z,PQ,_z,PQ,If,Y0,dja,cja,bja,aja,$ia,Ni,OQ,Bia,mc,mc,Ce,Zz,Ke,Ke,Ce,_ia,Zia,Ue,If,Ue,If,LQ,Wia,Via,mc,If,mc,mc,mc,Ue,Uia,KQ,Tia,Sia,Ria,Qia,Oi,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Ni,GQ,mc,mc,Ce,Ke,Ke,Ce,JQ,HQ,ag,Qg,T3,Dia,aA,Cia,mc,Aia,QQ,hia,Zha,Pha,Iha,Bha,tha,kha,aha,Vga,uha,nja,Yia,ria,su,bA,RQ,mc,If,mc,mc,mc,Ue,BQ,pia,oia,nia,mia,lia,Oi,kia,Ni,AQ,mc,mc,Ce,Ke,Ke,Ce,jia,iia,pQ,Xha,Wha,mc,If,mc,mc,mc,Ue,Vha,Uha,Tha,Sha,Oi,Rha,Ni,mQ,mc,mc,Ce,Ke,Ke,ju,Nha,mc,If,mc,mc,mc,Ue,lQ,Mha,Lha,Kha,Oi,Jha,Ni,jQ,mc,mc,Ce,Ke,Ke,su,bA,Gha,mc,If,mc,mc,mc,Ue,lQ,Fha,Eha,Dha,Oi,Cha,Ni,gQ,mc,mc,Ce,Ke,Ke,yQ,xQ,zha,mc,If,mc,mc,mc,Ue,wQ,yha,eia,dia,Oi,cia,Ni,bia,mc,mc,Ce,Ke,Ke,Ue,If,uQ,xha,wha,tQ,vha,sQ,rQ,xQ,gia,wQ,fia,uQ,aia,$ha,tQ,_ha,sQ,rQ,ju,rha,mc,If,mc,mc,mc,Ue,Ke,qha,pha,oha,Oi,nha,Ni,mha,mc,mc,Ce,Ke,Ke,dQ,iha,hha,mc,If,mc,mc,gha,Ue,fha,eha,dha,cha,Oi,bha,Ni,Sz,mc,mc,Ce,Ke,Ke,Ue,If,ju,_ga,mc,If,mc,mc,mc,Ue,BQ,Zga,Yga,Xga,Oi,Wga,Ni,_P,mc,mc,Ce,Ke,Ke,ju,Sga,mc,If,mc,mc,mc,Ue,Eo,Rga,Qga,Pga,Oi,Oga,Ni,YP,mc,mc,Ce,Ke,Ke,du,vc,pea,tO,QN,tO,TN,Um,WN,cu,hO,vq,au,Dca,Cca,PN,ON,MN,LN,KN,JN,IN,HN,GN,FN,EN,DN,BN,AN,zN,yN,xN,wN,vN,uN,tN,sN,qN,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,Le,Qg,Le,Qg,Le,Qg,Le,Qg,Qg,Yba,vc,Xba,Yt,yba,Sba,Le,Qg,Le,vc,xba,wba,Qg,YM,XM,YM,XM,Ue,Zt,Ue,Zt,$M,_M,$M,_M,vc,Bba,Le,vc,vba,uba,vc,QM,PM,Qg,rba,NM,qba,NM,tba,OM,sba,OM,vc,pba,oba,vc,MM,LM,Vt,Vt,Vt,Vt,nba,rz,rz,rz,vc,mba,lba,vc,KM,JM,iba,HM,hba,HM,kba,IM,jba,IM,vc,gba,fba,vc,GM,FM,Ut,Ut,Ut,Ut,eba,pz,pz,pz,Laa,vc,xm,vc,St,Qaa,Ce,Ce,Paa,Oaa,os,Naa,Maa,Qg,Qg,Saa,vc,xm,vc,CM,BM,Ce,mc,Ce,Zaa,Yaa,Xaa,Waa,Vaa,Uaa,Taa,Qg,Aaa,vc,xm,vc,sM,Daa,Caa,Baa,Qg,Faa,vc,xm,vc,BM,Haa,Gaa,r2,vc,xm,vc,vc,x2,Ce,Ce,os,ns,w2,v2,u2,Ue,Zt,Ue,Zt,iaa,haa,gaa,lo,Ty,Ue,AL,zL,yL,mc,mc,aaa,xL,$9,Ht,_9,Ht,Dt,Oy,Ue,AL,zL,yL,mc,mc,P9,xL,O9,Ht,N9,Ht,Ct,F9,G9,E9,J9,I9,H9,oq,eL,D9,C9,Et,Py,pL,oL,Ff,dL,B9,A9,Gt,Ry,vL,uL,Le,vc,z9,c4,b4,$3,y9,Un,baa,mc,v9,Ty,i9,h9,g9,f9,kL,Uy,Cl,Uy,Ty,l9,VK,k9,j9,Oy,p9,o9,n9,m9,Gt,Ry,vL,uL,kL,Uy,Oy,s9,VK,r9,q9,Et,Py,pL,oL,YI,P5,ru,zI,h4,g4,f4,a9,AI,k4,j4,i4,Z8,Ys,Y5,X5,V5,U5,T5,kY,S5,R5,Q5,Us,GI,x4,w4,v4,u4,Xs,KI,R4,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,fy,GJ,A7,z7,y7,x7,mc,w7,v7,_x,eJ,ly,ky,jy,k6,j6,$x,fJ,ns,iy,hy,m6,l6,eJ,fJ,Le,vc,vc,h6,g6,f6,e6,d6,c6,b6,a6,kY,$5,_5,Z5,vc,ZI,ZI,gq,Ce,Ce,i6,Ce,vc,aJ,$I,gq,mc,mc,_I,Eo,vc,aJ,$I,gq,mc,mc,_I,Eo,vc,dJ,cJ,gq,mc,mc,bJ,Eo,vc,dJ,cJ,gq,mc,mc,bJ,Eo,Le,vc,c9,b9,Le,vc,$8,_8,vc,Y8,V8,U8,T8,vK,vK,S8,R8,Q8,P8,O8,vc,N8,M8,L8,K8,lK,lK,J8,I8,H8,G8,F8,vc,E8,D8,B8,A8,z8,y8,w8,v8,vc,u8,t8,r8,q8,p8,o8,m8,l8,Le,vc,Ke,k8,j8,i8,h8,g8,f8,A6,z6,y6,x6,v6,t6,r6,Le,vc,Ke,e8,d8,c8,b8,a8,$7,O6,N6,M6,L6,J6,H6,F6,HI,z4,y4,td,Zx,Yx,Xx,Wx,Vx,Ux,RI,QI,PI,OI,NI,MI,LI,SI,U4,T4,td,Zx,Yx,Xx,Wx,Vx,Ux,RI,QI,PI,OI,NI,MI,LI,ay,Zs,_7,ay,Zs,Z7,Zs,Zs,vc,dt,dt,ii,ii,ii,cK,mc,hi,hi,vc,dt,dt,ii,ii,ii,cK,mc,hi,hi,vc,ct,ct,ii,ii,ii,bK,mc,hi,hi,vc,ct,ct,ii,ii,ii,bK,mc,hi,hi,BI,n4,ly,ky,jy,aK,lz,$J,_J,ZJ,bt,CI,p4,ly,ky,jy,aK,lz,$J,_J,ZJ,bt,DI,q4,ns,iy,hy,YJ,XJ,WJ,VJ,bt,UJ,EI,r4,ns,iy,hy,YJ,XJ,WJ,VJ,bt,UJ,vc,Y7,T7,vc,R7,N7,vc,L7,I7,vc,H7,E7,vc,HJ,D7,Ue,vc,HJ,C7,Ue,vc,vc,Le,vc,B7,GJ,Le,vc,Le,vc,Le,vc,Le,vc,GI,KI,Le,Qg,vc,d4,vc,_3,vI,vc,Z3,Y3,vI,Un,Qg,vc,W3,va,Le,vc,If,If,S3,K3,M3,N3,vc,F3,vc,E3,co,Un,co,co,co,co,Un,vc,D3,vc,J3,L3,O3,vc,R3,Q3,P3,vc,G3]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":Z0,"wa":JP,"xa":JP,"ya":LP,"za":LP,"Aa":vc,"Ba":Db,"Ca":Fga,"Da":IP,"Ea":Dga,"Fa":Cga,"Ga":iu,"Ha":Ue,"Ia":Iga,"Ja":Hga,"Ka":Lga,"La":$z,"Ma":Jga,"Na":MP,"Oa":Kga,"Pa":Le,"Qa":QP,"Ra":PP,"Sa":QP,"Ta":xO,"Ua":B3,"Va":A3,"Wa":y3,"Xa":Bga,"Ya":DP,"Za":yga,"_a":CP,"$a":nga,"ab":Cea,"bb":Dea,"cb":lga,"db":kga,"eb":jga,"fb":mga,"gb":Eea,"hb":Sea,"ib":yea,"jb":Uea,"kb":kfa,"lb":Aea,"mb":Wea,"nb":Bea,"ob":Vea,"pb":zea,"qb":Hea,"rb":Fea,"sb":Gea,"tb":Oea,"ub":Mea,"vb":Nea,"wb":Iea,"xb":Jea,"yb":Kea,"zb":Lea,"Ab":hfa,"Bb":ifa,"Cb":tfa,"Db":nfa,"Eb":mfa,"Fb":lfa,"Gb":sfa,"Hb":qfa,"Ib":ofa,"Jb":pfa,"Kb":yfa,"Lb":zfa,"Mb":ufa,"Nb":wfa,"Ob":vfa,"Pb":afa,"Qb":ffa,"Rb":dfa,"Sb":cfa,"Tb":efa,"Ub":bfa,"Vb":Rea,"Wb":Bfa,"Xb":$ea,"Yb":Zea,"Zb":jfa,"_b":Tea,"$b":_ea,"ac":Yea,"bc":Xea,"cc":Cfa,"dc":Pea,"ec":Dfa,"fc":Qea,"gc":Afa,"hc":xga,"ic":vga,"jc":x3,"kc":uga,"lc":tga,"mc":sga,"nc":qga,"oc":w3,"pc":pga,"qc":oga,"rc":iga,"sc":gga,"tc":dga,"uc":Efa,"vc":cga,"wc":pc,"xc":QN,"yc":wq,"zc":Fd,"Ac":UN,"Bc":VN,"Cc":xda,"Dc":yda,"Ec":TN,"Fc":$da,"Gc":bea,"Hc":aea,"Ic":gO,"Jc":gO,"Kc":xO,"Lc":mI,"Mc":mI,"Nc":lI,"Oc":lI,"Pc":v3,"Qc":XN,"Rc":_N,"Sc":fO,"Tc":eO,"Uc":YN,"Vc":bO,"Wc":aO,"Xc":ZN,"Yc":dO,"Zc":cO,"_c":$N,"$c":Um,"ad":WN,"bd":Zda,"cd":Uca,"dd":Wda,"ed":kda,"fd":Zca,"gd":Vda,"hd":Vca,"id":Qda,"jd":lda,"kd":Xda,"ld":Kda,"md":Jda,"nd":Hda,"od":Nda,"pd":Mda,"qd":Lda,"rd":Oda,"sd":Rda,"td":Pda,"ud":Sda,"vd":eda,"wd":vda,"xd":Sca,"yd":gda,"zd":fda,"Ad":ada,"Bd":hda,"Cd":$ca,"Dd":sda,"Ed":Nca,"Fd":Pca,"Gd":Qca,"Hd":Oca,"Id":Kca,"Jd":Jca,"Kd":mda,"Ld":oda,"Md":uda,"Nd":nda,"Od":_ca,"Pd":qda,"Qd":bda,"Rd":ida,"Sd":pda,"Td":cda,"Ud":Xca,"Vd":jda,"Wd":dda,"Xd":Wca,"Yd":Lca,"Zd":Ica,"_d":Hca,"$d":Rca,"ae":Mca,"be":Fca,"ce":Gca,"de":tda,"ee":u3,"fe":Tca,"ge":wda,"he":Gda,"ie":Yda,"je":t3,"ke":Uda,"le":_da,"me":iO,"ne":kO,"oe":lO,"pe":mO,"qe":oO,"re":pO,"se":sO,"te":nO,"ue":cu,"ve":hO,"we":jO,"xe":eea,"ye":oea,"ze":pc,"Ae":UN,"Be":VN,"Ce":wq,"De":XN,"Ee":_N,"Fe":fO,"Ge":eO,"He":YN,"Ie":bO,"Je":aO,"Ke":ZN,"Le":dO,"Me":cO,"Ne":$N,"Oe":Um,"Pe":iO,"Qe":kO,"Re":lO,"Se":mO,"Te":oO,"Ue":pO,"Ve":sO,"We":nO,"Xe":cu,"Ye":jO,"Ze":ib,"_e":Yca,"$e":Qha,"af":Gga,"bf":rfa,"cf":U3,"df":V3,"ef":I3,"ff":H3,"gf":s3,"hf":r3,"jf":p3,"kf":l3,"lf":q3,"mf":p3,"nf":o3,"of":m3,"pf":n3,"qf":m3,"rf":l3,"sf":l3}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];
